#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_arabic_category_label

covid_pandemic_data = {
    "Category:Deaths from the COVID-19 pandemic by country subdivision": "تصنيف:وفيات من جائحة فيروس كورونا حسب تقسيم البلد",
    "Category:Deaths from the COVID-19 pandemic in Afghanistan": "تصنيف:وفيات من جائحة فيروس كورونا في أفغانستان",
    "Category:Deaths from the COVID-19 pandemic in Alabama": "تصنيف:وفيات من جائحة فيروس كورونا في ألاباما",
    "Category:Deaths from the COVID-19 pandemic in Alaska": "تصنيف:وفيات من جائحة فيروس كورونا في ألاسكا",
    "Category:Deaths from the COVID-19 pandemic in Albania": "تصنيف:وفيات من جائحة فيروس كورونا في ألبانيا",
    "Category:Deaths from the COVID-19 pandemic in Amapá": "تصنيف:وفيات من جائحة فيروس كورونا في أمابا",
    "Category:Deaths from the COVID-19 pandemic in Ankara": "تصنيف:وفيات من جائحة فيروس كورونا في أنقرة",
    "Category:Deaths from the COVID-19 pandemic in Apulia": "تصنيف:وفيات من جائحة فيروس كورونا في بوليا",
    "Category:Deaths from the COVID-19 pandemic in Arizona": "تصنيف:وفيات من جائحة فيروس كورونا في أريزونا",
    "Category:Deaths from the COVID-19 pandemic in Armenia": "تصنيف:وفيات من جائحة فيروس كورونا في أرمينيا",
    "Category:Deaths from the COVID-19 pandemic in Australia": "تصنيف:وفيات من جائحة فيروس كورونا في أستراليا",
    "Category:Deaths from the COVID-19 pandemic in Austria": "تصنيف:وفيات من جائحة فيروس كورونا في النمسا",
    "Category:Deaths from the COVID-19 pandemic in Bahia": "تصنيف:وفيات من جائحة فيروس كورونا في باهيا",
    "Category:Deaths from the COVID-19 pandemic in Bangladesh": "تصنيف:وفيات من جائحة فيروس كورونا في بنغلاديش",
    "Category:Deaths from the COVID-19 pandemic in Belarus": "تصنيف:وفيات من جائحة فيروس كورونا في روسيا البيضاء",
    "Category:Deaths from the COVID-19 pandemic in Belgium": "تصنيف:وفيات من جائحة فيروس كورونا في بلجيكا",
    "Category:Deaths from the COVID-19 pandemic in Bolivia": "تصنيف:وفيات من جائحة فيروس كورونا في بوليفيا",
    "Category:Deaths from the COVID-19 pandemic in Botswana": "تصنيف:وفيات من جائحة فيروس كورونا في بوتسوانا",
    "Category:Deaths from the COVID-19 pandemic in Brazil by state": "تصنيف:وفيات من جائحة فيروس كورونا في البرازيل حسب الولاية",
    "Category:Deaths from the COVID-19 pandemic in Burundi": "تصنيف:وفيات من جائحة فيروس كورونا في بوروندي",
    "Category:Deaths from the COVID-19 pandemic in Cameroon": "تصنيف:وفيات من جائحة فيروس كورونا في الكاميرون",
    "Category:Deaths from the COVID-19 pandemic in Ceará": "تصنيف:وفيات من جائحة فيروس كورونا في سيارا",
    "Category:Deaths from the COVID-19 pandemic in Chile": "تصنيف:وفيات من جائحة فيروس كورونا في تشيلي",
    "Category:Deaths from the COVID-19 pandemic in Colorado": "تصنيف:وفيات من جائحة فيروس كورونا في كولورادو",
    "Category:Deaths from the COVID-19 pandemic in Croatia": "تصنيف:وفيات من جائحة فيروس كورونا في كرواتيا",
    "Category:Deaths from the COVID-19 pandemic in Cuba": "تصنيف:وفيات من جائحة فيروس كورونا في كوبا",
    "Category:Deaths from the COVID-19 pandemic in Ecuador": "تصنيف:وفيات من جائحة فيروس كورونا في الإكوادور",
    "Category:Deaths from the COVID-19 pandemic in Emilia-Romagna": "تصنيف:وفيات من جائحة فيروس كورونا في إميليا-رومانيا",
    "Category:Deaths from the COVID-19 pandemic in Ethiopia": "تصنيف:وفيات من جائحة فيروس كورونا في إثيوبيا",
    "Category:Deaths from the COVID-19 pandemic in Georgia (country)": "تصنيف:وفيات من جائحة فيروس كورونا في جورجيا",
    "Category:Deaths from the COVID-19 pandemic in Georgia (U.S. state)": "تصنيف:وفيات من جائحة فيروس كورونا في ولاية جورجيا",
    "Category:Deaths from the COVID-19 pandemic in Ghana": "تصنيف:وفيات من جائحة فيروس كورونا في غانا",
    "Category:Deaths from the COVID-19 pandemic in Goiás": "تصنيف:وفيات من جائحة فيروس كورونا في غوياس",
    "Category:Deaths from the COVID-19 pandemic in Greece": "تصنيف:وفيات من جائحة فيروس كورونا في اليونان",
    "Category:Deaths from the COVID-19 pandemic in Guinea": "تصنيف:وفيات من جائحة فيروس كورونا في غينيا",
    "Category:Deaths from the COVID-19 pandemic in Guinea-Bissau": "تصنيف:وفيات من جائحة فيروس كورونا في غينيا بيساو",
    "Category:Deaths from the COVID-19 pandemic in Hawaii": "تصنيف:وفيات من جائحة فيروس كورونا في هاواي",
    "Category:Deaths from the COVID-19 pandemic in Honduras": "تصنيف:وفيات من جائحة فيروس كورونا في هندوراس",
    "Category:Deaths from the COVID-19 pandemic in Idaho": "تصنيف:وفيات من جائحة فيروس كورونا في أيداهو",
    "Category:Deaths from the COVID-19 pandemic in Islamabad": "تصنيف:وفيات من جائحة فيروس كورونا في إسلام آباد",
    "Category:Deaths from the COVID-19 pandemic in Israel": "تصنيف:وفيات من جائحة فيروس كورونا في إسرائيل",
    "Category:Deaths from the COVID-19 pandemic in Italy by region": "تصنيف:وفيات من جائحة فيروس كورونا في إيطاليا حسب المنطقة",
    "Category:Deaths from the COVID-19 pandemic in Ivory Coast": "تصنيف:وفيات من جائحة فيروس كورونا في ساحل العاج",
    "Category:Deaths from the COVID-19 pandemic in Jamaica": "تصنيف:وفيات من جائحة فيروس كورونا في جامايكا",
    "Category:Deaths from the COVID-19 pandemic in Kentucky": "تصنيف:وفيات من جائحة فيروس كورونا في كنتاكي",
    "Category:Deaths from the COVID-19 pandemic in Kenya": "تصنيف:وفيات من جائحة فيروس كورونا في كينيا",
    "Category:Deaths from the COVID-19 pandemic in Latvia": "تصنيف:وفيات من جائحة فيروس كورونا في لاتفيا",
    "Category:Deaths from the COVID-19 pandemic in Lazio": "تصنيف:وفيات من جائحة فيروس كورونا في لاتسيو",
    "Category:Deaths from the COVID-19 pandemic in Libya": "تصنيف:وفيات من جائحة فيروس كورونا في ليبيا",
    "Category:Deaths from the COVID-19 pandemic in Liguria": "تصنيف:وفيات من جائحة فيروس كورونا في ليغوريا",
    "Category:Deaths from the COVID-19 pandemic in Lombardy": "تصنيف:وفيات من جائحة فيروس كورونا في لومبارديا",
    "Category:Deaths from the COVID-19 pandemic in Maine": "تصنيف:وفيات من جائحة فيروس كورونا في مين",
    "Category:Deaths from the COVID-19 pandemic in Malaysia": "تصنيف:وفيات من جائحة فيروس كورونا في ماليزيا",
    "Category:Deaths from the COVID-19 pandemic in Maranhão": "تصنيف:وفيات من جائحة فيروس كورونا في مارانهاو",
    "Category:Deaths from the COVID-19 pandemic in Maryland": "تصنيف:وفيات من جائحة فيروس كورونا في ماريلند",
    "Category:Deaths from the COVID-19 pandemic in Mato Grosso do Sul": "تصنيف:وفيات من جائحة فيروس كورونا في ماتو غروسو دو سول",
    "Category:Deaths from the COVID-19 pandemic in Mato Grosso": "تصنيف:وفيات من جائحة فيروس كورونا في ماتو غروسو",
    "Category:Deaths from the COVID-19 pandemic in Minas Gerais": "تصنيف:وفيات من جائحة فيروس كورونا في ميناس جيرايس",
    "Category:Deaths from the COVID-19 pandemic in Mississippi": "تصنيف:وفيات من جائحة فيروس كورونا في مسيسيبي",
    "Category:Deaths from the COVID-19 pandemic in Missouri": "تصنيف:وفيات من جائحة فيروس كورونا في ميزوري",
    "Category:Deaths from the COVID-19 pandemic in Moldova": "تصنيف:وفيات من جائحة فيروس كورونا في مولدوفا",
    "Category:Deaths from the COVID-19 pandemic in Myanmar": "تصنيف:وفيات من جائحة فيروس كورونا في ميانمار",
    "Category:Deaths from the COVID-19 pandemic in Nepal": "تصنيف:وفيات من جائحة فيروس كورونا في نيبال",
    "Category:Deaths from the COVID-19 pandemic in New Mexico": "تصنيف:وفيات من جائحة فيروس كورونا في نيومكسيكو",
    "Category:Deaths from the COVID-19 pandemic in North Carolina": "تصنيف:وفيات من جائحة فيروس كورونا في كارولاينا الشمالية",
    "Category:Deaths from the COVID-19 pandemic in Northern Ireland": "تصنيف:وفيات من جائحة فيروس كورونا في أيرلندا الشمالية",
    "Category:Deaths from the COVID-19 pandemic in Ohio": "تصنيف:وفيات من جائحة فيروس كورونا في أوهايو",
    "Category:Deaths from the COVID-19 pandemic in Pakistan by administrative unit": "تصنيف:وفيات من جائحة فيروس كورونا في باكستان حسب الوحدة الإدارية",
    "Category:Deaths from the COVID-19 pandemic in Papua New Guinea": "تصنيف:وفيات من جائحة فيروس كورونا في بابوا غينيا الجديدة",
    "Category:Deaths from the COVID-19 pandemic in Paraguay": "تصنيف:وفيات من جائحة فيروس كورونا في باراغواي",
    "Category:Deaths from the COVID-19 pandemic in Paraná (state)": "تصنيف:وفيات من جائحة فيروس كورونا في ولاية بارانا",
    "Category:Deaths from the COVID-19 pandemic in Paraíba": "تصنيف:وفيات من جائحة فيروس كورونا في بارايبا",
    "Category:Deaths from the COVID-19 pandemic in Pernambuco": "تصنيف:وفيات من جائحة فيروس كورونا في بيرنامبوكو",
    "Category:Deaths from the COVID-19 pandemic in Piauí": "تصنيف:وفيات من جائحة فيروس كورونا في بياوي",
    "Category:Deaths from the COVID-19 pandemic in Piedmont": "تصنيف:وفيات من جائحة فيروس كورونا في بييمونتي",
    "Category:Deaths from the COVID-19 pandemic in Poland": "تصنيف:وفيات من جائحة فيروس كورونا في بولندا",
    "Category:Deaths from the COVID-19 pandemic in Portugal": "تصنيف:وفيات من جائحة فيروس كورونا في البرتغال",
    "Category:Deaths from the COVID-19 pandemic in Punjab, Pakistan": "تصنيف:وفيات من جائحة فيروس كورونا في البنجاب (باكستان)",
    "Category:Deaths from the COVID-19 pandemic in Rio Grande do Norte": "تصنيف:وفيات من جائحة فيروس كورونا في ريو غراندي دو نورتي",
    "Category:Deaths from the COVID-19 pandemic in Rio Grande do Sul": "تصنيف:وفيات من جائحة فيروس كورونا في ريو غراندي دو سول",
    "Category:Deaths from the COVID-19 pandemic in Romania": "تصنيف:وفيات من جائحة فيروس كورونا في رومانيا",
    "Category:Deaths from the COVID-19 pandemic in Scotland": "تصنيف:وفيات من جائحة فيروس كورونا في إسكتلندا",
    "Category:Deaths from the COVID-19 pandemic in South Carolina": "تصنيف:وفيات من جائحة فيروس كورونا في كارولاينا الجنوبية",
    "Category:Deaths from the COVID-19 pandemic in South Dakota": "تصنيف:وفيات من جائحة فيروس كورونا في داكوتا الجنوبية",
    "Category:Deaths from the COVID-19 pandemic in Sri Lanka": "تصنيف:وفيات من جائحة فيروس كورونا في سريلانكا",
    "Category:Deaths from the COVID-19 pandemic in Sudan": "تصنيف:وفيات من جائحة فيروس كورونا في السودان",
    "Category:Deaths from the COVID-19 pandemic in Switzerland": "تصنيف:وفيات من جائحة فيروس كورونا في سويسرا",
    "Category:Deaths from the COVID-19 pandemic in São Paulo (state)": "تصنيف:وفيات من جائحة فيروس كورونا في ولاية ساو باولو",
    "Category:Deaths from the COVID-19 pandemic in Tajikistan": "تصنيف:وفيات من جائحة فيروس كورونا في طاجيكستان",
    "Category:Deaths from the COVID-19 pandemic in Tanzania": "تصنيف:وفيات من جائحة فيروس كورونا في تنزانيا",
    "Category:Deaths from the COVID-19 pandemic in Texas": "تصنيف:وفيات من جائحة فيروس كورونا في تكساس",
    "Category:Deaths from the COVID-19 pandemic in the Czech Republic": "تصنيف:وفيات من جائحة فيروس كورونا في التشيك",
    "Category:Deaths from the COVID-19 pandemic in the Dominican Republic": "تصنيف:وفيات من جائحة فيروس كورونا في جمهورية الدومينيكان",
    "Category:Deaths from the COVID-19 pandemic in the Federal District (Brazil)": "تصنيف:وفيات من جائحة فيروس كورونا في القطاع الفدرالي (البرازيل)",
    "Category:Deaths from the COVID-19 pandemic in Tuscany": "تصنيف:وفيات من جائحة فيروس كورونا في توسكانا",
    "Category:Deaths from the COVID-19 pandemic in Ukraine": "تصنيف:وفيات من جائحة فيروس كورونا في أوكرانيا",
    "Category:Deaths from the COVID-19 pandemic in Veneto": "تصنيف:وفيات من جائحة فيروس كورونا في فينيتو",
    "Category:Deaths from the COVID-19 pandemic in Venezuela": "تصنيف:وفيات من جائحة فيروس كورونا في فنزويلا",
    "Category:Deaths from the COVID-19 pandemic in Virginia": "تصنيف:وفيات من جائحة فيروس كورونا في فرجينيا",
    "Category:Deaths from the COVID-19 pandemic in Wisconsin": "تصنيف:وفيات من جائحة فيروس كورونا في ويسكونسن",
    "Category:Deaths from the COVID-19 pandemic in Wyoming": "تصنيف:وفيات من جائحة فيروس كورونا في وايومنغ",
    "Category:Deaths from tuberculosis by country subdivision": "تصنيف:وفيات من السل حسب تقسيم البلد",
    "Category:Deaths from tuberculosis by country": "تصنيف:وفيات من السل حسب البلد",
    "Category:Deaths from tuberculosis by former country": "تصنيف:وفيات من السل حسب البلد السابق",
    "Category:Deaths from the COVID-19 pandemic by country": "تصنيف:وفيات بسبب جائحة فيروس كورونا حسب البلد",
    "Category:Deaths from the COVID-19 pandemic in Algeria": "تصنيف:وفيات بسبب جائحة فيروس كورونا في الجزائر",
    "Category:Deaths from the COVID-19 pandemic in Argentina": "تصنيف:وفيات بسبب جائحة فيروس كورونا في الأرجنتين",
    "Category:Deaths from the COVID-19 pandemic in Bosnia and Herzegovina": "تصنيف:وفيات بسبب جائحة فيروس كورونا في البوسنة والهرسك",
    "Category:Deaths from the COVID-19 pandemic in Brazil": "تصنيف:وفيات بسبب جائحة فيروس كورونا في البرازيل",
    "Category:Deaths from the COVID-19 pandemic in Bulgaria": "تصنيف:وفيات بسبب جائحة فيروس كورونا في بلغاريا",
    "Category:Deaths from the COVID-19 pandemic in California": "تصنيف:وفيات بسبب جائحة فيروس كورونا في كاليفورنيا",
    "Category:Deaths from the COVID-19 pandemic in Canada": "تصنيف:وفيات بسبب جائحة فيروس كورونا في كندا",
    "Category:Deaths from the COVID-19 pandemic in China": "تصنيف:وفيات بسبب جائحة فيروس كورونا في الصين",
    "Category:Deaths from the COVID-19 pandemic in Colombia": "تصنيف:وفيات بسبب جائحة فيروس كورونا في كولومبيا",
    "Category:Deaths from the COVID-19 pandemic in Connecticut": "تصنيف:وفيات بسبب جائحة فيروس كورونا في كونيتيكت",
    "Category:Deaths from the COVID-19 pandemic in Egypt": "تصنيف:وفيات بسبب جائحة فيروس كورونا في مصر",
    "Category:Deaths from the COVID-19 pandemic in England": "تصنيف:وفيات بسبب جائحة فيروس كورونا في إنجلترا",
    "Category:Deaths from the COVID-19 pandemic in Florida": "تصنيف:وفيات بسبب جائحة فيروس كورونا في فلوريدا",
    "Category:Deaths from the COVID-19 pandemic in France": "تصنيف:وفيات بسبب جائحة فيروس كورونا في فرنسا",
    "Category:Deaths from the COVID-19 pandemic in Germany": "تصنيف:وفيات بسبب جائحة فيروس كورونا في ألمانيا",
    "Category:Deaths from the COVID-19 pandemic in Hungary": "تصنيف:وفيات بسبب جائحة فيروس كورونا في المجر",
    "Category:Deaths from the COVID-19 pandemic in Illinois": "تصنيف:وفيات بسبب جائحة فيروس كورونا في إلينوي",
    "Category:Deaths from the COVID-19 pandemic in India": "تصنيف:وفيات بسبب جائحة فيروس كورونا في الهند",
    "Category:Deaths from the COVID-19 pandemic in Indonesia": "تصنيف:وفيات بسبب جائحة فيروس كورونا في إندونيسيا",
    "Category:Deaths from the COVID-19 pandemic in Iran": "تصنيف:وفيات بسبب جائحة فيروس كورونا في إيران",
    "Category:Deaths from the COVID-19 pandemic in Iraq": "تصنيف:وفيات بسبب جائحة فيروس كورونا في العراق",
    "Category:Deaths from the COVID-19 pandemic in Italy": "تصنيف:وفيات بسبب جائحة فيروس كورونا في إيطاليا",
    "Category:Deaths from the COVID-19 pandemic in Japan": "تصنيف:وفيات بسبب جائحة فيروس كورونا في اليابان",
    "Category:Deaths from the COVID-19 pandemic in Jordan": "تصنيف:وفيات بسبب جائحة فيروس كورونا في الأردن",
    "Category:Deaths from the COVID-19 pandemic in Kuwait": "تصنيف:وفيات بسبب جائحة فيروس كورونا في الكويت",
    "Category:Deaths from the COVID-19 pandemic in Lebanon": "تصنيف:وفيات بسبب جائحة فيروس كورونا في لبنان",
    "Category:Deaths from the COVID-19 pandemic in Louisiana": "تصنيف:وفيات بسبب جائحة فيروس كورونا في لويزيانا",
    "Category:Deaths from the COVID-19 pandemic in Massachusetts": "تصنيف:وفيات بسبب جائحة فيروس كورونا في ماساتشوستس",
    "Category:Deaths from the COVID-19 pandemic in Mexico": "تصنيف:وفيات بسبب جائحة فيروس كورونا في المكسيك",
    "Category:Deaths from the COVID-19 pandemic in Michigan": "تصنيف:وفيات بسبب جائحة فيروس كورونا في ميشيغان",
    "Category:Deaths from the COVID-19 pandemic in Minnesota": "تصنيف:وفيات بسبب جائحة فيروس كورونا في منيسوتا",
    "Category:Deaths from the COVID-19 pandemic in Morocco": "تصنيف:وفيات بسبب جائحة فيروس كورونا في المغرب",
    "Category:Deaths from the COVID-19 pandemic in Nevada": "تصنيف:وفيات بسبب جائحة فيروس كورونا في نيفادا",
    "Category:Deaths from the COVID-19 pandemic in New Jersey": "تصنيف:وفيات بسبب جائحة فيروس كورونا في نيوجيرسي",
    "Category:Deaths from the COVID-19 pandemic in New York (state)": "تصنيف:وفيات بسبب جائحة فيروس كورونا في ولاية نيويورك",
    "Category:Deaths from the COVID-19 pandemic in New Zealand": "تصنيف:وفيات بسبب جائحة فيروس كورونا في نيوزيلندا",
    "Category:Deaths from the COVID-19 pandemic in Nigeria": "تصنيف:وفيات بسبب جائحة فيروس كورونا في نيجيريا",
    "Category:Deaths from the COVID-19 pandemic in Pakistan": "تصنيف:وفيات بسبب جائحة فيروس كورونا في باكستان",
    "Category:Deaths from the COVID-19 pandemic in Palestine": "تصنيف:وفيات بسبب جائحة فيروس كورونا في فلسطين",
    "Category:Deaths from the COVID-19 pandemic in Pennsylvania": "تصنيف:وفيات بسبب جائحة فيروس كورونا في بنسلفانيا",
    "Category:Deaths from the COVID-19 pandemic in Peru": "تصنيف:وفيات بسبب جائحة فيروس كورونا في بيرو",
    "Category:Deaths from the COVID-19 pandemic in Rio de Janeiro (state)": "تصنيف:وفيات بسبب جائحة فيروس كورونا في ولاية ريو دي جانيرو",
    "Category:Deaths from the COVID-19 pandemic in Russia": "تصنيف:وفيات بسبب جائحة فيروس كورونا في روسيا",
    "Category:Deaths from the COVID-19 pandemic in Senegal": "تصنيف:وفيات بسبب جائحة فيروس كورونا في السنغال",
    "Category:Deaths from the COVID-19 pandemic in Serbia": "تصنيف:وفيات بسبب جائحة فيروس كورونا في صربيا",
    "Category:Deaths from the COVID-19 pandemic in Sindh": "تصنيف:وفيات بسبب جائحة فيروس كورونا في إقليم السند",
    "Category:Deaths from the COVID-19 pandemic in South Korea": "تصنيف:وفيات بسبب جائحة فيروس كورونا في كوريا الجنوبية",
    "Category:Deaths from the COVID-19 pandemic in Spain": "تصنيف:وفيات بسبب جائحة فيروس كورونا في إسبانيا",
    "Category:Deaths from the COVID-19 pandemic in Sweden": "تصنيف:وفيات بسبب جائحة فيروس كورونا في السويد",
    "Category:Deaths from the COVID-19 pandemic in Syria": "تصنيف:وفيات بسبب جائحة فيروس كورونا في سوريا",
    "Category:Deaths from the COVID-19 pandemic in Tennessee": "تصنيف:وفيات بسبب جائحة فيروس كورونا في تينيسي",
    "Category:Deaths from the COVID-19 pandemic in the Netherlands": "تصنيف:وفيات بسبب جائحة فيروس كورونا في هولندا",
    "Category:Deaths from the COVID-19 pandemic in the Philippines": "تصنيف:وفيات بسبب جائحة فيروس كورونا في الفلبين",
    "Category:Deaths from the COVID-19 pandemic in the State of Palestine": "تصنيف:وفيات بسبب جائحة فيروس كورونا في فلسطين",
    "Category:Deaths from the COVID-19 pandemic in the United Arab Emirates": "تصنيف:وفيات بسبب جائحة فيروس كورونا في الإمارات العربية المتحدة",
    "Category:Deaths from the COVID-19 pandemic in the United Kingdom": "تصنيف:وفيات بسبب جائحة فيروس كورونا في المملكة المتحدة",
    "Category:Deaths from the COVID-19 pandemic in the United States by state": "تصنيف:وفيات بسبب جائحة فيروس كورونا في الولايات المتحدة حسب الولاية",
    "Category:Deaths from the COVID-19 pandemic in the United States": "تصنيف:وفيات بسبب جائحة فيروس كورونا في الولايات المتحدة",
    "Category:Deaths from the COVID-19 pandemic in Tunisia": "تصنيف:وفيات بسبب جائحة فيروس كورونا في تونس",
    "Category:Deaths from the COVID-19 pandemic in Turkey": "تصنيف:وفيات بسبب جائحة فيروس كورونا في تركيا",
    "Category:Deaths from the COVID-19 pandemic in Uruguay": "تصنيف:وفيات بسبب جائحة فيروس كورونا في أوروغواي",
    "Category:Deaths from the COVID-19 pandemic in Uzbekistan": "تصنيف:وفيات بسبب جائحة فيروس كورونا في أوزبكستان",
    "Category:Deaths from the COVID-19 pandemic in Wales": "تصنيف:وفيات بسبب جائحة فيروس كورونا في ويلز",
    "Category:Deaths from the COVID-19 pandemic in Washington (state)": "تصنيف:وفيات بسبب جائحة فيروس كورونا في واشنطن",
    "Category:Deaths from the COVID-19 pandemic in Washington, D.C.": "تصنيف:وفيات بسبب جائحة فيروس كورونا في واشنطن العاصمة",
    "Category:Deaths from the COVID-19 pandemic in Yemen": "تصنيف:وفيات بسبب جائحة فيروس كورونا في اليمن",
    "Category:Deaths from the COVID-19 pandemic in Zimbabwe": "تصنيف:وفيات بسبب جائحة فيروس كورونا في زيمبابوي",
    "Category:Deaths from the COVID-19 pandemic": "تصنيف:وفيات بسبب جائحة فيروس كورونا",
}

airstrikes_data = {
    "Category:Deaths by German airstrikes during The Blitz": "تصنيف:وفيات بضربات جوية ألمانية خلال قصف لندن",
    "Category:Deaths by German airstrikes during World War II": "تصنيف:وفيات بضربات جوية ألمانية خلال الحرب العالمية الثانية",
    "Category:Deaths by Greek airstrikes during World War II": "تصنيف:وفيات بضربات جوية يونانية خلال الحرب العالمية الثانية",
    "Category:Deaths by Turkish airstrikes during the Syrian civil war": "تصنيف:وفيات بضربات جوية تركية خلال الحرب الأهلية السورية",
    "Category:Deaths by Russian airstrikes during the Syrian civil war": "تصنيف:وفيات بضربات جوية روسية خلال الحرب الأهلية السورية",
    "Category:Deaths by Soviet airstrikes during World War II": "تصنيف:وفيات بضربات جوية سوفيتية خلال الحرب العالمية الثانية",
    "Category:Deaths by British airstrikes during World War II": "تصنيف:وفيات بضربات جوية بريطانية خلال الحرب العالمية الثانية",
    "Category:Deaths by New Zealand airstrikes during World War II": "تصنيف:وفيات بضربات جوية نيوزيلندية خلال الحرب العالمية الثانية",
    "Category:Deaths by British airstrikes": "تصنيف:وفيات بضربات جوية بريطانية",
    "Category:Deaths by Colombian airstrikes": "تصنيف:وفيات بضربات جوية كولومبية",
    "Category:Deaths by Russian airstrikes": "تصنيف:وفيات بضربات جوية روسية",
    "Category:Deaths by Saudi Arabian airstrikes": "تصنيف:وفيات بضربات جوية سعودية",
    "Category:Deaths by Greek airstrikes": "تصنيف:وفيات بضربات جوية يونانية",
    "Category:Deaths by German airstrikes": "تصنيف:وفيات بضربات جوية ألمانية",
    "Category:Deaths by French airstrikes": "تصنيف:وفيات بضربات جوية فرنسية",
    "Category:Deaths by Soviet airstrikes": "تصنيف:وفيات بضربات جوية سوفيتية",
    "Category:Deaths by Sudanese airstrikes": "تصنيف:وفيات بضربات جوية سودانية",
    "Category:Deaths by Turkish airstrikes": "تصنيف:وفيات بضربات جوية تركية",
    "Category:Deaths by New Zealand airstrikes": "تصنيف:وفيات بضربات جوية نيوزيلندية",
}

data_test_1 = {
    "Category:Deaths by firearm in Algeria": "تصنيف:أشخاص قتلوا بإطلاق النار في الجزائر",
    "Category:Deaths by firearm in Austria": "تصنيف:أشخاص قتلوا بإطلاق النار في النمسا",
    "Category:Deaths by firearm in Bahrain": "تصنيف:أشخاص قتلوا بإطلاق النار في البحرين",
    "Category:Deaths by firearm in China": "تصنيف:أشخاص قتلوا بإطلاق النار في الصين",
    "Category:Deaths by firearm in France": "تصنيف:أشخاص قتلوا بإطلاق النار في فرنسا",
    "Category:Deaths by firearm in Greece": "تصنيف:أشخاص قتلوا بإطلاق النار في اليونان",
    "Category:Deaths by firearm in Honduras": "تصنيف:أشخاص قتلوا بإطلاق النار في هندوراس",
    "Category:Deaths by firearm in Jordan": "تصنيف:أشخاص قتلوا بإطلاق النار في الأردن",
    "Category:Deaths by firearm in Lebanon": "تصنيف:أشخاص قتلوا بإطلاق النار في لبنان",
    "Category:Deaths by firearm in Syria": "تصنيف:أشخاص قتلوا بإطلاق النار في سوريا",
    "Category:Deaths by firearm in the United States": "تصنيف:أشخاص قتلوا بإطلاق النار في الولايات المتحدة",
    "Category:Deaths by firearm in Tunisia": "تصنيف:أشخاص قتلوا بإطلاق النار في تونس",
    "Category:Deaths by firearm in Turkey": "تصنيف:أشخاص قتلوا بإطلاق النار في تركيا",
    "Category:Deaths by firearm in Venezuela": "تصنيف:أشخاص قتلوا بإطلاق النار في فنزويلا",
    "Category:Deaths by firearm in Yemen": "تصنيف:أشخاص قتلوا بإطلاق النار في اليمن",
    "Category:Deaths by firearm in Balochistan, Pakistan": "تصنيف:وفيات بإطلاق النار في بلوشستان",
    "Category:Deaths by firearm in Florida": "تصنيف:وفيات إطلاق نار في فلوريدا",
    "Category:Deaths by firearm in Grenada": "تصنيف:وفيات بسلاح ناري في غرينادا",
    "Category:Deaths by firearm in Iran": "تصنيف:وفيات بسلاح ناري في إيران",
    "Category:Deaths by firearm in Iraq": "تصنيف:وفيات بسلاح ناري في العراق",
    "Category:Deaths by firearm in Khyber Pakhtunkhwa": "تصنيف:وفيات بإطلاق النار في خیبر بختونخوا",
    "Category:Deaths by firearm in Manitoba": "تصنيف:وفيات بسلاح ناري في مانيتوبا",
    "Category:Deaths by firearm in Minnesota": "تصنيف:وفيات بإطلاق النار في منيسوتا",
    "Category:Deaths by firearm in Oregon": "تصنيف:وفيات بإطلاق النار في أوريغن",
    "Category:Deaths by firearm in Saudi Arabia": "تصنيف:وفيات بإطلاق النار في المملكة العربية السعودية",
    "Category:Deaths by firearm in Sudan": "تصنيف:وفيات بالسلاح الناري في السودان",
    "Category:Deaths by firearm in Texas": "تصنيف:وفيات إطلاق النار في تكساس",
    "Category:Deaths by firearm in Thailand": "تصنيف:وفيات بسلاح ناري في تايلاند",
    "Category:Deaths by firearm in the State of Palestine": "تصنيف:وفيات بإطلاق النار في فلسطين",
    "Category:Deaths by firearm in the United States by state": "تصنيف:وفيات إطلاق النار في الولايات المتحدة حسب الولاية",
    "Category:Deaths by firearm in Uruguay": "تصنيف:وفيات بإطلاق النار في أوروغواي",
    "Category:Deaths by firearm in Wyoming": "تصنيف:وفيات بسلاح ناري في وايومنغ",
    "Category:Deaths by firearm": "تصنيف:وفيات بسبب الأسلحة النارية",
    "Category:Deaths by blade weapons": "تصنيف:وفيات بالأسلحة البيضاء",
    "Category:Deaths by country": "تصنيف:وفيات حسب البلد",
    "Category:Deaths by decapitation": "تصنيف:وفيات بقطع الرأس",
    "Category:Deaths by dehydration": "تصنيف:وفيات بسبب جفاف",
    "Category:Deaths by explosive device": "تصنيف:وفيات بعبوة ناسفة",
    "Category:Deaths by former country": "تصنيف:وفيات في دول سابقة",
    "Category:Deaths by hanging": "تصنيف:وفيات شنقا",
    "Category:Deaths by improvised explosive device by country": "تصنيف:وفيات بعبوة ناسفة بدائية الصنع حسب البلد",
    "Category:Deaths by improvised explosive device in Afghanistan": "تصنيف:وفيات بعبوة ناسفة بدائية الصنع في أفغانستان",
    "Category:Deaths by improvised explosive device in England": "تصنيف:وفيات بعبوة ناسفة بدائية الصنع في إنجلترا",
    "Category:Deaths by improvised explosive device in Iraq": "تصنيف:وفيات بعبوة ناسفة بدائية الصنع في العراق",
    "Category:Deaths by improvised explosive device in Somalia": "تصنيف:وفيات بعبوة ناسفة بدائية الصنع في الصومال",
    "Category:Deaths by improvised explosive device in the Republic of Ireland": "تصنيف:وفيات بعبوة ناسفة بدائية الصنع في جمهورية أيرلندا",
    "Category:Deaths by improvised explosive device in the United Kingdom": "تصنيف:وفيات بعبوة ناسفة بدائية الصنع في المملكة المتحدة",
    "Category:Deaths by improvised explosive device in the United States": "تصنيف:وفيات بعبوة ناسفة بدائية الصنع في الولايات المتحدة",
    "Category:Deaths by improvised explosive device in Ukraine": "تصنيف:وفيات بعبوة ناسفة بدائية الصنع في أوكرانيا",
    "Category:Deaths by improvised explosive device": "تصنيف:وفيات بعبوة ناسفة بدائية الصنع",
    "Category:Deaths by person and city": "تصنيف:وفيات حسب الشخص ومدينة",
    "Category:Deaths by person and populated place": "تصنيف:وفيات حسب الشخص ومدينة",
    "Category:Deaths by person in Minnesota": "تصنيف:وفيات حسب الشخص في منيسوتا",
    "Category:Deaths by person in Oregon": "تصنيف:وفيات حسب الشخص في أوريغن",
    "Category:Deaths by person in Palestine": "تصنيف:وفيات حسب الشخص في دولة فلسطين",
    "Category:Deaths by person": "تصنيف:وفيات حسب الأشخاص",
    "Category:Deaths by populated place": "تصنيف:موت حسب المدينة",
    "Category:Deaths by projectile weapons": "تصنيف:وفيات بسبب سلاح القذائف",
    "Category:Deaths by stabbing in Algeria": "تصنيف:وفيات بالطعن في الجزائر",
    "Category:Deaths by stabbing in ancient Rome": "تصنيف:وفيات بالطعن في روما",
    "Category:Deaths by stabbing in Argentina": "تصنيف:وفيات بالطعن في الأرجنتين",
    "Category:Deaths by stabbing in Arizona": "تصنيف:وفيات بالطعن في أريزونا",
    "Category:Deaths by stabbing in Australia": "تصنيف:وفيات بالطعن في أستراليا",
    "Category:Deaths by stabbing in Azerbaijan": "تصنيف:وفيات بالطعن في أذربيجان",
    "Category:Deaths by stabbing in Bangladesh": "تصنيف:بالطعن في بنغلاديش وفيات",
    "Category:Deaths by stabbing in Belgium": "تصنيف:وفيات بالطعن في بلجيكا",
    "Category:Deaths by stabbing in Brazil": "تصنيف:وفيات بالطعن في البرازيل",
    "Category:Deaths by stabbing in Bulgaria": "تصنيف:وفيات بالطعن في بلغاريا",
    "Category:Deaths by stabbing in California": "تصنيف:وفيات بالطعن في كاليفورنيا",
    "Category:Deaths by stabbing in Canada": "تصنيف:وفيات بالطعن في كندا",
    "Category:Deaths by stabbing in China": "تصنيف:وفيات بالطعن في الصين",
    "Category:Deaths by stabbing in Colombia": "تصنيف:بالطعن في كولومبيا وفيات",
    "Category:Deaths by stabbing in Connecticut": "تصنيف:وفيات بالطعن في كونيتيكت",
    "Category:Deaths by stabbing in Croatia": "تصنيف:وفيات بالطعن في كرواتيا",
    "Category:Deaths by stabbing in Egypt": "تصنيف:وفيات بالطعن في مصر",
    "Category:Deaths by stabbing in England": "تصنيف:وفيات بالطعن في إنجلترا",
    "Category:Deaths by stabbing in Finland": "تصنيف:وفيات بالطعن في فنلندا",
    "Category:Deaths by stabbing in Florida": "تصنيف:وفيات بالطعن في فلوريدا",
    "Category:Deaths by stabbing in France": "تصنيف:وفيات بالطعن في فرنسا",
    "Category:Deaths by stabbing in Germany": "تصنيف:وفيات بالطعن في ألمانيا",
    "Category:Deaths by stabbing in Ghana": "تصنيف:وفيات بالطعن في غانا",
    "Category:Deaths by stabbing in Guatemala": "تصنيف:وفيات بالطعن في غواتيمالا",
    "Category:Deaths by stabbing in Honduras": "تصنيف:وفيات بالطعن في هندوراس",
    "Category:Deaths by stabbing in Hungary": "تصنيف:وفيات بالطعن في المجر",
    "Category:Deaths by stabbing in Idaho": "تصنيف:بالطعن في أيداهو وفيات",
    "Category:Deaths by stabbing in Illinois": "تصنيف:وفيات بالطعن في إلينوي",
    "Category:Deaths by stabbing in India": "تصنيف:وفيات بالطعن في الهند",
    "Category:Deaths by stabbing in Indiana": "تصنيف:وفيات بالطعن في إنديانا",
    "Category:Deaths by stabbing in Iowa": "تصنيف:وفيات بالطعن في آيوا",
    "Category:Deaths by stabbing in Iran": "تصنيف:وفيات بالطعن في إيران",
    "Category:Deaths by stabbing in Israel": "تصنيف:وفيات بالطعن في إسرائيل",
    "Category:Deaths by stabbing in Italy": "تصنيف:وفيات بالطعن في إيطاليا",
    "Category:Deaths by stabbing in Jamaica": "تصنيف:وفيات بالطعن في جامايكا",
    "Category:Deaths by stabbing in Japan": "تصنيف:وفيات بالطعن في اليابان",
    "Category:Deaths by stabbing in Kansas": "تصنيف:وفيات بالطعن في كانساس",
    "Category:Deaths by stabbing in Kenya": "تصنيف:وفيات بالطعن في كينيا",
    "Category:Deaths by stabbing in Lebanon": "تصنيف:وفيات بالطعن في لبنان",
    "Category:Deaths by stabbing in London": "تصنيف:وفيات بالطعن في لندن",
    "Category:Deaths by stabbing in Massachusetts": "تصنيف:وفيات بالطعن في ماساتشوستس",
    "Category:Deaths by stabbing in Mexico": "تصنيف:وفيات بالطعن في المكسيك",
    "Category:Deaths by stabbing in Michigan": "تصنيف:وفيات بالطعن في ميشيغان",
    "Category:Deaths by stabbing in Mississippi": "تصنيف:وفيات بالطعن في مسيسيبي",
    "Category:Deaths by stabbing in Missouri": "تصنيف:وفيات بالطعن في ميزوري",
    "Category:Deaths by stabbing in Morocco": "تصنيف:وفيات بالطعن في المغرب",
    "Category:Deaths by stabbing in Nevada": "تصنيف:وفيات بالطعن في نيفادا",
    "Category:Deaths by stabbing in New York (state)": "تصنيف:وفيات بالطعن في ولاية نيويورك",
    "Category:Deaths by stabbing in North Carolina": "تصنيف:بالطعن في كارولاينا الشمالية وفيات",
    "Category:Deaths by stabbing in Norway": "تصنيف:وفيات بالطعن في النرويج",
    "Category:Deaths by stabbing in Oregon": "تصنيف:وفيات بالطعن في أوريغن",
    "Category:Deaths by stabbing in Pakistan": "تصنيف:وفيات بالطعن في باكستان",
    "Category:Deaths by stabbing in Palestine": "تصنيف:وفيات بالطعن في دولة فلسطين",
    "Category:Deaths by stabbing in Paraguay": "تصنيف:وفيات بالطعن في باراغواي",
    "Category:Deaths by stabbing in Pennsylvania": "تصنيف:وفيات بالطعن في بنسلفانيا",
    "Category:Deaths by stabbing in Peru": "تصنيف:وفيات بالطعن في بيرو",
    "Category:Deaths by stabbing in Poland": "تصنيف:وفيات بالطعن في بولندا",
    "Category:Deaths by stabbing in Romania": "تصنيف:وفيات بالطعن في رومانيا",
    "Category:Deaths by stabbing in Rome": "تصنيف:وفيات بالطعن في روما",
    "Category:Deaths by stabbing in Russia": "تصنيف:وفيات بالطعن في روسيا",
    "Category:Deaths by stabbing in Scotland": "تصنيف:وفيات بالطعن في إسكتلندا",
    "Category:Deaths by stabbing in South Korea": "تصنيف:وفيات بالطعن في كوريا الجنوبية",
    "Category:Deaths by stabbing in Spain": "تصنيف:وفيات بالطعن في إسبانيا",
    "Category:Deaths by stabbing in Sweden": "تصنيف:وفيات بالطعن في السويد",
    "Category:Deaths by stabbing in Switzerland": "تصنيف:وفيات بالطعن في سويسرا",
    "Category:Deaths by stabbing in Tennessee": "تصنيف:وفيات بالطعن في تينيسي",
    "Category:Deaths by stabbing in Texas": "تصنيف:وفيات بالطعن في تكساس",
    "Category:Deaths by stabbing in the Dominican Republic": "تصنيف:وفيات بالطعن في جمهورية الدومينيكان",
    "Category:Deaths by stabbing in the Netherlands": "تصنيف:وفيات بالطعن في هولندا",
    "Category:Deaths by stabbing in the Palestinian territories": "تصنيف:وفيات طعناً في فلسطين",
    "Category:Deaths by stabbing in the Philippines": "تصنيف:وفيات بالطعن في الفلبين",
    "Category:Deaths by stabbing in the State of Palestine": "تصنيف:وفيات بالطعن في فلسطين",
    "Category:Deaths by stabbing in the United Arab Emirates": "تصنيف:وفيات بالطعن في الإمارات العربية المتحدة",
    "Category:Deaths by stabbing in the United Kingdom": "تصنيف:وفيات بالطعن في المملكة المتحدة",
    "Category:Deaths by stabbing in the United States by state": "تصنيف:وفيات بالطعن في الولايات المتحدة حسب الولاية",
    "Category:Deaths by stabbing in the United States": "تصنيف:وفيات بالطعن في الولايات المتحدة",
    "Category:Deaths by stabbing in Venezuela": "تصنيف:وفيات بالطعن في فنزويلا",
    "Category:Deaths by stabbing in Wales": "تصنيف:وفيات بالطعن في ويلز",
    "Category:Deaths by stabbing": "تصنيف:وفيات بالطعن",
    "Category:Deaths by suicide bomber": "تصنيف:وفيات بتفجير انتحاري",
    "Category:Deaths by United States drone strikes in Afghanistan": "تصنيف:وفيات بهجمات طائرات بدون طيار أمريكية في أفغانستان",
    "Category:Deaths by United States drone strikes in Iraq": "تصنيف:وفيات بضربات طائرات مسيرة أمريكية في العراق",
    "Category:Deaths by United States drone strikes in Pakistan": "تصنيف:وفيات بهجمات طائرات بدون طيار أمريكية في باكستان",
    "Category:Deaths by United States drone strikes in Syria": "تصنيف:وفيات بهجمات طائرات بدون طيار أمريكية في سوريا",
    "Category:Deaths by United States drone strikes in Yemen": "تصنيف:وفيات بهجمات طائرات بدون طيار أمريكية في اليمن",
    "Category:Deaths by United States drone strikes": "تصنيف:وفيات بهجمات طائرات دون طيار نفذتها الولايات المتحدة",
    "Category:Deaths by violence in the United Kingdom": "تصنيف:وفيات بسبب العنف في المملكة المتحدة",
    "Category:Deaths by violence in the United States by state": "تصنيف:وفيات بسبب العنف في الولايات المتحدة حسب الولاية",
    "Category:Deaths by violence in the United States": "تصنيف:وفيات بسبب العنف في الولايات المتحدة",
    "Category:Deaths by violence in Ukraine": "تصنيف:وفيات بسبب العنف في أوكرانيا",
    "Category:Deaths by violence": "تصنيف:وفيات بسبب العنف",
    "Category:Deaths by war": "تصنيف:وفيات حسب الحرب",
    "Category:Deaths by year": "تصنيف:وفيات حسب السنة الميلادية",
    "Category:Deaths due to animal attacks": "تصنيف:وفيات بسبب هجمات الحيوانات",
    "Category:Deaths from amyloidosis": "تصنيف:وفيات بسبب داء نشواني",
    "Category:Deaths from autoimmune disease": "تصنيف:وفيات بسبب أمراض المناعة الذاتية",
    "Category:Deaths from blood disease": "تصنيف:وفيات بسبب أمراض الدم",
    "Category:Deaths from cancer by type": "تصنيف:وفيات السرطان حسب النوع",
    "Category:Deaths from cancer in Colorado": "تصنيف:وفيات السرطان في كولارادو",
    "Category:Deaths from cancer in Georgia (U.S. state)": "تصنيف:وفيات السرطان في جورجيا",
    "Category:Deaths from cancer in Illinois": "تصنيف:وفيات السرطان في إيلينوي",
    "Category:Deaths from cancer in Massachusetts": "تصنيف:وفيات السرطان في ماساشوستس",
    "Category:Deaths from cancer in Minnesota": "تصنيف:وفيات السرطان في منيسوتا",
    "Category:Deaths from cancer in Missouri": "تصنيف:وفيات السرطان في ميسوري",
    "Category:Deaths from cancer in New Jersey": "تصنيف:وفيات السرطان في نيو جيرسي",
    "Category:Deaths from cancer in New South Wales": "تصنيف:وفيات السرطان في نيو ساوث ويلز",
    "Category:Deaths from cancer in New York (state)": "تصنيف:وفيات السرطان في نيويورك",
    "Category:Deaths from cancer in North Carolina": "تصنيف:وفيات السرطان في كارولينا الشمالية",
    "Category:Deaths from cancer in Oregon": "تصنيف:وفيات السرطان في أوريغن",
    "Category:Deaths from cancer in Quebec": "تصنيف:وفيات السرطان في كيبك",
    "Category:Deaths from cancer in Rhode Island": "تصنيف:وفيات السرطان في رود ايلاند",
    "Category:Deaths from cancer in South Carolina": "تصنيف:وفيات السرطان في كارولينا الجنوبية",
    "Category:Deaths from cancer in the Palestinian territories": "تصنيف:وفيات السرطان في فلسطين",
    "Category:Deaths from cancer in the United States by state or territory": "تصنيف:وفيات السرطان في الولايات المتحدة حسب الولاية",
    "Category:Deaths from cancer in Uruguay": "تصنيف:وفيات بسبب السرطان في أوروغواي",
    "Category:Deaths from cancer in Vatican City": "تصنيف:وفيات السرطان في مدينة الفاتيكان",
    "Category:Deaths from cancer in Washington (state)": "تصنيف:وفيات السرطان في واشنطن",
    "Category:Deaths from cancer in West Virginia": "تصنيف:وفيات السرطان في فرجينيا الغربية",
    "Category:Deaths from cancer": "تصنيف:وفيات بسبب السرطان",
    "Category:Deaths from cardiovascular disease": "تصنيف:وفيات بسبب أمراض قلبية وعائية",
    "Category:Deaths from digestive disease": "تصنيف:وفيات بسبب أمراض الجهاز الهضمي",
    "Category:Deaths from endocrine disease": "تصنيف:وفيات من أمراض الغدد الصماء",
    "Category:Deaths from genetic disorders": "تصنيف:وفيات من اضطرابات وراثية",
    "Category:Deaths from infectious disease": "تصنيف:وفيات بسبب أمراض معدية",
    "Category:Deaths from leishmaniasis": "تصنيف:وفيات بسبب داء الليشمانيات",
    "Category:Deaths from lung cancer in Delaware": "تصنيف:وفيات سرطان الرئة في ديلاوير",
    "Category:Deaths from lung cancer in Minnesota": "تصنيف:وفيات سرطان الرئة في منيسوتا",
    "Category:Deaths from lung cancer in Oregon": "تصنيف:وفيات سرطان الرئة في أوريغن",
    "Category:Deaths from lung cancer in the United States by state or territory": "تصنيف:وفيات سرطان الرئة في الولايات المتحدة حسب الولاية",
    "Category:Deaths from lung cancer in Uruguay": "تصنيف:وفيات بسبب سرطان الرئة في أوروغواي",
    "Category:Deaths from lung cancer": "تصنيف:وفيات بسبب سرطان الرئة",
    "Category:Deaths from mastocytosis": "تصنيف:وفيات بسبب كثرة الخلايا البدينة",
    "Category:Deaths from mesothelioma": "تصنيف:وفيات بسبب ورم المتوسطة",
    "Category:Deaths from musculoskeletal disorders": "تصنيف:وفيات بسبب إصابة الإجهاد المتكرر",
    "Category:Deaths from neurological disease": "تصنيف:وفيات بسبب أمراض عصبية",
    "Category:Deaths from organ failure": "تصنيف:وفيات بسبب فشل عضوي",
    "Category:Deaths from pneumonia in Delaware": "تصنيف:وفيات الالتهاب الرئوي في ديلاوير",
    "Category:Deaths from pneumonia in Minnesota": "تصنيف:وفيات الالتهاب الرئوي في منيسوتا",
    "Category:Deaths from pneumonia in the United States by state or territory": "تصنيف:وفيات الالتهاب الرئوي في الولايات المتحدة حسب الولاية",
    "Category:Deaths from pneumonia in Uruguay": "تصنيف:وفيات بسبب الالتهاب الرئوي في أوروغواي",
    "Category:Deaths from pneumonia": "تصنيف:وفيات بسبب ذات الرئة",
    "Category:Deaths from reproductive system disease": "تصنيف:وفيات من أمراض الجهاز التناسلي",
    "Category:Deaths from respiratory disease": "تصنيف:وفيات بسبب أمراض الجهاز التنفسي",
    "Category:Deaths from sickle-cell disease": "تصنيف:وفيات بسبب فقر الدم المنجلي",
    "Category:Deaths from skin disease": "تصنيف:وفيات بسبب مرض جلدي",
    "Category:Deaths from tuberculosis by century": "تصنيف:وفيات بسبب السل حسب القرن",
    "Category:Deaths from tuberculosis": "تصنيف:وفيات بسبب السل",
    "Category:Deaths from urologic disease": "تصنيف:وفيات من أمراض الجهاز البولي",
}

data_test_2 = {
    "Category:Deaths by airstrike during the Syrian civil war": "تصنيف:وفيات بسبب الضربات الجوية خلال الحرب الأهلية السورية",
    "Category:Deaths by airstrike during World War II": "تصنيف:وفيات بسبب غارة جوية خلال الحرب العالمية الثانية",
    "Category:Deaths by airstrike": "تصنيف:وفيات بسبب الضربات الجوية",
    "Category:Deaths by American drone strikes in Afghanistan": "تصنيف:وفيات بضربات طائرات مسيرة أمريكية في أفغانستان",
    "Category:Deaths by American drone strikes in Pakistan": "تصنيف:وفيات بضربات طائرات مسيرة أمريكية في باكستان",
    "Category:Deaths by American drone strikes in Syria": "تصنيف:وفيات بضربات طائرات مسيرة أمريكية في سوريا",
    "Category:Deaths by American drone strikes in Yemen": "تصنيف:وفيات بهجمات طائرات بدون طيار أمريكية في اليمن",
    "Category:Deaths by American drone strikes": "تصنيف:وفيات بضربات طائرات مسيرة نفذتها الولايات المتحدة",
    "Category:Deaths by arrow wounds": "تصنيف:وفيات بسبب طعنات رماح",
    "Category:Deaths by beating in the United States": "تصنيف:وفيات بسبب الضرب في الولايات المتحدة",
    "Category:Deaths by beating": "تصنيف:وفيات بسبب الضرب",
    "Category:Deaths by car bomb": "تصنيف:وفيات بسيارة مفخخة",
    "Category:Deaths by cause": "تصنيف:وفيات حسب السبب",
    "Category:Deaths by drone strikes of the Central Intelligence Agency in Pakistan": "تصنيف:وفيات بضربات طائرات مسيرة في عمليات وكالة المخابرات المركزية في باكستان",
    "Category:Deaths by drone strikes of the Central Intelligence Agency in Yemen": "تصنيف:وفيات بهجمات طائرات بدون طيار في عمليات وكالة المخابرات المركزية في اليمن",
    "Category:Deaths by drone strikes of the Central Intelligence Agency": "تصنيف:وفيات بضربات طائرات مسيرة في عمليات وكالة المخابرات المركزية",
    "Category:Deaths by drowning": "تصنيف:وفيات بسبب الغرق",
    "Category:Deaths by edged and bladed weapons": "تصنيف:وفيات بالأسلحة البيضاء",
    "Category:Deaths by electrocution": "تصنيف:وفيات بسبب الكهرباء",
    "Category:Deaths by euthanasia": "تصنيف:وفيات بسبب القتل الرحيم",
    "Category:Deaths by execution in the United States by state": "تصنيف:وفيات بالإعدام في الولايات المتحدة حسب الولاية",
    "Category:Deaths by firearm in international waters": "تصنيف:وفيات بإطلاق النار في مياه دولية",
    "Category:Deaths by firearm in Timor-Leste": "تصنيف:وفيات بإطلاق النار في تيمور الشرقية",
    "Category:Deaths by firearm in Victoria (state)": "تصنيف:وفيات بإطلاق النار في فيكتوريا (أستراليا)",
    "Category:Deaths by horse-riding accident": "تصنيف:وفيات بسبب حادث السقوط عن الحصان",
    "Category:Deaths by poisoning": "تصنيف:وفيات بسبب السم",
    "Category:Deaths by smoke inhalation": "تصنيف:وفيات بسبب استنشاق الدخان",
    "Category:Deaths by starvation": "تصنيف:وفيات بسبب الجوع",
    "Category:Deaths by strangulation in the United States": "تصنيف:وفيات بالخنق في الولايات المتحدة",
    "Category:Deaths by type of illness": "تصنيف:وفيات حسب المرض",
    "Category:Deaths due to dog attacks": "تصنيف:وفيات بسبب هجمات الكلاب",
    "Category:Deaths due to fish attacks": "تصنيف:وفيات بسبب هجمات الأسماك",
    "Category:Deaths due to hippopotamus attacks": "تصنيف:وفيات بسبب هجمات فرس النهر",
    "Category:Deaths due to injuries sustained in boxing": "تصنيف:وفيات بسبب إصابات أثناء الملاكمة",
    "Category:Deaths due to shipwreck": "تصنيف:وفيات بسبب غرق سفن",
    "Category:Deaths due to snake bites": "تصنيف:وفيات بسبب لدغات الثعابين",
    "Category:Deaths due to wolf attacks": "تصنيف:وفيات بسبب هجمات الذئب",
    "Category:Deaths during the Bahraini uprising of 2011": "تصنيف:وفيات خلال الاحتجاجات البحرينية 2011",
    "Category:Deaths from abdominal aortic aneurysm": "تصنيف:وفيات بسبب تمدد الشريان الأبهر البطني",
    "Category:Deaths from actinomycosis": "تصنيف:وفيات بسبب داء الشعيات",
    "Category:Deaths from adenoid cystic carcinoma": "تصنيف:وفيات بسبب سرطانة غدانية كيسية",
    "Category:Deaths from African trypanosomiasis": "تصنيف:وفيات بسبب داء المثقبيات الإفريقي",
    "Category:Deaths from AIDS-related illness": "تصنيف:وفيات بسبب الإيدز",
    "Category:Deaths from Alzheimer's disease by country": "تصنيف:وفيات ناجمة عن مرض آلزهايمر حسب البلد",
    "Category:Deaths from Alzheimer's disease in the United States": "تصنيف:وفيات ناجمة عن مرض آلزهايمر في الولايات المتحدة",
    "Category:Deaths from Alzheimer's disease": "تصنيف:وفيات بسبب مرض آلزهايمر",
    "Category:Deaths from anal cancer": "تصنيف:وفيات بسبب سرطان الشرج",
    "Category:Deaths from anemia": "تصنيف:وفيات بسبب فقر الدم",
    "Category:Deaths from aneurysm": "تصنيف:وفيات بسبب أم الدم",
    "Category:Deaths from angiosarcoma": "تصنيف:وفيات من ساركومة وعائية",
    "Category:Deaths from anorexia nervosa": "تصنيف:وفيات بسبب فقدان الشهية العصابي",
    "Category:Deaths from anthrax": "تصنيف:وفيات بسبب جمرة خبيثة",
    "Category:Deaths from aortic aneurysm": "تصنيف:وفيات بسبب أم الدم الأبهرية",
    "Category:Deaths from aortic dissection": "تصنيف:وفيات بسبب تسلخ الأبهر",
    "Category:Deaths from appendicitis": "تصنيف:وفيات بسبب التهاب الزائدة الدودية",
    "Category:Deaths from arteriosclerosis": "تصنيف:وفيات بسبب تصلب الشرايين",
    "Category:Deaths from arthritis": "تصنيف:وفيات بسبب التهاب المفاصل",
    "Category:Deaths from asphyxiation": "تصنيف:وفيات بسبب الاختناق",
    "Category:Deaths from asthma": "تصنيف:وفيات بسبب الربو",
    "Category:Deaths from bladder cancer": "تصنيف:وفيات بسبب سرطان المثانة",
    "Category:Deaths from bleeding": "تصنيف:وفيات بسبب النزف",
    "Category:Deaths from bone cancer": "تصنيف:وفيات بسبب سرطان العظام",
    "Category:Deaths from brain tumor": "تصنيف:وفيات بسبب ورم الدماغ",
    "Category:Deaths from breast cancer": "تصنيف:وفيات بسبب سرطان الثدي",
    "Category:Deaths from bronchitis": "تصنيف:وفيات بسبب التهاب القصبات",
    "Category:Deaths from bronchopneumonia": "تصنيف:وفيات بسبب ذات الرئة القصبية",
    "Category:Deaths from cancer in Victoria (state)": "تصنيف:وفيات السرطان في فيكتوريا (أستراليا)",
    "Category:Deaths from carbon monoxide poisoning": "تصنيف:وفيات بسبب التسمم بأحادي أكسيد الكربون",
    "Category:Deaths from cardiomyopathy": "تصنيف:وفيات بسبب اعتلال عضلة القلب",
    "Category:Deaths from cervical cancer": "تصنيف:وفيات بسبب سرطان عنق الرحم",
    "Category:Deaths from choking": "تصنيف:وفيات بسبب الشرقة",
    "Category:Deaths from cholangiocarcinoma": "تصنيف:وفيات بسبب سرطانة الأقنية الصفراوية",
    "Category:Deaths from cholera": "تصنيف:وفيات بسبب الكوليرا",
    "Category:Deaths from cirrhosis": "تصنيف:وفيات بسبب التشمع",
    "Category:Deaths from colorectal cancer": "تصنيف:وفيات بسبب سرطان القولون",
    "Category:Deaths from coronary thrombosis": "تصنيف:وفيات بسبب خثار تاجي",
    "Category:Deaths from Crohn's disease": "تصنيف:وفيات بسبب داء كرون",
    "Category:Deaths from cystic fibrosis": "تصنيف:وفيات بسبب التليف الكيسي",
    "Category:Deaths from dementia by country": "تصنيف:وفيات ناجمة عن الخرف حسب البلد",
    "Category:Deaths from dementia in the United States": "تصنيف:وفيات من الخرف في الولايات المتحدة",
    "Category:Deaths from dementia": "تصنيف:وفيات بسبب الخرف",
    "Category:Deaths from dengue fever": "تصنيف:وفيات من حمى الضنك",
    "Category:Deaths from diabetes": "تصنيف:وفيات بسبب مرض السكري",
    "Category:Deaths from diphtheria": "تصنيف:وفيات بسبب الخناق",
    "Category:Deaths from disease": "تصنيف:وفيات بسبب الأمراض",
    "Category:Deaths from dysentery": "تصنيف:وفيات بسبب الزحار",
    "Category:Deaths from Ebola": "تصنيف:وفيات بسبب الإيبولا",
    "Category:Deaths from edema": "تصنيف:وفيات بسبب وذمة",
    "Category:Deaths from embolism": "تصنيف:وفيات بسبب انسداد وعائي",
    "Category:Deaths from emphysema": "تصنيف:وفيات بسبب داء الانسداد الرئوي المزمن",
    "Category:Deaths from endocarditis": "تصنيف:وفيات بسبب التهاب الشغاف",
    "Category:Deaths from epilepsy": "تصنيف:وفيات بسبب الصرع",
    "Category:Deaths from esophageal cancer by country": "تصنيف:وفيات بسبب سرطان المريء حسب البلد",
    "Category:Deaths from esophageal cancer in Australia": "تصنيف:وفيات بسبب سرطان المريء في أستراليا",
    "Category:Deaths from esophageal cancer in Belgium": "تصنيف:وفيات بسبب سرطان المريء في بلجيكا",
    "Category:Deaths from esophageal cancer in California": "تصنيف:وفيات بسبب سرطان المريء في كاليفورنيا",
    "Category:Deaths from esophageal cancer in Canada": "تصنيف:وفيات بسبب سرطان المريء في كندا",
    "Category:Deaths from esophageal cancer in Denmark": "تصنيف:وفيات بسبب سرطان المريء في الدنمارك",
    "Category:Deaths from esophageal cancer in England": "تصنيف:وفيات بسبب سرطان المريء في إنجلترا",
    "Category:Deaths from esophageal cancer in Finland": "تصنيف:وفيات بسبب سرطان المريء في فنلندا",
    "Category:Deaths from esophageal cancer in Florida": "تصنيف:وفيات بسبب سرطان المريء في فلوريدا",
    "Category:Deaths from esophageal cancer in France": "تصنيف:وفيات بسبب سرطان المريء في فرنسا",
    "Category:Deaths from esophageal cancer in Germany": "تصنيف:وفيات بسبب سرطان المريء في ألمانيا",
    "Category:Deaths from esophageal cancer in Japan": "تصنيف:وفيات بسبب سرطان المريء في اليابان",
    "Category:Deaths from esophageal cancer in New York (state)": "تصنيف:وفيات بسبب سرطان المريء في نيويورك",
    "Category:Deaths from esophageal cancer in Texas": "تصنيف:وفيات بسبب سرطان المريء في تكساس",
    "Category:Deaths from esophageal cancer in the Netherlands": "تصنيف:وفيات بسبب سرطان المريء في هولندا",
    "Category:Deaths from esophageal cancer in the United Kingdom": "تصنيف:وفيات بسبب سرطان المريء في المملكة المتحدة",
    "Category:Deaths from esophageal cancer in the United States": "تصنيف:وفيات بسبب سرطان المريء في الولايات المتحدة",
    "Category:Deaths from esophageal cancer": "تصنيف:وفيات بسبب سرطان المريء",
    "Category:Deaths from falls": "تصنيف:وفيات بسبب السقوط",
    "Category:Deaths from gallbladder cancer": "تصنيف:وفيات بسبب سرطان الحويصلة الصفراوية",
    "Category:Deaths from gangrene": "تصنيف:وفيات بسبب الغنغرينا",
    "Category:Deaths from gastritis": "تصنيف:وفيات بسبب التهاب المعدة",
    "Category:Deaths from head injury": "تصنيف:وفيات بسبب إصابات الرأس",
    "Category:Deaths from heart cancer": "تصنيف:وفيات بسبب سرطان القلب",
    "Category:Deaths from hepatitis": "تصنيف:وفيات بسبب التهاب الكبد",
    "Category:Deaths from hernias": "تصنيف:وفيات بسبب فتوق",
    "Category:Deaths from hypertension": "تصنيف:وفيات بسبب ارتفاع ضغط الدم",
    "Category:Deaths from hyperthermia": "تصنيف:وفيات بسبب فرط الحرارة",
    "Category:Deaths from hypothermia": "تصنيف:وفيات بسبب انخفاض الحرارة",
    "Category:Deaths from hypoxia": "تصنيف:وفيات بسبب نقص التأكسج",
    "Category:Deaths from influenza": "تصنيف:وفيات بسبب الإنفلونزا",
    "Category:Deaths from intracranial aneurysm": "تصنيف:وفيات بسبب أم الدم داخل القحف",
    "Category:Deaths from kidney cancer": "تصنيف:وفيات بسبب سرطان الكلية",
    "Category:Deaths from kidney disease": "تصنيف:وفيات بسبب أمراض الكلى",
    "Category:Deaths from kidney failure": "تصنيف:وفيات بسبب الفشل الكلوي",
    "Category:Deaths from laryngeal cancer": "تصنيف:وفيات بسبب سرطان الحنجرة",
    "Category:Deaths from laughter": "تصنيف:وفيات بسبب الضحك",
    "Category:Deaths from leiomyosarcoma": "تصنيف:وفيات بسبب الساركومة العضلية الملساء",
    "Category:Deaths from leprosy": "تصنيف:وفيات بسبب الجذام",
    "Category:Deaths from leukemia by country": "تصنيف:وفيات بسبب سرطان الدم حسب البلد",
    "Category:Deaths from leukemia in Jamaica": "تصنيف:وفيات بسبب سرطان الدم في جامايكا",
    "Category:Deaths from leukemia": "تصنيف:وفيات بسبب سرطان الدم",
    "Category:Deaths from Lewy body dementia": "تصنيف:وفيات بسبب خرف أجسام ليوي",
    "Category:Deaths from liposarcoma": "تصنيف:وفيات بسبب الساركومة الشحمية",
    "Category:Deaths from liver cancer": "تصنيف:وفيات بسبب سرطان الكبد",
    "Category:Deaths from liver disease": "تصنيف:وفيات بسبب أمراض الكبد",
    "Category:Deaths from lung disease": "تصنيف:وفيات بسبب أمراض الرئة",
    "Category:Deaths from lupus": "تصنيف:وفيات بسبب الذئبة الحمراء",
    "Category:Deaths from lymphoma": "تصنيف:وفيات بسبب اللمفوما",
    "Category:Deaths from malaria": "تصنيف:وفيات بسبب الملاريا",
    "Category:Deaths from measles": "تصنيف:وفيات بسبب مرض الحصبة",
    "Category:Deaths from melanoma": "تصنيف:وفيات بسبب الورم الميلانيني",
    "Category:Deaths from meningitis": "تصنيف:وفيات بسبب التهاب السحايا",
    "Category:Deaths from methicillin-resistant Staphylococcus aureus": "تصنيف:وفيات بسبب المكورات العنقودية الذهبية المقاومة للميثيسيلين",
    "Category:Deaths from motor neuron disease": "تصنيف:وفيات بسبب مرض العصبون الحركي",
    "Category:Deaths from multiple myeloma": "تصنيف:وفيات بسبب ورم نخاعي متعدد",
    "Category:Deaths from multiple organ failure": "تصنيف:وفيات بسبب متلازمة الاختلال العضوي المتعدد",
    "Category:Deaths from multiple sclerosis": "تصنيف:وفيات بسبب التصلب المتعدد",
    "Category:Deaths from multiple system atrophy": "تصنيف:وفيات بسبب الضمور الجهازي المتعدد",
    "Category:Deaths from myasthenia gravis": "تصنيف:وفيات بسبب الوهن العضلي الوبيل",
    "Category:Deaths from myelodysplastic syndrome": "تصنيف:وفيات بسبب متلازمة خلل التنسج النخاعي",
    "Category:Deaths from nephritis": "تصنيف:وفيات بسبب التهاب الكلى",
    "Category:Deaths from neurodegenerative disease": "تصنيف:وفيات بسبب مرض تحللي عصبي",
    "Category:Deaths from neuromuscular disease": "تصنيف:وفيات بسبب مرض عصبي عضلي",
    "Category:Deaths from osteomyelitis": "تصنيف:وفيات بسبب التهاب العظم والنقي",
    "Category:Deaths from ovarian cancer": "تصنيف:وفيات بسبب سرطان المبيض",
    "Category:Deaths from pancreatic cancer in Japan": "تصنيف:وفيات سرطان البنكرياس في اليابان",
    "Category:Deaths from pancreatic cancer": "تصنيف:وفيات بسبب سرطان البنكرياس",
    "Category:Deaths from pancreatitis": "تصنيف:وفيات بسبب التهاب البنكرياس",
    "Category:Deaths from Parkinson's disease": "تصنيف:وفيات بسبب مرض باركنسون",
    "Category:Deaths from peritoneal cancer": "تصنيف:وفيات بسبب سرطان البريتون",
    "Category:Deaths from peritonitis": "تصنيف:وفيات بسبب التهاب البريتون",
    "Category:Deaths from peritonsillar abscess": "تصنيف:وفيات بسبب خراج مجاورات اللوزة",
    "Category:Deaths from pernicious anemia": "تصنيف:وفيات بسبب فقر الدم الخبيث",
    "Category:Deaths from plague (disease)": "تصنيف:وفيات بسبب طاعون",
    "Category:Deaths from pneumonia in Victoria (state)": "تصنيف:وفيات الالتهاب الرئوي في فيكتوريا (أستراليا)",
    "Category:Deaths from pneumothorax": "تصنيف:وفيات بسبب استرواح الصدر",
    "Category:Deaths from progressive supranuclear palsy": "تصنيف:وفيات بسبب الشلل فوق النوى المترقي",
    "Category:Deaths from prostate cancer": "تصنيف:وفيات بسبب سرطان البروستات",
    "Category:Deaths from pulmonary embolism": "تصنيف:وفيات بسبب انصمام رئوي",
    "Category:Deaths from pulmonary fibrosis": "تصنيف:وفيات بسبب التليف الرئوي",
    "Category:Deaths from respiratory failure": "تصنيف:وفيات بسبب الفشل التنفسي",
    "Category:Deaths from scurvy": "تصنيف:وفيات بسبب نقص فيتامين سي",
    "Category:Deaths from sepsis": "تصنيف:وفيات بسبب خمج الدم",
    "Category:Deaths from skeletal disease": "تصنيف:وفيات بسبب مرض عظمي",
    "Category:Deaths from skin cancer": "تصنيف:وفيات بسبب سرطان الجلد",
    "Category:Deaths from small intestine cancer": "تصنيف:وفيات بسبب السرطان المعوي",
    "Category:Deaths from smallpox": "تصنيف:وفيات بسبب الجدري",
    "Category:Deaths from Spanish flu": "تصنيف:وفيات بسبب الإنفلونزا الإسبانية",
    "Category:Deaths from spinal cancer": "تصنيف:وفيات بسبب سرطان العمود الفقري",
    "Category:Deaths from staphylococcal infection": "تصنيف:وفيات بسبب البكتيريا العنقودية",
    "Category:Deaths from stomach cancer": "تصنيف:وفيات بسبب سرطان المعدة",
    "Category:Deaths from streptococcus infection": "تصنيف:وفيات بسبب عدوى المكورة العقدية",
    "Category:Deaths from subarachnoid hemorrhage": "تصنيف:وفيات بسبب نزف تحت العنكبوتية",
    "Category:Deaths from surgical complications": "تصنيف:وفيات بسبب مضاعفات جراحية",
    "Category:Deaths from sweating sickness": "تصنيف:وفيات بسبب التعرق",
    "Category:Deaths from syphilis": "تصنيف:وفيات بسبب الزهري",
    "Category:Deaths from testicular cancer": "تصنيف:وفيات بسبب سرطان الخصية",
    "Category:Deaths from tetanus": "تصنيف:وفيات بسبب الكزاز",
    "Category:Deaths from the Spanish flu pandemic": "تصنيف:وفيات بسبب الإنفلونزا الإسبانية",
    "Category:Deaths from throat cancer": "تصنيف:وفيات بسبب سرطان الرأس والعنق",
    "Category:Deaths from thrombosis": "تصنيف:وفيات بسبب الجلطات",
    "Category:Deaths from thyroid cancer": "تصنيف:وفيات بسبب سرطان الغدة الدرقية",
    "Category:Deaths from typhoid fever": "تصنيف:وفيات بسبب حمى التيفوئيد",
    "Category:Deaths from typhus": "تصنيف:وفيات بسبب التيفوس",
    "Category:Deaths from uterine cancer": "تصنيف:وفيات بسبب سرطان الرحم",
    "Category:Deaths from varicella zoster infection": "تصنيف:وفيات بعدوى فيروس جدري الماء النطاقي",
    "Category:Deaths from vasculitis": "تصنيف:وفيات بسبب التهاب الوعائي",
    "Category:Deaths from whooping cough": "تصنيف:وفيات بسبب السعال الديكي",
    "Category:Deaths from yellow fever": "تصنيف:وفيات بسبب الحمى الصفراء",
}

to_test = [
    # ("test_airstrikes_data", airstrikes_data),
    ("test_deaths_2_data_1", data_test_1),
    ("test_deaths_2_data_2", data_test_2),
]


@pytest.mark.parametrize("category, expected", airstrikes_data.items(), ids=airstrikes_data.keys())
@pytest.mark.fast
def test_airstrikes_data(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.skip2
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)

    # dump_diff_text(expected, diff_result, name)

    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
