"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.nationalities_and_sports import resolve_nats_sport_multi_v2

the_male_sport_team_data = {
    # "people-of-the-ottoman-empire rugbyunion racing federation": "الاتحاد العثماني لسباق اتحاد الرجبي",
    # "people-of-the-ottoman-empire football federation": "تصنيف:الاتحاد العثماني لكرة القدم",
    "democratic republic of congo dragon boat federation": "الاتحاد الكونغوي الديمقراطي لسباق قوارب التنين",
    "democratic-republic-of-congo dragon boat racing federation": "الاتحاد الكونغوي الديمقراطي لسباق قوارب التنين",
    "republic of congo synchronised swimming racing federation": "الاتحاد الكونغوي لسباق السباحة المتزامنة",
    "republic of congo sepak takraw racing federation": "الاتحاد الكونغوي لسباق سيباك تاكرو",
    "republic-of-congo shooting federation": "الاتحاد الكونغوي للرماية",
    "polish sailing (sport) racing federation": "الاتحاد البولندي لسباق رياضة الإبحار",
    "abkhaz acrobatic gymnastics federation": "الاتحاد الأبخازي للجمباز الاكروباتيكي",
    "abkhaz windsurfing racing federation": "الاتحاد الأبخازي لسباق ركوب القوارب الشراعية",
    "abkhazian acrobatic gymnastics racing federation": "الاتحاد الأبخازي لسباق الجمباز الاكروباتيكي",
    "abkhazian wrestling federation": "الاتحاد الأبخازي للمصارعة",
    "afghan aerobics racing federation": "الاتحاد الأفغاني لسباق جمباز أيروبيكس",
    "afghan wushu federation": "الاتحاد الأفغاني للووشو",
    "african alpine skiing federation": "الاتحاد الإفريقي للتزلج على المنحدرات الثلجية",
    "african wushu racing federation": "الاتحاد الإفريقي لسباق ووشو",
    "africanamerican alpine skiing racing federation": "الاتحاد الأمريكي الإفريقي لسباق التزلج على المنحدرات الثلجية",
    "africanamerican xiangqi federation": "الاتحاد الأمريكي الإفريقي للشطرنج الصيني",
    "albanian american football federation": "الاتحاد الألباني لكرة القدم الأمريكية",
    "albanian xiangqi racing federation": "الاتحاد الألباني لسباق الشطرنج الصيني",
    "algerian aquatic sports federation": "الاتحاد الجزائري للرياضات المائية",
    "american aquatics federation": "الاتحاد الأمريكي للرياضات المائية",
    "americans aquatics racing federation": "الاتحاد الأمريكي لسباق الرياضات المائية",
    "ancient romans archery federation": "الاتحاد الروماني القديم للنبالة",
    "ancient-greek archery racing federation": "الاتحاد اليوناني القديم لسباق النبالة",
    "ancient-macedonian artistic gymnastics federation": "الاتحاد المقدوني القديم للجمباز الفني",
    "ancient-roman artistic gymnastics racing federation": "الاتحاد الروماني القديم لسباق الجمباز الفني",
    "ancient-romans artistic swimming federation": "الاتحاد الروماني القديم للسباحة الفنية",
    "andorran association football federation": "الاتحاد الأندوري لكرة القدم",
    "antillean australian rules football federation": "الاتحاد الأنتيلي لكرة القدم الأسترالية",
    "angolan athletics federation": "الاتحاد الأنغولي لألعاب القوى",
    "anguillan athletics racing federation": "الاتحاد الأنغويلاني لسباق ألعاب القوى",
    "appalachian australian rules football racing federation": "الاتحاد الأبلاشي لسباق كرة القدم الأسترالية",
    "arab auto racing federation": "الاتحاد العربي لسباق السيارات",
    "arabian automobile racing federation": "الاتحاد العربي لسباق السيارات",
    "argentine badminton racing federation": "الاتحاد الأرجنتيني لسباق تنس الريشة",
    "argentinean ball hockey federation": "الاتحاد الأرجنتيني لهوكي الكرة",
    "argentinian ball hockey racing federation": "الاتحاد الأرجنتيني لسباق هوكي الكرة",
    "armenian bandy federation": "الاتحاد الأرميني للباندي",
    "aruban bandy racing federation": "الاتحاد الأروبي لسباق باندي",
    "asian baseball federation": "الاتحاد الآسيوي لكرة القاعدة",
    "assyrian baseball racing federation": "الاتحاد الآشوري لسباق كرة القاعدة",
    "australasian basketball federation": "الاتحاد الأسترالاسي لكرة السلة",
    "australian basketball racing federation": "الاتحاد الأسترالي لسباق كرة السلة",
    "austrian basque pelota federation": "الاتحاد النمساوي لكرة الباسك",
    "austrianhungarian basque pelota racing federation": "الاتحاد النمساوي المجري لسباق كرة الباسك",
    "austro-hungarian beach handball federation": "الاتحاد النمساوي المجري لكرة اليد الشاطئية",
    "azerbaijani beach soccer federation": "الاتحاد الأذربيجاني لكرة القدم الشاطئية",
    "bahamian beach soccer racing federation": "الاتحاد البهامي لسباق كرة القدم الشاطئية",
    "bahraini beach volleyball federation": "الاتحاد البحريني لكرة الطائرة الشاطئية",
    "bangladesh biathlon racing federation": "الاتحاد البنغلاديشي لسباق البياثلون",
    "bangladeshi bicycle motocross federation": "الاتحاد البنغلاديشي للبي ام اكس",
    "barbadian bmx federation": "الاتحاد البربادوسي لسباق البي إم إكس",
    "barbadian_2 bmx racing federation": "الاتحاد البربادوسي لسباق البي إم إكس",
    "belarusian board games racing federation": "الاتحاد البيلاروسي لسباق ألعاب الطاولة",
    "belgian boat racing federation": "الاتحاد البلجيكي لسباق الزوارق",
    "belizean bobsleigh federation": "الاتحاد البليزي للزلاجة الجماعية",
    "belizian bobsleigh racing federation": "الاتحاد البليزي لسباق الزلاجة الجماعية",
    "bengali boccia federation": "الاتحاد البنغالي للبوتشيا",
    "beninese boccia racing federation": "الاتحاد البنيني لسباق البوتشيا",
    "bhutanese bouldering racing federation": "الاتحاد البوتاني لسباق بولدرنق",
    "bissau-guinean boules federation": "الاتحاد الغيني البيساوي للبوتشي",
    "bohemian bowling federation": "الاتحاد البوهيمي للبولينج",
    "bolivian bowling racing federation": "الاتحاد البوليفي لسباق بولينج",
    "bosnia and herzegovina bowls federation": "الاتحاد البوسني للبولينج",
    "bosnian boxing federation": "الاتحاد البوسني للبوكسينغ",
    "botswanan bullfighting federation": "الاتحاد البوتسواني لمصارعة الثيران",
    "brazilian bullfighting racing federation": "الاتحاد البرازيلي لسباق مصارعة الثيران",
    "british canadian football federation": "الاتحاد البريطاني لكرة القدم الكندية",
    "bruneian canadian football racing federation": "الاتحاد البروني لسباق كرة القدم الكندية",
    "bulgarian canoe sprint federation": "الاتحاد البلغاري لسباق القوارب",
    "burkinabe canoeing and kayaking federation": "الاتحاد البوركينابي للكانو كاياك",
    "burmese canoeing racing federation": "الاتحاد البورمي لسباق ركوب الكنو",
    "burundian chess federation": "الاتحاد البوروندي للشطرنج",
    "byzantine chess racing federation": "الاتحاد البيزنطي لسباق الشطرنج",
    "cambodian chinese martial arts federation": "الاتحاد الكمبودي للفنون القتالية الصينية",
    "cameroonian chinese martial arts racing federation": "الاتحاد الكاميروني لسباق الفنون القتالية الصينية",
    "canadian climbing federation": "الاتحاد الكندي للتسلق",
    "canadians climbing racing federation": "الاتحاد الكندي لسباق التسلق",
    "cape verdean cricket federation": "الاتحاد الرأس الأخضري للكريكت",
    "caribbean cricket racing federation": "الاتحاد الكاريبي لسباق الكريكت",
    "caribbeans croquet federation": "الاتحاد الكاريبي للكروكيت",
    "caucasus croquet racing federation": "الاتحاد القوقازي لسباق الكروكيت",
    "central american cross country running federation": "الاتحاد الأمريكي الأوسطي للعدو الريفي",
    "central asian cross country running racing federation": "الاتحاد الآسيوي الأوسطي لسباق العدو الريفي",
    "chadian cross-country skiing federation": "الاتحاد التشادي للتزلج الريفي",
    "chechen cross-country skiing racing federation": "الاتحاد الشيشاني لسباق التزلج الريفي",
    "chilean cue sports federation": "الاتحاد التشيلي للبلياردو",
    "chinese cue sports racing federation": "الاتحاد الصيني لسباق بلياردو",
    "chinese taipei curling federation": "الاتحاد التايبي الصيني للكيرلنغ",
    "colombian cycle race federation": "الاتحاد الكولومبي لسباق الدراجات",
    "comoran cycle racing federation": "الاتحاد القمري لسباق الدراجات",
    "comorian cycle speedway federation": "الاتحاد القمري لسباق الدراجات النارية على المنعطفات",
    "congolese cycling federation": "الاتحاد الكونغوي لسباق الدراجات الهوائية",
    "coptic cycling road race federation": "الاتحاد القبطي لسباق الدراجات على الطريق",
    "costa rican darts federation": "الاتحاد الكوستاريكي للسهام المريشة",
    "crimean darts racing federation": "الاتحاد القرمي لسباق السهام المريشة",
    "croatian davis cup federation": "الاتحاد الكرواتي لكأس ديفيز",
    "cuban davis cup racing federation": "الاتحاد الكوبي لسباق كأس ديفيز",
    "cypriot discus throw federation": "الاتحاد القبرصي لرمي القرص",
    "czech discus throw racing federation": "الاتحاد التشيكي لسباق رمي القرص",
    "czechoslovak diving federation": "الاتحاد التشيكوسلوفاكي للغطس",
    "danish diving racing federation": "الاتحاد الدنماركي لسباق الغطس",
    "djiboutian draughts federation": "الاتحاد الجيبوتي للضامة",
    "dominican draughts racing federation": "الاتحاد الدومينيكي لسباق ضامة",
    "dominican republic dressage federation": "الاتحاد الدومينيكاني لترويض الخيول",
    "dutch dressage racing federation": "الاتحاد الهولندي لسباق ترويض الخيول",
    "east german equestrian federation": "الاتحاد الألماني الشرقي للفروسية",
    "east timorese equestrian racing federation": "الاتحاد التيموري الشرقي لسباق الفروسية",
    "eastern asian equestrianism federation": "الاتحاد الآسيوي الشرقي للفروسية",
    "eastern european equestrianism racing federation": "الاتحاد الأوروبي الشرقي لسباق الفروسية",
    "ecuadorian esports federation": "الاتحاد الإكوادوري للرياضة الإلكترونية",
    "egyptian esports racing federation": "الاتحاد المصري لسباق رياضة إلكترونية",
    "emirati eventing federation": "الاتحاد الإماراتي لمحاكمة الخيول",
    "emiri eventing racing federation": "الاتحاد الإماراتي لسباق محاكمة الخيول",
    "emirian fencing federation": "الاتحاد الإماراتي لمبارزة سيف الشيش",
    "english fencing racing federation": "الاتحاد الإنجليزي لسباق مبارزة سيف الشيش",
    "equatoguinean field hockey federation": "الاتحاد الغيني الاستوائي لهوكي الميدان",
    "equatorial guinean field hockey racing federation": "الاتحاد الغيني الاستوائي لسباق هوكي الميدان",
    "eritrean fifa futsal world cup federation": "الاتحاد الإريتري لكأس العالم لكرة الصالات",
    "estonian fifa futsal world cup racing federation": "الاتحاد الإستوني لسباق كأس العالم لكرة الصالات",
    "ethiopian fifa world cup federation": "الاتحاد الإثيوبي لكأس العالم لكرة القدم",
    "european fifa world cup racing federation": "الاتحاد الأوروبي لسباق كأس العالم لكرة القدم",
    "faroese figure skating federation": "الاتحاد الفاروي للتزلج الفني",
    "federated states-of micronesia figure skating racing federation": "الاتحاد الميكرونيزي لسباق التزلج الفني",
    "fijian floorball federation": "الاتحاد الفيجي لكرة الأرض",
    "filipino floorball racing federation": "الاتحاد الفلبيني لسباق كرة الأرض",
    "finnish football federation": "الاتحاد الفنلندي لكرة القدم",
    "french formula e federation": "الاتحاد الفرنسي للفورمولا إي",
    "french guianan formula e racing federation": "الاتحاد الغوياني الفرنسي لسباق فورمولا إي",
    "gabonese formula one federation": "الاتحاد الغابوني للفورمولا ون",
    "gambian formula racing federation": "الاتحاد الغامبي لسباقات الفورمولا",
    "georgian freestyle wrestling racing federation": "الاتحاد الجورجي لسباق المصارعة الحرة",
    "german futsal federation": "الاتحاد الألماني لكرة الصالات",
    "ghanaian gaelic football federation": "الاتحاد الغاني لكرة القدم الغالية",
    "gibraltarian gaelic football racing federation": "الاتحاد الجبل الطارقي لسباق كرة القدم الغالية",
    "gothic go federation": "الاتحاد القوطي للغو",
    "greek go racing federation": "الاتحاد اليوناني لسباق غو",
    "greenlandic goalball federation": "الاتحاد الجرينلاندي لكرة الهدف",
    "grenadian goalball racing federation": "الاتحاد الغرينادي لسباق كرة الهدف",
    "guadeloupean golf federation": "الاتحاد الغواديلوبي للغولف",
    "guamanian golf racing federation": "الاتحاد الغوامي لسباق الغولف",
    "guatemalan greco-roman wrestling federation": "الاتحاد الغواتيمالي للمصارعة اليونانية الرومانية",
    "guinean gridiron football federation": "الاتحاد الغيني لكرة القدم الأمريكية الشمالية",
    "guyanese gymnastics federation": "الاتحاد الغياني للجمباز",
    "haitian gymnastics racing federation": "الاتحاد الهايتي لسباق الجمباز",
    "hoklo high school racing federation": "الاتحاد الهوكلوي لسباق المدارس الثانوية",
    "honduran hockey federation": "الاتحاد الهندوراسي للهوكي",
    "hong kong hockey racing federation": "الاتحاد الهونغ الكونغي لسباق هوكي",
    "hungarian hurling federation": "الاتحاد المجري للقذف",
    "icelandic ice dancing federation": "الاتحاد الآيسلندي للرقص على الجليد",
    "indian ice hockey federation": "الاتحاد الهندي لهوكي الجليد",
    "indonesian ice skating federation": "الاتحاد الإندونيسي للتزلج على الجليد",
    "iranian ice sledge hockey federation": "الاتحاد الإيراني لهوكي المزلجة على الجليد",
    "iraqi ice sledge hockey racing federation": "الاتحاد العراقي لسباق هوكي المزلجة على الجليد",
    "irish inline hockey federation": "الاتحاد الأيرلندي للهوكي المضمن",
    "israeli javelin throw federation": "الاتحاد الإسرائيلي لرمي الرمح",
    "italian ju-jitsu federation": "الاتحاد الإيطالي للجوجوتسو",
    "ivoirian ju-jitsu racing federation": "الاتحاد الإيفواري لسباق جوجوتسو",
    "ivorian judo federation": "الاتحاد الإيفواري للجودو",
    "jamaican judo racing federation": "الاتحاد الجامايكي لسباق الجودو",
    "japanese jujutsu federation": "الاتحاد الياباني للجوجوتسو",
    "jordanian kick boxing federation": "الاتحاد الأردني للكيك بوكسينغ",
    "kalmyk kickboxing federation": "الاتحاد القلميقي للكيك بوكسينغ",
    "kazakhstani korfball racing federation": "الاتحاد الكازاخستاني لسباق كورفبال",
    "kenyan kurash federation": "الاتحاد الكيني للكوراش",
    "kiribati long jump racing federation": "الاتحاد الكيريباتي لسباق القفز الطويل",
    "korean long-distance running racing federation": "الاتحاد الكوري لسباق ركض المسافات الطويلة",
    "kosovan luge federation": "الاتحاد الكوسوفي للزحف الثلجي",
    "kosovar luge racing federation": "الاتحاد الكوسوفي لسباق الزحف الثلجي",
    "kuwaiti martial arts federation": "الاتحاد الكويتي للفنون القتالية",
    "kyrgyz martial arts racing federation": "الاتحاد القيرغيزي لسباق الفنون القتالية",
    "kyrgyzstani middle-distance running federation": "الاتحاد القيرغيزستاني لركض المسافات المتوسطة",
    "lao middle-distance running racing federation": "الاتحاد اللاوسي لسباق ركض المسافات المتوسطة",
    "laotian mixed martial arts federation": "الاتحاد اللاوسي لفنون القتال المختلطة",
    "latvian mixed martial arts racing federation": "الاتحاد اللاتفي لسباق فنون القتال المختلطة",
    "lebanese modern pentathlon federation": "الاتحاد اللبناني للخماسي الحديث",
    "lesotho modern pentathlon racing federation": "الاتحاد الليسوتي لسباق الخماسي الحديث",
    "liberian motocross federation": "الاتحاد الليبيري للموتو كروس",
    "libyan motocross racing federation": "الاتحاد الليبي لسباق موتو كروس",
    "liechtenstein motor federation": "الاتحاد الليختنشتاني للمحركات",
    "liechtensteiner motor racing federation": "الاتحاد الليختنشتاني لسباق المحركات",
    "lithuanian motorboat federation": "الاتحاد الليتواني للزوارق النارية",
    "luxembourg motorcycle federation": "الاتحاد اللوكسمبورغي للدراجات النارية",
    "luxembourgian motorcycle racing federation": "الاتحاد اللوكسمبورغي لسباق الدراجات النارية",
    "luxembourgish motorsport federation": "الاتحاد اللوكسمبورغي لرياضة المحركات",
    "macanese motorsport racing federation": "الاتحاد الماكاوي لسباق رياضة المحركات",
    "macedonian motorsports federation": "الاتحاد المقدوني لرياضة المحركات",
    "malagasy mountain bike racing federation": "الاتحاد المدغشقري لسباق الدراجات الجبلية",
    "malawian muay thai federation": "الاتحاد الملاوي للموياي تاي",
    "malaysian muay thai racing federation": "الاتحاد الماليزي لسباق موياي تاي",
    "malian netball federation": "الاتحاد المالي لكرة الشبكة",
    "maltese netball racing federation": "الاتحاد المالطي لسباق كرة الشبكة",
    "martiniquais orienteering federation": "الاتحاد المارتينيكي لسباق الموجه",
    "mauritanian pair skating federation": "الاتحاد الموريتاني للتزلج الفني على الجليد",
    "mauritian pair skating racing federation": "الاتحاد الموريشيوسي لسباق التزلج الفني على الجليد",
    "melanesian pencak silat federation": "الاتحاد الميلانيزي للبنكات سيلات",
    "mexican pentathlon federation": "الاتحاد المكسيكي للخماسي",
    "middle eastern pentathlon racing federation": "الاتحاد الشرقي الأوسطي لسباق الخماسي",
    "moldovan pesäpallo federation": "الاتحاد المولدوفي للبيسبالو",
    "mongolian poker racing federation": "الاتحاد المنغولي لسباق البوكر",
    "montenegrin pole vault federation": "الاتحاد المونتينيغري للقفز بالزانة",
    "montserratian pole vault racing federation": "الاتحاد المونتسراتي لسباق القفز بالزانة",
    "moravian polo racing federation": "الاتحاد المورافي لسباق البولو",
    "moroccan powerlifting federation": "الاتحاد المغربي لرياضة القوة",
    "mosotho powerlifting racing federation": "الاتحاد الليسوتي لسباق رياضة القوة",
    "mozambican professional wrestling federation": "الاتحاد الموزمبيقي لمصارعة المحترفين",
    "myanmarian racingxx federation": "الاتحاد الميانماري لسباق السيارات",
    "namibian racquetball federation": "الاتحاد الناميبي لكرة الراح",
    "nasovietna racquetball racing federation": "الاتحاد السوفييتي لسباق كرة الراح",
    "nauruan rally federation": "الاتحاد الناوروني للرالي",
    "nazis rally racing federation": "الاتحاد النازي لسباق الرالي",
    "nepalese rally raid federation": "الاتحاد النيبالي للرالي رايد",
    "nepali rally raid racing federation": "الاتحاد النيبالي لسباق الرالي رايد",
    "new zealanders rallying racing federation": "الاتحاد النيوزيلندي لسباق الراليات",
    "new zealanders relay race federation": "الاتحاد النيوزيلندي لسباق التتابع",
    "nicaraguan rhythmic gymnastics racing federation": "الاتحاد النيكاراغوي لسباق الجمباز الإيقاعي",
    "nigerian rifle shooting federation": "الاتحاد النيجيري لرماية البندقية",
    "nigerien rifle shooting racing federation": "الاتحاد النيجري لسباق رماية البندقية",
    "nordic road bicycle racing federation": "الاتحاد النوردي لسباق الدراجات على الطريق",
    "north african road cycling federation": "الاتحاد الإفريقي الشمالي لسباق الدراجات على الطريق",
    "north american road race federation": "الاتحاد الأمريكي الشمالي لسباق الدراجات على الطريق",
    "north macedonian roller hockey racing federation": "الاتحاد المقدوني الشمالي لسباق هوكي الدحرجة",
    "north yemeni roller hockey federation": "الاتحاد اليمني الشمالي لهوكي الدحرجة",
    "northern cypriot roller hockey racing federation": "الاتحاد القبرصي الشمالي لسباق هوكي الدحرجة",
    "northern ireland roller skating federation": "الاتحاد الأيرلندي الشمالي للتزلج بالعجلات",
    "norwegian roller skating racing federation": "الاتحاد النرويجي لسباق التزلج بالعجلات",
    "oceanian rowing racing federation": "الاتحاد الأوقيانوسي لسباق التجديف",
    "omani rugby federation": "الاتحاد العماني للرجبي",
    "ossetian rugby football federation": "الاتحاد الأوسيتي لكرة قدم الرجبي",
    "ottoman rugby football racing federation": "الاتحاد العثماني لسباق كرة قدم الرجبي",
    "pakistani rugby league federation": "الاتحاد الباكستاني لدوري الرجبي",
    "palauan rugby league racing federation": "الاتحاد البالاوي لسباق دوري الرجبي",
    "palestinian rugby racing federation": "الاتحاد الفلسطيني لسباق الرجبي",
    "panamanian rugby sevens federation": "الاتحاد البنمي لسباعيات الرجبي",
    "paraguayan rugby union federation": "الاتحاد البارغواياني لاتحاد الرجبي",
    "parthian rugby union racing federation": "الاتحاد الفرثي لسباق اتحاد الرجبي",
    "peruvian running racing federation": "الاتحاد البيروي لسباق الركض",
    "portuguese sailing federation": "الاتحاد البرتغالي للإبحار",
    "prussian sailing racing federation": "الاتحاد البروسي لسباق الإبحار",
    "puerto rican sambo racing federation": "الاتحاد البورتوريكي لسباق سامبو",
    "qatari sepak takraw federation": "الاتحاد القطري للسيباك تاكرو",
    "rhodesian shooting racing federation": "الاتحاد الرودوسي لسباق الرماية",
    "roman shooting sport racing federation": "الاتحاد الروماني لسباق الرماية",
    "romanian shooting sports federation": "الاتحاد الروماني للرماية",
    "russian short track speed skating federation": "الاتحاد الروسي للتزلج على مسار قصير",
    "russians short track speed skating racing federation": "الاتحاد الروسي لسباق التزلج على مسار قصير",
    "rwandan shot put federation": "الاتحاد الرواندي لدفع الثقل",
    "sahrawi show jumping federation": "الاتحاد الصحراوي لقفز الحواجز",
    "salvadoran show jumping racing federation": "الاتحاد السلفادوري لسباق قفز الحواجز",
    "salvadorean silat federation": "الاتحاد السلفادوري للسيلات",
    "sammarinese silat racing federation": "الاتحاد السان الماريني لسباق سيلات",
    "samoan single skating federation": "الاتحاد الساموي للتزلج الفردي على الجليد",
    "sasanian skateboarding federation": "الاتحاد الساساني للتزلج على اللوح",
    "saudi skateboarding racing federation": "الاتحاد السعودي لسباق التزلج على اللوح",
    "saudiarabian skating federation": "الاتحاد السعودي للتزلج",
    "scottish skating racing federation": "الاتحاد الإسكتلندي لسباق التزلج",
    "senegalese skeleton federation": "الاتحاد السنغالي للزلاجات الصدرية",
    "serbian skeleton racing federation": "الاتحاد الصربي لسباق الزلاجات الصدرية",
    "seychellois ski flying federation": "الاتحاد السيشلي لتزلج طائر",
    "sierra leonean ski flying racing federation": "الاتحاد السيراليوني لسباق التزلج الطائر",
    "singapore ski jumping federation": "الاتحاد السنغافوري للقفز التزلجي",
    "singaporean ski jumping racing federation": "الاتحاد السنغافوري لسباق القفز التزلجي",
    "slovak skiing federation": "الاتحاد السلوفاكي للتزلج",
    "slovakian skiing racing federation": "الاتحاد السلوفاكي لسباق التزلج",
    "slovene sledge hockey federation": "الاتحاد السلوفيني لهوكي المزلجة",
    "slovenian sledge hockey racing federation": "الاتحاد السلوفيني لسباق هوكي المزلجة",
    "somali snooker federation": "الاتحاد الصومالي للسنوكر",
    "somalian snooker racing federation": "الاتحاد الصومالي لسباق السنوكر",
    "south sudanese soft tennis federation": "الاتحاد السوداني الجنوبي لكرة المضرب اللينة",
    "southeast asian softball federation": "الاتحاد الآسيوي الجنوبي الشرقي للكرة اللينة",
    "south american snowboarding racing federation": "الاتحاد الأمريكي الجنوبي لسباق التزلج على الثلوج",
    "south korean soccer federation": "الاتحاد الكوري الجنوبي لكرة القدم",
    "south ossetian soccer racing federation": "الاتحاد الأوسيتي لسباق كرة القدم",
    "south yemeni soft tennis racing federation": "الاتحاد اليمني الجنوبي لسباق كرة المضرب اللينة",
    "southern european softball racing federation": "الاتحاد الأوروبي الجنوبي لسباق الكرة اللينة",
    "southwest asian speed skating federation": "الاتحاد الآسيوي الجنوبي الغربي لتزلج السريع",
    "soviet speed skating racing federation": "الاتحاد السوفيتي لسباق التزلج السريع",
    "spanish speed skiing federation": "الاتحاد الإسباني للتزلج السريع",
    "sri lankan speed skiing racing federation": "الاتحاد السريلانكي لسباق التزلج السريع",
    "sudanese sport climbing federation": "الاتحاد السوداني للتسلق",
    "swazi sprinting federation": "الاتحاد السوازيلندي للجري السريع",
    "swedish sprinting racing federation": "الاتحاد السويدي لسباق الجري السريع",
    "swiss squash federation": "الاتحاد السويسري للاسكواش",
    "syrian squash racing federation": "الاتحاد السوري لسباق اسكواش",
    "são toméan submission wrestling federation": "الاتحاد الساوتومي لمصارعة الخضوع",
    "taiwanese sumo racing federation": "الاتحاد التايواني لسباق السومو",
    "tajikistani surfing federation": "الاتحاد الطاجيكي للركمجة",
    "tanzanian swimming federation": "الاتحاد التنزاني للسباحة",
    "thai synchronised swimming federation": "الاتحاد التايلندي للسباحة المتزامنة",
    "republic-of ireland synchronized swimming federation": "الاتحاد الأيرلندي للسباحة المتزامنة",
    "timorese synchronized swimming racing federation": "الاتحاد التيموري لسباق السباحة المتزامنة",
    "togolese table tennis federation": "الاتحاد التوغوي لكرة الطاولة",
    "tongan table tennis racing federation": "الاتحاد التونغاني لسباق كرة الطاولة",
    "trinidad and tobago taekwondo federation": "الاتحاد الترنيدادي للتايكوندو",
    "trinidadian taekwondo racing federation": "الاتحاد الترنيدادي لسباق التايكوندو",
    "trinidadians tennis federation": "الاتحاد الترنيدادي لكرة المضرب",
    "tunisian tennis racing federation": "الاتحاد التونسي لسباق كرة المضرب",
    "turkish cypriot track and field federation": "الاتحاد القبرصي الشمالي لسباقات المضمار والميدان",
    "turkish time trial federation": "الاتحاد التركي لسباق الدراجات ضد الساعة",
    "turkmen track cycling federation": "الاتحاد التركماني لسباق الدراجات على المضمار",
    "turkmenistan track-and-field athletics federation": "الاتحاد التركماني لألعاب قوى المضمار والميدان",
    "turkmenistani track-and-field athletics racing federation": "الاتحاد التركماني لسباق ألعاب قوى المضمار والميدان",
    "tuvaluan trampolining federation": "الاتحاد التوفالي لجمباز القفز",
    "ugandan triathlon federation": "الاتحاد الأوغندي للسباق الثلاثي",
    "ukrainian triple jump federation": "الاتحاد الأوكراني للقفز الثلاثي",
    "uruguayan uiiu 22 formula e season racing federation": "الاتحاد الأوروغوياني لسباق موسم فورمولا إي",
    "uzbek underwater hockey federation": "الاتحاد الأوزبكي للهوكي تحت الماء",
    "uzbekistani underwater hockey racing federation": "الاتحاد الأوزبكستاني لسباق هوكي تحت الماء",
    "vanuatuan volleyball federation": "الاتحاد الفانواتي لكرة الطائرة",
    "vatican volleyball racing federation": "الاتحاد الفاتيكاني لسباق كرة الطائرة",
    "venezuelan water polo federation": "الاتحاد الفنزويلي لكرة الماء",
    "victorian water polo racing federation": "الاتحاد الفيكتوري لسباق كرة الماء",
    "vietnamese water skiing federation": "الاتحاد الفيتنامي لتزلج على الماء",
    "vietnamesei water skiing racing federation": "الاتحاد الفيتنامي لسباق التزلج على الماء",
    "welsh waterskiing federation": "الاتحاد الويلزي للتزلج على الماء",
    "west german waterskiing racing federation": "الاتحاد الألماني الغربي لسباق التزلج على الماء",
    "western canadian weightlifting racing federation": "الاتحاد الكندي الغربي لسباق رفع الأثقال",
    "yemeni wheelchair beach handball federation": "الاتحاد اليمني لكرة اليد الشاطئية على الكراسي المتحركة",
    "yemenite wheelchair curling federation": "الاتحاد اليمني للكيرلنغ على الكراسي المتحركة",
    "yoruba wheelchair fencing federation": "الاتحاد اليوروبي لمبارزة سيف الشيش على الكراسي المتحركة",
    "yugoslav wheelchair handball federation": "الاتحاد اليوغسلافي لكرة اليد على الكراسي المتحركة",
    "zambian wheelchair rugby federation": "الاتحاد الزامبي للرجبي على الكراسي المتحركة",
    "zanzibari wheelchair rugby league federation": "الاتحاد الزنجباري لدوري الرجبي على الكراسي المتحركة",
    "zimbabwean wheelchair tennis federation": "الاتحاد الزيمبابوي لكرة المضرب على الكراسي المتحركة",
    "zulu windsurfing federation": "الاتحاد الزولي لركوب القوارب الشراعية",
    "north korean roller hockey federation": "الاتحاد الكوري الشمالي لهوكي الدحرجة",
}


@pytest.mark.parametrize(
    "category, expected_key", the_male_sport_team_data.items(), ids=the_male_sport_team_data.keys()
)
@pytest.mark.fast
def test_the_male_sport_team_data(category: str, expected_key: str) -> None:
    label2 = resolve_nats_sport_multi_v2(category)
    assert label2 == expected_key


TEMPORAL_CASES = [
    ("test_the_male_sport_team_data", the_male_sport_team_data, resolve_nats_sport_multi_v2),
]


@pytest.mark.dump
@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback, do_strip=True)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
