#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_label_ar

data_skip = {
    "January 2021 in Antigua and Barbuda": "أنتيغوا وباربودا في يناير 2021",
    "November 2018 in Antigua and Barbuda": "أنتيغوا وباربودا في نوفمبر 2018",
    "October 2023 in Antigua and Barbuda": "أنتيغوا وباربودا في أكتوبر 2023",
    "March 2018 in Antigua and Barbuda": "أنتيغوا وباربودا في مارس 2018",
    "March 2021 in Antigua and Barbuda": "أنتيغوا وباربودا في مارس 2021",
    "March 2023 in Antigua and Barbuda": "أنتيغوا وباربودا في مارس 2023",
    "Antigua and Barbuda and the Commonwealth of Nations": "x",
    "Antigua and Barbuda articles by importance": "x",
    "Antigua and Barbuda articles by quality": "x",
    "Antigua and Barbuda at the Junior Pan American Games": "x",
    "Antigua and Barbuda aviation law": "x",
    "Antigua and Barbuda beauty pageant winners": "x",
    "Antigua and Barbuda calypsonians": "x",
    "Antigua and Barbuda court system": "x",
    "Antigua and Barbuda cricket people": "x",
    "Antigua and Barbuda dressage riders": "x",
    "Antigua and Barbuda evangelicals": "x",
    "Antigua and Barbuda fiction": "x",
    "Antigua and Barbuda Football Association competitions": "x",
    "Antigua and Barbuda geography-related lists": "x",
    "Antigua and Barbuda judges on the courts of Anguilla": "x",
    "Antigua and Barbuda judges on the courts of Belize": "x",
    "Antigua and Barbuda judges on the courts of Grenada": "x",
    "Antigua and Barbuda judges on the courts of Montserrat": "x",
    "Antigua and Barbuda judges on the courts of Saint Lucia": "x",
    "Antigua and Barbuda knights": "x",
    "Antigua and Barbuda Labour Party politicians": "x",
    "Antigua and Barbuda location map modules": "x",
    "Antigua and Barbuda masters athletes": "x",
    "Antigua and Barbuda modules": "x",
    "Antigua and Barbuda people of Saint Kitts and Nevis descent": "x",
    "Antigua and Barbuda Protestants": "x",
    "Antigua and Barbuda records": "x",
    "Antigua and Barbuda religion-related lists": "x",
    "Antigua and Barbuda Salvationists": "x",
    "Antigua and Barbuda Seventh-day Adventists": "x",
    "Antigua and Barbuda slave owners": "x",
    "Antigua and Barbuda social democrats": "x",
    "Antigua and Barbuda stub templates": "x",
    "Antigua and Barbuda transport-related lists": "x",
    "Antigua and Barbuda user categories": "x",
    "Antigua and Barbuda user templates": "x",
    "Antigua and Barbuda Wikipedians": "x",
    "Antigua and Barbuda–Holy See relations": "x",
    "Apostolic nuncios to Antigua and Barbuda": "x",
    "Australian judges on the courts of Antigua and Barbuda": "x",
    "Baroque architecture in Antigua and Barbuda": "x",
    "Beauty pageants in Antigua and Barbuda": "x",
    "Bilateral sports relations of Antigua and Barbuda": "x",
    "Bird family (Antigua and Barbuda)": "x",
    "British judges on the courts of Antigua and Barbuda": "x",
    "British Virgin Islands expatriates in Antigua and Barbuda": "x",
    "British Virgin Islands judges on the courts of Antigua and Barbuda": "x",
    "Buildings and structures in Saint John Parish, Antigua and Barbuda": "x",
    "By-elections in Antigua and Barbuda": "x",
    "Catholic Church in Antigua and Barbuda": "x",
    "Catholic secondary schools in Antigua and Barbuda": "x",
    "Constitution of Antigua and Barbuda": "x",
    "Country data templates of Antigua and Barbuda": "x",
    "Cricket grounds in Antigua and Barbuda": "x",
    "Dominica expatriate sportspeople in Antigua and Barbuda": "x",
    "Dominica expatriates in Antigua and Barbuda": "x",
    "Dominica judges on the courts of Antigua and Barbuda": "x",
    "Dominica people of Antigua and Barbuda descent": "x",
    "Dominican Republic expatriate sportspeople in Antigua and Barbuda": "x",
    "Education, sports and creative industries ministers of Antigua and Barbuda": "x",
    "Emergency services in Antigua and Barbuda": "x",
    "Endemic birds of Antigua and Barbuda": "x",
    "Endemic fauna of Antigua and Barbuda": "x",
    "Expatriate judges on the courts of Antigua and Barbuda": "x",
    "Federalism in Antigua and Barbuda": "x",
    "Folk festivals in Antigua and Barbuda": "x",
    "Ghanaian judges on the courts of Antigua and Barbuda": "x",
    "Girls' schools in Antigua and Barbuda": "x",
    "Guyanese judges on the courts of Antigua and Barbuda": "x",
    "High commissioners of Antigua and Barbuda": "x",
    "High commissioners of Antigua and Barbuda to Canada": "x",
    "High commissioners of Antigua and Barbuda to Saint Kitts and Nevis": "x",
    "High commissioners of Antigua and Barbuda to the United Kingdom": "x",
    "High commissioners of Australia to Antigua and Barbuda": "x",
    "High commissioners of Canada to Antigua and Barbuda": "x",
    "High commissioners of India to Antigua and Barbuda": "x",
    "High commissioners of South Africa to Antigua and Barbuda": "x",
    "High commissioners of the United Kingdom to Antigua and Barbuda": "x",
    "High commissioners to Antigua and Barbuda": "x",
    "High schools and secondary schools in Antigua and Barbuda": "x",
    "History of sport in Antigua and Barbuda": "x",
    "Hurricanes in Antigua and Barbuda": "x",
    "Important Bird Areas of Antigua and Barbuda": "x",
    "Jamaican judges on the courts of Antigua and Barbuda": "x",
    "John Hughes, Antigua and Barbuda": "x",
    "Judicial Committee of the Privy Council cases on appeal from Antigua and Barbuda": "x",
    "Major divisions of Antigua and Barbuda": "x",
    "Members of the 14th legislature of Antigua and Barbuda": "x",
    "Members of the 15th legislature of Antigua and Barbuda": "x",
    "Members of the 16th legislature of Antigua and Barbuda": "x",
    "Members of the House of Representatives (Antigua and Barbuda)": "x",
    "Merchant ships of Antigua and Barbuda": "x",
    "Micronations in Antigua and Barbuda": "x",
    "Monarchy of Antigua and Barbuda": "x",
    "National Cultural Heritage of Antigua and Barbuda": "x",
    "National Security Council (Antigua and Barbuda)": "x",
    "Olympic sailors for Antigua and Barbuda": "x",
    "Parades in Antigua and Barbuda": "x",
    "Parliaments of Antigua and Barbuda": "x",
    "People from Saint George, Antigua and Barbuda": "x",
    "People from Saint John, Antigua and Barbuda": "x",
    "People from Saint Mary, Antigua and Barbuda": "x",
    "People from Saint Paul, Antigua and Barbuda": "x",
    "People from Saint Peter, Antigua and Barbuda": "x",
    "People from Saint Philip, Antigua and Barbuda": "x",
    "Permanent representatives of Antigua and Barbuda to the World Trade Organization": "x",
    "Places in Saint John Parish, Antigua and Barbuda": "x",
    "Private islands of Antigua and Barbuda": "x",
    "Ramsar sites in Antigua and Barbuda": "x",
    "Recipients of the Order of the Nation (Antigua and Barbuda)": "x",
    "Recipients of the Order of the National Hero (Antigua and Barbuda)": "x",
    "Republicanism in Antigua and Barbuda": "x",
    "Saint George, Antigua and Barbuda": "x",
    "Saint John, Antigua and Barbuda": "x",
    "Saint Kitts and Nevis expatriates in Antigua and Barbuda": "x",
    "Saint Kitts and Nevis judges on the courts of Antigua and Barbuda": "x",
    "Saint Kitts and Nevis people of Antigua and Barbuda descent": "x",
    "Saint Lucian expatriates in Antigua and Barbuda": "x",
    "Saint Lucian judges on the courts of Antigua and Barbuda": "x",
    "Saint Lucian people of Antigua and Barbuda descent": "x",
    "Saint Mary, Antigua and Barbuda": "x",
    "Saint Paul, Antigua and Barbuda": "x",
    "Saint Peter, Antigua and Barbuda": "x",
    "Saint Philip, Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines expatriate sportspeople in Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines expatriates in Antigua and Barbuda": "x",
    "Saint Vincent and the Grenadines judges on the courts of Antigua and Barbuda": "x",
    "Scouting and Guiding in Antigua and Barbuda": "x",
    "Serbia and Montenegro expatriate sportspeople in Antigua and Barbuda": "x",
    "Socialism in Antigua and Barbuda": "x",
    "Speakers of the House of Representatives (Antigua and Barbuda)": "x",
    "United States Virgin Islands people of Antigua and Barbuda descent": "x",
    "Women ambassadors of Antigua and Barbuda": "x",
    "World Athletics Championships athletes for Antigua and Barbuda": "x",
}

data_0 = {
    "Antigua and Barbuda men athletes": "لاعبو قوى أنتيغويون وبربوديون",
    "Antigua and Barbuda men centenarians": "مئويون أنتيغويون وبربوديون",
    "Antigua and Barbuda men high jumpers": "متسابقو قفز عالي أنتيغويون وبربوديون",
    "Antigua and Barbuda men hurdlers": "لاعبو قفز الحواجز أنتيغويون وبربوديون",
    "Antigua and Barbuda men long jumpers": "لاعبو قفز طويل أنتيغويون وبربوديون",
    "Antigua and Barbuda men middle-distance runners": "عداؤو مسافات متوسطة أنتيغويون وبربوديون",
    "Antigua and Barbuda men sprinters": "عداؤون سريعون أنتيغويون وبربوديون",
    "Antigua and Barbuda men triple jumpers": "لاعبو وثب ثلاثي أنتيغويون وبربوديون",
    "Antigua and Barbuda men": "رجال أنتيغويون وبربوديون",
    "Antigua and Barbuda men's basketball players": "لاعبو كرة سلة أنتيغويون وبربوديون",
    "Antigua and Barbuda male actors": "ممثلون ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male boxers": "ملاكمون ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male canoeists": "متسابقو قوارب الكانوي ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male cyclists": "دراجون ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male freestyle swimmers": "سباحو تزلج حر ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male sailors (sport)": "بحارة رياضيون ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male swimmers": "سباحون ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda male tennis players": "لاعبو كرة مضرب ذكور أنتيغويون وبربوديون",
    "Antigua and Barbuda men's footballers": "لاعبو كرة قدم أنتيغويون وبربوديون",
    "Men's footballers in Antigua and Barbuda by club": "لاعبو كرة قدم في أنتيغوا وباربودا حسب النادي",
    "Antigua and Barbuda expatriate footballers": "لاعبو كرة قدم أنتيغويون وبربوديون مغتربون",
    "Antigua and Barbuda expatriate men's footballers": "لاعبو كرة قدم أنتيغويون وبربوديون مغتربون",
}

data_1 = {
    "21st-century Antigua and Barbuda politicians": "سياسيون أنتيغويون وبربوديون في القرن 21",
    "21st-century Antigua and Barbuda people": "أنتيغويون وبربوديون في القرن 21",
    "New Zealand emigrants to Antigua and Barbuda": "نيوزيلنديون مهاجرون إلى أنتيغوا وباربودا",
    "Paralympic competitors for Antigua and Barbuda": "منافسون بارالمبيون من أنتيغوا وباربودا",
    "Antigua and Barbuda people of New Zealand descent": "أنتيغويون وبربوديون من أصل نيوزيلندي",
    "Antigua and Barbuda sportsmen": "رياضيون رجال أنتيغويون وبربوديون",
    "21st-century Antigua and Barbuda sportsmen": "رياضيون رجال أنتيغويون وبربوديون في القرن 21",
    "Antigua and Barbuda clergy": "رجال دين أنتيغويون وبربوديون",
    "Men in Antigua and Barbuda": "رجال في أنتيغوا وباربودا",
    "1930s establishments in Antigua and Barbuda": "تأسيسات عقد 1930 في أنتيغوا وباربودا",
    "1930s in Antigua and Barbuda": "أنتيغوا وباربودا في عقد 1930",
    "1939 establishments in Antigua and Barbuda": "تأسيسات سنة 1939 في أنتيغوا وباربودا",
    "1939 in Antigua and Barbuda": "أنتيغوا وباربودا في 1939",
    "1940s establishments in Antigua and Barbuda": "تأسيسات عقد 1940 في أنتيغوا وباربودا",
    "1940s in Antigua and Barbuda": "أنتيغوا وباربودا في عقد 1940",
    "1946 in Antigua and Barbuda": "أنتيغوا وباربودا في 1946",
    "1947 establishments in Antigua and Barbuda": "تأسيسات سنة 1947 في أنتيغوا وباربودا",
    "1947 in Antigua and Barbuda": "أنتيغوا وباربودا في 1947",
    "1950s in Antigua and Barbuda": "أنتيغوا وباربودا في عقد 1950",
    "1951 in Antigua and Barbuda": "أنتيغوا وباربودا في 1951",
    "1956 in Antigua and Barbuda": "أنتيغوا وباربودا في 1956",
    "1960 establishments in Antigua and Barbuda": "تأسيسات سنة 1960 في أنتيغوا وباربودا",
    "1960 in Antigua and Barbuda": "أنتيغوا وباربودا في 1960",
    "1960s disestablishments in Antigua and Barbuda": "انحلالات عقد 1960 في أنتيغوا وباربودا",
    "1965 establishments in Antigua and Barbuda": "تأسيسات سنة 1965 في أنتيغوا وباربودا",
    "1965 in Antigua and Barbuda": "أنتيغوا وباربودا في 1965",
    "1966 establishments in Antigua and Barbuda": "تأسيسات سنة 1966 في أنتيغوا وباربودا",
    "1966 in Antigua and Barbuda": "أنتيغوا وباربودا في 1966",
    "1967 disestablishments in Antigua and Barbuda": "انحلالات سنة 1967 في أنتيغوا وباربودا",
    "1967 in Antigua and Barbuda": "أنتيغوا وباربودا في 1967",
    "1968 in Antigua and Barbuda": "أنتيغوا وباربودا في 1968",
    "1969 establishments in Antigua and Barbuda": "تأسيسات سنة 1969 في أنتيغوا وباربودا",
    "1969 in Antigua and Barbuda": "أنتيغوا وباربودا في 1969",
    "1971 establishments in Antigua and Barbuda": "تأسيسات سنة 1971 في أنتيغوا وباربودا",
    "1971 in Antigua and Barbuda": "أنتيغوا وباربودا في 1971",
    "1978 in Antigua and Barbuda": "أنتيغوا وباربودا في 1978",
    "1979 establishments in Antigua and Barbuda": "تأسيسات سنة 1979 في أنتيغوا وباربودا",
    "1979 in Antigua and Barbuda": "أنتيغوا وباربودا في 1979",
    "1980 establishments in Antigua and Barbuda": "تأسيسات سنة 1980 في أنتيغوا وباربودا",
    "1980 in Antigua and Barbuda": "أنتيغوا وباربودا في 1980",
    "1980s disestablishments in Antigua and Barbuda": "انحلالات عقد 1980 في أنتيغوا وباربودا",
    "1980s in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في عقد 1980",
    "1981 disestablishments in Antigua and Barbuda": "انحلالات سنة 1981 في أنتيغوا وباربودا",
    "1982 establishments in Antigua and Barbuda": "تأسيسات سنة 1982 في أنتيغوا وباربودا",
    "1982 in Antigua and Barbuda": "أنتيغوا وباربودا في 1982",
    "1983 in Antigua and Barbuda": "أنتيغوا وباربودا في 1983",
    "1983 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1983",
    "1984 in Antigua and Barbuda": "أنتيغوا وباربودا في 1984",
    "1986 disestablishments in Antigua and Barbuda": "انحلالات سنة 1986 في أنتيغوا وباربودا",
    "1986 establishments in Antigua and Barbuda": "تأسيسات سنة 1986 في أنتيغوا وباربودا",
    "1986 in Antigua and Barbuda": "أنتيغوا وباربودا في 1986",
    "1987 establishments in Antigua and Barbuda": "تأسيسات سنة 1987 في أنتيغوا وباربودا",
    "1987 in Antigua and Barbuda": "أنتيغوا وباربودا في 1987",
    "1988 establishments in Antigua and Barbuda": "تأسيسات سنة 1988 في أنتيغوا وباربودا",
    "1988 in Antigua and Barbuda": "أنتيغوا وباربودا في 1988",
    "1989 in Antigua and Barbuda": "أنتيغوا وباربودا في 1989",
    "1990s disestablishments in Antigua and Barbuda": "انحلالات عقد 1990 في أنتيغوا وباربودا",
    "1990s in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في عقد 1990",
    "1991 establishments in Antigua and Barbuda": "تأسيسات سنة 1991 في أنتيغوا وباربودا",
    "1991 in Antigua and Barbuda": "أنتيغوا وباربودا في 1991",
    "1992 disestablishments in Antigua and Barbuda": "انحلالات سنة 1992 في أنتيغوا وباربودا",
    "1992 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1992",
    "1994 in Antigua and Barbuda": "أنتيغوا وباربودا في 1994",
    "1995 establishments in Antigua and Barbuda": "تأسيسات سنة 1995 في أنتيغوا وباربودا",
    "1995 in Antigua and Barbuda": "أنتيغوا وباربودا في 1995",
    "1995 in Antigua and Barbuda law": "قانون أنتيغوي وبربودي في 1995",
    "1996 in Antigua and Barbuda": "أنتيغوا وباربودا في 1996",
    "1996 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1996",
    "1997 in Antigua and Barbuda": "أنتيغوا وباربودا في 1997",
    "1997 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1997",
    "1998 establishments in Antigua and Barbuda": "تأسيسات سنة 1998 في أنتيغوا وباربودا",
    "1998 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1998",
    "1999 establishments in Antigua and Barbuda": "تأسيسات سنة 1999 في أنتيغوا وباربودا",
    "1999 in Antigua and Barbuda": "أنتيغوا وباربودا في 1999",
    "1999 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 1999",
    "2000 in Antigua and Barbuda": "أنتيغوا وباربودا في 2000",
    "2000 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2000",
    "2000s disestablishments in Antigua and Barbuda": "انحلالات عقد 2000 في أنتيغوا وباربودا",
    "2000s in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في عقد 2000",
    "2001 establishments in Antigua and Barbuda": "تأسيسات سنة 2001 في أنتيغوا وباربودا",
    "2001 in Antigua and Barbuda": "أنتيغوا وباربودا في 2001",
    "2002 in Antigua and Barbuda": "أنتيغوا وباربودا في 2002",
    "2002 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2002",
    "2003 in Antigua and Barbuda law": "قانون أنتيغوي وبربودي في 2003",
    "2004 establishments in Antigua and Barbuda": "تأسيسات سنة 2004 في أنتيغوا وباربودا",
    "2004 in Antigua and Barbuda": "أنتيغوا وباربودا في 2004",
    "2004 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2004",
    "2005 in Antigua and Barbuda": "أنتيغوا وباربودا في 2005",
    "2005 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2005",
    "2006 in Antigua and Barbuda law": "قانون أنتيغوي وبربودي في 2006",
    "2006 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2006",
    "2007 in Antigua and Barbuda": "أنتيغوا وباربودا في 2007",
    "2007 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2007",
    "2008 in Antigua and Barbuda": "أنتيغوا وباربودا في 2008",
    "2008 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2008",
    "2009 disestablishments in Antigua and Barbuda": "انحلالات سنة 2009 في أنتيغوا وباربودا",
    "2009 in Antigua and Barbuda": "أنتيغوا وباربودا في 2009",
    "2009 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2009",
    "2010 in Antigua and Barbuda": "أنتيغوا وباربودا في 2010",
    "2010 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2010",
    "2010s disestablishments in Antigua and Barbuda": "انحلالات عقد 2010 في أنتيغوا وباربودا",
    "2010s establishments in Antigua and Barbuda": "تأسيسات عقد 2010 في أنتيغوا وباربودا",
    "2010s in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في عقد 2010",
    "2011 in Antigua and Barbuda": "أنتيغوا وباربودا في 2011",
    "2011 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2011",
    "2012 in Antigua and Barbuda": "أنتيغوا وباربودا في 2012",
    "2012 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2012",
    "2013 establishments in Antigua and Barbuda": "تأسيسات سنة 2013 في أنتيغوا وباربودا",
    "2013 in Antigua and Barbuda": "أنتيغوا وباربودا في 2013",
    "2013 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2013",
    "2014 in Antigua and Barbuda": "أنتيغوا وباربودا في 2014",
    "2014 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2014",
    "2015 disestablishments in Antigua and Barbuda": "انحلالات سنة 2015 في أنتيغوا وباربودا",
    "2015 in Antigua and Barbuda": "أنتيغوا وباربودا في 2015",
    "2015 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2015",
    "2016 in Antigua and Barbuda": "أنتيغوا وباربودا في 2016",
    "2016 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2016",
    "2017 in Antigua and Barbuda": "أنتيغوا وباربودا في 2017",
    "2017 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2017",
    "2018 in Antigua and Barbuda": "أنتيغوا وباربودا في 2018",
    "2018 in Antigua and Barbuda by month": "أنتيغوا وباربودا في 2018 حسب الشهر",
    "2018 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2018",
    "2019 in Antigua and Barbuda": "أنتيغوا وباربودا في 2019",
    "2019 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2019",
    "2020 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2020",
    "2020s in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في عقد 2020",
    "2021 in Antigua and Barbuda by month": "أنتيغوا وباربودا في 2021 حسب الشهر",
    "2021 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2021",
    "2022 in Antigua and Barbuda": "أنتيغوا وباربودا في 2022",
    "2022 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2022",
    "2023 in Antigua and Barbuda": "أنتيغوا وباربودا في 2023",
    "2023 in Antigua and Barbuda by month": "أنتيغوا وباربودا في 2023 حسب الشهر",
    "2023 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2023",
    "2024 in Antigua and Barbuda": "أنتيغوا وباربودا في 2024",
    "2024 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2024",
    "2025 in Antigua and Barbuda": "أنتيغوا وباربودا في 2025",
    "2025 in Antigua and Barbuda sport": "رياضة أنتيغوية وبربودية في 2025",
    "2026 in Antigua and Barbuda": "أنتيغوا وباربودا في 2026",
    "20th-century disestablishments in Antigua and Barbuda": "انحلالات القرن 20 في أنتيغوا وباربودا",
    "21st-century disestablishments in Antigua and Barbuda": "انحلالات القرن 21 في أنتيغوا وباربودا",
    "2nd-millennium disestablishments in Antigua and Barbuda": "انحلالات الألفية 2 في أنتيغوا وباربودا",
    "3rd-millennium disestablishments in Antigua and Barbuda": "انحلالات الألفية 3 في أنتيغوا وباربودا",
    "Airlines of Antigua and Barbuda": "شركات طيران في أنتيغوا وباربودا",
    "Ambassadors of Antigua and Barbuda to Estonia": "سفراء أنتيغوا وباربودا لدى إستونيا",
    "Ambassadors of Antigua and Barbuda to France": "سفراء أنتيغوا وباربودا لدى فرنسا",
    "Ambassadors of Antigua and Barbuda to Germany": "سفراء أنتيغوا وباربودا لدى ألمانيا",
    "Ambassadors of Antigua and Barbuda to Israel": "سفراء أنتيغوا وباربودا لدى إسرائيل",
    "Ambassadors of Antigua and Barbuda to Italy": "سفراء أنتيغوا وباربودا لدى إيطاليا",
    "Ambassadors of Antigua and Barbuda to Russia": "سفراء أنتيغوا وباربودا لدى روسيا",
    "Ambassadors of Antigua and Barbuda to Spain": "سفراء أنتيغوا وباربودا لدى إسبانيا",
    "Ambassadors of Antigua and Barbuda to the United States": "سفراء أنتيغوا وباربودا لدى الولايات المتحدة",
    "Ambassadors of China to Antigua and Barbuda": "سفراء الصين لدى أنتيغوا وباربودا",
    "Ambassadors of Israel to Antigua and Barbuda": "سفراء إسرائيل لدى أنتيغوا وباربودا",
    "Ambassadors of Japan to Antigua and Barbuda": "سفراء اليابان لدى أنتيغوا وباربودا",
    "Ambassadors of Poland to Antigua and Barbuda": "سفراء بولندا لدى أنتيغوا وباربودا",
    "American people of Antigua and Barbuda descent": "أمريكيون من أصل أنتيغوي وبربودي",
    "Amphibians of Antigua and Barbuda": "برمائيات أنتيغوا وباربودا",
    "Anguillan emigrants to Antigua and Barbuda": "أنغويلانيون مهاجرون إلى أنتيغوا وباربودا",
    "Antigua and Barbuda activists": "ناشطون أنتيغويون وبربوديون",
    "Antigua and Barbuda actors": "ممثلون أنتيغويون وبربوديون",
    "Antigua and Barbuda amputees": "أنتيغويون وبربوديون مبتورو أحد الأطراف",
    "Antigua and Barbuda artists": "فنانون أنتيغويون وبربوديون",
    "Antigua and Barbuda at the Pan American Games": "أنتيغوا وباربودا في دورة الألعاب الأمريكية",
    "Antigua and Barbuda at the Paralympics": "أنتيغوا وباربودا في الألعاب البارالمبية",
    "Antigua and Barbuda at the World Athletics Championships": "أنتيغوا وباربودا في بطولة العالم لألعاب القوى",
    "Antigua and Barbuda at the Youth Olympics": "أنتيغوا وباربودا في الألعاب الأولمبية الشبابية",
    "Antigua and Barbuda athletes": "لاعبو قوى أنتيغويون وبربوديون",
    "Antigua and Barbuda awards": "جوائز أنتيغوية وبربودية",
    "Antigua and Barbuda bankers": "مصرفيون أنتيغويون وبربوديون",
    "Antigua and Barbuda basketball players": "لاعبو كرة سلة أنتيغويون وبربوديون",
    "Antigua and Barbuda bishops": "أساقفة أنتيغويون وبربوديون",
    "Antigua and Barbuda boxers": "ملاكمون أنتيغويون وبربوديون",
    "Antigua and Barbuda businesspeople": "شخصيات أعمال أنتيغوية وبربودية",
    "Antigua and Barbuda businesswomen": "سيدات أعمال أنتيغويات وبربوديات",
    "Antigua and Barbuda canoeists": "متسابقو قوارب الكانوي أنتيغويون وبربوديون",
    "Antigua and Barbuda centenarians": "مئويون أنتيغويون وبربوديون",
    "Antigua and Barbuda Christians": "أنتيغويون وبربوديون مسيحيون",
    "Antigua and Barbuda communications-related lists": "قوائم متعلقة بالاتصالات الأنتيغوية والبربودية",
    "Antigua and Barbuda competitors by sports event": "منافسون أنتيغويون وبربوديون حسب الحدث الرياضي",
    "Antigua and Barbuda cricket coaches": "مدربو كريكت أنتيغويون وبربوديون",
    "Antigua and Barbuda criminals": "مجرمون أنتيغويون وبربوديون",
    "Antigua and Barbuda cuisine": "مطبخ أنتيغوي وبربودي",
    "Antigua and Barbuda cyclists": "دراجون أنتيغويون وبربوديون",
    "Antigua and Barbuda diaspora": "شتات أنتيغوي وبربودي",
    "Antigua and Barbuda diplomacy-related lists": "قوائم متعلقة بالدبلوماسية الأنتيغوية والبربودية",
    "Antigua and Barbuda diplomats": "دبلوماسيون أنتيغويون وبربوديون",
    "Antigua and Barbuda dramatists and playwrights": "كتاب دراما ومسرح أنتيغويون وبربوديون",
    "Antigua and Barbuda drug traffickers": "تجار مخدرات أنتيغويون وبربوديون",
    "Antigua and Barbuda economists": "اقتصاديون أنتيغويون وبربوديون",
    "Antigua and Barbuda educators": "معلمون أنتيغويون وبربوديون",
    "Antigua and Barbuda emigrants": "أنتيغويون وبربوديون مهاجرون",
    "Antigua and Barbuda emigrants to Bermuda": "أنتيغويون وبربوديون مهاجرون إلى برمودا",
    "Antigua and Barbuda emigrants to Canada": "أنتيغويون وبربوديون مهاجرون إلى كندا",
    "Antigua and Barbuda emigrants to England": "أنتيغويون وبربوديون مهاجرون إلى إنجلترا",
    "Antigua and Barbuda emigrants to Saint Kitts and Nevis": "أنتيغويون وبربوديون مهاجرون إلى سانت كيتس ونيفيس",
    "Antigua and Barbuda emigrants to the United Kingdom": "أنتيغويون وبربوديون مهاجرون إلى المملكة المتحدة",
    "Antigua and Barbuda emigrants to the United States": "أنتيغويون وبربوديون مهاجرون إلى الولايات المتحدة",
    "Antigua and Barbuda emigrants to the United States Virgin Islands": "أنتيغويون وبربوديون مهاجرون إلى جزر العذراء الأمريكية",
    "Antigua and Barbuda entertainers": "فنانون ترفيهيون أنتيغويون وبربوديون",
    "Antigua and Barbuda equestrians": "فرسان خيول أنتيغويون وبربوديون",
    "Antigua and Barbuda expatriate basketball people": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون",
    "Antigua and Barbuda expatriate basketball people in France": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون في فرنسا",
    "Antigua and Barbuda expatriate basketball people in Germany": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون في ألمانيا",
    "Antigua and Barbuda expatriate basketball people in Greece": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون في اليونان",
    "Antigua and Barbuda expatriate basketball people in Poland": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون في بولندا",
    "Antigua and Barbuda expatriate basketball people in Puerto Rico": "أعلام كرة سلة أنتيغويون وبربوديون مغتربون في بورتوريكو",
    "Antigua and Barbuda expatriate judges": "قضاة أنتيغويون وبربوديون مغتربون",
    "Antigua and Barbuda expatriate sportspeople": "رياضيون أنتيغويون وبربوديون مغتربون",
    "Antigua and Barbuda expatriate sportspeople by country of residence": "رياضيون أنتيغويون وبربوديون مغتربون حسب بلد الإقامة",
    "Antigua and Barbuda expatriate sportspeople in Cambodia": "رياضيون أنتيغويون وبربوديون مغتربون في كمبوديا",
    "Antigua and Barbuda expatriate sportspeople in Canada": "رياضيون أنتيغويون وبربوديون مغتربون في كندا",
    "Antigua and Barbuda expatriate sportspeople in England": "رياضيون أنتيغويون وبربوديون مغتربون في إنجلترا",
    "Antigua and Barbuda expatriate sportspeople in Finland": "رياضيون أنتيغويون وبربوديون مغتربون في فنلندا",
    "Antigua and Barbuda expatriate sportspeople in France": "رياضيون أنتيغويون وبربوديون مغتربون في فرنسا",
    "Antigua and Barbuda expatriate sportspeople in Germany": "رياضيون أنتيغويون وبربوديون مغتربون في ألمانيا",
    "Antigua and Barbuda expatriate sportspeople in Greece": "رياضيون أنتيغويون وبربوديون مغتربون في اليونان",
    "Antigua and Barbuda expatriate sportspeople in insular areas of the United States": "رياضيون أنتيغويون وبربوديون مغتربون في المناطق المعزولة في الولايات المتحدة",
    "Antigua and Barbuda expatriate sportspeople in Jamaica": "رياضيون أنتيغويون وبربوديون مغتربون في جامايكا",
    "Antigua and Barbuda expatriate sportspeople in Kenya": "رياضيون أنتيغويون وبربوديون مغتربون في كينيا",
    "Antigua and Barbuda expatriate sportspeople in Poland": "رياضيون أنتيغويون وبربوديون مغتربون في بولندا",
    "Antigua and Barbuda expatriate sportspeople in Puerto Rico": "رياضيون أنتيغويون وبربوديون مغتربون في بورتوريكو",
    "Antigua and Barbuda expatriate sportspeople in Slovenia": "رياضيون أنتيغويون وبربوديون مغتربون في سلوفينيا",
    "Antigua and Barbuda expatriate sportspeople in South Africa": "رياضيون أنتيغويون وبربوديون مغتربون في جنوب إفريقيا",
    "Antigua and Barbuda expatriate sportspeople in Thailand": "رياضيون أنتيغويون وبربوديون مغتربون في تايلاند",
    "Antigua and Barbuda expatriate sportspeople in the United Kingdom": "رياضيون أنتيغويون وبربوديون مغتربون في المملكة المتحدة",
    "Antigua and Barbuda expatriate sportspeople in the United States": "رياضيون أنتيغويون وبربوديون مغتربون في الولايات المتحدة",
    "Antigua and Barbuda expatriate sportspeople in Trinidad and Tobago": "رياضيون أنتيغويون وبربوديون مغتربون في ترينيداد وتوباغو",
    "Antigua and Barbuda expatriate sportspeople in Wales": "رياضيون أنتيغويون وبربوديون مغتربون في ويلز",
    "Antigua and Barbuda expatriates": "أنتيغويون وبربوديون مغتربون",
    "Antigua and Barbuda expatriates in Anguilla": "أنتيغويون وبربوديون مغتربون في أنغويلا",
    "Antigua and Barbuda expatriates in Belize": "أنتيغويون وبربوديون مغتربون في بليز",
    "Antigua and Barbuda expatriates in Canada": "أنتيغويون وبربوديون مغتربون في كندا",
    "Antigua and Barbuda expatriates in England": "أنتيغويون وبربوديون مغتربون في إنجلترا",
    "Antigua and Barbuda expatriates in Finland": "أنتيغويون وبربوديون مغتربون في فنلندا",
    "Antigua and Barbuda expatriates in France": "أنتيغويون وبربوديون مغتربون في فرنسا",
    "Antigua and Barbuda expatriates in Germany": "أنتيغويون وبربوديون مغتربون في ألمانيا",
    "Antigua and Barbuda expatriates in Greece": "أنتيغويون وبربوديون مغتربون في اليونان",
    "Antigua and Barbuda expatriates in Grenada": "أنتيغويون وبربوديون مغتربون في غرينادا",
    "Antigua and Barbuda expatriates in insular areas of the United States": "أنتيغويون وبربوديون مغتربون في المناطق المعزولة في الولايات المتحدة",
    "Antigua and Barbuda expatriates in Jamaica": "أنتيغويون وبربوديون مغتربون في جامايكا",
    "Antigua and Barbuda expatriates in Kenya": "أنتيغويون وبربوديون مغتربون في كينيا",
    "Antigua and Barbuda expatriates in Montserrat": "أنتيغويون وبربوديون مغتربون في مونتسرات",
    "Antigua and Barbuda expatriates in Poland": "أنتيغويون وبربوديون مغتربون في بولندا",
    "Antigua and Barbuda expatriates in Puerto Rico": "أنتيغويون وبربوديون مغتربون في بورتوريكو",
    "Antigua and Barbuda expatriates in Saint Lucia": "أنتيغويون وبربوديون مغتربون في سانت لوسيا",
    "Antigua and Barbuda expatriates in South Africa": "أنتيغويون وبربوديون مغتربون في جنوب إفريقيا",
    "Antigua and Barbuda expatriates in the United Kingdom": "أنتيغويون وبربوديون مغتربون في المملكة المتحدة",
    "Antigua and Barbuda expatriates in the United States": "أنتيغويون وبربوديون مغتربون في الولايات المتحدة",
    "Antigua and Barbuda expatriates in Trinidad and Tobago": "أنتيغويون وبربوديون مغتربون في ترينيداد وتوباغو",
    "Antigua and Barbuda expatriates in Wales": "أنتيغويون وبربوديون مغتربون في ويلز",
    "Antigua and Barbuda families": "عائلات أنتيغوية وبربودية",
    "Antigua and Barbuda female canoeists": "متسابقات قوارب الكانوي أنتيغويات وبربوديات",
    "Antigua and Barbuda female cyclists": "دراجات أنتيغويات وبربوديات",
    "Antigua and Barbuda female equestrians": "فارسات خيول أنتيغويات وبربوديات",
    "Antigua and Barbuda female freestyle swimmers": "سباحات تزلج حر أنتيغويات وبربوديات",
    "Antigua and Barbuda female sailors (sport)": "بحارات رياضيات أنتيغويات وبربوديات",
    "Antigua and Barbuda female swimmers": "سباحات أنتيغويات وبربوديات",
    "Antigua and Barbuda filmmakers": "صانعو أفلام أنتيغويون وبربوديون",
    "Antigua and Barbuda films": "أفلام أنتيغوية وبربودية",
    "Antigua and Barbuda Football Association": "الرابطة الأنتيغوية والبربودية لكرة القدم",
    "Antigua and Barbuda football club seasons": "مواسم أندية كرة قدم أنتيغوية وبربودية",
    "Antigua and Barbuda football logos": "شعارات كرة القدم الأنتيغوية والبربودية",
    "Antigua and Barbuda football managers": "مدربو كرة قدم أنتيغويون وبربوديون",
    "Antigua and Barbuda freestyle swimmers": "سباحو تزلج حر أنتيغويون وبربوديون",
    "Antigua and Barbuda high jumpers": "متسابقو قفز عالي أنتيغويون وبربوديون",
    "Antigua and Barbuda hurdlers": "لاعبو قفز الحواجز أنتيغويون وبربوديون",
    "Antigua and Barbuda illustrators": "رسامون توضيحيون أنتيغويون وبربوديون",
    "Antigua and Barbuda in World War II": "أنتيغوا وباربودا في الحرب العالمية الثانية",
    "Antigua and Barbuda Jews": "أنتيغويون وبربوديون يهود",
    "Antigua and Barbuda judges": "قضاة أنتيغويون وبربوديون",
    "Antigua and Barbuda judges of international courts and tribunals": "قضاة أنتيغويون وبربوديون في محاكم وهيئات قضائية دولية",
    "Antigua and Barbuda jurists": "حقوقيون أنتيغويون وبربوديون",
    "Antigua and Barbuda law by year": "قانون أنتيغوي وبربودي حسب السنة",
    "Antigua and Barbuda lawyers": "محامون أنتيغويون وبربوديون",
    "Antigua and Barbuda literature": "أدب أنتيغوي وبربودي",
    "Antigua and Barbuda long jumpers": "لاعبو قفز طويل أنتيغويون وبربوديون",
    "Antigua and Barbuda Methodists": "ميثوديون أنتيغويون وبربوديون",
    "Antigua and Barbuda middle-distance runners": "عداؤو مسافات متوسطة أنتيغويون وبربوديون",
    "Antigua and Barbuda murder victims": "ضحايا قتل أنتيغويون وبربوديون",
    "Antigua and Barbuda musical groups": "فرق موسيقية أنتيغوية وبربودية",
    "Antigua and Barbuda musicians": "موسيقيون أنتيغويون وبربوديون",
    "Antigua and Barbuda navigational boxes": "صناديق تصفح أنتيغوا وباربودا",
    "Antigua and Barbuda novels": "روايات أنتيغوية وبربودية",
    "Antigua and Barbuda officials of the United Nations": "مسؤولون أنتيغويون وبربوديون في الأمم المتحدة",
    "Antigua and Barbuda people by descent": "أنتيغويون وبربوديون حسب الأصل العرقي أو الوطني",
    "Antigua and Barbuda people by occupation": "أنتيغويون وبربوديون حسب المهنة",
    "Antigua and Barbuda people by parish": "أنتيغويون وبربوديون حسب الأبرشية",
    "Antigua and Barbuda people by political orientation": "أنتيغويون وبربوديون حسب التوجه السياسي",
    "Antigua and Barbuda people by religion": "أنتيغويون وبربوديون حسب الدين",
    "Antigua and Barbuda people imprisoned abroad": "أنتيغويون وبربوديون مسجونون في الخارج",
    "Antigua and Barbuda people in sports": "أنتيغويون وبربوديون في ألعاب رياضية",
    "Antigua and Barbuda people murdered abroad": "أنتيغويون وبربوديون قتلوا في الخارج",
    "Antigua and Barbuda people of African descent": "أنتيغويون وبربوديون من أصل إفريقي",
    "Antigua and Barbuda people of American descent": "أنتيغويون وبربوديون من أصل أمريكي",
    "Antigua and Barbuda people of Anguillan descent": "أنتيغويون وبربوديون من أصل أنغويلاني",
    "Antigua and Barbuda people of Barbadian descent": "أنتيغويون وبربوديون من أصل بربادوسي",
    "Antigua and Barbuda people of British descent": "أنتيغويون وبربوديون من أصل بريطاني",
    "Antigua and Barbuda people of Caribbean descent": "أنتيغويون وبربوديون من أصل كاريبي",
    "Antigua and Barbuda people of Cuban descent": "أنتيغويون وبربوديون من أصل كوبي",
    "Antigua and Barbuda people of English descent": "أنتيغويون وبربوديون من أصل إنجليزي",
    "Antigua and Barbuda people of European descent": "أنتيغويون وبربوديون من أصل أوروبي",
    "Antigua and Barbuda people of German descent": "أنتيغويون وبربوديون من أصل ألماني",
    "Antigua and Barbuda people of Ghanaian descent": "أنتيغويون وبربوديون من أصل غاني",
    "Antigua and Barbuda people of Guyanese descent": "أنتيغويون وبربوديون من أصل غياني",
    "Antigua and Barbuda people of Indian descent": "أنتيغويون وبربوديون من أصل هندي",
    "Antigua and Barbuda people of Irish descent": "أنتيغويون وبربوديون من أصل أيرلندي",
    "Antigua and Barbuda people of Israeli descent": "أنتيغويون وبربوديون من أصل إسرائيلي",
    "Antigua and Barbuda people of Italian descent": "أنتيغويون وبربوديون من أصل إيطالي",
    "Antigua and Barbuda people of Jamaican descent": "أنتيغويون وبربوديون من أصل جامايكي",
    "Antigua and Barbuda people of Jewish descent": "أنتيغويون وبربوديون من أصل يهودي",
    "Antigua and Barbuda people of Kenyan descent": "أنتيغويون وبربوديون من أصل كيني",
    "Antigua and Barbuda people of Montserratian descent": "أنتيغويون وبربوديون من أصل مونتسراتي",
    "Antigua and Barbuda people of Nigerian descent": "أنتيغويون وبربوديون من أصل نيجيري",
    "Antigua and Barbuda people of North American descent": "أنتيغويون وبربوديون من أصل أمريكي شمالي",
    "Antigua and Barbuda people of Portuguese descent": "أنتيغويون وبربوديون من أصل برتغالي",
    "Antigua and Barbuda people of Russian descent": "أنتيغويون وبربوديون من أصل روسي",
    "Antigua and Barbuda people of Spanish descent": "أنتيغويون وبربوديون من أصل إسباني",
    "Antigua and Barbuda people of Syrian descent": "أنتيغويون وبربوديون من أصل سوري",
    "Antigua and Barbuda people of Trinidad and Tobago descent": "أنتيغويون وبربوديون من أصل ترنيدادي",
    "Antigua and Barbuda people with disabilities": "أنتيغويون وبربوديون بإعاقات",
    "Antigua and Barbuda philanthropists": "فاعلو خير أنتيغويون وبربوديون",
    "Antigua and Barbuda physicians": "أطباء أنتيغويون وبربوديون",
    "Antigua and Barbuda police officers": "ضباط شرطة أنتيغويون وبربوديون",
    "antigua and barbuda political people": "ساسة أنتيغويون وبربوديون",
    "antigua and barbuda politicians by party": "سياسيون أنتيغويون وبربوديون حسب الحزب",
    "antigua and barbuda politicians": "سياسيون أنتيغويون وبربوديون",
    "antigua and barbuda politics-related lists": "قوائم متعلقة بالسياسة الأنتيغوية والبربودية",
    "antigua and barbuda prisoners and detainees": "سجناء ومعتقلون أنتيغويون وبربوديون",
    "antigua and barbuda professional wrestlers": "مصارعون محترفون أنتيغويون وبربوديون",
    "antigua and barbuda religious leaders": "قادة دينيون أنتيغويون وبربوديون",
    "antigua and barbuda republicans": "جمهوريون أنتيغويون وبربوديون",
    "antigua and barbuda roman catholic bishops": "أساقفة كاثوليك رومان أنتيغويون وبربوديون",
    "antigua and barbuda roman catholics": "رومان كاثوليك أنتيغويون وبربوديون",
    "antigua and barbuda runners": "عداؤون أنتيغويون وبربوديون",
    "antigua and barbuda sailors (sport)": "بحارة رياضيون أنتيغويون وبربوديون",
    "antigua and barbuda singers": "مغنون أنتيغويون وبربوديون",
    "antigua and barbuda socialists": "اشتراكيون أنتيغويون وبربوديون",
    "antigua and barbuda sport by decade": "رياضة أنتيغوية وبربودية حسب العقد",
    "antigua and barbuda sport by year": "رياضة أنتيغوية وبربودية حسب السنة",
    "antigua and barbuda sport-related lists": "قوائم متعلقة برياضة أنتيغوية وبربودية",
    "antigua and barbuda sports coaches": "مدربو رياضة أنتيغويون وبربوديون",
    "antigua and barbuda sportspeople by sport": "رياضيون أنتيغويون وبربوديون حسب الرياضة",
    "antigua and barbuda sportspeople": "رياضيون أنتيغويون وبربوديون",
    "antigua and barbuda sportswomen": "رياضيات أنتيغويات وبربوديات",
    "antigua and barbuda sprinters": "عداؤون سريعون أنتيغويون وبربوديون",
    "antigua and barbuda swimmers": "سباحون أنتيغويون وبربوديون",
    "antigua and barbuda tennis players": "لاعبو كرة مضرب أنتيغويون وبربوديون",
    "antigua and barbuda triple jumpers": "لاعبو وثب ثلاثي أنتيغويون وبربوديون",
    "antigua and barbuda victims of crime": "ضحايا جرائم أنتيغويون وبربوديون",
    "antigua and barbuda windsurfers": "راكبو أمواج أنتيغويون وبربوديون",
    "antigua and barbuda women athletes": "لاعبات قوى أنتيغويات وبربوديات",
    "antigua and barbuda women by occupation": "أنتيغويات وبربوديات حسب المهنة",
    "antigua and barbuda women cricketers": "لاعبات كريكت أنتيغويات وبربوديات",
    "antigua and barbuda women high jumpers": "متسابقات قفز عالي أنتيغويات وبربوديات",
    "antigua and barbuda women illustrators": "رسامات توضيحيات أنتيغويات وبربوديات",
    "antigua and barbuda women in politics": "أنتيغويات وبربوديات في السياسة",
    "antigua and barbuda women long jumpers": "لاعبات قفز طويل أنتيغويات وبربوديات",
    "antigua and barbuda women middle-distance runners": "عداءات مسافات متوسطة أنتيغويات وبربوديات",
    "antigua and barbuda women runners": "عداءات أنتيغويات وبربوديات",
    "antigua and barbuda women sprinters": "عداءات سريعات أنتيغويات وبربوديات",
    "antigua and barbuda women writers": "كاتبات أنتيغويات وبربوديات",
    "antigua and barbuda women": "أنتيغويات وبربوديات",
    "antigua and barbuda women's national football team managers": "مدربو منتخب أنتيغوا وباربودا لكرة القدم للسيدات",
    "antigua and barbuda writers": "كتاب أنتيغويون وبربوديون",
    "antigua and barbuda–argentina relations": "العلاقات الأرجنتينية الأنتيغوية والبربودية",
    "antigua and barbuda–australia relations": "العلاقات الأسترالية الأنتيغوية والبربودية",
    "antigua and barbuda–australia sports relations": "العلاقات الأسترالية الأنتيغوية والبربودية الرياضية",
    "antigua and barbuda–barbados relations": "العلاقات الأنتيغوية والبربودية البربادوسية",
    "antigua and barbuda–belize relations": "العلاقات الأنتيغوية والبربودية البليزية",
    "antigua and barbuda–brazil relations": "العلاقات الأنتيغوية والبربودية البرازيلية",
    "antigua and barbuda–canada relations": "العلاقات الأنتيغوية والبربودية الكندية",
    "antigua and barbuda–chile relations": "العلاقات الأنتيغوية والبربودية التشيلية",
    "antigua and barbuda–china relations": "العلاقات الأنتيغوية والبربودية الصينية",
    "antigua and barbuda–colombia relations": "العلاقات الأنتيغوية والبربودية الكولومبية",
    "antigua and barbuda–cuba relations": "العلاقات الأنتيغوية والبربودية الكوبية",
    "antigua and barbuda–democratic republic of the congo relations": "العلاقات الأنتيغوية والبربودية الكونغوية الديمقراطية",
    "antigua and barbuda–dominica relations": "علاقات أنتيغوا وباربودا ودومينيكا",
    "antigua and barbuda–dominican republic relations": "العلاقات الأنتيغوية والبربودية الدومينيكانية",
    "antigua and barbuda–estonia relations": "العلاقات الأنتيغوية والبربودية الإستونية",
    "antigua and barbuda–finland relations": "العلاقات الأنتيغوية والبربودية الفنلندية",
    "antigua and barbuda–france border": "الحدود الأنتيغوية والبربودية الفرنسية",
    "antigua and barbuda–france relations": "العلاقات الأنتيغوية والبربودية الفرنسية",
    "antigua and barbuda–germany relations": "العلاقات الألمانية الأنتيغوية والبربودية",
    "antigua and barbuda–ghana relations": "العلاقات الأنتيغوية والبربودية الغانية",
    "antigua and barbuda–greece relations": "العلاقات الأنتيغوية والبربودية اليونانية",
    "antigua and barbuda–grenada relations": "العلاقات الأنتيغوية والبربودية الغرينادية",
    "antigua and barbuda–guadeloupe border": "الحدود الأنتيغوية والبربودية الغواديلوبية",
    "antigua and barbuda–guyana relations": "العلاقات الأنتيغوية والبربودية الغيانية",
    "antigua and barbuda–haiti relations": "العلاقات الأنتيغوية والبربودية الهايتية",
    "antigua and barbuda–india relations": "العلاقات الأنتيغوية والبربودية الهندية",
    "antigua and barbuda–india sports relations": "العلاقات الأنتيغوية والبربودية الهندية الرياضية",
    "antigua and barbuda–ireland relations": "العلاقات الأنتيغوية والبربودية الأيرلندية",
    "antigua and barbuda–israel relations": "العلاقات الأنتيغوية والبربودية الإسرائيلية",
    "antigua and barbuda–italy relations": "العلاقات الأنتيغوية والبربودية الإيطالية",
    "antigua and barbuda–jamaica relations": "العلاقات الأنتيغوية والبربودية الجامايكية",
    "antigua and barbuda–japan relations": "العلاقات الأنتيغوية والبربودية اليابانية",
    "antigua and barbuda–kenya relations": "العلاقات الأنتيغوية والبربودية الكينية",
    "antigua and barbuda–mexico relations": "العلاقات الأنتيغوية والبربودية المكسيكية",
    "antigua and barbuda–netherlands relations": "العلاقات الأنتيغوية والبربودية الهولندية",
    "antigua and barbuda–new zealand relations": "العلاقات الأنتيغوية والبربودية النيوزيلندية",
    "antigua and barbuda–nigeria relations": "العلاقات الأنتيغوية والبربودية النيجيرية",
    "antigua and barbuda–paraguay relations": "العلاقات الأنتيغوية والبربودية البارغوايانية",
    "antigua and barbuda–peru relations": "العلاقات الأنتيغوية والبربودية البيروية",
    "antigua and barbuda–poland relations": "العلاقات الأنتيغوية والبربودية البولندية",
    "antigua and barbuda–portugal relations": "العلاقات الأنتيغوية والبربودية البرتغالية",
    "antigua and barbuda–russia relations": "العلاقات الأنتيغوية والبربودية الروسية",
    "antigua and barbuda–saint kitts and nevis relations": "علاقات أنتيغوا وباربودا وسانت كيتس ونيفيس",
    "antigua and barbuda–saint lucia relations": "علاقات أنتيغوا وباربودا وسانت لوسيا",
    "antigua and barbuda–saint vincent and the grenadines relations": "علاقات أنتيغوا وباربودا وسانت فنسنت وجزر غرينادين",
    "antigua and barbuda–south africa relations": "العلاقات الأنتيغوية والبربودية الجنوب الإفريقية",
    "antigua and barbuda–south africa sports relations": "العلاقات الأنتيغوية والبربودية الجنوب الإفريقية الرياضية",
    "antigua and barbuda–spain relations": "العلاقات الأنتيغوية والبربودية الإسبانية",
    "antigua and barbuda–syria relations": "العلاقات الأنتيغوية والبربودية السورية",
    "antigua and barbuda–trinidad and tobago relations": "العلاقات الأنتيغوية والبربودية الترنيدادية",
    "antigua and barbuda–turkey relations": "العلاقات الأنتيغوية والبربودية التركية",
    "antigua and barbuda–ukraine relations": "العلاقات الأنتيغوية والبربودية الأوكرانية",
    "antigua and barbuda–united kingdom sports relations": "العلاقات الأنتيغوية والبربودية البريطانية الرياضية",
    "Antigua and Barbuda–Ukraine relations": "العلاقات الأنتيغوية والبربودية الأوكرانية",
    "Antigua and Barbuda–United Kingdom relations": "العلاقات الأنتيغوية والبربودية البريطانية",
    "Antigua and Barbuda–United Kingdom sports relations": "العلاقات الأنتيغوية والبربودية البريطانية الرياضية",
    "Antigua and Barbuda–United States relations": "العلاقات الأمريكية الأنتيغوية والبربودية",
    "Antigua and Barbuda–United States sports relations": "العلاقات الأمريكية الأنتيغوية والبربودية الرياضية",
    "Antigua and Barbuda–Venezuela relations": "العلاقات الأنتيغوية والبربودية الفنزويلية",
    "Argentine expatriate sportspeople in Antigua and Barbuda": "رياضيون أرجنتينيون مغتربون في أنتيغوا وباربودا",
    "Argentine expatriates in Antigua and Barbuda": "أرجنتينيون مغتربون في أنتيغوا وباربودا",
    "Arts festivals in Antigua and Barbuda": "مهرجانات فنية في أنتيغوا وباربودا",
    "Arts organisations based in Antigua and Barbuda": "منظمات فنية مقرها في أنتيغوا وباربودا",
    "Athletics in Antigua and Barbuda": "ألعاب القوى في أنتيغوا وباربودا",
    "Athletics venues in Antigua and Barbuda": "ملاعب ألعاب القوى في أنتيغوا وباربودا",
    "Attorneys general of Antigua and Barbuda": "مدعون عامون من أنتيغوا وباربودا",
    "Australian expatriates in Antigua and Barbuda": "أستراليون مغتربون في أنتيغوا وباربودا",
    "Australian people of Antigua and Barbuda descent": "أستراليون من أصل أنتيغوي وبربودي",
    "Aviation accidents and incidents in Antigua and Barbuda": "حوادث طيران في أنتيغوا وباربودا",
    "Banks of Antigua and Barbuda": "بنوك أنتيغوا وباربودا",
    "Beaches of Antigua and Barbuda": "شواطئ أنتيغوا وباربودا",
    "Bermudian expatriates in Antigua and Barbuda": "برموديون مغتربون في أنتيغوا وباربودا",
    "Bermudian people of Antigua and Barbuda descent": "برموديون من أصل أنتيغوي وبربودي",
    "Biology in Antigua and Barbuda": "علم الأحياء في أنتيغوا وباربودا",
    "Birds of Antigua and Barbuda": "طيور أنتيغوا وباربودا",
    "Bodies of water of Antigua and Barbuda": "مسطحات مائية في أنتيغوا وباربودا",
    "Borders of Antigua and Barbuda": "حدود أنتيغوا وباربودا",
    "British emigrants to Antigua and Barbuda": "بريطانيون مهاجرون إلى أنتيغوا وباربودا",
    "Business organisations based in Antigua and Barbuda": "منظمات أعمال مقرها في أنتيغوا وباربودا",
    "Canadian people of Antigua and Barbuda descent": "كنديون من أصل أنتيغوي وبربودي",
    "Canoeing in Antigua and Barbuda": "ركوب الكنو في أنتيغوا وباربودا",
    "Cargo ships of Antigua and Barbuda": "سفن بضائع أنتيغوا وباربودا",
    "Carnivals in Antigua and Barbuda": "كرنفالات في أنتيغوا وباربودا",
    "Cathedrals in Antigua and Barbuda": "كاتدرائيات في أنتيغوا وباربودا",
    "Central American and Caribbean Games bronze medalists for Antigua and Barbuda": "فائزون بميداليات برونزية في ألعاب أمريكا الوسطى والكاريبي من أنتيغوا وباربودا",
    "Christian missionaries in Antigua and Barbuda": "مبشرون مسيحيون في أنتيغوا وباربودا",
    "Churches in Antigua and Barbuda": "كنائس في أنتيغوا وباربودا",
    "Companies of Antigua and Barbuda": "شركات في أنتيغوا وباربودا",
    "Constituencies of Antigua and Barbuda": "دوائر إنتخابية في أنتيغوا وباربودا",
    "Cricket in Antigua and Barbuda": "الكريكت في أنتيغوا وباربودا",
    "Cricket teams in Antigua and Barbuda": "فرق الكريكت في أنتيغوا وباربودا",
    "Crime in Antigua and Barbuda": "جريمة في أنتيغوا وباربودا",
    "Cultural festivals in Antigua and Barbuda": "مهرجانات ثقافية في أنتيغوا وباربودا",
    "Cycle racing in Antigua and Barbuda": "سباق دراجات في أنتيغوا وباربودا",
    "Cycling in Antigua and Barbuda": "ركوب الدراجات في أنتيغوا وباربودا",
    "Dams in Antigua and Barbuda": "سدود في أنتيغوا وباربودا",
    "Death in Antigua and Barbuda": "الموت في أنتيغوا وباربودا",
    "Deaths by firearm in Antigua and Barbuda": "وفيات بإطلاق النار في أنتيغوا وباربودا",
    "Deaths in Antigua and Barbuda": "وفيات في أنتيغوا وباربودا",
    "Defunct airlines of Antigua and Barbuda": "شركات طيران سابقة في أنتيغوا وباربودا",
    "Defunct banks of Antigua and Barbuda": "بنوك سابقة في أنتيغوا وباربودا",
    "Defunct companies of Antigua and Barbuda": "شركات سابقة في أنتيغوا وباربودا",
    "Defunct organisations based in Antigua and Barbuda": "منظمات سابقة مقرها في أنتيغوا وباربودا",
    "Defunct political parties in Antigua and Barbuda": "أحزاب سياسية سابقة في أنتيغوا وباربودا",
    "Democratic Republic of the Congo expatriate sportspeople in Antigua and Barbuda": "رياضيون كونغويون ديمقراطيون مغتربون في أنتيغوا وباربودا",
    "Democratic Republic of the Congo expatriates in Antigua and Barbuda": "كونغويون ديمقراطيون مغتربون في أنتيغوا وباربودا",
    "Demographics by parish in Antigua and Barbuda": "التركيبة السكانية حسب الأبرشية في أنتيغوا وباربودا",
    "Diplomatic missions of Antigua and Barbuda": "بعثات أنتيغوا وباربودا الدبلوماسية",
    "Disestablishments in Antigua and Barbuda by century": "انحلالات في أنتيغوا وباربودا حسب القرن",
    "Disestablishments in Antigua and Barbuda by decade": "انحلالات في أنتيغوا وباربودا حسب العقد",
    "Disestablishments in Antigua and Barbuda by millennium": "انحلالات في أنتيغوا وباربودا حسب الألفية",
    "Disestablishments in Antigua and Barbuda by year": "انحلالات في أنتيغوا وباربودا حسب السنة",
    "Dominican Republic expatriates in Antigua and Barbuda": "دومينيكانيون مغتربون في أنتيغوا وباربودا",
    "Education in Antigua and Barbuda": "التعليم في أنتيغوا وباربودا",
    "Educational organisations based in Antigua and Barbuda": "منظمات تعليمية مقرها في أنتيغوا وباربودا",
    "Elections in Antigua and Barbuda": "انتخابات في أنتيغوا وباربودا",
    "Festivals in Antigua and Barbuda": "مهرجانات في أنتيغوا وباربودا",
    "Films shot in Antigua and Barbuda": "أفلام مصورة في أنتيغوا وباربودا",
    "Financial services companies of Antigua and Barbuda": "شركات خدمات مالية في أنتيغوا وباربودا",
    "Financial services in Antigua and Barbuda": "خدمات مالية في أنتيغوا وباربودا",
    "Food and drink in Antigua and Barbuda": "أطعمة ومشروبات في أنتيغوا وباربودا",
    "Football clubs in Antigua and Barbuda": "أندية كرة قدم في أنتيغوا وباربودا",
    "Footballers in Antigua and Barbuda by club": "لاعبو كرة قدم في أنتيغوا وباربودا حسب النادي",
    "Fortifications in Antigua and Barbuda": "تحصينات في أنتيغوا وباربودا",
    "Forts in Antigua and Barbuda": "حصون في أنتيغوا وباربودا",
    "Gambling in Antigua and Barbuda": "مقامرة في أنتيغوا وباربودا",
    "Geology of Antigua and Barbuda": "جيولوجيا أنتيغوا وباربودا",
    "German expatriate sportspeople in Antigua and Barbuda": "رياضيون ألمان مغتربون في أنتيغوا وباربودا",
    "German expatriates in Antigua and Barbuda": "ألمان مغتربون في أنتيغوا وباربودا",
    "Ghanaian expatriates in Antigua and Barbuda": "غانيون مغتربون في أنتيغوا وباربودا",
    "Government ministries of Antigua and Barbuda": "وزارات حكومة أنتيغوا وباربودا",
    "Grenadian expatriate sportspeople in Antigua and Barbuda": "رياضيون غريناديون مغتربون في أنتيغوا وباربودا",
    "Grenadian expatriates in Antigua and Barbuda": "غريناديون مغتربون في أنتيغوا وباربودا",
    "Guyanese emigrants to Antigua and Barbuda": "غيانيون مهاجرون إلى أنتيغوا وباربودا",
    "Guyanese expatriate sportspeople in Antigua and Barbuda": "رياضيون غيانيون مغتربون في أنتيغوا وباربودا",
    "Guyanese expatriates in Antigua and Barbuda": "غيانيون مغتربون في أنتيغوا وباربودا",
    "Guyanese people of Antigua and Barbuda descent": "غيانيون من أصل أنتيغوي وبربودي",
    "Healthcare in Antigua and Barbuda": "الرعاية الصحية في أنتيغوا وباربودا",
    "Heritage registers in Antigua and Barbuda": "سجلات التراث في أنتيغوا وباربودا",
    "Historic sites in Antigua and Barbuda": "مواقع تاريخية في أنتيغوا وباربودا",
    "History of British Antigua and Barbuda": "تاريخ أنتيغويون وبربوديون بريطانيون",
    "History of football in Antigua and Barbuda": "تاريخ كرة القدم في أنتيغوا وباربودا",
    "Indian people of Antigua and Barbuda descent": "هنود من أصل أنتيغوي وبربودي",
    "Insects of Antigua and Barbuda": "حشرات أنتيغوا وباربودا",
    "International association football competitions hosted by Antigua and Barbuda": "منافسات كرة قدم دولية استضافتها أنتيغوا وباربودا",
    "International sports competitions hosted by Antigua and Barbuda": "منافسات رياضية دولية استضافتها أنتيغوا وباربودا",
    "Irish people of Antigua and Barbuda descent": "أيرلنديون من أصل أنتيغوي وبربودي",
    "Jamaican emigrants to Antigua and Barbuda": "جامايكيون مهاجرون إلى أنتيغوا وباربودا",
    "Jamaican people of Antigua and Barbuda descent": "جامايكيون من أصل أنتيغوي وبربودي",
    "Judiciary of Antigua and Barbuda": "النظام القضائي أنتيغوا وباربودا",
    "Labour relations in Antigua and Barbuda": "علاقات عمالية في أنتيغوا وباربودا",
    "Landmarks in Antigua and Barbuda": "معالم في أنتيغوا وباربودا",
    "Law enforcement in Antigua and Barbuda": "تطبيق القانون في أنتيغوا وباربودا",
    "Lebanese people of Antigua and Barbuda descent": "لبنانيون من أصل أنتيغوي وبربودي",
    "Libraries in Antigua and Barbuda": "مكتبات في أنتيغوا وباربودا",
    "Lists of ambassadors of Antigua and Barbuda": "قوائم سفراء أنتيغوا وباربودا",
    "Lists of ambassadors to Antigua and Barbuda": "قوائم سفراء لدى أنتيغوا وباربودا",
    "Lists of Antigua and Barbuda people by occupation": "قوائم أنتيغويون وبربوديون حسب المهنة",
    "Lists of Antigua and Barbuda sportspeople": "قوائم رياضيون أنتيغويون وبربوديون",
    "Lists of biota of Antigua and Barbuda": "قوائم حيويات أنتيغوا وباربودا",
    "Lists of buildings and structures in Antigua and Barbuda": "قوائم مبان ومنشآت في أنتيغوا وباربودا",
    "Lists of religious buildings and structures in Antigua and Barbuda": "قوائم مبان ومنشآت دينية في أنتيغوا وباربودا",
    "Lists of tourist attractions in Antigua and Barbuda": "قوائم مواقع جذب سياحي في أنتيغوا وباربودا",
    "Local government in Antigua and Barbuda": "الحكومة المحلية في أنتيغوا وباربودا",
    "Mass media in Antigua and Barbuda": "وسائل إعلام في أنتيغوا وباربودا",
    "Medical and health organisations based in Antigua and Barbuda": "منظمات طبية وصحية مقرها في أنتيغوا وباربودا",
    "Medical schools in Antigua and Barbuda": "مدارس طبية في أنتيغوا وباربودا",
    "Medicine in Antigua and Barbuda": "الطب في أنتيغوا وباربودا",
    "Members of the Parliament of Antigua and Barbuda": "أعضاء برلمان أنتيغوا وباربودا",
    "Members of the Parliament of Antigua and Barbuda by term": "أعضاء برلمان أنتيغوا وباربودا حسب الفترة",
    "Members of the Senate (Antigua and Barbuda)": "أعضاء مجلس الشيوخ (أنتيغوا وباربودا)",
    "Military equipment of Antigua and Barbuda": "عتاد أنتيغوا وباربودا العسكري",
    "Montserratian emigrants to Antigua and Barbuda": "مونتسراتيون مهاجرون إلى أنتيغوا وباربودا",
    "Montserratian expatriates in Antigua and Barbuda": "مونتسراتيون مغتربون في أنتيغوا وباربودا",
    "Montserratian people of Antigua and Barbuda descent": "مونتسراتيون من أصل أنتيغوي وبربودي",
    "Museums in Antigua and Barbuda": "متاحف في أنتيغوا وباربودا",
    "Music festivals in Antigua and Barbuda": "مهرجانات موسيقية في أنتيغوا وباربودا",
    "Music of Antigua and Barbuda": "موسيقى أنتيغوا وباربودا",
    "Music organisations based in Antigua and Barbuda": "منظمات موسيقى مقرها في أنتيغوا وباربودا",
    "National parks of Antigua and Barbuda": "متنزهات وطنية في أنتيغوا وباربودا",
    "Naval ships of Antigua and Barbuda": "سفن قوات بحرية في أنتيغوا وباربودا",
    "Newspapers published in Antigua and Barbuda": "صحف نشرت في أنتيغوا وباربودا",
    "Nigerian expatriates in Antigua and Barbuda": "نيجيريون مغتربون في أنتيغوا وباربودا",
    "Nigerian people of Antigua and Barbuda descent": "نيجيريون من أصل أنتيغوي وبربودي",
    "Olympic boxers for Antigua and Barbuda": "ملاكمون أولمبيون في أنتيغوا وباربودا",
    "Olympic canoeists for Antigua and Barbuda": "متسابقو قوارب الكانوي أولمبيون في أنتيغوا وباربودا",
    "Olympic cyclists for Antigua and Barbuda": "دراجون أولمبيون في أنتيغوا وباربودا",
    "Orders, decorations, and medals of Antigua and Barbuda": "مراتب تشريفية وأوسمة وميداليات أنتيغوا وباربودا",
    "Pan American Games bronze medalists for Antigua and Barbuda": "فائزون بميداليات برونزية في دورة الألعاب الأمريكية من أنتيغوا وباربودا",
    "Pan American Games gold medalists for Antigua and Barbuda": "فائزون بميداليات ذهبية في دورة الألعاب الأمريكية من أنتيغوا وباربودا",
    "Pan American Games medalists for Antigua and Barbuda": "فائزون بميداليات دورة الألعاب الأمريكية من أنتيغوا وباربودا",
    "Pan American Games silver medalists for Antigua and Barbuda": "فائزون بميداليات فضية في دورة الألعاب الأمريكية من أنتيغوا وباربودا",
    "Paralympic athletes for Antigua and Barbuda": "لاعبو قوى في الألعاب البارالمبية في أنتيغوا وباربودا",
    "People murdered in Antigua and Barbuda": "أشخاص قتلوا في أنتيغوا وباربودا",
    "Permanent delegates of Antigua and Barbuda to UNESCO": "مندوبو أنتيغوا وباربودا الدائمون لدى يونسكو",
    "Permanent representatives of Antigua and Barbuda to the Organization of American States": "مندوبو أنتيغوا وباربودا الدائمون إلى منظمة الدول الأمريكية",
    "Political history of Antigua and Barbuda": "تاريخ أنتيغوا وباربودا السياسي",
    "Political movements in Antigua and Barbuda": "حركات سياسية في أنتيغوا وباربودا",
    "Presidents of the Senate (Antigua and Barbuda)": "رؤساء مجلس الشيوخ (أنتيغوا وباربودا)",
    "Professional wrestling in Antigua and Barbuda": "مصارعة المحترفين في أنتيغوا وباربودا",
    "Protected areas of Antigua and Barbuda": "مناطق محمية في أنتيغوا وباربودا",
    "Protestant missionaries in Antigua and Barbuda": "مبشرون بروتستانتيون في أنتيغوا وباربودا",
    "Protestantism in Antigua and Barbuda": "البروتستانتية في أنتيغوا وباربودا",
    "Public holidays in Antigua and Barbuda": "عطلات رسمية في أنتيغوا وباربودا",
    "Recipients of orders, decorations, and medals of Antigua and Barbuda": "حاصلون على مراتب تشريفية وأوسمة وميداليات أنتيغوا وباربودا",
    "Referendums in Antigua and Barbuda": "استفتاءات في أنتيغوا وباربودا",
    "Religious buildings and structures in Antigua and Barbuda": "مبان ومنشآت دينية في أنتيغوا وباربودا",
    "Religious festivals in Antigua and Barbuda": "مهرجانات دينية في أنتيغوا وباربودا",
    "Religious organisations based in Antigua and Barbuda": "منظمات دينية مقرها في أنتيغوا وباربودا",
    "Reptiles of Antigua and Barbuda": "زواحف أنتيغوا وباربودا",
    "Rivers of Antigua and Barbuda": "أنهار أنتيغوا وباربودا",
    "Road transport in Antigua and Barbuda": "نقل بري في أنتيغوا وباربودا",
    "Rugby union in Antigua and Barbuda": "اتحاد الرجبي في أنتيغوا وباربودا",
    "Running in Antigua and Barbuda": "ركض في أنتيغوا وباربودا",
    "Sailing competitions in Antigua and Barbuda": "منافسات إبحار في أنتيغوا وباربودا",
    "Sailing in Antigua and Barbuda": "الإبحار في أنتيغوا وباربودا",
    "Schools in Antigua and Barbuda": "مدارس في أنتيغوا وباربودا",
    "Science and technology in Antigua and Barbuda": "العلوم والتقانة في أنتيغوا وباربودا",
    "Scottish people of Antigua and Barbuda descent": "إسكتلنديون من أصل أنتيغوي وبربودي",
    "Seasons in Antigua and Barbuda sport": "مواسم في رياضة أنتيغوية وبربودية",
    "Service companies of Antigua and Barbuda": "شركات خدمات في أنتيغوا وباربودا",
    "Ships of Antigua and Barbuda": "سفن أنتيغوا وباربودا",
    "Spanish people of Antigua and Barbuda descent": "إسبان من أصل أنتيغوي وبربودي",
    "Sportspeople of Antigua and Barbuda descent": "رياضيون من أصل أنتيغوي وبربودي",
    "Telecommunications in Antigua and Barbuda": "الاتصالات عن بعد في أنتيغوا وباربودا",
    "Television shows filmed in Antigua and Barbuda": "عروض تلفزيونية صورت في أنتيغوا وباربودا",
    "Tennis tournaments in Antigua and Barbuda": "بطولات كرة مضرب في أنتيغوا وباربودا",
    "Towns in Antigua and Barbuda": "بلدات في أنتيغوا وباربودا",
    "Trade unions in Antigua and Barbuda": "نقابات عمالية في أنتيغوا وباربودا",
    "Transport disasters in Antigua and Barbuda": "كوارث نقل في أنتيغوا وباربودا",
    "Transport organisations based in Antigua and Barbuda": "منظمات نقل مقرها في أنتيغوا وباربودا",
    "Treaties extended to British Antigua and Barbuda": "اتفاقيات امتدت إلى أنتيغويون وبربوديون بريطانيون",
    "Trinidad and Tobago expatriate sportspeople in Antigua and Barbuda": "رياضيون ترنيداديون مغتربون في أنتيغوا وباربودا",
    "Trinidad and Tobago expatriates in Antigua and Barbuda": "ترنيداديون مغتربون في أنتيغوا وباربودا",
    "Turkish people of Antigua and Barbuda descent": "أتراك من أصل أنتيغوي وبربودي",
    "Universities and colleges in Antigua and Barbuda": "جامعات وكليات في أنتيغوا وباربودا",
    "Universities in Antigua and Barbuda": "جامعات في أنتيغوا وباربودا",
    "Violence in Antigua and Barbuda": "عنف في أنتيغوا وباربودا",
    "Violent deaths in Antigua and Barbuda": "وفيات عنيفة في أنتيغوا وباربودا",
    "Water transport in Antigua and Barbuda": "نقل مائي في أنتيغوا وباربودا",
    "Weightlifting in Antigua and Barbuda": "رفع الأثقال في أنتيغوا وباربودا",
    "Welsh people of Antigua and Barbuda descent": "ويلزيون من أصل أنتيغوي وبربودي",
    "West German expatriate sportspeople in Antigua and Barbuda": "رياضيون ألمانيون غربيون مغتربون في أنتيغوا وباربودا",
    "West German expatriates in Antigua and Barbuda": "ألمانيون غربيون مغتربون في أنتيغوا وباربودا",
    "Wetlands of Antigua and Barbuda": "مناطق رطبة في أنتيغوا وباربودا",
    "Women's cricket in Antigua and Barbuda": "الكريكت للسيدات في أنتيغوا وباربودا",
    "Years in Antigua and Barbuda by month": "سنوات في أنتيغوا وباربودا حسب الشهر",
    "Youth in Antigua and Barbuda": "الشباب في أنتيغوا وباربودا",
    "Youth organisations based in Antigua and Barbuda": "منظمات شبابية مقرها في أنتيغوا وباربودا",
    "Youth sport in Antigua and Barbuda": "رياضة شبابية في أنتيغوا وباربودا",
}

to_test = [
    ("test_antigua_and_barbuda_0", data_0),
    ("test_antigua_and_barbuda_1", data_1),
]


@pytest.mark.parametrize("category, expected", data_0.items(), ids=data_0.keys())
@pytest.mark.fast
def test_antigua_and_barbuda_0(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_antigua_and_barbuda_1(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)
    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"


@pytest.mark.parametrize("name,data", [("test_antigua_and_barbuda_data_skip", data_skip)])
@pytest.mark.skip2
def test_dump_it_skip2(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)
    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
