#
import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {}

data2 = {
    "Category:1964 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1964",
    "Category:1972 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1972",
    "Category:2003 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2003",
    "Category:2026 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2026",
    "Category:american women's sports": "تصنيف:رياضات نسائية أمريكية",
    "Category:canadian women's sports": "تصنيف:رياضات نسائية كندية",
    "Category:mexican women's sports": "تصنيف:رياضات نسائية مكسيكية",
    "Category:1550 in sports": "تصنيف:ألعاب رياضية في 1550",
    "Category:december 1550 in sports": "تصنيف:ألعاب رياضية في ديسمبر 1550",
    "Category:june 1550 in sports": "تصنيف:ألعاب رياضية في يونيو 1550",
    "Category:Sports leagues in Papua New Guinea": "تصنيف:دوريات رياضية في بابوا غينيا الجديدة",
    "Category:honduran people in sports": "تصنيف:هندوراسيون في ألعاب رياضية",
    "Category:Jewish sports": "تصنيف:ألعاب رياضية يهودية",
    "Category:surinamese sports federation": "تصنيف:الاتحاد السورينامي للرياضة",
    "Category:zaïrean wheelchair sports federation": "تصنيف:الاتحاد الزائيري للرياضة على الكراسي المتحركة",
    "Category:American women's sports by year": "تصنيف:رياضات نسائية أمريكية حسب السنة",
    "Category:American women's sports by decade": "تصنيف:رياضات نسائية أمريكية حسب العقد",
    "Category:1887 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1887",
    "Category:1889 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1889",
    "Category:1930 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1930",
    "Category:1931 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1931",
    "Category:1934 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1934",
    "Category:1938 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1938",
    "Category:1945 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1945",
    "Category:1946 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1946",
    "Category:1947 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1947",
    "Category:1948 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1948",
    "Category:1950 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1950",
    "Category:1951 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1951",
    "Category:1953 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1953",
    "Category:1954 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1954",
    "Category:1955 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1955",
    "Category:1956 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1956",
    "Category:1959 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1959",
    "Category:1961 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1961",
    "Category:1963 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1963",
    "Category:1966 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1966",
    "Category:1967 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1967",
    "Category:1968 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1968",
    "Category:1970 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1970",
    "Category:1971 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1971",
    "Category:1973 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1973",
    "Category:1974 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1974",
    "Category:1975 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1975",
    "Category:1978 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1978",
    "Category:1979 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1979",
    "Category:1980 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1980",
    "Category:1982 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1982",
    "Category:1983 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1983",
    "Category:1984 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1984",
    "Category:1985 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1985",
    "Category:1986 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1986",
    "Category:1987 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1987",
    "Category:1989 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1989",
    "Category:1990 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1990",
    "Category:1991 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1991",
    "Category:1992 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1992",
    "Category:1993 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1993",
    "Category:1995 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1995",
    "Category:1996 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1996",
    "Category:1998 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 1998",
    "Category:2000 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2000",
    "Category:2001 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2001",
    "Category:2004 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2004",
    "Category:2005 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2005",
    "Category:2006 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2006",
    "Category:2007 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2007",
    "Category:2009 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2009",
    "Category:2010 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2010",
    "Category:2011 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2011",
    "Category:2012 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2012",
    "Category:2013 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2013",
    "Category:2014 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2014",
    "Category:2015 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2015",
    "Category:2016 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2016",
    "Category:2017 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2017",
    "Category:2018 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2018",
    "Category:2021 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2021",
    "Category:2022 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2022",
    "Category:2023 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2023",
    "Category:2024 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2024",
    "Category:2025 in American women's sports": "تصنيف:رياضات نسائية أمريكية في 2025",
    "Category:1880s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1880",
    "Category:1930s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1930",
    "Category:1940s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1940",
    "Category:1950s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1950",
    "Category:1960s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1960",
    "Category:1970s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1970",
    "Category:1980s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1980",
    "Category:1990s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 1990",
    "Category:2010s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 2010",
    "Category:2020s in American women's sports": "تصنيف:رياضات نسائية أمريكية في عقد 2020",
    "Category:Canadian women's sports by year": "تصنيف:رياضات نسائية كندية حسب السنة",
    "Category:Canadian women's sports by decade": "تصنيف:رياضات نسائية كندية حسب العقد",
    "Category:1983 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 1983",
    "Category:2004 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2004",
    "Category:2007 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2007",
    "Category:2011 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2011",
    "Category:2012 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2012",
    "Category:2023 in Canadian women's sports": "تصنيف:رياضات نسائية كندية في 2023",
    "Category:1980s in Canadian women's sports": "تصنيف:رياضات نسائية كندية في عقد 1980",
    "Category:1990s in Canadian women's sports": "تصنيف:رياضات نسائية كندية في عقد 1990",
    "Category:2000s in Canadian women's sports": "تصنيف:رياضات نسائية كندية في عقد 2000",
    "Category:2010s in Canadian women's sports": "تصنيف:رياضات نسائية كندية في عقد 2010",
    "Category:2020s in Canadian women's sports": "تصنيف:رياضات نسائية كندية في عقد 2020",
    "Category:Mexican women's sports by year": "تصنيف:رياضات نسائية مكسيكية حسب السنة",
    "Category:Mexican women's sports by decade": "تصنيف:رياضات نسائية مكسيكية حسب العقد",
    "Category:1971 in Mexican women's sports": "تصنيف:رياضات نسائية مكسيكية في 1971",
    "Category:1974 in Mexican women's sports": "تصنيف:رياضات نسائية مكسيكية في 1974",
    "Category:2010 in Mexican women's sports": "تصنيف:رياضات نسائية مكسيكية في 2010",
    "Category:1970s in Mexican women's sports": "تصنيف:رياضات نسائية مكسيكية في عقد 1970",
    "Category:2010s in Mexican women's sports": "تصنيف:رياضات نسائية مكسيكية في عقد 2010",
}

data3 = {
    "Category:Documentary films about women's sports": "تصنيف:أفلام وثائقية عن رياضات نسائية",
    "Category:History of women's sports": "تصنيف:تاريخ رياضات نسائية",
    "Category:Women's sports by dependent territory": "تصنيف:رياضات نسائية حسب الأقاليم التابعة",
    "Category:Women's sports by populated place": "تصنيف:رياضات نسائية حسب المكان المأهول",
    "Category:Women's sports by sport and country": "تصنيف:رياضات نسائية حسب الرياضة والبلد",
    "Category:Women's sports by year": "تصنيف:رياضات نسائية حسب السنة",
    "Category:Women's sports in American Samoa": "تصنيف:رياضات نسائية في ساموا الأمريكية",
    "Category:Women's sports in Arizona": "تصنيف:رياضات نسائية في أريزونا",
    "Category:Women's sports in Atlanta": "تصنيف:رياضات نسائية في أتلانتا (جورجيا)",
    "Category:Women's sports in Boston": "تصنيف:رياضات نسائية في بوسطن",
    "Category:Women's sports in Botswana": "تصنيف:رياضات نسائية في بوتسوانا",
    "Category:Women's sports in British Columbia": "تصنيف:رياضات نسائية في كولومبيا البريطانية",
    "Category:Women's sports in California": "تصنيف:رياضات نسائية في كاليفورنيا",
    "Category:Women's sports in Canada": "تصنيف:رياضات نسائية في كندا",
    "Category:Women's sports in Charlotte, North Carolina": "تصنيف:رياضات نسائية في تشارلوت (كارولاينا الشمالية)",
    "Category:Women's sports in Chicago": "تصنيف:رياضات نسائية في شيكاغو",
    "Category:Women's sports in Cleveland": "تصنيف:رياضات نسائية في كليفلاند",
    "Category:Women's sports in Connecticut": "تصنيف:رياضات نسائية في كونيتيكت",
    "Category:Women's sports in Dallas": "تصنيف:رياضات نسائية في دالاس",
    "Category:Women's sports in Detroit": "تصنيف:رياضات نسائية في ديترويت",
    "Category:Women's sports in Florida": "تصنيف:رياضات نسائية في فلوريدا",
    "Category:Women's sports in Georgia (U.S. state)": "تصنيف:رياضات نسائية في ولاية جورجيا",
    "Category:Women's sports in Guam": "تصنيف:رياضات نسائية في غوام",
    "Category:Women's sports in Haryana": "تصنيف:رياضات نسائية في هاريانا",
    "Category:Women's sports in Houston": "تصنيف:رياضات نسائية في هيوستن",
    "Category:Women's sports in Illinois": "تصنيف:رياضات نسائية في إلينوي",
    "Category:Women's sports in Indiana": "تصنيف:رياضات نسائية في إنديانا",
    "Category:Women's sports in insular areas of the United States": "تصنيف:رياضات نسائية في المناطق المعزولة في الولايات المتحدة",
    "Category:Women's sports in Iowa": "تصنيف:رياضات نسائية في آيوا",
    "Category:Women's sports in Istanbul": "تصنيف:رياضات نسائية في إسطنبول",
    "Category:Women's sports in Kansas": "تصنيف:رياضات نسائية في كانساس",
    "Category:Women's sports in Kansas City, Missouri": "تصنيف:رياضات نسائية في كانساس سيتي (ميزوري)",
    "Category:Women's sports in Kentucky": "تصنيف:رياضات نسائية في كنتاكي",
    "Category:Women's sports in Lebanon": "تصنيف:رياضات نسائية في لبنان",
    "Category:Women's sports in Los Angeles": "تصنيف:رياضات نسائية في لوس أنجلوس",
    "Category:Women's sports in Louisiana": "تصنيف:رياضات نسائية في لويزيانا",
    "Category:Women's sports in Manitoba": "تصنيف:رياضات نسائية في مانيتوبا",
    "Category:Women's sports in Maryland": "تصنيف:رياضات نسائية في ماريلند",
    "Category:Women's sports in Massachusetts": "تصنيف:رياضات نسائية في ماساتشوستس",
    "Category:Women's sports in Miami": "تصنيف:رياضات نسائية في ميامي",
    "Category:Women's sports in Michigan": "تصنيف:رياضات نسائية في ميشيغان",
    "Category:Women's sports in Minnesota": "تصنيف:رياضات نسائية في منيسوتا",
    "Category:Women's sports in Missouri": "تصنيف:رياضات نسائية في ميزوري",
    "Category:Women's sports in Nevada": "تصنيف:رياضات نسائية في نيفادا",
    "Category:Women's sports in New Jersey": "تصنيف:رياضات نسائية في نيوجيرسي",
    "Category:Women's sports in New York (state)": "تصنيف:رياضات نسائية في ولاية نيويورك",
    "Category:Women's sports in New York City": "تصنيف:رياضات نسائية في مدينة نيويورك",
    "Category:Women's sports in North America": "تصنيف:رياضات نسائية في أمريكا الشمالية",
    "Category:Women's sports in North Carolina": "تصنيف:رياضات نسائية في كارولاينا الشمالية",
    "Category:Women's sports in Nova Scotia": "تصنيف:رياضات نسائية في نوفا سكوشا",
    "Category:Women's sports in Oceania": "تصنيف:رياضات نسائية في أوقيانوسيا",
    "Category:Women's sports in Ohio": "تصنيف:رياضات نسائية في أوهايو",
    "Category:Women's sports in Oklahoma": "تصنيف:رياضات نسائية في أوكلاهوما",
    "Category:Women's sports in Pennsylvania": "تصنيف:رياضات نسائية في بنسلفانيا",
    "Category:Women's sports in Philadelphia": "تصنيف:رياضات نسائية في فيلادلفيا",
    "Category:Women's sports in Puerto Rico": "تصنيف:رياضات نسائية في بورتوريكو",
    "Category:Women's sports in Quebec": "تصنيف:رياضات نسائية في كيبك",
    "Category:Women's sports in Quebec City": "تصنيف:رياضات نسائية في مدينة كيبك",
    "Category:Women's sports in Rhode Island": "تصنيف:رياضات نسائية في رود آيلاند",
    "Category:Women's sports in San Diego": "تصنيف:رياضات نسائية في سان دييغو",
    "Category:Women's sports in Seattle": "تصنيف:رياضات نسائية في سياتل",
    "Category:Women's sports in South Carolina": "تصنيف:رياضات نسائية في كارولاينا الجنوبية",
    "Category:Women's sports in Texas": "تصنيف:رياضات نسائية في تكساس",
    "Category:Women's sports in the Philippines": "تصنيف:رياضات نسائية في الفلبين",
    "Category:Women's sports in the United States": "تصنيف:رياضات نسائية في الولايات المتحدة",
    "Category:Women's sports in the United States by state": "تصنيف:رياضات نسائية في الولايات المتحدة حسب الولاية",
    "Category:Women's sports in Utah": "تصنيف:رياضات نسائية في يوتا",
    "Category:Women's sports in Vancouver": "تصنيف:رياضات نسائية في فانكوفر",
    "Category:Women's sports in West Germany": "تصنيف:رياضات نسائية في ألمانيا الغربية",
    "Category:Women's sports in Wisconsin": "تصنيف:رياضات نسائية في ويسكونسن",
    "Category:Works about women's sports": "تصنيف:أعمال عن رياضات نسائية",
    "Category:1884 in women's sport": "تصنيف:رياضة نسائية في 1884",
    "Category:1885 in women's sport": "تصنيف:رياضة نسائية في 1885",
    "Category:1886 in women's sport": "تصنيف:رياضة نسائية في 1886",
    "Category:1887 in women's sport": "تصنيف:رياضة نسائية في 1887",
    "Category:1888 in women's sport": "تصنيف:رياضة نسائية في 1888",
    "Category:1891 in women's sport": "تصنيف:رياضة نسائية في 1891",
    "Category:1892 in women's sport": "تصنيف:رياضة نسائية في 1892",
    "Category:1893 in women's sport": "تصنيف:رياضة نسائية في 1893",
    "Category:1894 in women's sport": "تصنيف:رياضة نسائية في 1894",
    "Category:1895 in women's sport": "تصنيف:رياضة نسائية في 1895",
    "Category:1896 in women's sport": "تصنيف:رياضة نسائية في 1896",
    "Category:1897 in women's sport": "تصنيف:رياضة نسائية في 1897",
    "Category:1901 in women's sport": "تصنيف:رياضة نسائية في 1901",
    "Category:1902 in women's sport": "تصنيف:رياضة نسائية في 1902",
    "Category:1903 in women's sport": "تصنيف:رياضة نسائية في 1903",
    "Category:1904 in women's sport": "تصنيف:رياضة نسائية في 1904",
    "Category:1905 in women's sport": "تصنيف:رياضة نسائية في 1905",
    "Category:1906 in women's sport": "تصنيف:رياضة نسائية في 1906",
    "Category:1907 in women's sport": "تصنيف:رياضة نسائية في 1907",
    "Category:1908 in women's sport": "تصنيف:رياضة نسائية في 1908",
    "Category:1909 in women's sport": "تصنيف:رياضة نسائية في 1909",
    "Category:1910 in women's sport": "تصنيف:رياضة نسائية في 1910",
    "Category:1911 in women's sport": "تصنيف:رياضة نسائية في 1911",
    "Category:1912 in women's sport": "تصنيف:رياضة نسائية في 1912",
    "Category:1913 in women's sport": "تصنيف:رياضة نسائية في 1913",
    "Category:1914 in women's sport": "تصنيف:رياضة نسائية في 1914",
    "Category:1919 in women's sport": "تصنيف:رياضة نسائية في 1919",
    "Category:1920 in women's sport": "تصنيف:رياضة نسائية في 1920",
    "Category:1921 in women's sport": "تصنيف:رياضة نسائية في 1921",
    "Category:1922 in women's sport": "تصنيف:رياضة نسائية في 1922",
    "Category:1923 in women's sport": "تصنيف:رياضة نسائية في 1923",
    "Category:1924 in women's sport": "تصنيف:رياضة نسائية في 1924",
    "Category:1926 in women's sport": "تصنيف:رياضة نسائية في 1926",
    "Category:1927 in women's sport": "تصنيف:رياضة نسائية في 1927",
    "Category:1928 in women's sport": "تصنيف:رياضة نسائية في 1928",
    "Category:1929 in women's sport": "تصنيف:رياضة نسائية في 1929",
    "Category:1930 in women's sport": "تصنيف:رياضة نسائية في 1930",
    "Category:1932 in women's sport": "تصنيف:رياضة نسائية في 1932",
    "Category:1933 in women's sport": "تصنيف:رياضة نسائية في 1933",
    "Category:1934 in women's sport": "تصنيف:رياضة نسائية في 1934",
    "Category:1936 in women's sport": "تصنيف:رياضة نسائية في 1936",
    "Category:1937 in women's sport": "تصنيف:رياضة نسائية في 1937",
    "Category:1946 in women's sport": "تصنيف:رياضة نسائية في 1946",
    "Category:1947 in women's sport": "تصنيف:رياضة نسائية في 1947",
    "Category:1948 in women's sport": "تصنيف:رياضة نسائية في 1948",
    "Category:1949 in women's sport": "تصنيف:رياضة نسائية في 1949",
    "Category:1950 in women's sport": "تصنيف:رياضة نسائية في 1950",
    "Category:1952 in women's sport": "تصنيف:رياضة نسائية في 1952",
    "Category:1953 in women's sport": "تصنيف:رياضة نسائية في 1953",
    "Category:1954 in women's sport": "تصنيف:رياضة نسائية في 1954",
    "Category:1956 in women's sport": "تصنيف:رياضة نسائية في 1956",
    "Category:1957 in women's sport": "تصنيف:رياضة نسائية في 1957",
    "Category:1959 in women's sport": "تصنيف:رياضة نسائية في 1959",
    "Category:1961 in women's sport": "تصنيف:رياضة نسائية في 1961",
    "Category:1963 in women's sport": "تصنيف:رياضة نسائية في 1963",
    "Category:1964 in women's sport": "تصنيف:رياضة نسائية في 1964",
    "Category:1965 in women's sport": "تصنيف:رياضة نسائية في 1965",
    "Category:1969 in women's sport": "تصنيف:رياضة نسائية في 1969",
    "Category:1970 in women's sport": "تصنيف:رياضة نسائية في 1970",
    "Category:1971 in women's sport": "تصنيف:رياضة نسائية في 1971",
    "Category:1972 in women's sport": "تصنيف:رياضة نسائية في 1972",
    "Category:1973 in women's sport": "تصنيف:رياضة نسائية في 1973",
    "Category:1974 in women's sport": "تصنيف:رياضة نسائية في 1974",
    "Category:1974 in women's sport by country": "تصنيف:رياضة نسائية في 1974 حسب البلد",
    "Category:1975 in women's sport": "تصنيف:رياضة نسائية في 1975",
    "Category:1976 in women's sport": "تصنيف:رياضة نسائية في 1976",
    "Category:1977 in women's sport": "تصنيف:رياضة نسائية في 1977",
    "Category:1978 in women's sport": "تصنيف:رياضة نسائية في 1978",
    "Category:1986 in women's sport by country": "تصنيف:رياضة نسائية في 1986 حسب البلد",
    "Category:1987 in women's sport by country": "تصنيف:رياضة نسائية في 1987 حسب البلد",
    "Category:1988 in women's sport": "تصنيف:رياضة نسائية في 1988",
    "Category:1988 in women's sport by country": "تصنيف:رياضة نسائية في 1988 حسب البلد",
    "Category:1989 in women's sport by country": "تصنيف:رياضة نسائية في 1989 حسب البلد",
    "Category:1990 in women's sport by country": "تصنيف:رياضة نسائية في 1990 حسب البلد",
    "Category:1991 in women's sport by country": "تصنيف:رياضة نسائية في 1991 حسب البلد",
    "Category:1992 in women's sport": "تصنيف:رياضة نسائية في 1992",
    "Category:1992 in women's sport by country": "تصنيف:رياضة نسائية في 1992 حسب البلد",
    "Category:1993 in women's sport by country": "تصنيف:رياضة نسائية في 1993 حسب البلد",
    "Category:1994 in women's sport by country": "تصنيف:رياضة نسائية في 1994 حسب البلد",
    "Category:1995 in women's sport by country": "تصنيف:رياضة نسائية في 1995 حسب البلد",
    "Category:1996 in women's sport by country": "تصنيف:رياضة نسائية في 1996 حسب البلد",
    "Category:1998 in women's sport by country": "تصنيف:رياضة نسائية في 1998 حسب البلد",
    "Category:1999 in women's sport by country": "تصنيف:رياضة نسائية في 1999 حسب البلد",
    "Category:2000 in women's sport by country": "تصنيف:رياضة نسائية في 2000 حسب البلد",
    "Category:2001 in women's sport by country": "تصنيف:رياضة نسائية في 2001 حسب البلد",
    "Category:2003 in women's sport by country": "تصنيف:رياضة نسائية في 2003 حسب البلد",
    "Category:2004 in women's sport by country": "تصنيف:رياضة نسائية في 2004 حسب البلد",
    "Category:2005 in women's sport by country": "تصنيف:رياضة نسائية في 2005 حسب البلد",
    "Category:2006 in women's sport by country": "تصنيف:رياضة نسائية في 2006 حسب البلد",
    "Category:2008 in women's sport by country": "تصنيف:رياضة نسائية في 2008 حسب البلد",
    "Category:2009 in women's sport by country": "تصنيف:رياضة نسائية في 2009 حسب البلد",
    "Category:2010 in women's sport": "تصنيف:رياضة نسائية في 2010",
    "Category:2010 in women's sport by country": "تصنيف:رياضة نسائية في 2010 حسب البلد",
    "Category:2013 in women's sport by country": "تصنيف:رياضة نسائية في 2013 حسب البلد",
    "Category:2014 in women's sport": "تصنيف:رياضة نسائية في 2014",
    "Category:2014 in women's sport by country": "تصنيف:رياضة نسائية في 2014 حسب البلد",
    "Category:2015 in women's sport": "تصنيف:رياضة نسائية في 2015",
    "Category:2015 in women's sport by country": "تصنيف:رياضة نسائية في 2015 حسب البلد",
    "Category:2017 in women's sport by country": "تصنيف:رياضة نسائية في 2017 حسب البلد",
    "Category:2018 in women's sport": "تصنيف:رياضة نسائية في 2018",
    "Category:2018 in women's sport by country": "تصنيف:رياضة نسائية في 2018 حسب البلد",
    "Category:2019 in women's sport by country": "تصنيف:رياضة نسائية في 2019 حسب البلد",
    "Category:Women's sport-related lists": "تصنيف:قوائم متعلقة برياضة نسائية",
    "Category:Women's sport by country and year": "تصنيف:رياضة نسائية حسب البلد والسنة",
    "Category:Women's sport by year and country": "تصنيف:رياضة نسائية حسب السنة والبلد",
    "Category:Women's sport in Afghanistan": "تصنيف:رياضة نسائية في أفغانستان",
    "Category:Women's sport in Albania": "تصنيف:رياضة نسائية في ألبانيا",
    "Category:Women's sport in Algeria": "تصنيف:رياضة نسائية في الجزائر",
    "Category:Women's sport in Amsterdam": "تصنيف:رياضة نسائية في أمستردام",
    "Category:Women's sport in Andorra": "تصنيف:رياضة نسائية في أندورا",
    "Category:Women's sport in Angola": "تصنيف:رياضة نسائية في أنغولا",
    "Category:Women's sport in Antigua and Barbuda": "تصنيف:رياضة نسائية في أنتيغوا وباربودا",
    "Category:Women's sport in Argentina": "تصنيف:رياضة نسائية في الأرجنتين",
    "Category:Women's sport in Armenia": "تصنيف:رياضة نسائية في أرمينيا",
    "Category:Women's sport in Aruba": "تصنيف:رياضة نسائية في أروبا",
    "Category:Women's sport in Australia": "تصنيف:رياضة نسائية في أستراليا",
    "Category:Women's sport in Austria": "تصنيف:رياضة نسائية في النمسا",
    "Category:Women's sport in Azerbaijan": "تصنيف:رياضة نسائية في أذربيجان",
    "Category:Women's sport in Bangladesh": "تصنيف:رياضة نسائية في بنغلاديش",
    "Category:Women's sport in Barbados": "تصنيف:رياضة نسائية في بربادوس",
    "Category:Women's sport in Belarus": "تصنيف:رياضة نسائية في روسيا البيضاء",
    "Category:Women's sport in Belgium": "تصنيف:رياضة نسائية في بلجيكا",
    "Category:Women's sport in Belize": "تصنيف:رياضة نسائية في بليز",
    "Category:Women's sport in Benin": "تصنيف:رياضة نسائية في بنين",
    "Category:Women's sport in Bermuda": "تصنيف:رياضة نسائية في برمودا",
    "Category:Women's sport in Bhutan": "تصنيف:رياضة نسائية في بوتان",
    "Category:Women's sport in Bolivia": "تصنيف:رياضة نسائية في بوليفيا",
    "Category:Women's sport in Bosnia and Herzegovina": "تصنيف:رياضة نسائية في البوسنة والهرسك",
    "Category:Women's sport in Botswana": "تصنيف:رياضة نسائية في بوتسوانا",
    "Category:Women's sport in Brazil": "تصنيف:رياضة نسائية في البرازيل",
    "Category:Women's sport in Brunei": "تصنيف:رياضة نسائية في بروناي",
    "Category:Women's sport in Bulgaria": "تصنيف:رياضة نسائية في بلغاريا",
    "Category:Women's sport in Cambodia": "تصنيف:رياضة نسائية في كمبوديا",
    "Category:Women's sport in Cameroon": "تصنيف:رياضة نسائية في الكاميرون",
    "Category:Women's sport in Central America": "تصنيف:رياضة نسائية في أمريكا الوسطى",
    "Category:Women's sport in Chile": "تصنيف:رياضة نسائية في تشيلي",
    "Category:Women's sport in China": "تصنيف:رياضة نسائية في الصين",
    "Category:Women's sport in Costa Rica": "تصنيف:رياضة نسائية في كوستاريكا",
    "Category:Women's sport in Croatia": "تصنيف:رياضة نسائية في كرواتيا",
    "Category:Women's sport in Cuba": "تصنيف:رياضة نسائية في كوبا",
    "Category:Women's sport in Cyprus": "تصنيف:رياضة نسائية في قبرص",
    "Category:Women's sport in Czechoslovakia": "تصنيف:رياضة نسائية في تشيكوسلوفاكيا",
    "Category:Women's sport in dependent territories of the United Kingdom": "تصنيف:رياضة نسائية في أقاليم ما وراء البحار البريطانية",
    "Category:Women's sport in Djibouti": "تصنيف:رياضة نسائية في جيبوتي",
    "Category:Women's sport in East Germany": "تصنيف:رياضة نسائية في ألمانيا الشرقية",
    "Category:Women's sport in Ecuador": "تصنيف:رياضة نسائية في الإكوادور",
    "Category:Women's sport in Egypt": "تصنيف:رياضة نسائية في مصر",
    "Category:Women's sport in El Salvador": "تصنيف:رياضة نسائية في السلفادور",
    "Category:Women's sport in England": "تصنيف:رياضة نسائية في إنجلترا",
    "Category:Women's sport in Equatorial Guinea": "تصنيف:رياضة نسائية في غينيا الاستوائية",
    "Category:Women's sport in Estonia": "تصنيف:رياضة نسائية في إستونيا",
    "Category:Women's sport in Ethiopia": "تصنيف:رياضة نسائية في إثيوبيا",
    "Category:Women's sport in Fiji": "تصنيف:رياضة نسائية في فيجي",
    "Category:Women's sport in Finland": "تصنيف:رياضة نسائية في فنلندا",
    "Category:Women's sport in France": "تصنيف:رياضة نسائية في فرنسا",
    "Category:Women's sport in French Guiana": "تصنيف:رياضة نسائية في غويانا الفرنسية",
    "Category:Women's sport in Gabon": "تصنيف:رياضة نسائية في الغابون",
    "Category:Women's sport in Georgia (country)": "تصنيف:رياضة نسائية في جورجيا",
    "Category:Women's sport in Germany": "تصنيف:رياضة نسائية في ألمانيا",
    "Category:Women's sport in Ghana": "تصنيف:رياضة نسائية في غانا",
    "Category:Women's sport in Gibraltar": "تصنيف:رياضة نسائية في جبل طارق",
    "Category:Women's sport in Greenland": "تصنيف:رياضة نسائية في جرينلاند",
    "Category:Women's sport in Grenada": "تصنيف:رياضة نسائية في غرينادا",
    "Category:Women's sport in Guadeloupe": "تصنيف:رياضة نسائية في غوادلوب",
    "Category:Women's sport in Guatemala": "تصنيف:رياضة نسائية في غواتيمالا",
    "Category:Women's sport in Guinea": "تصنيف:رياضة نسائية في غينيا",
    "Category:Women's sport in Guyana": "تصنيف:رياضة نسائية في غيانا",
    "Category:Women's sport in Haiti": "تصنيف:رياضة نسائية في هايتي",
    "Category:Women's sport in Hong Kong": "تصنيف:رياضة نسائية في هونغ كونغ",
    "Category:Women's sport in Hungary": "تصنيف:رياضة نسائية في المجر",
    "Category:Women's sport in Iceland": "تصنيف:رياضة نسائية في آيسلندا",
    "Category:Women's sport in India": "تصنيف:رياضة نسائية في الهند",
    "Category:Women's sport in Indonesia": "تصنيف:رياضة نسائية في إندونيسيا",
    "Category:Women's sport in Iran": "تصنيف:رياضة نسائية في إيران",
    "Category:Women's sport in Iraq": "تصنيف:رياضة نسائية في العراق",
    "Category:Women's sport in Ireland": "تصنيف:رياضة نسائية في أيرلندا",
    "Category:Women's sport in Ireland by sport": "تصنيف:رياضة نسائية في أيرلندا حسب الرياضة",
    "Category:Women's sport in Israel": "تصنيف:رياضة نسائية في إسرائيل",
    "Category:Women's sport in Italy": "تصنيف:رياضة نسائية في إيطاليا",
    "Category:Women's sport in Ivory Coast": "تصنيف:رياضة نسائية في ساحل العاج",
    "Category:Women's sport in Jamaica": "تصنيف:رياضة نسائية في جامايكا",
    "Category:Women's sport in Japan": "تصنيف:رياضة نسائية في اليابان",
    "Category:Women's sport in Jordan": "تصنيف:رياضة نسائية في الأردن",
    "Category:Women's sport in Kazakhstan": "تصنيف:رياضة نسائية في كازاخستان",
    "Category:Women's sport in Kenya": "تصنيف:رياضة نسائية في كينيا",
    "Category:Women's sport in Korea": "تصنيف:رياضة نسائية في كوريا",
    "Category:Women's sport in Kosovo": "تصنيف:رياضة نسائية في كوسوفو",
    "Category:Women's sport in Kuwait": "تصنيف:رياضة نسائية في الكويت",
    "Category:Women's sport in Kyrgyzstan": "تصنيف:رياضة نسائية في قيرغيزستان",
    "Category:Women's sport in Laos": "تصنيف:رياضة نسائية في لاوس",
    "Category:Women's sport in Latvia": "تصنيف:رياضة نسائية في لاتفيا",
    "Category:Women's sport in Lebanon": "تصنيف:رياضة نسائية في لبنان",
    "Category:Women's sport in Lesotho": "تصنيف:رياضة نسائية في ليسوتو",
    "Category:Women's sport in Liberia": "تصنيف:رياضة نسائية في ليبيريا",
    "Category:Women's sport in Libya": "تصنيف:رياضة نسائية في ليبيا",
    "Category:Women's sport in Liechtenstein": "تصنيف:رياضة نسائية في ليختنشتاين",
    "Category:Women's sport in Lithuania": "تصنيف:رياضة نسائية في ليتوانيا",
    "Category:Women's sport in London": "تصنيف:رياضة نسائية في لندن",
    "Category:Women's sport in Luxembourg": "تصنيف:رياضة نسائية في لوكسمبورغ",
    "Category:Women's sport in Macau": "تصنيف:رياضة نسائية في ماكاو",
    "Category:Women's sport in Madagascar": "تصنيف:رياضة نسائية في مدغشقر",
    "Category:Women's sport in Malawi": "تصنيف:رياضة نسائية في ملاوي",
    "Category:Women's sport in Malaysia": "تصنيف:رياضة نسائية في ماليزيا",
    "Category:Women's sport in Mali": "تصنيف:رياضة نسائية في مالي",
    "Category:Women's sport in Malta": "تصنيف:رياضة نسائية في مالطا",
    "Category:Women's sport in Mauritius": "تصنيف:رياضة نسائية في موريشيوس",
    "Category:Women's sport in Mexico": "تصنيف:رياضة نسائية في المكسيك",
    "Category:Women's sport in Moldova": "تصنيف:رياضة نسائية في مولدوفا",
    "Category:Women's sport in Monaco": "تصنيف:رياضة نسائية في موناكو",
    "Category:Women's sport in Mongolia": "تصنيف:رياضة نسائية في منغوليا",
    "Category:Women's sport in Montenegro": "تصنيف:رياضة نسائية في الجبل الأسود",
    "Category:Women's sport in Morocco": "تصنيف:رياضة نسائية في المغرب",
    "Category:Women's sport in Mozambique": "تصنيف:رياضة نسائية في موزمبيق",
    "Category:Women's sport in Myanmar": "تصنيف:رياضة نسائية في ميانمار",
    "Category:Women's sport in Namibia": "تصنيف:رياضة نسائية في ناميبيا",
    "Category:Women's sport in Nepal": "تصنيف:رياضة نسائية في نيبال",
    "Category:Women's sport in New Zealand": "تصنيف:رياضة نسائية في نيوزيلندا",
    "Category:Women's sport in Nicaragua": "تصنيف:رياضة نسائية في نيكاراغوا",
    "Category:Women's sport in Niger": "تصنيف:رياضة نسائية في النيجر",
    "Category:Women's sport in Nigeria": "تصنيف:رياضة نسائية في نيجيريا",
    "Category:Women's sport in North Korea": "تصنيف:رياضة نسائية في كوريا الشمالية",
    "Category:Women's sport in North Macedonia": "تصنيف:رياضة نسائية في مقدونيا الشمالية",
    "Category:Women's sport in Northern Ireland": "تصنيف:رياضة نسائية في أيرلندا الشمالية",
    "Category:Women's sport in Norway": "تصنيف:رياضة نسائية في النرويج",
    "Category:Women's sport in Oman": "تصنيف:رياضة نسائية في سلطنة عمان",
    "Category:Women's sport in Pakistan": "تصنيف:رياضة نسائية في باكستان",
    "Category:Women's sport in Palestine": "تصنيف:رياضة نسائية في فلسطين",
    "Category:Women's sport in Panama": "تصنيف:رياضة نسائية في بنما",
    "Category:Women's sport in Papua New Guinea": "تصنيف:رياضة نسائية في بابوا غينيا الجديدة",
    "Category:Women's sport in Paraguay": "تصنيف:رياضة نسائية في باراغواي",
    "Category:Women's sport in Peru": "تصنيف:رياضة نسائية في بيرو",
    "Category:Women's sport in Poland": "تصنيف:رياضة نسائية في بولندا",
    "Category:Women's sport in Portugal": "تصنيف:رياضة نسائية في البرتغال",
    "Category:Women's sport in Qatar": "تصنيف:رياضة نسائية في قطر",
    "Category:Women's sport in Romania": "تصنيف:رياضة نسائية في رومانيا",
    "Category:Women's sport in Russia": "تصنيف:رياضة نسائية في روسيا",
    "Category:Women's sport in Rwanda": "تصنيف:رياضة نسائية في رواندا",
    "Category:Women's sport in Samoa": "تصنيف:رياضة نسائية في ساموا",
    "Category:Women's sport in San Marino": "تصنيف:رياضة نسائية في سان مارينو",
    "Category:Women's sport in Scotland": "تصنيف:رياضة نسائية في إسكتلندا",
    "Category:Women's sport in Senegal": "تصنيف:رياضة نسائية في السنغال",
    "Category:Women's sport in Serbia": "تصنيف:رياضة نسائية في صربيا",
    "Category:Women's sport in Seychelles": "تصنيف:رياضة نسائية في سيشل",
    "Category:Women's sport in Singapore": "تصنيف:رياضة نسائية في سنغافورة",
    "Category:Women's sport in Slovakia": "تصنيف:رياضة نسائية في سلوفاكيا",
    "Category:Women's sport in Slovenia": "تصنيف:رياضة نسائية في سلوفينيا",
    "Category:Women's sport in Somalia": "تصنيف:رياضة نسائية في الصومال",
    "Category:Women's sport in South Africa": "تصنيف:رياضة نسائية في جنوب إفريقيا",
    "Category:Women's sport in South Korea": "تصنيف:رياضة نسائية في كوريا الجنوبية",
    "Category:Women's sport in South Sudan": "تصنيف:رياضة نسائية في جنوب السودان",
    "Category:Women's sport in Southeast Asia": "تصنيف:رياضة نسائية في جنوب شرق آسيا",
    "Category:Women's sport in Spain": "تصنيف:رياضة نسائية في إسبانيا",
    "Category:Women's sport in Sri Lanka": "تصنيف:رياضة نسائية في سريلانكا",
    "Category:Women's sport in Sudan": "تصنيف:رياضة نسائية في السودان",
    "Category:Women's sport in Switzerland": "تصنيف:رياضة نسائية في سويسرا",
    "Category:Women's sport in Syria": "تصنيف:رياضة نسائية في سوريا",
    "Category:Women's sport in Taiwan": "تصنيف:رياضة نسائية في تايوان",
    "Category:Women's sport in Tajikistan": "تصنيف:رياضة نسائية في طاجيكستان",
    "Category:Women's sport in Tanzania": "تصنيف:رياضة نسائية في تنزانيا",
    "Category:Women's sport in Thailand": "تصنيف:رياضة نسائية في تايلاند",
    "Category:Women's sport in the Bahamas": "تصنيف:رياضة نسائية في باهاماس",
    "Category:Women's sport in the Caribbean": "تصنيف:رياضة نسائية في الكاريبي",
    "Category:Women's sport in the Cayman Islands": "تصنيف:رياضة نسائية في جزر كايمان",
    "Category:Women's sport in the Central African Republic": "تصنيف:رياضة نسائية في جمهورية إفريقيا الوسطى",
    "Category:Women's sport in the Comoros": "تصنيف:رياضة نسائية في جزر القمر",
    "Category:Women's sport in the Czech Republic": "تصنيف:رياضة نسائية في التشيك",
    "Category:Women's sport in the Democratic Republic of the Congo": "تصنيف:رياضة نسائية في جمهورية الكونغو الديمقراطية",
    "Category:Women's sport in the Dominican Republic": "تصنيف:رياضة نسائية في جمهورية الدومينيكان",
    "Category:Women's sport in the Faroe Islands": "تصنيف:رياضة نسائية في جزر فارو",
    "Category:Women's sport in the Republic of Ireland": "تصنيف:رياضة نسائية في جمهورية أيرلندا",
    "Category:Women's sport in the Republic of the Congo": "تصنيف:رياضة نسائية في جمهورية الكونغو",
    "Category:Women's sport in the Soviet Union": "تصنيف:رياضة نسائية في الاتحاد السوفيتي",
    "Category:Women's sport in the United Arab Emirates": "تصنيف:رياضة نسائية في الإمارات العربية المتحدة",
    "Category:Women's sport in the United Kingdom": "تصنيف:رياضة نسائية في المملكة المتحدة",
    "Category:Women's sport in Togo": "تصنيف:رياضة نسائية في توغو",
    "Category:Women's sport in Trinidad and Tobago": "تصنيف:رياضة نسائية في ترينيداد وتوباغو",
    "Category:Women's sport in Tunisia": "تصنيف:رياضة نسائية في تونس",
    "Category:Women's sport in Turkey": "تصنيف:رياضة نسائية في تركيا",
    "Category:Women's sport in Turkmenistan": "تصنيف:رياضة نسائية في تركمانستان",
    "Category:Women's sport in Uganda": "تصنيف:رياضة نسائية في أوغندا",
    "Category:Women's sport in Ukraine": "تصنيف:رياضة نسائية في أوكرانيا",
    "Category:Women's sport in Uruguay": "تصنيف:رياضة نسائية في أوروغواي",
    "Category:Women's sport in Uzbekistan": "تصنيف:رياضة نسائية في أوزبكستان",
    "Category:Women's sport in Vanuatu": "تصنيف:رياضة نسائية في فانواتو",
    "Category:Women's sport in Venezuela": "تصنيف:رياضة نسائية في فنزويلا",
    "Category:Women's sport in Vietnam": "تصنيف:رياضة نسائية في فيتنام",
    "Category:Women's sport in Wales": "تصنيف:رياضة نسائية في ويلز",
    "Category:Women's sport in West Germany": "تصنيف:رياضة نسائية في ألمانيا الغربية",
    "Category:Women's sport in Yemen": "تصنيف:رياضة نسائية في اليمن",
    "Category:Women's sport in Yugoslavia": "تصنيف:رياضة نسائية في يوغسلافيا",
    "Category:Women's sport in Zambia": "تصنيف:رياضة نسائية في زامبيا",
    "Category:Women's sport in Zimbabwe": "تصنيف:رياضة نسائية في زيمبابوي",
    "Category:Women's sport navigational boxes": "تصنيف:صناديق تصفح رياضة نسائية",
    "Category:Women's sport templates": "تصنيف:قوالب رياضة نسائية",
    "Category:Women's sports clubs and teams in Afghanistan": "تصنيف:أندية وفرق رياضية نسائية في أفغانستان",
    "Category:Women's sports clubs and teams in Albania": "تصنيف:أندية وفرق رياضية نسائية في ألبانيا",
    "Category:Women's sports clubs and teams in Andorra": "تصنيف:أندية وفرق رياضية نسائية في أندورا",
    "Category:Women's sports clubs and teams in Armenia": "تصنيف:أندية وفرق رياضية نسائية في أرمينيا",
    "Category:Women's sports clubs and teams in Azerbaijan": "تصنيف:أندية وفرق رياضية نسائية في أذربيجان",
    "Category:Women's sports clubs and teams in Bangladesh": "تصنيف:أندية وفرق رياضية نسائية في بنغلاديش",
    "Category:Women's sports clubs and teams in Botswana": "تصنيف:أندية وفرق رياضية نسائية في بوتسوانا",
    "Category:Women's sports clubs and teams in Denmark": "تصنيف:أندية وفرق رياضية نسائية في الدنمارك",
    "Category:Women's sports clubs and teams in Fiji": "تصنيف:أندية وفرق رياضية نسائية في فيجي",
    "Category:Women's sports clubs and teams in Gabon": "تصنيف:أندية وفرق رياضية نسائية في الغابون",
    "Category:Women's sports clubs and teams in Georgia (country)": "تصنيف:أندية وفرق رياضية نسائية في جورجيا",
    "Category:Women's sports clubs and teams in Guatemala": "تصنيف:أندية وفرق رياضية نسائية في غواتيمالا",
    "Category:Women's sports clubs and teams in Guyana": "تصنيف:أندية وفرق رياضية نسائية في غيانا",
    "Category:Women's sports clubs and teams in Haiti": "تصنيف:أندية وفرق رياضية نسائية في هايتي",
    "Category:Women's sports clubs and teams in Hong Kong": "تصنيف:أندية وفرق رياضية نسائية في هونغ كونغ",
    "Category:Women's sports clubs and teams in Ivory Coast": "تصنيف:أندية وفرق رياضية نسائية في ساحل العاج",
    "Category:Women's sports clubs and teams in Kenya": "تصنيف:أندية وفرق رياضية نسائية في كينيا",
    "Category:Women's sports clubs and teams in Kosovo": "تصنيف:أندية وفرق رياضية نسائية في كوسوفو",
    "Category:Women's sports clubs and teams in Laos": "تصنيف:أندية وفرق رياضية نسائية في لاوس",
    "Category:Women's sports clubs and teams in Lebanon": "تصنيف:أندية وفرق رياضية نسائية في لبنان",
    "Category:Women's sports clubs and teams in Lesotho": "تصنيف:أندية وفرق رياضية نسائية في ليسوتو",
    "Category:Women's sports clubs and teams in Malawi": "تصنيف:أندية وفرق رياضية نسائية في ملاوي",
    "Category:Women's sports clubs and teams in Malaysia": "تصنيف:أندية وفرق رياضية نسائية في ماليزيا",
    "Category:Women's sports clubs and teams in Moldova": "تصنيف:أندية وفرق رياضية نسائية في مولدوفا",
    "Category:Women's sports clubs and teams in Montenegro": "تصنيف:أندية وفرق رياضية نسائية في الجبل الأسود",
    "Category:Women's sports clubs and teams in Morocco": "تصنيف:أندية وفرق رياضية نسائية في المغرب",
    "Category:Women's sports clubs and teams in Niger": "تصنيف:أندية وفرق رياضية نسائية في النيجر",
    "Category:Women's sports clubs and teams in Pakistan": "تصنيف:أندية وفرق رياضية نسائية في باكستان",
    "Category:Women's sports clubs and teams in Paraguay": "تصنيف:أندية وفرق رياضية نسائية في باراغواي",
    "Category:Women's sports clubs and teams in Rwanda": "تصنيف:أندية وفرق رياضية نسائية في رواندا",
    "Category:Women's sports clubs and teams in Singapore": "تصنيف:أندية وفرق رياضية نسائية في سنغافورة",
    "Category:Women's sports clubs and teams in Sri Lanka": "تصنيف:أندية وفرق رياضية نسائية في سريلانكا",
    "Category:Women's sports clubs and teams in Syria": "تصنيف:أندية وفرق رياضية نسائية في سوريا",
    "Category:Women's sports clubs and teams in Tajikistan": "تصنيف:أندية وفرق رياضية نسائية في طاجيكستان",
    "Category:Women's sports clubs and teams in the Cayman Islands": "تصنيف:أندية وفرق رياضية نسائية في جزر كايمان",
    "Category:Women's sports clubs and teams in the Central African Republic": "تصنيف:أندية وفرق رياضية نسائية في جمهورية إفريقيا الوسطى",
    "Category:Women's sports clubs and teams in the Dominican Republic": "تصنيف:أندية وفرق رياضية نسائية في جمهورية الدومينيكان",
    "Category:Women's sports clubs and teams in the Philippines": "تصنيف:أندية وفرق رياضية نسائية في الفلبين",
    "Category:Women's sports clubs and teams in Togo": "تصنيف:أندية وفرق رياضية نسائية في توغو",
    "Category:Women's sports clubs and teams in Trinidad and Tobago": "تصنيف:أندية وفرق رياضية نسائية في ترينيداد وتوباغو",
    "Category:Women's sports clubs and teams in Uganda": "تصنيف:أندية وفرق رياضية نسائية في أوغندا",
    "Category:Women's sports clubs and teams in Venezuela": "تصنيف:أندية وفرق رياضية نسائية في فنزويلا",
    "Category:Women's sports clubs and teams in Zambia": "تصنيف:أندية وفرق رياضية نسائية في زامبيا",
    "Category:Women's sports clubs and teams in Zimbabwe": "تصنيف:أندية وفرق رياضية نسائية في زيمبابوي",
    "Category:Women's sports in Indianapolis": "تصنيف:رياضات نسائية في إنديانابوليس",
    "Category:Women's sports in Minneapolis": "تصنيف:رياضات نسائية في مينيابوليس",
    "Category:Women's sports in Oregon": "تصنيف:رياضات نسائية في أوريغن",
    "Category:Women's sports in Palau": "تصنيف:رياضات نسائية في بالاو",
    "Category:Women's sports in Vienna": "تصنيف:رياضات نسائية في فيينا",
}

to_test = [
    ("test_sports_data_1", data1),
    ("test_sports_data_2", data2),
    ("test_sports_data_3", data3),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
def test_sports_data_1(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data2.items(), ids=data2.keys())
def test_sports_data_2(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data3.items(), ids=data3.keys())
def test_sports_data_3(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)
    # dump_same_and_not_same(data, diff_result, name, True)
    # dump_diff_text (expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
