#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data0 = {}

data_1 = {
    "Category:1690s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1690",
    "Category:1620s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1620",
    "Category:1580s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1580",
    "Category:1540s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1540",
    "Category:1550s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1550",
    "Category:1510s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1510",
    "Category:1520s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1520",
    "Category:1500s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1500",
    "Category:1590s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1590",
    "Category:1610s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1610",
    "Category:1630s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1630",
    "Category:1670s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1670",
    "Category:1570s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1570",
    "Category:1680s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1680",
    "Category:1460s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1460",
    "Category:1410s missing person cases": "تصنيف:قضايا أشخاص مفقودين في عقد 1410",
    "Category:Film people from Northern Ireland": "تصنيف:أعلام أفلام من أيرلندا الشمالية",
    "Category:20th-century architects from Northern Ireland": "تصنيف:معماريون من أيرلندا الشمالية في القرن 20",
    "Category:20th-century engineers from Northern Ireland": "تصنيف:مهندسون من أيرلندا الشمالية في القرن 20",
    "Category:20th-century musicians by instrument from Northern Ireland": "تصنيف:موسيقيون في القرن 20 حسب الآلة من أيرلندا الشمالية",
    "Category:21st-century engineers from Northern Ireland": "تصنيف:مهندسون من أيرلندا الشمالية في القرن 21",
    "Category:21st-century male artists from Northern Ireland": "تصنيف:فنانون ذكور من أيرلندا الشمالية في القرن 21",
    "Category:21st-century medical doctors from Northern Ireland": "تصنيف:أطباء من أيرلندا الشمالية في القرن 21",
    "Category:21st-century musicians by instrument from Northern Ireland": "تصنيف:موسيقيون في القرن 21 حسب الآلة من أيرلندا الشمالية",
    "Category:21st-century painters from Northern Ireland": "تصنيف:رسامون من أيرلندا الشمالية في القرن 21",
    "Category:21st-century women educators from Northern Ireland": "تصنيف:معلمات من أيرلندا الشمالية في القرن 21",
    "Category:21st-century women medical doctors from Northern Ireland": "تصنيف:طبيبات من أيرلندا الشمالية في القرن 21",
    "Category:Accountants from Northern Ireland": "تصنيف:محاسبون من أيرلندا الشمالية",
    "Category:Anarchists from Northern Ireland": "تصنيف:لاسلطويون من أيرلندا الشمالية",
    "Category:Archers from Northern Ireland": "تصنيف:نبالون من أيرلندا الشمالية",
    "Category:Art historians from Northern Ireland": "تصنيف:مؤرخو الفن من أيرلندا الشمالية",
    "Category:Audio engineers from Northern Ireland": "تصنيف:مهندسو صوت من أيرلندا الشمالية",
    "Category:Badminton players from Northern Ireland": "تصنيف:لاعبو تنس ريشة من أيرلندا الشمالية",
    "Category:Basketball players from Northern Ireland": "تصنيف:لاعبو كرة سلة من أيرلندا الشمالية",
    "Category:Bassoonists from Northern Ireland": "تصنيف:عازفو باسون من أيرلندا الشمالية",
    "Category:Canoeists from Northern Ireland": "تصنيف:متسابقو قوارب الكانوي من أيرلندا الشمالية",
    "Category:Cardiologists from Northern Ireland": "تصنيف:أطباء قلب من أيرلندا الشمالية",
    "Category:Choreographers from Northern Ireland": "تصنيف:مصممو رقص من أيرلندا الشمالية",
    "Category:Classical scholars from Northern Ireland": "تصنيف:باحثون كلاسيكيون من أيرلندا الشمالية",
    "Category:Comedy writers from Northern Ireland": "تصنيف:كتاب كوميديا من أيرلندا الشمالية",
    "Category:Dance music groups from Northern Ireland": "تصنيف:فرق موسيقى الرقص من أيرلندا الشمالية",
    "Category:Documentary filmmakers from Northern Ireland": "تصنيف:صانعو أفلام وثائقية من أيرلندا الشمالية",
    "Category:Editorial cartoonists from Northern Ireland": "تصنيف:محررون كارتونيون من أيرلندا الشمالية",
    "Category:Editors from Northern Ireland": "تصنيف:محررون من أيرلندا الشمالية",
    "Category:Electronic music groups from Northern Ireland": "تصنيف:فرق موسيقى إلكترونية من أيرلندا الشمالية",
    "Category:Epidemiologists from Northern Ireland": "تصنيف:علماء وبائيات من أيرلندا الشمالية",
    "Category:Explorers from Northern Ireland": "تصنيف:مستكشفون من أيرلندا الشمالية",
    "Category:Female archers from Northern Ireland": "تصنيف:نبالات من أيرلندا الشمالية",
    "Category:Female badminton players from Northern Ireland": "تصنيف:لاعبات تنس ريشة من أيرلندا الشمالية",
    "Category:Female equestrians from Northern Ireland": "تصنيف:فارسات خيول من أيرلندا الشمالية",
    "Category:Female golfers from Northern Ireland": "تصنيف:لاعبات غولف من أيرلندا الشمالية",
    "Category:Female judoka from Northern Ireland": "تصنيف:لاعبات جودو من أيرلندا الشمالية",
    "Category:Female martial artists from Northern Ireland": "تصنيف:ممارسات فنون قتالية من أيرلندا الشمالية",
    "Category:Female sport shooters from Northern Ireland": "تصنيف:لاعبات رماية من أيرلندا الشمالية",
    "Category:Female swimmers from Northern Ireland": "تصنيف:سباحات من أيرلندا الشمالية",
    "Category:Feminists from Northern Ireland": "تصنيف:نسويون من أيرلندا الشمالية",
    "Category:Fiddlers from Northern Ireland": "تصنيف:عازفو كمان من أيرلندا الشمالية",
    "Category:Film critics from Northern Ireland": "تصنيف:نقاد أفلام من أيرلندا الشمالية",
    "Category:Film editors from Northern Ireland": "تصنيف:محررو أفلام من أيرلندا الشمالية",
    "Category:Films scored by composers from Northern Ireland": "تصنيف:أفلام سجلها ملحنون من أيرلندا الشمالية",
    "Category:Folk music groups from Northern Ireland": "تصنيف:فرق موسيقى تقليدية من أيرلندا الشمالية",
    "Category:Gaelic footballers from Northern Ireland by county": "تصنيف:لاعبو كرة قدم غيلية من أيرلندا الشمالية حسب المقاطعة",
    "Category:Gaelic footballers from Northern Ireland": "تصنيف:لاعبو كرة قدم غيلية من أيرلندا الشمالية",
    "Category:Gamblers from Northern Ireland": "تصنيف:مقامرون من أيرلندا الشمالية",
    "Category:Geologists from Northern Ireland": "تصنيف:جيولوجيون من أيرلندا الشمالية",
    "Category:Horticulturists from Northern Ireland": "تصنيف:بستانيون من أيرلندا الشمالية",
    "Category:Humorists from Northern Ireland": "تصنيف:فكاهيون من أيرلندا الشمالية",
    "Category:Installation artists from Northern Ireland": "تصنيف:فنانون تنصيبيون من أيرلندا الشمالية",
    "Category:Jazz musicians from Northern Ireland": "تصنيف:موسيقيو جاز من أيرلندا الشمالية",
    "Category:Legal scholars from Northern Ireland": "تصنيف:أساتذة قانون من أيرلندا الشمالية",
    "Category:Lists of politicians from Northern Ireland": "تصنيف:قوائم سياسيون من أيرلندا الشمالية",
    "Category:Local politicians in Northern Ireland": "تصنيف:سياسيون محليون في أيرلندا الشمالية",
    "Category:Lyricists from Northern Ireland": "تصنيف:شعراء غنائيون من أيرلندا الشمالية",
    "Category:Male chefs from Northern Ireland": "تصنيف:طباخون ذكور من أيرلندا الشمالية",
    "Category:Male fiddlers from Northern Ireland": "تصنيف:عازفو كمان ذكور من أيرلندا الشمالية",
    "Category:Male sailors (sport) from Northern Ireland": "تصنيف:بحارة رياضيون ذكور من أيرلندا الشمالية",
    "Category:Male sport shooters from Northern Ireland": "تصنيف:لاعبو رماية ذكور من أيرلندا الشمالية",
    "Category:Marxists from Northern Ireland": "تصنيف:ماركسيون من أيرلندا الشمالية",
    "Category:Meteorologists from Northern Ireland": "تصنيف:خبراء أرصاد جوية من أيرلندا الشمالية",
    "Category:Music critics from Northern Ireland": "تصنيف:نقاد موسيقى من أيرلندا الشمالية",
    "Category:Music journalists from Northern Ireland": "تصنيف:صحفيون موسيقيون من أيرلندا الشمالية",
    "Category:Music video directors from Northern Ireland": "تصنيف:مخرجو فيديوهات موسيقية من أيرلندا الشمالية",
    "Category:Musicologists from Northern Ireland": "تصنيف:علماء موسيقى من أيرلندا الشمالية",
    "Category:Nature writers from Northern Ireland": "تصنيف:كتاب طبيعة من أيرلندا الشمالية",
    "Category:Netball players from Northern Ireland": "تصنيف:لاعبو كرة شبكة من أيرلندا الشمالية",
    "Category:Neurologists from Northern Ireland": "تصنيف:أطباء أعصاب من أيرلندا الشمالية",
    "Category:Neuroscientists from Northern Ireland": "تصنيف:علماء أعصاب من أيرلندا الشمالية",
    "Category:Newspaper editors from Northern Ireland": "تصنيف:محررو صحف من أيرلندا الشمالية",
    "Category:Newspaper people by newspaper in Northern Ireland": "تصنيف:شخصيات صحف حسب الصحيفة في أيرلندا الشمالية",
    "Category:Newspaper people from Northern Ireland": "تصنيف:شخصيات صحف من أيرلندا الشمالية",
    "Category:Nurses from Northern Ireland": "تصنيف:ممرضون من أيرلندا الشمالية",
    "Category:Organists from Northern Ireland": "تصنيف:عازفو أورغن من أيرلندا الشمالية",
    "Category:Ornithologists from Northern Ireland": "تصنيف:علماء طيور من أيرلندا الشمالية",
    "Category:Poker players from Northern Ireland": "تصنيف:لاعبو بوكر من أيرلندا الشمالية",
    "Category:Political scientists from Northern Ireland": "تصنيف:علماء سياسة من أيرلندا الشمالية",
    "Category:Political writers from Northern Ireland": "تصنيف:كتاب سياسة من أيرلندا الشمالية",
    "Category:Pop music groups from Northern Ireland": "تصنيف:فرق موسيقى بوب من أيرلندا الشمالية",
    "Category:Radio actresses from Northern Ireland": "تصنيف:ممثلات راديو من أيرلندا الشمالية",
    "Category:Radio producers from Northern Ireland": "تصنيف:منتجو راديو من أيرلندا الشمالية",
    "Category:Radiologists from Northern Ireland": "تصنيف:أخصائيو أشعة من أيرلندا الشمالية",
    "Category:Sailors (sport) from Northern Ireland": "تصنيف:بحارة رياضيون من أيرلندا الشمالية",
    "Category:Satirists from Northern Ireland": "تصنيف:كتاب هجائيون من أيرلندا الشمالية",
    "Category:Silent film actors from Northern Ireland": "تصنيف:ممثلو أفلام صامتة من أيرلندا الشمالية",
    "Category:Sport shooters from Northern Ireland": "تصنيف:لاعبو رماية من أيرلندا الشمالية",
    "Category:Sports broadcasters from Northern Ireland": "تصنيف:مذيعون رياضيون من أيرلندا الشمالية",
    "Category:Sportspeople from Northern Ireland in doping cases": "تصنيف:رياضيون من أيرلندا الشمالية في قضايا منشطات",
    "Category:Statisticians from Northern Ireland": "تصنيف:إحصائيون من أيرلندا الشمالية",
    "Category:Surrealist artists from Northern Ireland": "تصنيف:فنانون سرياليون من أيرلندا الشمالية",
    "Category:Table tennis players from Northern Ireland": "تصنيف:لاعبو كرة طاولة من أيرلندا الشمالية",
    "Category:Television chefs from Northern Ireland": "تصنيف:طباخو تلفاز من أيرلندا الشمالية",
    "Category:Television talk show hosts from Northern Ireland": "تصنيف:مقدمو برامج تلفزيونية حوارية من أيرلندا الشمالية",
    "Category:Video artists from Northern Ireland": "تصنيف:فنانو فيديو من أيرلندا الشمالية",
    "Category:Watercolourists from Northern Ireland": "تصنيف:رسامون مائيون من أيرلندا الشمالية",
    "Category:Women academics from Northern Ireland": "تصنيف:أكاديميات من أيرلندا الشمالية",
    "Category:Women boxers from Northern Ireland": "تصنيف:ملاكمات من أيرلندا الشمالية",
    "Category:Women chefs from Northern Ireland": "تصنيف:طباخات من أيرلندا الشمالية",
    "Category:Women choreographers from Northern Ireland": "تصنيف:مصممات رقص من أيرلندا الشمالية",
    "Category:Women civil servants from Northern Ireland": "تصنيف:موظفات خدمة مدنية من أيرلندا الشمالية",
    "Category:Women comedians from Northern Ireland": "تصنيف:كوميديات من أيرلندا الشمالية",
    "Category:Women judges from Northern Ireland": "تصنيف:قاضيات من أيرلندا الشمالية",
    "Category:Women mathematicians from Northern Ireland": "تصنيف:عالمات رياضيات من أيرلندا الشمالية",
    "Category:Women mayors of places in Northern Ireland": "تصنيف:رئيسات بلديات في أيرلندا الشمالية",
    "Category:Women members of the Parliament of Northern Ireland": "تصنيف:عضوات برلمان أيرلندا الشمالية",
    "Category:Women photographers from Northern Ireland": "تصنيف:مصورات من أيرلندا الشمالية",
    "Category:Women television personalities from Northern Ireland": "تصنيف:شخصيات تلفزيون من أيرلندا الشمالية",
    "Category:Women travel writers from Northern Ireland": "تصنيف:كاتبات سفر من أيرلندا الشمالية",
}

data_2 = {
    "Category:20th-century MEPs for Northern Ireland": "",
    "Category:20th-century Presbyterian ministers from Northern Ireland": "",
    "Category:21st-century MEPs for Northern Ireland": "",
    "Category:21st-century Presbyterian ministers from Northern Ireland": "",
    "Category:21st-century women MEPs for Northern Ireland": "",
    "Category:Advocates general for Northern Ireland": "",
    "Category:All-female bands from Northern Ireland": "",
    "Category:Alliance Party of Northern Ireland politicians": "",
    "Category:Anaesthetists from Northern Ireland": "",
    "Category:Antiquarians from Northern Ireland": "",
    "Category:Artistic directors from Northern Ireland": "",
    "Category:Banjoists from Northern Ireland": "",
    "Category:Barristers from Northern Ireland": "",
    "Category:Blues musical groups from Northern Ireland": "",
    "Category:Bouzouki players from Northern Ireland": "",
    "Category:Boxing promoters from Northern Ireland": "",
    "Category:Ceremonial officers in Northern Ireland": "",
    "Category:Chief Medical Officers for Northern Ireland": "",
    "Category:Children's entertainers from Northern Ireland": "",
    "Category:Children's television presenters from Northern Ireland": "",
    "Category:Civil servants in the Northern Ireland Office": "",
    "Category:Cookbook writers from Northern Ireland": "",
    "Category:Councillors in Northern Ireland": "",
    "Category:Deputy lieutenants in Northern Ireland": "",
    "Category:Drag queens from Northern Ireland": "",
    "Category:Experimental musical groups from Northern Ireland": "",
    "Category:Far-right politicians from Northern Ireland": "",
    "Category:Film score composers from Northern Ireland": "",
    "Category:Folk-song collectors from Northern Ireland": "",
    "Category:Game show hosts from Northern Ireland": "",
    "Category:Gay actors from Northern Ireland": "",
    "Category:Gay men from Northern Ireland by occupation": "",
    "Category:Gay musicians from Northern Ireland": "",
    "Category:Gay writers from Northern Ireland": "",
    "Category:General practitioners from Northern Ireland": "",
    "Category:Green Party Northern Ireland politicians": "",
    "Category:Hammered dulcimer players from Northern Ireland": "",
    "Category:Harpists from Northern Ireland": "",
    "Category:Heads of the Northern Ireland Civil Service": "",
    "Category:Health professionals from Northern Ireland by county": "",
    "Category:Health professionals from Northern Ireland": "",
    "Category:High Court judges of Northern Ireland": "",
    "Category:High shrievalties in Northern Ireland": "",
    "Category:Hurlers from Northern Ireland by county": "",
    "Category:Hurlers from Northern Ireland": "",
    "Category:Hymnwriters from Northern Ireland": "",
    "Category:Independent politicians in Northern Ireland": "",
    "Category:Ladies' Gaelic footballers from Northern Ireland": "",
    "Category:Leaders of the Alliance Party of Northern Ireland": "",
    "Category:LGBTQ comedians from Northern Ireland": "",
    "Category:LGBTQ dramatists and playwrights from Northern Ireland": "",
    "Category:LGBTQ models from Northern Ireland": "",
    "Category:Local government officers in Northern Ireland": "",
    "Category:Lord chief justices of Northern Ireland": "",
    "Category:Lord-lieutenants in Northern Ireland": "",
    "Category:Lords Justice of Appeal of Northern Ireland": "",
    "Category:Male harpists from Northern Ireland": "",
    "Category:Male uilleann pipers from Northern Ireland": "",
    "Category:Marxist writers from Northern Ireland": "",
    "Category:Mass media people from Northern Ireland by county": "",
    "Category:Media personalities from Northern Ireland": "",
    "Category:Members of the Northern Ireland Civil Service": "",
    "Category:Members of the Northern Ireland Constitutional Convention": "",
    "Category:Members of the Northern Ireland Forum": "",
    "Category:Members of the Privy Council of Northern Ireland": "",
    "Category:Methodist ministers from Northern Ireland": "",
    "Category:Musical duos from Northern Ireland": "",
    "Category:Musical quartets from Northern Ireland": "",
    "Category:Musical quintets from Northern Ireland": "",
    "Category:Musical theatre composers from Northern Ireland": "",
    "Category:Musical trios from Northern Ireland": "",
    "Category:National Democratic Party (Northern Ireland) politicians": "",
    "Category:Noise musical groups from Northern Ireland": "",
    "Category:Northern Ireland (UK) MP stubs": "",
    "Category:Northern Ireland Assembly member stubs": "",
    "Category:Northern Ireland Government ministers": "",
    "Category:Northern Ireland justices of the peace": "",
    "Category:Northern Ireland King's Counsel": "",
    "Category:Northern Ireland Labour Party politicians": "",
    "Category:Northern Ireland MLAs 1998–2003": "",
    "Category:Northern Ireland politician stubs": "",
    "Category:Northern Ireland prison officers": "",
    "Category:Northern Ireland Unionist Party politicians": "",
    "Category:Northern Ireland Women's Coalition politicians": "",
    "Category:Oboists from Northern Ireland": "",
    "Category:Ombudsmen in Northern Ireland": "",
    "Category:Orchestras from Northern Ireland": "",
    "Category:Palaeontologists from Northern Ireland": "",
    "Category:Parliament of Northern Ireland member stubs": "",
    "Category:Permanent under-secretaries of state for Northern Ireland": "",
    "Category:Players of English billiards from Northern Ireland": "",
    "Category:Pool players from Northern Ireland": "",
    "Category:Presbyterian ministers from Northern Ireland": "",
    "Category:Psychologists from Northern Ireland": "",
    "Category:Punk rock musicians from Northern Ireland": "",
    "Category:Radio DJs from Northern Ireland": "",
    "Category:Roboticists from Northern Ireland": "",
    "Category:Shakespearean actors from Northern Ireland": "",
    "Category:Songs by songwriters from Northern Ireland": "",
    "Category:Sportspeople from Northern Ireland stubs": "",
    "Category:Strength athletes from Northern Ireland": "",
    "Category:TikTokers from Northern Ireland": "",
    "Category:Tin whistle players from Northern Ireland": "",
    "Category:Uilleann pipers from Northern Ireland": "",
    "Category:Wikipedia categories named after actors from Northern Ireland": "",
    "Category:Wikipedia categories named after musical groups from Northern Ireland": "",
    "Category:Wikipedia categories named after musicians from Northern Ireland": "",
    "Category:Women councillors in Northern Ireland": "",
    "Category:Women harpists from Northern Ireland": "",
    "Category:Women MEPs for Northern Ireland": "",
    "Category:Women political office-holders in Northern Ireland": "",
}

to_test = [
    ("test_northern_ireland_1", data_1),
    # ("test_northern_ireland_2", data_2),
]


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_northern_ireland_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
