"""
Tests
"""

from typing import Callable

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.countries_names_resolvers.medalists_resolvers import resolve_countries_names_medalists

main_data = {
    "universiade competitors": "منافسون في الألعاب الجامعية",
    "universiade medalists": "فائزون بميداليات الألعاب الجامعية",
    "commonwealth games gold medalists": "فائزون بميداليات ذهبية في ألعاب الكومنولث",
    "Olympic gold medalists for Papua New Guinea": "فائزون بميداليات ذهبية أولمبية من بابوا غينيا الجديدة",
    "Olympic gold medalists for the United States in alpine skiing": "فائزون بميداليات ذهبية أولمبية من الولايات المتحدة في التزلج على المنحدرات الثلجية",
    "Olympic gold medalists for the United States": "فائزون بميداليات ذهبية أولمبية من الولايات المتحدة",
    "islamic solidarity games silver medalists": "فائزون بميداليات فضية في ألعاب التضامن الإسلامي",
    "summer islamic solidarity games medalists": "فائزون بميداليات ألعاب التضامن الإسلامي الصيفية",
}

summer_winter_tabs = {
    "african games bids": "عروض الألعاب الإفريقية",
    "african games competitions": "منافسات الألعاب الإفريقية",
    "african games events": "أحداث الألعاب الإفريقية",
    "african games festival": "مهرجانات الألعاب الإفريقية",
    "african games templates": "قوالب الألعاب الإفريقية",
    "all-africa games bids": "عروض ألعاب عموم إفريقيا",
    "all-africa games competitions": "منافسات ألعاب عموم إفريقيا",
    "all-africa games events": "أحداث ألعاب عموم إفريقيا",
    "all-africa games festival": "مهرجانات ألعاب عموم إفريقيا",
    "all-africa games templates": "قوالب ألعاب عموم إفريقيا",
    "asian beach games bids": "عروض دورة الألعاب الآسيوية الشاطئية",
    "asian beach games competitions": "منافسات دورة الألعاب الآسيوية الشاطئية",
    "asian beach games events": "أحداث دورة الألعاب الآسيوية الشاطئية",
    "asian beach games festival": "مهرجانات دورة الألعاب الآسيوية الشاطئية",
    "asian beach games templates": "قوالب دورة الألعاب الآسيوية الشاطئية",
    "asian games bids": "عروض الألعاب الآسيوية",
    "asian games competitions": "منافسات الألعاب الآسيوية",
    "asian games events": "أحداث الألعاب الآسيوية",
    "asian games festival": "مهرجانات الألعاب الآسيوية",
    "asian games templates": "قوالب الألعاب الآسيوية",
    "asian indoor games bids": "عروض دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games competitions": "منافسات دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games events": "أحداث دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games festival": "مهرجانات دورة الألعاب الآسيوية داخل الصالات",
    "asian indoor games templates": "قوالب دورة الألعاب الآسيوية داخل الصالات",
    "asian para games bids": "عروض الألعاب البارالمبية الآسيوية",
    "asian para games competitions": "منافسات الألعاب البارالمبية الآسيوية",
    "asian para games events": "أحداث الألعاب البارالمبية الآسيوية",
    "asian para games festival": "مهرجانات الألعاب البارالمبية الآسيوية",
    "asian para games templates": "قوالب الألعاب البارالمبية الآسيوية",
    "asian summer games bids": "عروض الألعاب الآسيوية الصيفية",
    "asian summer games competitions": "منافسات الألعاب الآسيوية الصيفية",
    "asian summer games events": "أحداث الألعاب الآسيوية الصيفية",
    "asian summer games festival": "مهرجانات الألعاب الآسيوية الصيفية",
    "asian summer games templates": "قوالب الألعاب الآسيوية الصيفية",
    "asian winter games bids": "عروض الألعاب الآسيوية الشتوية",
    "asian winter games competitions": "منافسات الألعاب الآسيوية الشتوية",
    "asian winter games events": "أحداث الألعاب الآسيوية الشتوية",
    "asian winter games festival": "مهرجانات الألعاب الآسيوية الشتوية",
    "asian winter games templates": "قوالب الألعاب الآسيوية الشتوية",
    "bolivarian games bids": "عروض الألعاب البوليفارية",
    "bolivarian games competitions": "منافسات الألعاب البوليفارية",
    "bolivarian games events": "أحداث الألعاب البوليفارية",
    "bolivarian games festival": "مهرجانات الألعاب البوليفارية",
    "bolivarian games templates": "قوالب الألعاب البوليفارية",
    "central american and caribbean games bids": "عروض ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games competitions": "منافسات ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games events": "أحداث ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games festival": "مهرجانات ألعاب أمريكا الوسطى والكاريبي",
    "central american and caribbean games templates": "قوالب ألعاب أمريكا الوسطى والكاريبي",
    "central american games bids": "عروض ألعاب أمريكا الوسطى",
    "central american games competitions": "منافسات ألعاب أمريكا الوسطى",
    "central american games events": "أحداث ألعاب أمريكا الوسطى",
    "central american games festival": "مهرجانات ألعاب أمريكا الوسطى",
    "central american games templates": "قوالب ألعاب أمريكا الوسطى",
    "commonwealth games bids": "عروض ألعاب الكومنولث",
    "commonwealth games competitions": "منافسات ألعاب الكومنولث",
    "commonwealth games events": "أحداث ألعاب الكومنولث",
    "commonwealth games festival": "مهرجانات ألعاب الكومنولث",
    "commonwealth games templates": "قوالب ألعاب الكومنولث",
    "commonwealth youth games bids": "عروض ألعاب الكومنولث الشبابية",
    "commonwealth youth games competitions": "منافسات ألعاب الكومنولث الشبابية",
    "commonwealth youth games events": "أحداث ألعاب الكومنولث الشبابية",
    "commonwealth youth games festival": "مهرجانات ألعاب الكومنولث الشبابية",
    "commonwealth youth games templates": "قوالب ألعاب الكومنولث الشبابية",
    "deaflympic games bids": "عروض ألعاب ديفلمبياد",
    "deaflympic games competitions": "منافسات ألعاب ديفلمبياد",
    "deaflympic games events": "أحداث ألعاب ديفلمبياد",
    "deaflympic games festival": "مهرجانات ألعاب ديفلمبياد",
    "deaflympic games templates": "قوالب ألعاب ديفلمبياد",
    "east african games bids": "عروض الألعاب الإفريقية الشرقية",
    "east african games competitions": "منافسات الألعاب الإفريقية الشرقية",
    "east african games events": "أحداث الألعاب الإفريقية الشرقية",
    "east african games festival": "مهرجانات الألعاب الإفريقية الشرقية",
    "east african games templates": "قوالب الألعاب الإفريقية الشرقية",
    "east all-africa games bids": "عروض ألعاب عموم إفريقيا الشرقية",
    "east all-africa games competitions": "منافسات ألعاب عموم إفريقيا الشرقية",
    "east all-africa games events": "أحداث ألعاب عموم إفريقيا الشرقية",
    "east all-africa games festival": "مهرجانات ألعاب عموم إفريقيا الشرقية",
    "east all-africa games templates": "قوالب ألعاب عموم إفريقيا الشرقية",
    "east asian games bids": "عروض الألعاب الآسيوية الشرقية",
    "east asian games competitions": "منافسات الألعاب الآسيوية الشرقية",
    "east asian games events": "أحداث الألعاب الآسيوية الشرقية",
    "east asian games festival": "مهرجانات الألعاب الآسيوية الشرقية",
    "east asian games templates": "قوالب الألعاب الآسيوية الشرقية",
    "east central american games bids": "عروض ألعاب أمريكا الوسطى الشرقية",
    "east central american games competitions": "منافسات ألعاب أمريكا الوسطى الشرقية",
    "east central american games events": "أحداث ألعاب أمريكا الوسطى الشرقية",
    "east central american games festival": "مهرجانات ألعاب أمريكا الوسطى الشرقية",
    "east central american games templates": "قوالب ألعاب أمريكا الوسطى الشرقية",
    "east commonwealth games bids": "عروض ألعاب الكومنولث الشرقية",
    "east commonwealth games competitions": "منافسات ألعاب الكومنولث الشرقية",
    "east commonwealth games events": "أحداث ألعاب الكومنولث الشرقية",
    "east commonwealth games festival": "مهرجانات ألعاب الكومنولث الشرقية",
    "east commonwealth games templates": "قوالب ألعاب الكومنولث الشرقية",
    "east deaflympic games bids": "عروض ألعاب ديفلمبياد الشرقية",
    "east deaflympic games competitions": "منافسات ألعاب ديفلمبياد الشرقية",
    "east deaflympic games events": "أحداث ألعاب ديفلمبياد الشرقية",
    "east deaflympic games festival": "مهرجانات ألعاب ديفلمبياد الشرقية",
    "east deaflympic games templates": "قوالب ألعاب ديفلمبياد الشرقية",
    "east european youth olympic bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic winter bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east european youth olympic winter competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east european youth olympic winter events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east european youth olympic winter festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east european youth olympic winter templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east jeux de la francophonie bids": "عروض الألعاب الفرانكوفونية الشرقية",
    "east jeux de la francophonie competitions": "منافسات الألعاب الفرانكوفونية الشرقية",
    "east jeux de la francophonie events": "أحداث الألعاب الفرانكوفونية الشرقية",
    "east jeux de la francophonie festival": "مهرجانات الألعاب الفرانكوفونية الشرقية",
    "east jeux de la francophonie templates": "قوالب الألعاب الفرانكوفونية الشرقية",
    "east olympic games bids": "عروض الألعاب الأولمبية الشرقية",
    "east olympic games competitions": "منافسات الألعاب الأولمبية الشرقية",
    "east olympic games events": "أحداث الألعاب الأولمبية الشرقية",
    "east olympic games festival": "مهرجانات الألعاب الأولمبية الشرقية",
    "east olympic games templates": "قوالب الألعاب الأولمبية الشرقية",
    "east olympics bids": "عروض الألعاب الأولمبية الشرقية",
    "east olympics competitions": "منافسات الألعاب الأولمبية الشرقية",
    "east olympics events": "أحداث الألعاب الأولمبية الشرقية",
    "east olympics festival": "مهرجانات الألعاب الأولمبية الشرقية",
    "east olympics templates": "قوالب الألعاب الأولمبية الشرقية",
    "east paralympics games bids": "عروض الألعاب البارالمبية الشرقية",
    "east paralympics games competitions": "منافسات الألعاب البارالمبية الشرقية",
    "east paralympics games events": "أحداث الألعاب البارالمبية الشرقية",
    "east paralympics games festival": "مهرجانات الألعاب البارالمبية الشرقية",
    "east paralympics games templates": "قوالب الألعاب البارالمبية الشرقية",
    "east south american games bids": "عروض ألعاب أمريكا الجنوبية الشرقية",
    "east south american games competitions": "منافسات ألعاب أمريكا الجنوبية الشرقية",
    "east south american games events": "أحداث ألعاب أمريكا الجنوبية الشرقية",
    "east south american games festival": "مهرجانات ألعاب أمريكا الجنوبية الشرقية",
    "east south american games templates": "قوالب ألعاب أمريكا الجنوبية الشرقية",
    "east universiade bids": "عروض الألعاب الجامعية الشرقية",
    "east universiade competitions": "منافسات الألعاب الجامعية الشرقية",
    "east universiade events": "أحداث الألعاب الجامعية الشرقية",
    "east universiade festival": "مهرجانات الألعاب الجامعية الشرقية",
    "east universiade templates": "قوالب الألعاب الجامعية الشرقية",
    "east world games bids": "عروض دورة الألعاب العالمية الشرقية",
    "east world games competitions": "منافسات دورة الألعاب العالمية الشرقية",
    "east world games events": "أحداث دورة الألعاب العالمية الشرقية",
    "east world games festival": "مهرجانات دورة الألعاب العالمية الشرقية",
    "east world games templates": "قوالب دورة الألعاب العالمية الشرقية",
    "east youth olympic games bids": "عروض الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympic games competitions": "منافسات الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympic games events": "أحداث الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympic games festival": "مهرجانات الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympic games templates": "قوالب الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics bids": "عروض الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics competitions": "منافسات الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics events": "أحداث الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics festival": "مهرجانات الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics templates": "قوالب الألعاب الأولمبية الشبابية الشرقية",
    "european games bids": "عروض الألعاب الأوروبية",
    "european games competitions": "منافسات الألعاب الأوروبية",
    "european games events": "أحداث الألعاب الأوروبية",
    "european games festival": "مهرجانات الألعاب الأوروبية",
    "european games templates": "قوالب الألعاب الأوروبية",
    "european youth olympic bids": "عروض الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic events": "أحداث الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic winter bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "european youth olympic winter templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "fis nordic world ski championships bids": "عروض بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships competitions": "منافسات بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships events": "أحداث بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships festival": "مهرجانات بطولة العالم للتزلج النوردي على الثلج",
    "fis nordic world ski championships templates": "قوالب بطولة العالم للتزلج النوردي على الثلج",
    "friendship games bids": "عروض ألعاب الصداقة",
    "friendship games competitions": "منافسات ألعاب الصداقة",
    "friendship games events": "أحداث ألعاب الصداقة",
    "friendship games festival": "مهرجانات ألعاب الصداقة",
    "friendship games templates": "قوالب ألعاب الصداقة",
    "goodwill games bids": "عروض ألعاب النوايا الحسنة",
    "goodwill games competitions": "منافسات ألعاب النوايا الحسنة",
    "goodwill games events": "أحداث ألعاب النوايا الحسنة",
    "goodwill games festival": "مهرجانات ألعاب النوايا الحسنة",
    "goodwill games templates": "قوالب ألعاب النوايا الحسنة",
    "islamic solidarity games bids": "عروض ألعاب التضامن الإسلامي",
    "islamic solidarity games competitions": "منافسات ألعاب التضامن الإسلامي",
    "islamic solidarity games events": "أحداث ألعاب التضامن الإسلامي",
    "islamic solidarity games festival": "مهرجانات ألعاب التضامن الإسلامي",
    "islamic solidarity games templates": "قوالب ألعاب التضامن الإسلامي",
    "jeux de la francophonie bids": "عروض الألعاب الفرانكوفونية",
    "jeux de la francophonie competitions": "منافسات الألعاب الفرانكوفونية",
    "jeux de la francophonie events": "أحداث الألعاب الفرانكوفونية",
    "jeux de la francophonie festival": "مهرجانات الألعاب الفرانكوفونية",
    "jeux de la francophonie templates": "قوالب الألعاب الفرانكوفونية",
    "maccabiah games bids": "عروض الألعاب المكابيه",
    "maccabiah games competitions": "منافسات الألعاب المكابيه",
    "maccabiah games events": "أحداث الألعاب المكابيه",
    "maccabiah games festival": "مهرجانات الألعاب المكابيه",
    "maccabiah games templates": "قوالب الألعاب المكابيه",
    "mediterranean games bids": "عروض الألعاب المتوسطية",
    "mediterranean games competitions": "منافسات الألعاب المتوسطية",
    "mediterranean games events": "أحداث الألعاب المتوسطية",
    "mediterranean games festival": "مهرجانات الألعاب المتوسطية",
    "mediterranean games templates": "قوالب الألعاب المتوسطية",
    "micronesian games bids": "عروض الألعاب الميكرونيزية",
    "micronesian games competitions": "منافسات الألعاب الميكرونيزية",
    "micronesian games events": "أحداث الألعاب الميكرونيزية",
    "micronesian games festival": "مهرجانات الألعاب الميكرونيزية",
    "micronesian games templates": "قوالب الألعاب الميكرونيزية",
    "military world games bids": "عروض دورة الألعاب العسكرية",
    "military world games competitions": "منافسات دورة الألعاب العسكرية",
    "military world games events": "أحداث دورة الألعاب العسكرية",
    "military world games festival": "مهرجانات دورة الألعاب العسكرية",
    "military world games templates": "قوالب دورة الألعاب العسكرية",
    "olympic games bids": "عروض الألعاب الأولمبية",
    "olympic games competitions": "منافسات الألعاب الأولمبية",
    "olympic games events": "أحداث الألعاب الأولمبية",
    "olympic games festival": "مهرجانات الألعاب الأولمبية",
    "olympic games templates": "قوالب الألعاب الأولمبية",
    "olympics bids": "عروض الألعاب الأولمبية",
    "olympics competitions": "منافسات الألعاب الأولمبية",
    "olympics events": "أحداث الألعاب الأولمبية",
    "olympics festival": "مهرجانات الألعاب الأولمبية",
    "olympics templates": "قوالب الألعاب الأولمبية",
    "pan american games bids": "عروض دورة الألعاب الأمريكية",
    "pan american games competitions": "منافسات دورة الألعاب الأمريكية",
    "pan american games events": "أحداث دورة الألعاب الأمريكية",
    "pan american games festival": "مهرجانات دورة الألعاب الأمريكية",
    "pan american games templates": "قوالب دورة الألعاب الأمريكية",
    "pan arab games bids": "عروض دورة الألعاب العربية",
    "pan arab games competitions": "منافسات دورة الألعاب العربية",
    "pan arab games events": "أحداث دورة الألعاب العربية",
    "pan arab games festival": "مهرجانات دورة الألعاب العربية",
    "pan arab games templates": "قوالب دورة الألعاب العربية",
    "pan asian games bids": "عروض دورة الألعاب الآسيوية",
    "pan asian games competitions": "منافسات دورة الألعاب الآسيوية",
    "pan asian games events": "أحداث دورة الألعاب الآسيوية",
    "pan asian games festival": "مهرجانات دورة الألعاب الآسيوية",
    "pan asian games templates": "قوالب دورة الألعاب الآسيوية",
    "paralympic bids": "عروض الألعاب البارالمبية",
    "paralympic competitions": "منافسات الألعاب البارالمبية",
    "paralympic events": "أحداث الألعاب البارالمبية",
    "paralympic festival": "مهرجانات الألعاب البارالمبية",
    "paralympic templates": "قوالب الألعاب البارالمبية",
    "paralympics bids": "عروض الألعاب البارالمبية",
    "paralympics competitions": "منافسات الألعاب البارالمبية",
    "paralympics events": "أحداث الألعاب البارالمبية",
    "paralympics festival": "مهرجانات الألعاب البارالمبية",
    "paralympics games bids": "عروض الألعاب البارالمبية",
    "paralympics games competitions": "منافسات الألعاب البارالمبية",
    "paralympics games events": "أحداث الألعاب البارالمبية",
    "paralympics games festival": "مهرجانات الألعاب البارالمبية",
    "paralympics games templates": "قوالب الألعاب البارالمبية",
    "paralympics templates": "قوالب الألعاب البارالمبية",
    "parapan american games bids": "عروض ألعاب بارابان الأمريكية",
    "parapan american games competitions": "منافسات ألعاب بارابان الأمريكية",
    "parapan american games events": "أحداث ألعاب بارابان الأمريكية",
    "parapan american games festival": "مهرجانات ألعاب بارابان الأمريكية",
    "parapan american games templates": "قوالب ألعاب بارابان الأمريكية",
    "sea games bids": "عروض ألعاب البحر",
    "sea games competitions": "منافسات ألعاب البحر",
    "sea games events": "أحداث ألعاب البحر",
    "sea games festival": "مهرجانات ألعاب البحر",
    "sea games templates": "قوالب ألعاب البحر",
    "south american games bids": "عروض ألعاب أمريكا الجنوبية",
    "south american games competitions": "منافسات ألعاب أمريكا الجنوبية",
    "south american games events": "أحداث ألعاب أمريكا الجنوبية",
    "south american games festival": "مهرجانات ألعاب أمريكا الجنوبية",
    "south american games templates": "قوالب ألعاب أمريكا الجنوبية",
    "south asian beach games bids": "عروض دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games competitions": "منافسات دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games events": "أحداث دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games festival": "مهرجانات دورة ألعاب جنوب أسيا الشاطئية",
    "south asian beach games templates": "قوالب دورة ألعاب جنوب أسيا الشاطئية",
    "south asian games bids": "عروض ألعاب جنوب أسيا",
    "south asian games competitions": "منافسات ألعاب جنوب أسيا",
    "south asian games events": "أحداث ألعاب جنوب أسيا",
    "south asian games festival": "مهرجانات ألعاب جنوب أسيا",
    "south asian games templates": "قوالب ألعاب جنوب أسيا",
    "south asian winter games bids": "عروض ألعاب جنوب آسيا الشتوية",
    "south asian winter games competitions": "منافسات ألعاب جنوب آسيا الشتوية",
    "south asian winter games events": "أحداث ألعاب جنوب آسيا الشتوية",
    "south asian winter games festival": "مهرجانات ألعاب جنوب آسيا الشتوية",
    "south asian winter games templates": "قوالب ألعاب جنوب آسيا الشتوية",
    "southeast asian games bids": "عروض ألعاب جنوب شرق آسيا",
    "southeast asian games competitions": "منافسات ألعاب جنوب شرق آسيا",
    "southeast asian games events": "أحداث ألعاب جنوب شرق آسيا",
    "southeast asian games festival": "مهرجانات ألعاب جنوب شرق آسيا",
    "southeast asian games templates": "قوالب ألعاب جنوب شرق آسيا",
    "summer african games bids": "عروض الألعاب الإفريقية الصيفية",
    "summer african games competitions": "منافسات الألعاب الإفريقية الصيفية",
    "summer african games events": "أحداث الألعاب الإفريقية الصيفية",
    "summer african games festival": "مهرجانات الألعاب الإفريقية الصيفية",
    "summer african games templates": "قوالب الألعاب الإفريقية الصيفية",
    "summer all-africa games bids": "عروض ألعاب عموم إفريقيا الصيفية",
    "summer all-africa games competitions": "منافسات ألعاب عموم إفريقيا الصيفية",
    "summer all-africa games events": "أحداث ألعاب عموم إفريقيا الصيفية",
    "summer all-africa games festival": "مهرجانات ألعاب عموم إفريقيا الصيفية",
    "summer all-africa games templates": "قوالب ألعاب عموم إفريقيا الصيفية",
    "summer asian games bids": "عروض الألعاب الآسيوية الصيفية",
    "summer asian games competitions": "منافسات الألعاب الآسيوية الصيفية",
    "summer asian games events": "أحداث الألعاب الآسيوية الصيفية",
    "summer asian games festival": "مهرجانات الألعاب الآسيوية الصيفية",
    "summer asian games templates": "قوالب الألعاب الآسيوية الصيفية",
    "summer central american games bids": "عروض ألعاب أمريكا الوسطى الصيفية",
    "summer central american games competitions": "منافسات ألعاب أمريكا الوسطى الصيفية",
    "summer central american games events": "أحداث ألعاب أمريكا الوسطى الصيفية",
    "summer central american games festival": "مهرجانات ألعاب أمريكا الوسطى الصيفية",
    "summer central american games templates": "قوالب ألعاب أمريكا الوسطى الصيفية",
    "summer commonwealth games bids": "عروض ألعاب الكومنولث الصيفية",
    "summer commonwealth games competitions": "منافسات ألعاب الكومنولث الصيفية",
    "summer commonwealth games events": "أحداث ألعاب الكومنولث الصيفية",
    "summer commonwealth games festival": "مهرجانات ألعاب الكومنولث الصيفية",
    "summer commonwealth games templates": "قوالب ألعاب الكومنولث الصيفية",
    "summer deaflympic games bids": "عروض ألعاب ديفلمبياد الصيفية",
    "summer deaflympic games competitions": "منافسات ألعاب ديفلمبياد الصيفية",
    "summer deaflympic games events": "أحداث ألعاب ديفلمبياد الصيفية",
    "summer deaflympic games festival": "مهرجانات ألعاب ديفلمبياد الصيفية",
    "summer deaflympic games templates": "قوالب ألعاب ديفلمبياد الصيفية",
    "summer european youth olympic bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic winter bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer european youth olympic winter competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer european youth olympic winter events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer european youth olympic winter festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer european youth olympic winter templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer jeux de la francophonie bids": "عروض الألعاب الفرانكوفونية الصيفية",
    "summer jeux de la francophonie competitions": "منافسات الألعاب الفرانكوفونية الصيفية",
    "summer jeux de la francophonie events": "أحداث الألعاب الفرانكوفونية الصيفية",
    "summer jeux de la francophonie festival": "مهرجانات الألعاب الفرانكوفونية الصيفية",
    "summer jeux de la francophonie templates": "قوالب الألعاب الفرانكوفونية الصيفية",
    "summer olympic games bids": "عروض الألعاب الأولمبية الصيفية",
    "summer olympic games competitions": "منافسات الألعاب الأولمبية الصيفية",
    "summer olympic games events": "أحداث الألعاب الأولمبية الصيفية",
    "summer olympic games festival": "مهرجانات الألعاب الأولمبية الصيفية",
    "summer olympic games templates": "قوالب الألعاب الأولمبية الصيفية",
    "summer olympics bids": "عروض الألعاب الأولمبية الصيفية",
    "summer olympics competitions": "منافسات الألعاب الأولمبية الصيفية",
    "summer olympics events": "أحداث الألعاب الأولمبية الصيفية",
    "summer olympics festival": "مهرجانات الألعاب الأولمبية الصيفية",
    "summer olympics templates": "قوالب الألعاب الأولمبية الصيفية",
    "summer paralympics games bids": "عروض الألعاب البارالمبية الصيفية",
    "summer paralympics games competitions": "منافسات الألعاب البارالمبية الصيفية",
    "summer paralympics games events": "أحداث الألعاب البارالمبية الصيفية",
    "summer paralympics games festival": "مهرجانات الألعاب البارالمبية الصيفية",
    "summer paralympics games templates": "قوالب الألعاب البارالمبية الصيفية",
    "summer south american games bids": "عروض ألعاب أمريكا الجنوبية الصيفية",
    "summer south american games competitions": "منافسات ألعاب أمريكا الجنوبية الصيفية",
    "summer south american games events": "أحداث ألعاب أمريكا الجنوبية الصيفية",
    "summer south american games festival": "مهرجانات ألعاب أمريكا الجنوبية الصيفية",
    "summer south american games templates": "قوالب ألعاب أمريكا الجنوبية الصيفية",
    "summer universiade bids": "عروض الألعاب الجامعية الصيفية",
    "summer universiade competitions": "منافسات الألعاب الجامعية الصيفية",
    "summer universiade events": "أحداث الألعاب الجامعية الصيفية",
    "summer universiade festival": "مهرجانات الألعاب الجامعية الصيفية",
    "summer universiade templates": "قوالب الألعاب الجامعية الصيفية",
    "summer world games bids": "عروض دورة الألعاب العالمية الصيفية",
    "summer world games competitions": "منافسات دورة الألعاب العالمية الصيفية",
    "summer world games events": "أحداث دورة الألعاب العالمية الصيفية",
    "summer world games festival": "مهرجانات دورة الألعاب العالمية الصيفية",
    "summer world games templates": "قوالب دورة الألعاب العالمية الصيفية",
    "summer world university games bids": "عروض ألعاب الجامعات العالمية الصيفية",
    "summer world university games competitions": "منافسات ألعاب الجامعات العالمية الصيفية",
    "summer world university games events": "أحداث ألعاب الجامعات العالمية الصيفية",
    "summer world university games festival": "مهرجانات ألعاب الجامعات العالمية الصيفية",
    "summer world university games templates": "قوالب ألعاب الجامعات العالمية الصيفية",
    "summer youth olympic games bids": "عروض الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympic games competitions": "منافسات الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympic games events": "أحداث الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympic games festival": "مهرجانات الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympic games templates": "قوالب الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics bids": "عروض الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics competitions": "منافسات الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics events": "أحداث الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics festival": "مهرجانات الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics templates": "قوالب الألعاب الأولمبية الشبابية الصيفية",
    "the universiade bids": "عروض الألعاب الجامعية",
    "the universiade competitions": "منافسات الألعاب الجامعية",
    "the universiade events": "أحداث الألعاب الجامعية",
    "the universiade festival": "مهرجانات الألعاب الجامعية",
    "the universiade templates": "قوالب الألعاب الجامعية",
    "universiade bids": "عروض الألعاب الجامعية",
    "universiade competitions": "منافسات الألعاب الجامعية",
    "universiade events": "أحداث الألعاب الجامعية",
    "universiade festival": "مهرجانات الألعاب الجامعية",
    "universiade templates": "قوالب الألعاب الجامعية",
    "west african games bids": "عروض الألعاب الإفريقية الغربية",
    "west african games competitions": "منافسات الألعاب الإفريقية الغربية",
    "west african games events": "أحداث الألعاب الإفريقية الغربية",
    "west african games festival": "مهرجانات الألعاب الإفريقية الغربية",
    "west african games templates": "قوالب الألعاب الإفريقية الغربية",
    "west all-africa games bids": "عروض ألعاب عموم إفريقيا الغربية",
    "west all-africa games competitions": "منافسات ألعاب عموم إفريقيا الغربية",
    "west all-africa games events": "أحداث ألعاب عموم إفريقيا الغربية",
    "west all-africa games festival": "مهرجانات ألعاب عموم إفريقيا الغربية",
    "west all-africa games templates": "قوالب ألعاب عموم إفريقيا الغربية",
    "west asian games bids": "عروض الألعاب الآسيوية الغربية",
    "west asian games competitions": "منافسات الألعاب الآسيوية الغربية",
    "west asian games events": "أحداث الألعاب الآسيوية الغربية",
    "west asian games festival": "مهرجانات الألعاب الآسيوية الغربية",
    "west asian games templates": "قوالب الألعاب الآسيوية الغربية",
    "west central american games bids": "عروض ألعاب أمريكا الوسطى الغربية",
    "west central american games competitions": "منافسات ألعاب أمريكا الوسطى الغربية",
    "west central american games events": "أحداث ألعاب أمريكا الوسطى الغربية",
    "west central american games festival": "مهرجانات ألعاب أمريكا الوسطى الغربية",
    "west central american games templates": "قوالب ألعاب أمريكا الوسطى الغربية",
    "west commonwealth games bids": "عروض ألعاب الكومنولث الغربية",
    "west commonwealth games competitions": "منافسات ألعاب الكومنولث الغربية",
    "west commonwealth games events": "أحداث ألعاب الكومنولث الغربية",
    "west commonwealth games festival": "مهرجانات ألعاب الكومنولث الغربية",
    "west commonwealth games templates": "قوالب ألعاب الكومنولث الغربية",
    "west deaflympic games bids": "عروض ألعاب ديفلمبياد الغربية",
    "west deaflympic games competitions": "منافسات ألعاب ديفلمبياد الغربية",
    "west deaflympic games events": "أحداث ألعاب ديفلمبياد الغربية",
    "west deaflympic games festival": "مهرجانات ألعاب ديفلمبياد الغربية",
    "west deaflympic games templates": "قوالب ألعاب ديفلمبياد الغربية",
    "west european youth olympic bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic winter bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west european youth olympic winter competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west european youth olympic winter events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west european youth olympic winter festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west european youth olympic winter templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west jeux de la francophonie bids": "عروض الألعاب الفرانكوفونية الغربية",
    "west jeux de la francophonie competitions": "منافسات الألعاب الفرانكوفونية الغربية",
    "west jeux de la francophonie events": "أحداث الألعاب الفرانكوفونية الغربية",
    "west jeux de la francophonie festival": "مهرجانات الألعاب الفرانكوفونية الغربية",
    "west jeux de la francophonie templates": "قوالب الألعاب الفرانكوفونية الغربية",
    "west olympic games bids": "عروض الألعاب الأولمبية الغربية",
    "west olympic games competitions": "منافسات الألعاب الأولمبية الغربية",
    "west olympic games events": "أحداث الألعاب الأولمبية الغربية",
    "west olympic games festival": "مهرجانات الألعاب الأولمبية الغربية",
    "west olympic games templates": "قوالب الألعاب الأولمبية الغربية",
    "west olympics bids": "عروض الألعاب الأولمبية الغربية",
    "west olympics competitions": "منافسات الألعاب الأولمبية الغربية",
    "west olympics events": "أحداث الألعاب الأولمبية الغربية",
    "west olympics festival": "مهرجانات الألعاب الأولمبية الغربية",
    "west olympics templates": "قوالب الألعاب الأولمبية الغربية",
    "west paralympics games bids": "عروض الألعاب البارالمبية الغربية",
    "west paralympics games competitions": "منافسات الألعاب البارالمبية الغربية",
    "west paralympics games events": "أحداث الألعاب البارالمبية الغربية",
    "west paralympics games festival": "مهرجانات الألعاب البارالمبية الغربية",
    "west paralympics games templates": "قوالب الألعاب البارالمبية الغربية",
    "west south american games bids": "عروض ألعاب أمريكا الجنوبية الغربية",
    "west south american games competitions": "منافسات ألعاب أمريكا الجنوبية الغربية",
    "west south american games events": "أحداث ألعاب أمريكا الجنوبية الغربية",
    "west south american games festival": "مهرجانات ألعاب أمريكا الجنوبية الغربية",
    "west south american games templates": "قوالب ألعاب أمريكا الجنوبية الغربية",
    "west universiade bids": "عروض الألعاب الجامعية الغربية",
    "west universiade competitions": "منافسات الألعاب الجامعية الغربية",
    "west universiade events": "أحداث الألعاب الجامعية الغربية",
    "west universiade festival": "مهرجانات الألعاب الجامعية الغربية",
    "west universiade templates": "قوالب الألعاب الجامعية الغربية",
    "west world games bids": "عروض دورة الألعاب العالمية الغربية",
    "west world games competitions": "منافسات دورة الألعاب العالمية الغربية",
    "west world games events": "أحداث دورة الألعاب العالمية الغربية",
    "west world games festival": "مهرجانات دورة الألعاب العالمية الغربية",
    "west world games templates": "قوالب دورة الألعاب العالمية الغربية",
    "west youth olympic games bids": "عروض الألعاب الأولمبية الشبابية الغربية",
    "west youth olympic games competitions": "منافسات الألعاب الأولمبية الشبابية الغربية",
    "west youth olympic games events": "أحداث الألعاب الأولمبية الشبابية الغربية",
    "west youth olympic games festival": "مهرجانات الألعاب الأولمبية الشبابية الغربية",
    "west youth olympic games templates": "قوالب الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics bids": "عروض الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics competitions": "منافسات الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics events": "أحداث الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics festival": "مهرجانات الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics templates": "قوالب الألعاب الأولمبية الشبابية الغربية",
    "winter african games bids": "عروض الألعاب الإفريقية الشتوية",
    "winter african games competitions": "منافسات الألعاب الإفريقية الشتوية",
    "winter african games events": "أحداث الألعاب الإفريقية الشتوية",
    "winter african games festival": "مهرجانات الألعاب الإفريقية الشتوية",
    "winter african games templates": "قوالب الألعاب الإفريقية الشتوية",
    "winter all-africa games bids": "عروض ألعاب عموم إفريقيا الشتوية",
    "winter all-africa games competitions": "منافسات ألعاب عموم إفريقيا الشتوية",
    "winter all-africa games events": "أحداث ألعاب عموم إفريقيا الشتوية",
    "winter all-africa games festival": "مهرجانات ألعاب عموم إفريقيا الشتوية",
    "winter all-africa games templates": "قوالب ألعاب عموم إفريقيا الشتوية",
    "winter asian games bids": "عروض الألعاب الآسيوية الشتوية",
    "winter asian games competitions": "منافسات الألعاب الآسيوية الشتوية",
    "winter asian games events": "أحداث الألعاب الآسيوية الشتوية",
    "winter asian games festival": "مهرجانات الألعاب الآسيوية الشتوية",
    "winter asian games templates": "قوالب الألعاب الآسيوية الشتوية",
    "winter central american games bids": "عروض ألعاب أمريكا الوسطى الشتوية",
    "winter central american games competitions": "منافسات ألعاب أمريكا الوسطى الشتوية",
    "winter central american games events": "أحداث ألعاب أمريكا الوسطى الشتوية",
    "winter central american games festival": "مهرجانات ألعاب أمريكا الوسطى الشتوية",
    "winter central american games templates": "قوالب ألعاب أمريكا الوسطى الشتوية",
    "winter commonwealth games bids": "عروض ألعاب الكومنولث الشتوية",
    "winter commonwealth games competitions": "منافسات ألعاب الكومنولث الشتوية",
    "winter commonwealth games events": "أحداث ألعاب الكومنولث الشتوية",
    "winter commonwealth games festival": "مهرجانات ألعاب الكومنولث الشتوية",
    "winter commonwealth games templates": "قوالب ألعاب الكومنولث الشتوية",
    "winter deaflympic games bids": "عروض ألعاب ديفلمبياد الشتوية",
    "winter deaflympic games competitions": "منافسات ألعاب ديفلمبياد الشتوية",
    "winter deaflympic games events": "أحداث ألعاب ديفلمبياد الشتوية",
    "winter deaflympic games festival": "مهرجانات ألعاب ديفلمبياد الشتوية",
    "winter deaflympic games templates": "قوالب ألعاب ديفلمبياد الشتوية",
    "winter european youth olympic bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic winter bids": "عروض الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter european youth olympic winter competitions": "منافسات الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter european youth olympic winter events": "أحداث الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter european youth olympic winter festival": "مهرجانات الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter european youth olympic winter templates": "قوالب الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter jeux de la francophonie bids": "عروض الألعاب الفرانكوفونية الشتوية",
    "winter jeux de la francophonie competitions": "منافسات الألعاب الفرانكوفونية الشتوية",
    "winter jeux de la francophonie events": "أحداث الألعاب الفرانكوفونية الشتوية",
    "winter jeux de la francophonie festival": "مهرجانات الألعاب الفرانكوفونية الشتوية",
    "winter jeux de la francophonie templates": "قوالب الألعاب الفرانكوفونية الشتوية",
    "winter olympic games bids": "عروض الألعاب الأولمبية الشتوية",
    "winter olympic games competitions": "منافسات الألعاب الأولمبية الشتوية",
    "winter olympic games events": "أحداث الألعاب الأولمبية الشتوية",
    "winter olympic games festival": "مهرجانات الألعاب الأولمبية الشتوية",
    "winter olympic games templates": "قوالب الألعاب الأولمبية الشتوية",
    "winter olympics bids": "عروض الألعاب الأولمبية الشتوية",
    "winter olympics competitions": "منافسات الألعاب الأولمبية الشتوية",
    "winter olympics events": "أحداث الألعاب الأولمبية الشتوية",
    "winter olympics festival": "مهرجانات الألعاب الأولمبية الشتوية",
    "winter olympics templates": "قوالب الألعاب الأولمبية الشتوية",
    "winter paralympics games bids": "عروض الألعاب البارالمبية الشتوية",
    "winter paralympics games competitions": "منافسات الألعاب البارالمبية الشتوية",
    "winter paralympics games events": "أحداث الألعاب البارالمبية الشتوية",
    "winter paralympics games festival": "مهرجانات الألعاب البارالمبية الشتوية",
    "winter paralympics games templates": "قوالب الألعاب البارالمبية الشتوية",
    "winter south american games bids": "عروض ألعاب أمريكا الجنوبية الشتوية",
    "winter south american games competitions": "منافسات ألعاب أمريكا الجنوبية الشتوية",
    "winter south american games events": "أحداث ألعاب أمريكا الجنوبية الشتوية",
    "winter south american games festival": "مهرجانات ألعاب أمريكا الجنوبية الشتوية",
    "winter south american games templates": "قوالب ألعاب أمريكا الجنوبية الشتوية",
    "winter universiade bids": "عروض الألعاب الجامعية الشتوية",
    "winter universiade competitions": "منافسات الألعاب الجامعية الشتوية",
    "winter universiade events": "أحداث الألعاب الجامعية الشتوية",
    "winter universiade festival": "مهرجانات الألعاب الجامعية الشتوية",
    "winter universiade templates": "قوالب الألعاب الجامعية الشتوية",
    "winter world games bids": "عروض دورة الألعاب العالمية الشتوية",
    "winter world games competitions": "منافسات دورة الألعاب العالمية الشتوية",
    "winter world games events": "أحداث دورة الألعاب العالمية الشتوية",
    "winter world games festival": "مهرجانات دورة الألعاب العالمية الشتوية",
    "winter world games templates": "قوالب دورة الألعاب العالمية الشتوية",
    "winter world university games bids": "عروض ألعاب الجامعات العالمية الشتوية",
    "winter world university games competitions": "منافسات ألعاب الجامعات العالمية الشتوية",
    "winter world university games events": "أحداث ألعاب الجامعات العالمية الشتوية",
    "winter world university games festival": "مهرجانات ألعاب الجامعات العالمية الشتوية",
    "winter world university games templates": "قوالب ألعاب الجامعات العالمية الشتوية",
    "winter youth olympic games bids": "عروض الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympic games competitions": "منافسات الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympic games events": "أحداث الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympic games festival": "مهرجانات الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympic games templates": "قوالب الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics bids": "عروض الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics competitions": "منافسات الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics events": "أحداث الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics festival": "مهرجانات الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics templates": "قوالب الألعاب الأولمبية الشبابية الشتوية",
    "world championships bids": "عروض بطولات العالم",
    "world championships competitions": "منافسات بطولات العالم",
    "world championships events": "أحداث بطولات العالم",
    "world championships festival": "مهرجانات بطولات العالم",
    "world championships templates": "قوالب بطولات العالم",
    "world games bids": "عروض دورة الألعاب العالمية",
    "world games competitions": "منافسات دورة الألعاب العالمية",
    "world games events": "أحداث دورة الألعاب العالمية",
    "world games festival": "مهرجانات دورة الألعاب العالمية",
    "world games templates": "قوالب دورة الألعاب العالمية",
    "youth olympic bids": "عروض الألعاب الأولمبية الشبابية",
    "youth olympic competitions": "منافسات الألعاب الأولمبية الشبابية",
    "youth olympic events": "أحداث الألعاب الأولمبية الشبابية",
    "youth olympic festival": "مهرجانات الألعاب الأولمبية الشبابية",
    "youth olympic games bids": "عروض الألعاب الأولمبية الشبابية",
    "youth olympic games competitions": "منافسات الألعاب الأولمبية الشبابية",
    "youth olympic games events": "أحداث الألعاب الأولمبية الشبابية",
    "youth olympic games festival": "مهرجانات الألعاب الأولمبية الشبابية",
    "youth olympic games templates": "قوالب الألعاب الأولمبية الشبابية",
    "youth olympic templates": "قوالب الألعاب الأولمبية الشبابية",
    "youth olympics bids": "عروض الألعاب الأولمبية الشبابية",
    "youth olympics competitions": "منافسات الألعاب الأولمبية الشبابية",
    "youth olympics events": "أحداث الألعاب الأولمبية الشبابية",
    "youth olympics festival": "مهرجانات الألعاب الأولمبية الشبابية",
    "youth olympics games bids": "عروض الألعاب الأولمبية الشبابية",
    "youth olympics games competitions": "منافسات الألعاب الأولمبية الشبابية",
    "youth olympics games events": "أحداث الألعاب الأولمبية الشبابية",
    "youth olympics games festival": "مهرجانات الألعاب الأولمبية الشبابية",
    "youth olympics games templates": "قوالب الألعاب الأولمبية الشبابية",
    "youth olympics templates": "قوالب الألعاب الأولمبية الشبابية",
}

summer_winter_games = {
    "african games": "الألعاب الإفريقية",
    "asian beach games": "دورة الألعاب الآسيوية الشاطئية",
    "asian games": "الألعاب الآسيوية",
    "asian indoor games": "دورة الألعاب الآسيوية داخل الصالات",
    "asian para games": "الألعاب البارالمبية الآسيوية",
    "asian summer games": "الألعاب الآسيوية الصيفية",
    "asian winter games": "الألعاب الآسيوية الشتوية",
    "bolivarian games": "الألعاب البوليفارية",
    "central american and caribbean games": "ألعاب أمريكا الوسطى والكاريبي",
    "central american games": "ألعاب أمريكا الوسطى",
    "commonwealth games": "ألعاب الكومنولث",
    "commonwealth youth games": "ألعاب الكومنولث الشبابية",
    "deaflympic games": "ألعاب ديفلمبياد",
    "european games": "الألعاب الأوروبية",
    "european youth olympic": "الألعاب الأولمبية الشبابية الأوروبية",
    "european youth olympic winter": "الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "fis nordic world ski championships": "بطولة العالم للتزلج النوردي على الثلج",
    "friendship games": "ألعاب الصداقة",
    "goodwill games": "ألعاب النوايا الحسنة",
    "islamic solidarity games": "ألعاب التضامن الإسلامي",
    "maccabiah games": "الألعاب المكابيه",
    "mediterranean games": "الألعاب المتوسطية",
    "micronesian games": "الألعاب الميكرونيزية",
    "military world games": "دورة الألعاب العسكرية",
    "pan american games": "دورة الألعاب الأمريكية",
    "pan arab games": "دورة الألعاب العربية",
    "pan asian games": "دورة الألعاب الآسيوية",
    "paralympic": "الألعاب البارالمبية",
    "paralympics": "الألعاب البارالمبية",
    "parapan american games": "ألعاب بارابان الأمريكية",
    "sea games": "ألعاب البحر",
    "south american games": "ألعاب أمريكا الجنوبية",
    "south asian beach games": "دورة ألعاب جنوب أسيا الشاطئية",
    "south asian games": "ألعاب جنوب أسيا",
    "south asian winter games": "ألعاب جنوب آسيا الشتوية",
    "southeast asian games": "ألعاب جنوب شرق آسيا",
    "summer olympics": "الألعاب الأولمبية الصيفية",
    "summer universiade": "الألعاب الجامعية الصيفية",
    "summer world university games": "ألعاب الجامعات العالمية الصيفية",
    "the universiade": "الألعاب الجامعية",
    "universiade": "الألعاب الجامعية",
    "winter olympics": "الألعاب الأولمبية الشتوية",
    "winter universiade": "الألعاب الجامعية الشتوية",
    "winter world university games": "ألعاب الجامعات العالمية الشتوية",
    "world championships": "بطولات العالم",
    "youth olympic": "الألعاب الأولمبية الشبابية",
    "youth olympics": "الألعاب الأولمبية الشبابية",
    "youth olympics games": "الألعاب الأولمبية الشبابية",
    "all-africa games": "ألعاب عموم إفريقيا",
    "east african games": "الألعاب الإفريقية الشرقية",
    "east all-africa games": "ألعاب عموم إفريقيا الشرقية",
    "east asian games": "الألعاب الآسيوية الشرقية",
    "east central american games": "ألعاب أمريكا الوسطى الشرقية",
    "east commonwealth games": "ألعاب الكومنولث الشرقية",
    "east deaflympic games": "ألعاب ديفلمبياد الشرقية",
    "east european youth olympic": "الألعاب الأولمبية الشبابية الأوروبية الشرقية",
    "east european youth olympic winter": "الألعاب الأولمبية الشبابية الأوروبية الشتوية الشرقية",
    "east jeux de la francophonie": "الألعاب الفرانكوفونية الشرقية",
    "east olympic games": "الألعاب الأولمبية الشرقية",
    "east olympics": "الألعاب الأولمبية الشرقية",
    "east paralympics games": "الألعاب البارالمبية الشرقية",
    "east south american games": "ألعاب أمريكا الجنوبية الشرقية",
    "east universiade": "الألعاب الجامعية الشرقية",
    "east world games": "دورة الألعاب العالمية الشرقية",
    "east youth olympic games": "الألعاب الأولمبية الشبابية الشرقية",
    "east youth olympics": "الألعاب الأولمبية الشبابية الشرقية",
    "jeux de la francophonie": "الألعاب الفرانكوفونية",
    "olympic games": "الألعاب الأولمبية",
    "olympics": "الألعاب الأولمبية",
    "paralympics games": "الألعاب البارالمبية",
    "summer african games": "الألعاب الإفريقية الصيفية",
    "summer all-africa games": "ألعاب عموم إفريقيا الصيفية",
    "summer asian games": "الألعاب الآسيوية الصيفية",
    "summer central american games": "ألعاب أمريكا الوسطى الصيفية",
    "summer commonwealth games": "ألعاب الكومنولث الصيفية",
    "summer deaflympic games": "ألعاب ديفلمبياد الصيفية",
    "summer european youth olympic": "الألعاب الأولمبية الشبابية الأوروبية الصيفية",
    "summer european youth olympic winter": "الألعاب الأولمبية الشبابية الأوروبية الشتوية الصيفية",
    "summer jeux de la francophonie": "الألعاب الفرانكوفونية الصيفية",
    "summer olympic games": "الألعاب الأولمبية الصيفية",
    "summer paralympics games": "الألعاب البارالمبية الصيفية",
    "summer south american games": "ألعاب أمريكا الجنوبية الصيفية",
    "summer world games": "دورة الألعاب العالمية الصيفية",
    "summer youth olympic games": "الألعاب الأولمبية الشبابية الصيفية",
    "summer youth olympics": "الألعاب الأولمبية الشبابية الصيفية",
    "west african games": "الألعاب الإفريقية الغربية",
    "west all-africa games": "ألعاب عموم إفريقيا الغربية",
    "west asian games": "الألعاب الآسيوية الغربية",
    "west central american games": "ألعاب أمريكا الوسطى الغربية",
    "west commonwealth games": "ألعاب الكومنولث الغربية",
    "west deaflympic games": "ألعاب ديفلمبياد الغربية",
    "west european youth olympic": "الألعاب الأولمبية الشبابية الأوروبية الغربية",
    "west european youth olympic winter": "الألعاب الأولمبية الشبابية الأوروبية الشتوية الغربية",
    "west jeux de la francophonie": "الألعاب الفرانكوفونية الغربية",
    "west olympic games": "الألعاب الأولمبية الغربية",
    "west olympics": "الألعاب الأولمبية الغربية",
    "west paralympics games": "الألعاب البارالمبية الغربية",
    "west south american games": "ألعاب أمريكا الجنوبية الغربية",
    "west universiade": "الألعاب الجامعية الغربية",
    "west world games": "دورة الألعاب العالمية الغربية",
    "west youth olympic games": "الألعاب الأولمبية الشبابية الغربية",
    "west youth olympics": "الألعاب الأولمبية الشبابية الغربية",
    "winter african games": "الألعاب الإفريقية الشتوية",
    "winter all-africa games": "ألعاب عموم إفريقيا الشتوية",
    "winter asian games": "الألعاب الآسيوية الشتوية",
    "winter central american games": "ألعاب أمريكا الوسطى الشتوية",
    "winter commonwealth games": "ألعاب الكومنولث الشتوية",
    "winter deaflympic games": "ألعاب ديفلمبياد الشتوية",
    "winter european youth olympic": "الألعاب الأولمبية الشبابية الأوروبية الشتوية",
    "winter european youth olympic winter": "الألعاب الأولمبية الشبابية الأوروبية الشتوية الشتوية",
    "winter jeux de la francophonie": "الألعاب الفرانكوفونية الشتوية",
    "winter olympic games": "الألعاب الأولمبية الشتوية",
    "winter paralympics games": "الألعاب البارالمبية الشتوية",
    "winter south american games": "ألعاب أمريكا الجنوبية الشتوية",
    "winter world games": "دورة الألعاب العالمية الشتوية",
    "winter youth olympic games": "الألعاب الأولمبية الشبابية الشتوية",
    "winter youth olympics": "الألعاب الأولمبية الشبابية الشتوية",
    "world games": "دورة الألعاب العالمية",
    "youth olympic games": "الألعاب الأولمبية الشبابية",
}


@pytest.mark.parametrize("category, expected", main_data.items(), ids=main_data.keys())
@pytest.mark.fast
def test_resolve_countries_names_medalists(category: str, expected: str) -> None:
    """
    pytest tests/new_resolvers/countries_names_resolvers/countries_names_medalists/test_countries_names_medalists.py::test_resolve_countries_names_medalists
    """
    label = resolve_countries_names_medalists(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", summer_winter_tabs.items(), ids=summer_winter_tabs.keys())
@pytest.mark.fast
def test_summer_winter_tabs(category: str, expected: str) -> None:
    label = resolve_countries_names_medalists(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", summer_winter_games.items(), ids=summer_winter_games.keys())
@pytest.mark.fast
def test_summer_winter_games(category: str, expected: str) -> None:
    label = resolve_countries_names_medalists(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_resolve_countries_names_medalists", main_data, resolve_countries_names_medalists),
    ("test_summer_winter_tabs", summer_winter_tabs, resolve_countries_names_medalists),
    ("test_summer_winter_games", summer_winter_games, resolve_countries_names_medalists),
]


@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback: Callable) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
