from ...helps import len_print

# --- Tour de

# ---
pp_ends_with_pase = {
    " - telugu": "{} - تيلوغوي",
    " - boys doubles": "{} - زوجي فتيان",
    " - boys qualification": "{} - تصفيات فتيان",
    " - boys singles": "{} - فردي فتيان",
    " - boys team": "{} - فريق فتيان",
    " - boys tournament": "{} - مسابقة فتيان",
    " - girls doubles": "{} - زوجي فتيات",
    " - girls qualification": "{} - تصفيات فتيات",
    " - girls singles": "{} - فردي فتيات",
    " - girls team": "{} - فريق فتيات",
    " - girls tournament": "{} - مسابقة فتيات",
    " - kannada": "{} - كنادي",
    " - ladies doubles": "{} - زوجي سيدات",
    " - ladies qualification": "{} - تصفيات سيدات",
    " - ladies singles": "{} - فردي سيدات",
    " - ladies team": "{} - فريق سيدات",
    " - ladies tournament": "{} - مسابقة سيدات",
    " - males doubles": "{} - زوجي رجال",
    " - males qualification": "{} - تصفيات رجال",
    " - males singles": "{} - فردي رجال",
    " - males team": "{} - فريق رجال",
    " - males tournament": "{} - مسابقة رجال",
    " - men's doubles": "{} - زوجي رجال",
    " - men's qualification": "{} - تصفيات الرجال",
    " - men's singles": "{} - فردي رجال",
    " - men's team": "{} - فريق رجال",
    " - men's tournament": "{} - مسابقة الرجال",
    " - mixed doubles": "{} - زوجي مختلط",
    " - mixed qualification": "{} - تصفيات مختلط",
    " - mixed singles": "{} - فردي مختلط",
    " - mixed team": "{} - فريق مختلط",
    " - mixed tournament": "{} - مسابقة مختلط",
    " - qualifying": "{} - التصفيات",
    " - singles doubles": "{} - زوجي فردي",
    " - singles qualification": "{} - تصفيات فردي",
    " - singles singles": "{} - فردي فردي",
    " - singles team": "{} - فريق فردي",
    " - singles tournament": "{} - مسابقة فردي",
    " - tamil": "{} - تاميلي",
    " - women's qualification": "{} - تصفيات السيدات",
    " - women's tournament": "{} - مسابقة السيدات",
    " - womens doubles": "{} - زوجي سيدات",
    " - womens qualification": "{} - تصفيات سيدات",
    " - womens singles": "{} - فردي سيدات",
    " - womens team": "{} - فريق سيدات",
    " - womens tournament": "{} - مسابقة سيدات",
    " – kannada": "{} – كنادي",
    " – men's qualification": "{} – تصفيات الرجال",
    " – men's tournament": "{} – مسابقة الرجال",
    " – mixed doubles": "{} – زوجي مختلط",
    " – qualifying": "{} – التصفيات",
    " – tamil": "{} – تاميلي",
    " – women's qualification": "{} – تصفيات السيدات",
    " – women's tournament": "{} – مسابقة السيدات",
}

pp_ends_with = {
    " womens tournament": "{} – مسابقة السيدات",
    " mens tournament": "{} - مسابقة الرجال",
    "-related lists": "قوائم متعلقة ب{}",
    "-related media": "إعلام متعلق ب{}",
    "-related professional associations": "جمعيات تخصصية متعلقة ب{}",
    "candidates": "مرشحو {}",
    "final tournaments": "نهائيات مسابقات {}",
    "finals": "نهائيات {}",
    "first division": "{} الدرجة الأولى",
    "forth division": "{} الدرجة الرابعة",
    "second division": "{} الدرجة الثانية",
    "squad": "تشكيلة {}",
    "squads": "تشكيلات {}",
    "third division": "{} الدرجة الثالثة",
    "with disabilities": "{} بإعاقات",
    " announcers": "مذيعو {}",
    " applications": "تطبيقات {}",
    " bids": "ترشيحات {}",
    " campaigns": "حملات {}",
    " categories": "تصانيف {}",
    " champions": "أبطال {}",
    " coaches": "مدربو {}",
    " counties": "مقاطعات {}",
    " elections": "انتخابات {}",
    " employees": "موظفو {}",
    " episodes": "حلقات {}",
    " equipment": "معدات {}",
    " genres": "أنواع {}",
    " leagues": "دوريات {}",
    " leagues seasons": "مواسم دوريات {}",
    " local elections": "انتخابات محلية {}",
    " logos": "شعارات {}",
    " managers": "مدربو {}",
    " navigational boxes": "صناديق تصفح {}",
    " non-profit organizations": "منظمات غير ربحية {}",
    " non-profit publishers": "ناشرون غير ربحيون {}",
    " nonprofits": "منظمات غير ربحية {}",
    " organizations": "منظمات {}",
    " owners": "ملاك {}",
    " owners and executives": "رؤساء تنفيذيون وملاك {} {}",
    " playoffs": "تصفيات {}",
    " presidential elections": "انتخابات رئاسية {}",
    " presidential primaries": "انتخابات رئاسية تمهيدية {}",
    " qualification": "تصفيات {}",
    " referees": "حكام {}",
    " resolutions": "قرارات {}",
    " scouts": "كشافة {}",
    " seasons": "مواسم {}",
    " squad templates": "قوالب تشكيلات {}",
    " squads navigational boxes": "صناديق تصفح تشكيلات {}",
    " stadiums": "استادات {}",
    " tactics and skills": "مهارات {}",
    " teams": "فرق {}",
    " templates": "قوالب {}",
    " terminology": "مصطلحات {}",
    " trainers": "مدربو {}",
    " treaties": "معاهدات {}",
    " trophies and awards": "جوائز وإنجازات {}",
    " uniforms": "بدلات {}",
    " variants": "أشكال {}",
    " venues": "ملاعب {}",
}

combined_suffix_mappings = {**pp_ends_with_pase, **pp_ends_with}

__all__ = [
    "combined_suffix_mappings",
]

len_print.data_len(
    "ends_keys.py",
    {
        "combined_suffix_mappings": combined_suffix_mappings,
    },
)
