"""
Tests
"""

import pytest

from ArWikiCats.legacy_bots.team_work import Get_team_work_Club

fast_data = {
    # "baseball world cup players": "لاعبو كأس العالم لكرة القاعدة",
    # "egyptian second division seasons": "مواسم الدوري المصري الدرجة الثانية",
    # "rugby world cup referees": "حكام كأس العالم للرجبي",
    # "taekwondo competitions": "منافسات تايكوندو",
    "ad alcorcón seasons": "مواسم نادي ألكوركون",
    "aj auxerre matches": "مباريات نادي أوكسير",
    "aj auxerre seasons": "مواسم نادي أوكسير",
    "al ansar fc matches": "مباريات نادي الأنصار",
    "aldershot f.c. managers": "مدربو نادي ألدرشوت",
    "algerian ligue professionnelle 1 seasons": "مواسم الرابطة الجزائرية المحترفة الأولى",
    "american football league seasons": "مواسم دوري كرة القدم الأمريكية",
    "associação chapecoense de futebol seasons": "مواسم نادي شابيكوينسي",
    "atlante f.c. footballers": "لاعبو أتلانتي إف سي",
    "bayer 04 leverkusen non-playing staff": "طاقم باير 04 ليفركوزن غير اللاعبين",
    "bc brno players": "لاعبو نادي برنو لكرة السلة",
    "bc juventus players": "لاعبو أوتينوس يوفنتوس",
    "bc lietkabelis coaches": "مدربو نادي ليتكابليس لكرة السلة",
    "birmingham city f.c. seasons": "مواسم برمنغهام سيتي",
    "blackburn rovers f.c. seasons": "مواسم بلاكبيرن روفرز",
    "blackpool f.c. seasons": "مواسم نادي بلاكبول",
    "borussia dortmund non-playing staff": "طاقم بوروسيا دورتموند غير اللاعبين",
    "boston redskins coaches": "مدربو بوسطن ريدسكينس",
    "buffalo sabres coaches": "مدربو بافالو سيبرز",
    "c.d. tondela matches": "مباريات نادي تونديلا",
    "canton charge players": "لاعبو كانتون شارج",
    "charlotte hornets owners": "ملاك شارلوت هورنتس",
    "copa américa managers": "مدربو كوبا أمريكا",
    "copa américa matches": "مباريات كوبا أمريكا",
    "cs sfaxien players": "لاعبو النادي الرياضي الصفاقسي",
    "dallas cowboys personnel": "أفراد دالاس كاوبويز",
    "deportivo toluca f.c. matches": "مباريات نادي تولوكا",
    "derry city f.c. matches": "مباريات ديري سيتي",
    "fc barcelona managers": "مدربو نادي برشلونة",
    "fc bunyodkor players": "لاعبو نادي بونيودكور لكرة القدم",
    "fc dinamo batumi players": "لاعبو نادي دينامو باتومي",
    "fc gueugnon players": "لاعبو نادي غويونيون",
    "fc haka players": "لاعبو هكا",
    "fc nantes seasons": "مواسم نادي نانت",
    "fc petrolul ploiești seasons": "مواسم نادي بترولول بلويشتي لكرة القدم",
    "fc wacker innsbruck seasons": "مواسم واكر انسبروك",
    "fifa women's world cup managers": "مدربو كأس العالم لكرة القدم للسيدات",
    "fk borac banja luka managers": "مدربو نادي بوراتس بانيا لوكا",
    "fk horizont turnovo seasons": "مواسم نادي هوريزونت تورنوفو",
    "fk spartaks jūrmala players": "لاعبو نادي سبارتاكس يورمالا",
    "gfa league first division players": "لاعبو دوري الدرجة الأولى الغامبي",
    "gimnasia y esgrima de jujuy managers": "مدربو خميناسيا خوخوي",
    "go ahead eagles matches": "مباريات غو أهد إيغلز",
    "harlem globetrotters coaches": "مدربو هارلم غلوبتروترز",
    "houston rockets seasons": "مواسم هيوستن روكتس",
    "if elfsborg managers": "مدربو نادي إلفسبورغ",
    "ifk mariehamn seasons": "مواسم نادي ماريهامن",
    "ipswich town f.c. non-playing staff": "طاقم إيبسويتش تاون غير اللاعبين",
    "kashiwa reysol players": "لاعبو كاشيوا ريسول",
    "kayserispor footballers": "لاعبو كايسري سبور",
    "kazma sc players": "لاعبو نادي كاظمة",
    "knattspyrnufélag reykjavíkur managers": "مدربو ناتدبيرنوفيلاغ ريكيافيكور",
    "liga mx seasons": "مواسم الدوري المكسيكي الممتاز",
    "ljungskile sk players": "لاعبو نادي ليونغسكايل",
    "los angeles angels coaches": "مدربو لوس أنجلوس آنجلز لأنهايم",
    "luxembourgian european commissioners": "مفوضو أوروبيون لوكسمبورغيون",
    "major league baseball owners and executives": "رؤساء تنفيذيون وملاك دوري كرة القاعدة الرئيسي",
    "mc oran players": "لاعبو مولودية وهران",
    "mighty jets f.c. players": "لاعبو مايتي جيتس",
    "music managers": "مدربو موسيقى",
    "nac breda non-playing staff": "طاقم إن أي سي بريدا غير اللاعبين",
    "oakland raiders owners": "ملاك أوكلاند ريدرز",
    "orlando pride players": "لاعبو أورلاندو برايد",
    "pfc beroe stara zagora players": "لاعبو نادي بيروي ستارا زاغورا",
    "philadelphia 76ers lists": "قوائم فيلادلفيا سفنتي سيكسرز",
    "portsmouth f.c. players": "لاعبو نادي بورتسموث",
    "queensland lions fc matches": "مباريات كوينزلاند ليونز",
    "racing club de avellaneda non-playing staff": "طاقم نادي راسينغ غير اللاعبين",
    "rampla juniors managers": "مدربو رامبلا جونيورز",
    "rosario central matches": "مباريات روزاريو سنترال",
    "san antonio spurs owners": "ملاك سان أنطونيو سبرز",
    "silkeborg if players": "لاعبو نادي سيلكيبورج",
    "smouha sc players": "لاعبو نادي سموحة",
    "stade lavallois players": "لاعبو نادي لافال",
    "toronto argonauts lists": "قوائم تورونتو أرغونتس",
    "tunisian ligue professionnelle 2 managers": "مدربو الرابطة التونسية المحترفة الثانية لكرة القدم",
    "u.d. leiria players": "لاعبو يو دي ليريا",
    "uae president's cup matches": "مباريات كأس رئيس دولة الإمارات",
    "udinese calcio players": "لاعبو نادي أودينيزي",
    "utah jazz players": "لاعبو يوتا جاز",
    "vegalta sendai matches": "مباريات فيغالتا سنداي",
    "vegas golden knights coaches": "مدربو فيجاس جولدن نايتس",
    "washington state cougars football players": "لاعبو واشنطن ستايت كوجرز فوتبول",
    "webcomic logos": "شعارات ويب كومكس",
    "western sydney wanderers fc players": "لاعبو نادي وسترن سيدني واندررز",
    "wta tour seasons": "مواسم رابطة محترفات التنس",
}


@pytest.mark.parametrize("category, expected", fast_data.items(), ids=fast_data.keys())
@pytest.mark.fast
def test_fast_data(category: str, expected: str) -> None:
    label = Get_team_work_Club(category)
    assert label == expected
