"""
Tests
"""

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.new_resolvers.resolve_languages import resolve_languages_labels

test_data_0 = {
    "Arabic-language action films": "أفلام حركة باللغة العربية",
}

test_data = {
    "urdu-language comedy films": "أفلام كوميدية باللغة الأردية",
    "Arabic language activists": "ناشطون بلغة عربية",
    "Arabic-language biographical drama films": "أفلام سير ذاتية درامية باللغة العربية",
    "Arabic-language biographical films": "أفلام سير ذاتية باللغة العربية",
    "Arabic-language comedy-drama films": "أفلام كوميدية درامية باللغة العربية",
    "Arabic-language crime action films": "أفلام جريمة حركة باللغة العربية",
    "Arabic-language crime films": "أفلام جريمة باللغة العربية",
    "Arabic-language documentary films": "أفلام وثائقية باللغة العربية",
    "Arabic-language fantasy films": "أفلام فانتازيا باللغة العربية",
    "Arabic-language horror films": "أفلام رعب باللغة العربية",
    "Arabic-language musical films": "أفلام موسيقية باللغة العربية",
    "Arabic-language romance films": "أفلام رومانسية باللغة العربية",
    "Arabic-language romantic comedy-drama films": "أفلام رومانسية كوميدية درامية باللغة العربية",
    "Arabic-language thriller films": "أفلام إثارة باللغة العربية",
    "Arabic-language war films": "أفلام حربية باللغة العربية",
    "Bengali-language action adventure films": "أفلام حركة مغامرات باللغة البنغالية",
    "Bengali-language action comedy films": "أفلام حركة كوميدية باللغة البنغالية",
    "Bengali-language action drama films": "أفلام حركة درامية باللغة البنغالية",
    "Bengali-language action films": "أفلام حركة باللغة البنغالية",
    "Bengali-language adventure films": "أفلام مغامرات باللغة البنغالية",
    "Bengali-language adventure horror films": "أفلام مغامرات رعب باللغة البنغالية",
    "Bengali-language adventure thriller films": "أفلام مغامرات إثارة باللغة البنغالية",
    "Bengali-language animated films": "أفلام رسوم متحركة باللغة البنغالية",
    "Bengali-language anthology films": "أفلام أنثولوجيا باللغة البنغالية",
    "Bengali-language biographical drama films": "أفلام سير ذاتية درامية باللغة البنغالية",
    "Bengali-language biographical films": "أفلام سير ذاتية باللغة البنغالية",
    "Bengali-language comedy horror films": "أفلام كوميدية رعب باللغة البنغالية",
    "Bengali-language comedy mystery films": "أفلام كوميدية غموض باللغة البنغالية",
    "Bengali-language comedy-drama films": "أفلام كوميدية درامية باللغة البنغالية",
    "Bengali-language crime action films": "أفلام جريمة حركة باللغة البنغالية",
    "Bengali-language crime films": "أفلام جريمة باللغة البنغالية",
    "Bengali-language family drama films": "أفلام عائلية درامية باللغة البنغالية",
    "Bengali-language historical action films": "أفلام تاريخية حركة باللغة البنغالية",
    "Bengali-language historical drama films": "أفلام تاريخية درامية باللغة البنغالية",
    "Bengali-language historical films": "أفلام تاريخية باللغة البنغالية",
    "Bengali-language horror drama films": "أفلام رعب درامية باللغة البنغالية",
    "Bengali-language horror films": "أفلام رعب باللغة البنغالية",
    "Bengali-language horror thriller films": "أفلام رعب إثارة باللغة البنغالية",
    "Bengali-language independent films": "أفلام مستقلة باللغة البنغالية",
    "Bengali-language musical films": "أفلام موسيقية باللغة البنغالية",
    "Bengali-language mystery comedy-drama films": "أفلام غموض كوميدية درامية باللغة البنغالية",
    "Bengali-language mystery crime films": "أفلام غموض جريمة باللغة البنغالية",
    "Bengali-language mystery drama films": "أفلام غموض درامية باللغة البنغالية",
    "Bengali-language mystery films": "أفلام غموض باللغة البنغالية",
    "Bengali-language mystery thriller films": "أفلام غموض إثارة باللغة البنغالية",
    "Bengali-language romance films": "أفلام رومانسية باللغة البنغالية",
    "Bengali-language romantic action films": "أفلام رومانسية حركة باللغة البنغالية",
    "Bengali-language romantic comedy-drama films": "أفلام رومانسية كوميدية درامية باللغة البنغالية",
    "Bengali-language romantic thriller films": "أفلام رومانسية إثارة باللغة البنغالية",
    "Bengali-language short films": "أفلام قصيرة باللغة البنغالية",
    "Bengali-language sports films": "أفلام رياضية باللغة البنغالية",
    "Bengali-language spy thriller films": "أفلام تجسسية إثارة باللغة البنغالية",
    "Bengali-language thriller films": "أفلام إثارة باللغة البنغالية",
    "Bengali-language war films": "أفلام حربية باللغة البنغالية",
    "Bulgarian-language comedy-drama films": "أفلام كوميدية درامية باللغة البلغارية",
    "Burmese-language action films": "أفلام حركة باللغة البورمية",
    "Burmese-language comedy horror films": "أفلام كوميدية رعب باللغة البورمية",
    "Burmese-language comedy-drama films": "أفلام كوميدية درامية باللغة البورمية",
    "Burmese-language historical films": "أفلام تاريخية باللغة البورمية",
    "Burmese-language horror films": "أفلام رعب باللغة البورمية",
    "Burmese-language romance films": "أفلام رومانسية باللغة البورمية",
    "Burmese-language thriller films": "أفلام إثارة باللغة البورمية",
    "Cantonese-language action comedy films": "أفلام حركة كوميدية باللغة الكانتونية",
    "Cantonese-language action films": "أفلام حركة باللغة الكانتونية",
    "Cantonese-language comedy-drama films": "أفلام كوميدية درامية باللغة الكانتونية",
    "Cantonese-language crime films": "أفلام جريمة باللغة الكانتونية",
    "Cantonese-language fantasy films": "أفلام فانتازيا باللغة الكانتونية",
    "Cantonese-language historical drama films": "أفلام تاريخية درامية باللغة الكانتونية",
    "Cantonese-language horror films": "أفلام رعب باللغة الكانتونية",
    "Cantonese-language romance films": "أفلام رومانسية باللغة الكانتونية",
    "Cantonese-language thriller films": "أفلام إثارة باللغة الكانتونية",
    "Cantonese-language war films": "أفلام حربية باللغة الكانتونية",
    "Croatian-language biographical films": "أفلام سير ذاتية باللغة الكرواتية",
    "Croatian-language comedy-drama films": "أفلام كوميدية درامية باللغة الكرواتية",
    "Croatian-language crime films": "أفلام جريمة باللغة الكرواتية",
    "Croatian-language romance films": "أفلام رومانسية باللغة الكرواتية",
    "Croatian-language war films": "أفلام حربية باللغة الكرواتية",
    "Czech-language adventure films": "أفلام مغامرات باللغة التشيكية",
    "Czech-language biographical films": "أفلام سير ذاتية باللغة التشيكية",
    "Czech-language comedy-drama films": "أفلام كوميدية درامية باللغة التشيكية",
    "Czech-language crime films": "أفلام جريمة باللغة التشيكية",
    "Czech-language documentary films": "أفلام وثائقية باللغة التشيكية",
    "Czech-language fantasy films": "أفلام فانتازيا باللغة التشيكية",
    "Czech-language historical drama films": "أفلام تاريخية درامية باللغة التشيكية",
    "Czech-language historical films": "أفلام تاريخية باللغة التشيكية",
    "Czech-language horror films": "أفلام رعب باللغة التشيكية",
    "Czech-language musical films": "أفلام موسيقية باللغة التشيكية",
    "Czech-language romance films": "أفلام رومانسية باللغة التشيكية",
    "Czech-language science fiction adventure films": "أفلام خيال علمي مغامرات باللغة التشيكية",
    "Czech-language sports films": "أفلام رياضية باللغة التشيكية",
    "Czech-language thriller films": "أفلام إثارة باللغة التشيكية",
    "Czech-language war films": "أفلام حربية باللغة التشيكية",
    "Danish-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الدنماركية",
    "Danish-language adventure films": "أفلام مغامرات باللغة الدنماركية",
    "Danish-language biographical films": "أفلام سير ذاتية باللغة الدنماركية",
    "Danish-language comedy-drama films": "أفلام كوميدية درامية باللغة الدنماركية",
    "Danish-language crime films": "أفلام جريمة باللغة الدنماركية",
    "Danish-language documentary films": "أفلام وثائقية باللغة الدنماركية",
    "Danish-language horror films": "أفلام رعب باللغة الدنماركية",
    "Danish-language musical films": "أفلام موسيقية باللغة الدنماركية",
    "Danish-language romance films": "أفلام رومانسية باللغة الدنماركية",
    "Danish-language thriller films": "أفلام إثارة باللغة الدنماركية",
    "Danish-language war films": "أفلام حربية باللغة الدنماركية",
    "Dutch-language action comedy films": "أفلام حركة كوميدية باللغة الهولندية",
    "Dutch-language comedy-drama films": "أفلام كوميدية درامية باللغة الهولندية",
    "Dutch-language crime films": "أفلام جريمة باللغة الهولندية",
    "Dutch-language documentary films": "أفلام وثائقية باللغة الهولندية",
    "Dutch-language erotic drama films": "أفلام إغرائية درامية باللغة الهولندية",
    "Dutch-language erotic films": "أفلام إغرائية باللغة الهولندية",
    "Dutch-language fantasy films": "أفلام فانتازيا باللغة الهولندية",
    "Dutch-language historical drama films": "أفلام تاريخية درامية باللغة الهولندية",
    "Dutch-language historical films": "أفلام تاريخية باللغة الهولندية",
    "Dutch-language horror films": "أفلام رعب باللغة الهولندية",
    "Dutch-language musical films": "أفلام موسيقية باللغة الهولندية",
    "Dutch-language romance films": "أفلام رومانسية باللغة الهولندية",
    "Dutch-language sports films": "أفلام رياضية باللغة الهولندية",
    "Dutch-language thriller films": "أفلام إثارة باللغة الهولندية",
    "Dutch-language war films": "أفلام حربية باللغة الهولندية",
    "English-language action adventure films": "أفلام حركة مغامرات باللغة الإنجليزية",
    "English-language action comedy films": "أفلام حركة كوميدية باللغة الإنجليزية",
    "English-language action comedy-drama films": "أفلام حركة كوميدية درامية باللغة الإنجليزية",
    "English-language action drama films": "أفلام حركة درامية باللغة الإنجليزية",
    "English-language action films": "أفلام حركة باللغة الإنجليزية",
    "English-language action horror films": "أفلام حركة رعب باللغة الإنجليزية",
    "English-language action war films": "أفلام حركة حربية باللغة الإنجليزية",
    "English-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الإنجليزية",
    "English-language adventure comedy-drama films": "أفلام مغامرات كوميدية درامية باللغة الإنجليزية",
    "English-language adventure drama films": "أفلام مغامرات درامية باللغة الإنجليزية",
    "English-language adventure films": "أفلام مغامرات باللغة الإنجليزية",
    "English-language adventure thriller films": "أفلام مغامرات إثارة باللغة الإنجليزية",
    "English-language biographical drama films": "أفلام سير ذاتية درامية باللغة الإنجليزية",
    "English-language biographical films": "أفلام سير ذاتية باللغة الإنجليزية",
    "English-language buddy comedy films": "أفلام رفقاء كوميدية باللغة الإنجليزية",
    "English-language buddy comedy-drama films": "أفلام رفقاء كوميدية درامية باللغة الإنجليزية",
    "English-language buddy drama films": "أفلام رفقاء درامية باللغة الإنجليزية",
    "English-language Christmas comedy films": "أفلام عيد الميلاد كوميدية باللغة الإنجليزية",
    "English-language Christmas comedy-drama films": "أفلام عيد الميلاد كوميدية درامية باللغة الإنجليزية",
    "English-language Christmas drama films": "أفلام عيد الميلاد درامية باللغة الإنجليزية",
    "English-language Christmas films": "أفلام عيد الميلاد باللغة الإنجليزية",
    "English-language Christmas horror films": "أفلام عيد الميلاد رعب باللغة الإنجليزية",
    "English-language comedy horror films": "أفلام كوميدية رعب باللغة الإنجليزية",
    "English-language comedy mystery films": "أفلام كوميدية غموض باللغة الإنجليزية",
    "English-language comedy short films": "أفلام كوميدية قصيرة باللغة الإنجليزية",
    "English-language comedy-drama films": "أفلام كوميدية درامية باللغة الإنجليزية",
    "English-language comedy-drama short films": "أفلام كوميدية درامية قصيرة باللغة الإنجليزية",
    "English-language crime action films": "أفلام جريمة حركة باللغة الإنجليزية",
    "English-language crime comedy-drama films": "أفلام جريمة كوميدية درامية باللغة الإنجليزية",
    "English-language crime films": "أفلام جريمة باللغة الإنجليزية",
    "English-language documentary films": "أفلام وثائقية باللغة الإنجليزية",
    "English-language drama short films": "أفلام درامية قصيرة باللغة الإنجليزية",
    "English-language erotic drama films": "أفلام إغرائية درامية باللغة الإنجليزية",
    "English-language erotic films": "أفلام إغرائية باللغة الإنجليزية",
    "English-language erotic romance films": "أفلام إغرائية رومانسية باللغة الإنجليزية",
    "English-language fantasy action films": "أفلام فانتازيا حركة باللغة الإنجليزية",
    "English-language fantasy adventure films": "أفلام فانتازيا مغامرات باللغة الإنجليزية",
    "English-language fantasy comedy films": "أفلام فانتازيا كوميدية باللغة الإنجليزية",
    "English-language fantasy comedy-drama films": "أفلام فانتازيا كوميدية درامية باللغة الإنجليزية",
    "English-language fantasy drama films": "أفلام فانتازيا درامية باللغة الإنجليزية",
    "English-language fantasy films": "أفلام فانتازيا باللغة الإنجليزية",
    "English-language fantasy thriller films": "أفلام فانتازيا إثارة باللغة الإنجليزية",
    "English-language historical action films": "أفلام تاريخية حركة باللغة الإنجليزية",
    "English-language historical adventure films": "أفلام تاريخية مغامرات باللغة الإنجليزية",
    "English-language historical comedy films": "أفلام تاريخية كوميدية باللغة الإنجليزية",
    "English-language historical comedy-drama films": "أفلام تاريخية كوميدية درامية باللغة الإنجليزية",
    "English-language historical drama films": "أفلام تاريخية درامية باللغة الإنجليزية",
    "English-language historical films": "أفلام تاريخية باللغة الإنجليزية",
    "English-language historical horror films": "أفلام تاريخية رعب باللغة الإنجليزية",
    "English-language historical musical films": "أفلام تاريخية موسيقية باللغة الإنجليزية",
    "English-language historical romance films": "أفلام تاريخية رومانسية باللغة الإنجليزية",
    "English-language historical thriller films": "أفلام تاريخية إثارة باللغة الإنجليزية",
    "English-language horror drama films": "أفلام رعب درامية باللغة الإنجليزية",
    "English-language horror films": "أفلام رعب باللغة الإنجليزية",
    "English-language horror short films": "أفلام رعب قصيرة باللغة الإنجليزية",
    "English-language horror thriller films": "أفلام رعب إثارة باللغة الإنجليزية",
    "English-language independent films": "أفلام مستقلة باللغة الإنجليزية",
    "English-language musical comedy-drama films": "أفلام موسيقية كوميدية درامية باللغة الإنجليزية",
    "English-language musical fantasy films": "أفلام موسيقية فانتازيا باللغة الإنجليزية",
    "English-language musical films": "أفلام موسيقية باللغة الإنجليزية",
    "English-language mystery comedy-drama films": "أفلام غموض كوميدية درامية باللغة الإنجليزية",
    "English-language mystery drama films": "أفلام غموض درامية باللغة الإنجليزية",
    "English-language mystery films": "أفلام غموض باللغة الإنجليزية",
    "English-language mystery horror films": "أفلام غموض رعب باللغة الإنجليزية",
    "English-language mystery thriller films": "أفلام غموض إثارة باللغة الإنجليزية",
    "English-language political comedy films": "أفلام سياسية كوميدية باللغة الإنجليزية",
    "English-language political satire films": "أفلام سياسية هجائية باللغة الإنجليزية",
    "English-language romance films": "أفلام رومانسية باللغة الإنجليزية",
    "English-language romantic comedy-drama films": "أفلام رومانسية كوميدية درامية باللغة الإنجليزية",
    "English-language romantic fantasy films": "أفلام رومانسية فانتازيا باللغة الإنجليزية",
    "English-language romantic musical films": "أفلام رومانسية موسيقية باللغة الإنجليزية",
    "English-language romantic thriller films": "أفلام رومانسية إثارة باللغة الإنجليزية",
    "English-language science fiction adventure films": "أفلام خيال علمي مغامرات باللغة الإنجليزية",
    "English-language science fiction comedy films": "أفلام خيال علمي كوميدية باللغة الإنجليزية",
    "English-language science fiction comedy-drama films": "أفلام خيال علمي كوميدية درامية باللغة الإنجليزية",
    "English-language science fiction drama films": "أفلام خيال علمي درامية باللغة الإنجليزية",
    "English-language science fiction horror films": "أفلام خيال علمي رعب باللغة الإنجليزية",
    "English-language science fiction romance films": "أفلام خيال علمي رومانسية باللغة الإنجليزية",
    "English-language sex comedy films": "أفلام جنسية كوميدية باللغة الإنجليزية",
    "English-language sex comedy-drama films": "أفلام جنسية كوميدية درامية باللغة الإنجليزية",
    "English-language short documentary films": "أفلام قصيرة وثائقية باللغة الإنجليزية",
    "English-language short films": "أفلام قصيرة باللغة الإنجليزية",
    "English-language sports comedy films": "أفلام رياضية كوميدية باللغة الإنجليزية",
    "English-language sports comedy-drama films": "أفلام رياضية كوميدية درامية باللغة الإنجليزية",
    "English-language sports films": "أفلام رياضية باللغة الإنجليزية",
    "English-language spy action films": "أفلام تجسسية حركة باللغة الإنجليزية",
    "English-language spy comedy films": "أفلام تجسسية كوميدية باللغة الإنجليزية",
    "English-language spy drama films": "أفلام تجسسية درامية باللغة الإنجليزية",
    "English-language spy thriller films": "أفلام تجسسية إثارة باللغة الإنجليزية",
    "English-language teen comedy films": "أفلام مراهقة كوميدية باللغة الإنجليزية",
    "English-language teen drama films": "أفلام مراهقة درامية باللغة الإنجليزية",
    "English-language teen films": "أفلام مراهقة باللغة الإنجليزية",
    "English-language thriller films": "أفلام إثارة باللغة الإنجليزية",
    "English-language war adventure films": "أفلام حربية مغامرات باللغة الإنجليزية",
    "English-language war comedy films": "أفلام حربية كوميدية باللغة الإنجليزية",
    "English-language war comedy-drama films": "أفلام حربية كوميدية درامية باللغة الإنجليزية",
    "English-language war films": "أفلام حربية باللغة الإنجليزية",
    "English-language war romance films": "أفلام حربية رومانسية باللغة الإنجليزية",
    "Estonian-language comedy-drama films": "أفلام كوميدية درامية باللغة الإستونية",
    "Finnish-language action films": "أفلام حركة باللغة الفنلندية",
    "Finnish-language biographical films": "أفلام سير ذاتية باللغة الفنلندية",
    "Finnish-language comedy horror films": "أفلام كوميدية رعب باللغة الفنلندية",
    "Finnish-language comedy-drama films": "أفلام كوميدية درامية باللغة الفنلندية",
    "Finnish-language crime films": "أفلام جريمة باللغة الفنلندية",
    "Finnish-language documentary films": "أفلام وثائقية باللغة الفنلندية",
    "Finnish-language erotic drama films": "أفلام إغرائية درامية باللغة الفنلندية",
    "Finnish-language erotic films": "أفلام إغرائية باللغة الفنلندية",
    "Finnish-language fantasy adventure films": "أفلام فانتازيا مغامرات باللغة الفنلندية",
    "Finnish-language fantasy films": "أفلام فانتازيا باللغة الفنلندية",
    "Finnish-language historical films": "أفلام تاريخية باللغة الفنلندية",
    "Finnish-language horror films": "أفلام رعب باللغة الفنلندية",
    "Finnish-language thriller films": "أفلام إثارة باللغة الفنلندية",
    "Finnish-language war films": "أفلام حربية باللغة الفنلندية",
    "French-language action comedy films": "أفلام حركة كوميدية باللغة الفرنسية",
    "French-language action films": "أفلام حركة باللغة الفرنسية",
    "French-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الفرنسية",
    "French-language adventure drama films": "أفلام مغامرات درامية باللغة الفرنسية",
    "French-language adventure films": "أفلام مغامرات باللغة الفرنسية",
    "French-language biographical drama films": "أفلام سير ذاتية درامية باللغة الفرنسية",
    "French-language biographical films": "أفلام سير ذاتية باللغة الفرنسية",
    "French-language comedy horror films": "أفلام كوميدية رعب باللغة الفرنسية",
    "French-language comedy mystery films": "أفلام كوميدية غموض باللغة الفرنسية",
    "French-language comedy-drama films": "أفلام كوميدية درامية باللغة الفرنسية",
    "French-language crime films": "أفلام جريمة باللغة الفرنسية",
    "French-language documentary films": "أفلام وثائقية باللغة الفرنسية",
    "French-language erotic drama films": "أفلام إغرائية درامية باللغة الفرنسية",
    "French-language erotic films": "أفلام إغرائية باللغة الفرنسية",
    "French-language fantasy films": "أفلام فانتازيا باللغة الفرنسية",
    "French-language historical adventure films": "أفلام تاريخية مغامرات باللغة الفرنسية",
    "French-language historical comedy films": "أفلام تاريخية كوميدية باللغة الفرنسية",
    "French-language historical drama films": "أفلام تاريخية درامية باللغة الفرنسية",
    "French-language historical films": "أفلام تاريخية باللغة الفرنسية",
    "French-language horror films": "أفلام رعب باللغة الفرنسية",
    "French-language independent films": "أفلام مستقلة باللغة الفرنسية",
    "French-language musical films": "أفلام موسيقية باللغة الفرنسية",
    "French-language mystery films": "أفلام غموض باللغة الفرنسية",
    "French-language mystery thriller films": "أفلام غموض إثارة باللغة الفرنسية",
    "French-language romance films": "أفلام رومانسية باللغة الفرنسية",
    "French-language sex comedy films": "أفلام جنسية كوميدية باللغة الفرنسية",
    "French-language sex comedy-drama films": "أفلام جنسية كوميدية درامية باللغة الفرنسية",
    "French-language short documentary films": "أفلام قصيرة وثائقية باللغة الفرنسية",
    "French-language short films": "أفلام قصيرة باللغة الفرنسية",
    "French-language sports comedy films": "أفلام رياضية كوميدية باللغة الفرنسية",
    "French-language sports films": "أفلام رياضية باللغة الفرنسية",
    "French-language thriller films": "أفلام إثارة باللغة الفرنسية",
    "French-language war adventure films": "أفلام حربية مغامرات باللغة الفرنسية",
    "French-language war comedy films": "أفلام حربية كوميدية باللغة الفرنسية",
    "French-language war films": "أفلام حربية باللغة الفرنسية",
    "German-language action comedy films": "أفلام حركة كوميدية باللغة الألمانية",
    "German-language action films": "أفلام حركة باللغة الألمانية",
    "German-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الألمانية",
    "German-language adventure drama films": "أفلام مغامرات درامية باللغة الألمانية",
    "German-language adventure films": "أفلام مغامرات باللغة الألمانية",
    "German-language biographical drama films": "أفلام سير ذاتية درامية باللغة الألمانية",
    "German-language biographical films": "أفلام سير ذاتية باللغة الألمانية",
    "German-language comedy horror films": "أفلام كوميدية رعب باللغة الألمانية",
    "German-language comedy-drama films": "أفلام كوميدية درامية باللغة الألمانية",
    "German-language crime films": "أفلام جريمة باللغة الألمانية",
    "German-language documentary films": "أفلام وثائقية باللغة الألمانية",
    "German-language erotic drama films": "أفلام إغرائية درامية باللغة الألمانية",
    "German-language erotic films": "أفلام إغرائية باللغة الألمانية",
    "German-language fantasy films": "أفلام فانتازيا باللغة الألمانية",
    "German-language historical adventure films": "أفلام تاريخية مغامرات باللغة الألمانية",
    "German-language historical comedy films": "أفلام تاريخية كوميدية باللغة الألمانية",
    "German-language historical drama films": "أفلام تاريخية درامية باللغة الألمانية",
    "German-language historical films": "أفلام تاريخية باللغة الألمانية",
    "German-language historical musical films": "أفلام تاريخية موسيقية باللغة الألمانية",
    "German-language horror films": "أفلام رعب باللغة الألمانية",
    "German-language independent films": "أفلام مستقلة باللغة الألمانية",
    "German-language musical films": "أفلام موسيقية باللغة الألمانية",
    "German-language mystery films": "أفلام غموض باللغة الألمانية",
    "German-language mystery thriller films": "أفلام غموض إثارة باللغة الألمانية",
    "German-language romance films": "أفلام رومانسية باللغة الألمانية",
    "German-language sex comedy films": "أفلام جنسية كوميدية باللغة الألمانية",
    "German-language sports comedy films": "أفلام رياضية كوميدية باللغة الألمانية",
    "German-language sports films": "أفلام رياضية باللغة الألمانية",
    "German-language spy drama films": "أفلام تجسسية درامية باللغة الألمانية",
    "German-language spy thriller films": "أفلام تجسسية إثارة باللغة الألمانية",
    "German-language thriller films": "أفلام إثارة باللغة الألمانية",
    "German-language war comedy films": "أفلام حربية كوميدية باللغة الألمانية",
    "German-language war films": "أفلام حربية باللغة الألمانية",
    "Greek-language adventure films": "أفلام مغامرات باللغة اليونانية",
    "Greek-language biographical films": "أفلام سير ذاتية باللغة اليونانية",
    "Greek-language comedy-drama films": "أفلام كوميدية درامية باللغة اليونانية",
    "Greek-language crime films": "أفلام جريمة باللغة اليونانية",
    "Greek-language horror films": "أفلام رعب باللغة اليونانية",
    "Greek-language musical films": "أفلام موسيقية باللغة اليونانية",
    "Greek-language romance films": "أفلام رومانسية باللغة اليونانية",
    "Greek-language thriller films": "أفلام إثارة باللغة اليونانية",
    "Greek-language war films": "أفلام حربية باللغة اليونانية",
    "Hebrew-language comedy-drama films": "أفلام كوميدية درامية باللغة العبرية",
    "Hebrew-language crime films": "أفلام جريمة باللغة العبرية",
    "Hebrew-language documentary films": "أفلام وثائقية باللغة العبرية",
    "Hebrew-language romance films": "أفلام رومانسية باللغة العبرية",
    "Hebrew-language thriller films": "أفلام إثارة باللغة العبرية",
    "Hebrew-language war films": "أفلام حربية باللغة العبرية",
    "Hindi-language action adventure films": "أفلام حركة مغامرات باللغة الهندية",
    "Hindi-language action comedy films": "أفلام حركة كوميدية باللغة الهندية",
    "Hindi-language action drama films": "أفلام حركة درامية باللغة الهندية",
    "Hindi-language action films": "أفلام حركة باللغة الهندية",
    "Hindi-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الهندية",
    "Hindi-language adventure films": "أفلام مغامرات باللغة الهندية",
    "Hindi-language biographical drama films": "أفلام سير ذاتية درامية باللغة الهندية",
    "Hindi-language biographical films": "أفلام سير ذاتية باللغة الهندية",
    "Hindi-language comedy horror films": "أفلام كوميدية رعب باللغة الهندية",
    "Hindi-language comedy-drama films": "أفلام كوميدية درامية باللغة الهندية",
    "Hindi-language crime action films": "أفلام جريمة حركة باللغة الهندية",
    "Hindi-language crime films": "أفلام جريمة باللغة الهندية",
    "Hindi-language fantasy comedy films": "أفلام فانتازيا كوميدية باللغة الهندية",
    "Hindi-language fantasy films": "أفلام فانتازيا باللغة الهندية",
    "Hindi-language horror films": "أفلام رعب باللغة الهندية",
    "Hindi-language horror thriller films": "أفلام رعب إثارة باللغة الهندية",
    "Hindi-language mystery films": "أفلام غموض باللغة الهندية",
    "Hindi-language mystery thriller films": "أفلام غموض إثارة باللغة الهندية",
    "Hindi-language romance films": "أفلام رومانسية باللغة الهندية",
    "Hindi-language romantic thriller films": "أفلام رومانسية إثارة باللغة الهندية",
    "Hindi-language sports films": "أفلام رياضية باللغة الهندية",
    "Hindi-language thriller films": "أفلام إثارة باللغة الهندية",
    "Hungarian-language adventure films": "أفلام مغامرات باللغة المجرية",
    "Hungarian-language biographical films": "أفلام سير ذاتية باللغة المجرية",
    "Hungarian-language comedy-drama films": "أفلام كوميدية درامية باللغة المجرية",
    "Hungarian-language crime films": "أفلام جريمة باللغة المجرية",
    "Hungarian-language historical drama films": "أفلام تاريخية درامية باللغة المجرية",
    "Hungarian-language historical films": "أفلام تاريخية باللغة المجرية",
    "Hungarian-language musical films": "أفلام موسيقية باللغة المجرية",
    "Hungarian-language romance films": "أفلام رومانسية باللغة المجرية",
    "Hungarian-language thriller films": "أفلام إثارة باللغة المجرية",
    "Hungarian-language war films": "أفلام حربية باللغة المجرية",
    "Icelandic-language comedy-drama films": "أفلام كوميدية درامية باللغة الآيسلندية",
    "Icelandic-language documentary films": "أفلام وثائقية باللغة الآيسلندية",
    "Indonesian-language action films": "أفلام حركة باللغة الإندونيسية",
    "Indonesian-language biographical films": "أفلام سير ذاتية باللغة الإندونيسية",
    "Indonesian-language comedy-drama films": "أفلام كوميدية درامية باللغة الإندونيسية",
    "Indonesian-language horror films": "أفلام رعب باللغة الإندونيسية",
    "Indonesian-language romance films": "أفلام رومانسية باللغة الإندونيسية",
    "Indonesian-language thriller films": "أفلام إثارة باللغة الإندونيسية",
    "Italian-language action adventure films": "أفلام حركة مغامرات باللغة الإيطالية",
    "Italian-language action films": "أفلام حركة باللغة الإيطالية",
    "Italian-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الإيطالية",
    "Italian-language adventure films": "أفلام مغامرات باللغة الإيطالية",
    "Italian-language biographical drama films": "أفلام سير ذاتية درامية باللغة الإيطالية",
    "Italian-language biographical films": "أفلام سير ذاتية باللغة الإيطالية",
    "Italian-language buddy comedy films": "أفلام رفقاء كوميدية باللغة الإيطالية",
    "Italian-language comedy-drama films": "أفلام كوميدية درامية باللغة الإيطالية",
    "Italian-language crime films": "أفلام جريمة باللغة الإيطالية",
    "Italian-language documentary films": "أفلام وثائقية باللغة الإيطالية",
    "Italian-language erotic drama films": "أفلام إغرائية درامية باللغة الإيطالية",
    "Italian-language erotic films": "أفلام إغرائية باللغة الإيطالية",
    "Italian-language fantasy adventure films": "أفلام فانتازيا مغامرات باللغة الإيطالية",
    "Italian-language fantasy films": "أفلام فانتازيا باللغة الإيطالية",
    "Italian-language historical adventure films": "أفلام تاريخية مغامرات باللغة الإيطالية",
    "Italian-language historical comedy films": "أفلام تاريخية كوميدية باللغة الإيطالية",
    "Italian-language historical drama films": "أفلام تاريخية درامية باللغة الإيطالية",
    "Italian-language historical films": "أفلام تاريخية باللغة الإيطالية",
    "Italian-language horror films": "أفلام رعب باللغة الإيطالية",
    "Italian-language independent films": "أفلام مستقلة باللغة الإيطالية",
    "Italian-language musical films": "أفلام موسيقية باللغة الإيطالية",
    "Italian-language mystery films": "أفلام غموض باللغة الإيطالية",
    "Italian-language mystery thriller films": "أفلام غموض إثارة باللغة الإيطالية",
    "Italian-language romance films": "أفلام رومانسية باللغة الإيطالية",
    "Italian-language science fiction adventure films": "أفلام خيال علمي مغامرات باللغة الإيطالية",
    "Italian-language science fiction comedy films": "أفلام خيال علمي كوميدية باللغة الإيطالية",
    "Italian-language sex comedy films": "أفلام جنسية كوميدية باللغة الإيطالية",
    "Italian-language sports comedy films": "أفلام رياضية كوميدية باللغة الإيطالية",
    "Italian-language sports films": "أفلام رياضية باللغة الإيطالية",
    "Italian-language spy comedy films": "أفلام تجسسية كوميدية باللغة الإيطالية",
    "Italian-language thriller films": "أفلام إثارة باللغة الإيطالية",
    "Italian-language war comedy films": "أفلام حربية كوميدية باللغة الإيطالية",
    "Italian-language war films": "أفلام حربية باللغة الإيطالية",
    "Japanese-language action comedy films": "أفلام حركة كوميدية باللغة اليابانية",
    "Japanese-language action films": "أفلام حركة باللغة اليابانية",
    "Japanese-language adventure films": "أفلام مغامرات باللغة اليابانية",
    "Japanese-language biographical films": "أفلام سير ذاتية باللغة اليابانية",
    "Japanese-language comedy-drama films": "أفلام كوميدية درامية باللغة اليابانية",
    "Japanese-language crime films": "أفلام جريمة باللغة اليابانية",
    "Japanese-language documentary films": "أفلام وثائقية باللغة اليابانية",
    "Japanese-language erotic drama films": "أفلام إغرائية درامية باللغة اليابانية",
    "Japanese-language erotic films": "أفلام إغرائية باللغة اليابانية",
    "Japanese-language fantasy films": "أفلام فانتازيا باللغة اليابانية",
    "Japanese-language historical drama films": "أفلام تاريخية درامية باللغة اليابانية",
    "Japanese-language historical films": "أفلام تاريخية باللغة اليابانية",
    "Japanese-language horror films": "أفلام رعب باللغة اليابانية",
    "Japanese-language musical films": "أفلام موسيقية باللغة اليابانية",
    "Japanese-language mystery films": "أفلام غموض باللغة اليابانية",
    "Japanese-language mystery thriller films": "أفلام غموض إثارة باللغة اليابانية",
    "Japanese-language romance films": "أفلام رومانسية باللغة اليابانية",
    "Japanese-language sex comedy films": "أفلام جنسية كوميدية باللغة اليابانية",
    "Japanese-language sports films": "أفلام رياضية باللغة اليابانية",
    "Japanese-language thriller films": "أفلام إثارة باللغة اليابانية",
    "Japanese-language war films": "أفلام حربية باللغة اليابانية",
    "Kannada-language action comedy films": "أفلام حركة كوميدية باللغة الكنادية",
    "Kannada-language action films": "أفلام حركة باللغة الكنادية",
    "Kannada-language comedy-drama films": "أفلام كوميدية درامية باللغة الكنادية",
    "Kannada-language mystery films": "أفلام غموض باللغة الكنادية",
    "Kannada-language mystery thriller films": "أفلام غموض إثارة باللغة الكنادية",
    "Kannada-language romance films": "أفلام رومانسية باللغة الكنادية",
    "Kannada-language thriller films": "أفلام إثارة باللغة الكنادية",
    "Korean-language action adventure films": "أفلام حركة مغامرات باللغة الكورية",
    "Korean-language action comedy films": "أفلام حركة كوميدية باللغة الكورية",
    "Korean-language action films": "أفلام حركة باللغة الكورية",
    "Korean-language action horror films": "أفلام حركة رعب باللغة الكورية",
    "Korean-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الكورية",
    "Korean-language biographical films": "أفلام سير ذاتية باللغة الكورية",
    "Korean-language comedy horror films": "أفلام كوميدية رعب باللغة الكورية",
    "Korean-language comedy-drama films": "أفلام كوميدية درامية باللغة الكورية",
    "Korean-language crime action films": "أفلام جريمة حركة باللغة الكورية",
    "Korean-language crime films": "أفلام جريمة باللغة الكورية",
    "Korean-language documentary films": "أفلام وثائقية باللغة الكورية",
    "Korean-language erotic drama films": "أفلام إغرائية درامية باللغة الكورية",
    "Korean-language erotic films": "أفلام إغرائية باللغة الكورية",
    "Korean-language fantasy films": "أفلام فانتازيا باللغة الكورية",
    "Korean-language historical drama films": "أفلام تاريخية درامية باللغة الكورية",
    "Korean-language historical films": "أفلام تاريخية باللغة الكورية",
    "Korean-language horror films": "أفلام رعب باللغة الكورية",
    "Korean-language musical films": "أفلام موسيقية باللغة الكورية",
    "Korean-language mystery films": "أفلام غموض باللغة الكورية",
    "Korean-language mystery thriller films": "أفلام غموض إثارة باللغة الكورية",
    "Korean-language romance films": "أفلام رومانسية باللغة الكورية",
    "Korean-language sports films": "أفلام رياضية باللغة الكورية",
    "Korean-language thriller films": "أفلام إثارة باللغة الكورية",
    "Korean-language war films": "أفلام حربية باللغة الكورية",
    "Malayalam-language action comedy films": "أفلام حركة كوميدية باللغة الماليالامية",
    "Malayalam-language comedy-drama films": "أفلام كوميدية درامية باللغة الماليالامية",
    "Malayalam-language romance films": "أفلام رومانسية باللغة الماليالامية",
    "Malayalam-language thriller films": "أفلام إثارة باللغة الماليالامية",
    "Marathi-language action comedy films": "أفلام حركة كوميدية باللغة الماراثية",
    "Marathi-language action drama films": "أفلام حركة درامية باللغة الماراثية",
    "Marathi-language action films": "أفلام حركة باللغة الماراثية",
    "Marathi-language adventure films": "أفلام مغامرات باللغة الماراثية",
    "Marathi-language biographical films": "أفلام سير ذاتية باللغة الماراثية",
    "Marathi-language comedy horror films": "أفلام كوميدية رعب باللغة الماراثية",
    "Marathi-language crime films": "أفلام جريمة باللغة الماراثية",
    "Marathi-language family drama films": "أفلام عائلية درامية باللغة الماراثية",
    "Marathi-language fantasy thriller films": "أفلام فانتازيا إثارة باللغة الماراثية",
    "Marathi-language historical films": "أفلام تاريخية باللغة الماراثية",
    "Marathi-language musical films": "أفلام موسيقية باللغة الماراثية",
    "Marathi-language period drama films": "أفلام حقبية درامية باللغة الماراثية",
    "Marathi-language romance films": "أفلام رومانسية باللغة الماراثية",
    "Marathi-language short films": "أفلام قصيرة باللغة الماراثية",
    "Marathi-language supernatural horror films": "أفلام خارقة للطبيعة رعب باللغة الماراثية",
    "Marathi-language thriller films": "أفلام إثارة باللغة الماراثية",
    "Norwegian-language comedy-drama films": "أفلام كوميدية درامية باللغة النرويجية",
    "Norwegian-language crime films": "أفلام جريمة باللغة النرويجية",
    "Norwegian-language documentary films": "أفلام وثائقية باللغة النرويجية",
    "Norwegian-language horror films": "أفلام رعب باللغة النرويجية",
    "Norwegian-language romance films": "أفلام رومانسية باللغة النرويجية",
    "Norwegian-language thriller films": "أفلام إثارة باللغة النرويجية",
    "Norwegian-language war films": "أفلام حربية باللغة النرويجية",
    "Persian-language adventure films": "أفلام مغامرات باللغة الفارسية",
    "Persian-language biographical films": "أفلام سير ذاتية باللغة الفارسية",
    "Persian-language comedy-drama films": "أفلام كوميدية درامية باللغة الفارسية",
    "Persian-language crime films": "أفلام جريمة باللغة الفارسية",
    "Persian-language documentary films": "أفلام وثائقية باللغة الفارسية",
    "Persian-language horror films": "أفلام رعب باللغة الفارسية",
    "Persian-language romance films": "أفلام رومانسية باللغة الفارسية",
    "Persian-language war films": "أفلام حربية باللغة الفارسية",
    "Polish-language adventure films": "أفلام مغامرات باللغة البولندية",
    "Polish-language biographical films": "أفلام سير ذاتية باللغة البولندية",
    "Polish-language comedy-drama films": "أفلام كوميدية درامية باللغة البولندية",
    "Polish-language crime films": "أفلام جريمة باللغة البولندية",
    "Polish-language documentary films": "أفلام وثائقية باللغة البولندية",
    "Polish-language fantasy films": "أفلام فانتازيا باللغة البولندية",
    "Polish-language historical drama films": "أفلام تاريخية درامية باللغة البولندية",
    "Polish-language historical films": "أفلام تاريخية باللغة البولندية",
    "Polish-language musical films": "أفلام موسيقية باللغة البولندية",
    "Polish-language romance films": "أفلام رومانسية باللغة البولندية",
    "Polish-language sports films": "أفلام رياضية باللغة البولندية",
    "Polish-language thriller films": "أفلام إثارة باللغة البولندية",
    "Polish-language war films": "أفلام حربية باللغة البولندية",
    "Portuguese-language action adventure films": "أفلام حركة مغامرات باللغة البرتغالية",
    "Portuguese-language action comedy films": "أفلام حركة كوميدية باللغة البرتغالية",
    "Portuguese-language action films": "أفلام حركة باللغة البرتغالية",
    "Portuguese-language adventure films": "أفلام مغامرات باللغة البرتغالية",
    "Portuguese-language biographical drama films": "أفلام سير ذاتية درامية باللغة البرتغالية",
    "Portuguese-language biographical films": "أفلام سير ذاتية باللغة البرتغالية",
    "Portuguese-language comedy-drama films": "أفلام كوميدية درامية باللغة البرتغالية",
    "Portuguese-language crime films": "أفلام جريمة باللغة البرتغالية",
    "Portuguese-language documentary films": "أفلام وثائقية باللغة البرتغالية",
    "Portuguese-language fantasy films": "أفلام فانتازيا باللغة البرتغالية",
    "Portuguese-language historical drama films": "أفلام تاريخية درامية باللغة البرتغالية",
    "Portuguese-language historical films": "أفلام تاريخية باللغة البرتغالية",
    "Portuguese-language horror films": "أفلام رعب باللغة البرتغالية",
    "Portuguese-language musical films": "أفلام موسيقية باللغة البرتغالية",
    "Portuguese-language mystery films": "أفلام غموض باللغة البرتغالية",
    "Portuguese-language romance films": "أفلام رومانسية باللغة البرتغالية",
    "Portuguese-language sports films": "أفلام رياضية باللغة البرتغالية",
    "Portuguese-language thriller films": "أفلام إثارة باللغة البرتغالية",
    "Romanian-language action comedy films": "أفلام حركة كوميدية باللغة الرومانية",
    "Romanian-language action films": "أفلام حركة باللغة الرومانية",
    "Romanian-language comedy-drama films": "أفلام كوميدية درامية باللغة الرومانية",
    "Romanian-language crime films": "أفلام جريمة باللغة الرومانية",
    "Romanian-language fantasy films": "أفلام فانتازيا باللغة الرومانية",
    "Romanian-language historical drama films": "أفلام تاريخية درامية باللغة الرومانية",
    "Romanian-language historical films": "أفلام تاريخية باللغة الرومانية",
    "Romanian-language thriller films": "أفلام إثارة باللغة الرومانية",
    "Romanian-language war films": "أفلام حربية باللغة الرومانية",
    "Russian-language action adventure films": "أفلام حركة مغامرات باللغة الروسية",
    "Russian-language action drama films": "أفلام حركة درامية باللغة الروسية",
    "Russian-language action films": "أفلام حركة باللغة الروسية",
    "Russian-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الروسية",
    "Russian-language adventure drama films": "أفلام مغامرات درامية باللغة الروسية",
    "Russian-language adventure films": "أفلام مغامرات باللغة الروسية",
    "Russian-language adventure thriller films": "أفلام مغامرات إثارة باللغة الروسية",
    "Russian-language biographical drama films": "أفلام سير ذاتية درامية باللغة الروسية",
    "Russian-language biographical films": "أفلام سير ذاتية باللغة الروسية",
    "Russian-language comedy short films": "أفلام كوميدية قصيرة باللغة الروسية",
    "Russian-language comedy-drama films": "أفلام كوميدية درامية باللغة الروسية",
    "Russian-language crime action films": "أفلام جريمة حركة باللغة الروسية",
    "Russian-language crime films": "أفلام جريمة باللغة الروسية",
    "Russian-language documentary films": "أفلام وثائقية باللغة الروسية",
    "Russian-language fantasy adventure films": "أفلام فانتازيا مغامرات باللغة الروسية",
    "Russian-language fantasy comedy films": "أفلام فانتازيا كوميدية باللغة الروسية",
    "Russian-language fantasy drama films": "أفلام فانتازيا درامية باللغة الروسية",
    "Russian-language fantasy films": "أفلام فانتازيا باللغة الروسية",
    "Russian-language historical action films": "أفلام تاريخية حركة باللغة الروسية",
    "Russian-language historical adventure films": "أفلام تاريخية مغامرات باللغة الروسية",
    "Russian-language historical comedy films": "أفلام تاريخية كوميدية باللغة الروسية",
    "Russian-language historical drama films": "أفلام تاريخية درامية باللغة الروسية",
    "Russian-language historical films": "أفلام تاريخية باللغة الروسية",
    "Russian-language historical musical films": "أفلام تاريخية موسيقية باللغة الروسية",
    "Russian-language horror films": "أفلام رعب باللغة الروسية",
    "Russian-language horror thriller films": "أفلام رعب إثارة باللغة الروسية",
    "Russian-language independent films": "أفلام مستقلة باللغة الروسية",
    "Russian-language musical comedy-drama films": "أفلام موسيقية كوميدية درامية باللغة الروسية",
    "Russian-language musical films": "أفلام موسيقية باللغة الروسية",
    "Russian-language mystery drama films": "أفلام غموض درامية باللغة الروسية",
    "Russian-language mystery films": "أفلام غموض باللغة الروسية",
    "Russian-language mystery thriller films": "أفلام غموض إثارة باللغة الروسية",
    "Russian-language romance films": "أفلام رومانسية باللغة الروسية",
    "Russian-language romantic comedy-drama films": "أفلام رومانسية كوميدية درامية باللغة الروسية",
    "Russian-language romantic musical films": "أفلام رومانسية موسيقية باللغة الروسية",
    "Russian-language science fiction adventure films": "أفلام خيال علمي مغامرات باللغة الروسية",
    "Russian-language science fiction comedy films": "أفلام خيال علمي كوميدية باللغة الروسية",
    "Russian-language science fiction drama films": "أفلام خيال علمي درامية باللغة الروسية",
    "Russian-language science fiction horror films": "أفلام خيال علمي رعب باللغة الروسية",
    "Russian-language short films": "أفلام قصيرة باللغة الروسية",
    "Russian-language sports films": "أفلام رياضية باللغة الروسية",
    "Russian-language thriller films": "أفلام إثارة باللغة الروسية",
    "Russian-language war adventure films": "أفلام حربية مغامرات باللغة الروسية",
    "Russian-language war comedy films": "أفلام حربية كوميدية باللغة الروسية",
    "Russian-language war films": "أفلام حربية باللغة الروسية",
    "Serbian-language biographical films": "أفلام سير ذاتية باللغة الصربية",
    "Serbian-language comedy-drama films": "أفلام كوميدية درامية باللغة الصربية",
    "Serbian-language documentary films": "أفلام وثائقية باللغة الصربية",
    "Serbian-language historical drama films": "أفلام تاريخية درامية باللغة الصربية",
    "Serbian-language horror films": "أفلام رعب باللغة الصربية",
    "Serbian-language romance films": "أفلام رومانسية باللغة الصربية",
    "Serbian-language war films": "أفلام حربية باللغة الصربية",
    "Sinhala-language romance films": "أفلام رومانسية باللغة السنهالية",
    "Sinhala-language thriller films": "أفلام إثارة باللغة السنهالية",
    "Spanish-language action adventure films": "أفلام حركة مغامرات باللغة الإسبانية",
    "Spanish-language action comedy films": "أفلام حركة كوميدية باللغة الإسبانية",
    "Spanish-language action drama films": "أفلام حركة درامية باللغة الإسبانية",
    "Spanish-language action films": "أفلام حركة باللغة الإسبانية",
    "Spanish-language adventure comedy films": "أفلام مغامرات كوميدية باللغة الإسبانية",
    "Spanish-language adventure drama films": "أفلام مغامرات درامية باللغة الإسبانية",
    "Spanish-language adventure films": "أفلام مغامرات باللغة الإسبانية",
    "Spanish-language biographical drama films": "أفلام سير ذاتية درامية باللغة الإسبانية",
    "Spanish-language comedy horror films": "أفلام كوميدية رعب باللغة الإسبانية",
    "Spanish-language comedy mystery films": "أفلام كوميدية غموض باللغة الإسبانية",
    "Spanish-language comedy-drama films": "أفلام كوميدية درامية باللغة الإسبانية",
    "Spanish-language crime films": "أفلام جريمة باللغة الإسبانية",
    "Spanish-language documentary films": "أفلام وثائقية باللغة الإسبانية",
    "Spanish-language erotic drama films": "أفلام إغرائية درامية باللغة الإسبانية",
    "Spanish-language erotic films": "أفلام إغرائية باللغة الإسبانية",
    "Spanish-language fantasy adventure films": "أفلام فانتازيا مغامرات باللغة الإسبانية",
    "Spanish-language fantasy films": "أفلام فانتازيا باللغة الإسبانية",
    "Spanish-language historical adventure films": "أفلام تاريخية مغامرات باللغة الإسبانية",
    "Spanish-language historical comedy films": "أفلام تاريخية كوميدية باللغة الإسبانية",
    "Spanish-language historical drama films": "أفلام تاريخية درامية باللغة الإسبانية",
    "Spanish-language historical films": "أفلام تاريخية باللغة الإسبانية",
    "Spanish-language historical romance films": "أفلام تاريخية رومانسية باللغة الإسبانية",
    "Spanish-language horror drama films": "أفلام رعب درامية باللغة الإسبانية",
    "Spanish-language horror films": "أفلام رعب باللغة الإسبانية",
    "Spanish-language independent films": "أفلام مستقلة باللغة الإسبانية",
    "Spanish-language musical films": "أفلام موسيقية باللغة الإسبانية",
    "Spanish-language mystery films": "أفلام غموض باللغة الإسبانية",
    "Spanish-language mystery thriller films": "أفلام غموض إثارة باللغة الإسبانية",
    "Spanish-language romance films": "أفلام رومانسية باللغة الإسبانية",
    "Spanish-language romantic comedy-drama films": "أفلام رومانسية كوميدية درامية باللغة الإسبانية",
    "Spanish-language romantic musical films": "أفلام رومانسية موسيقية باللغة الإسبانية",
    "Spanish-language science fiction adventure films": "أفلام خيال علمي مغامرات باللغة الإسبانية",
    "Spanish-language science fiction comedy films": "أفلام خيال علمي كوميدية باللغة الإسبانية",
    "Spanish-language sex comedy films": "أفلام جنسية كوميدية باللغة الإسبانية",
    "Spanish-language sex comedy-drama films": "أفلام جنسية كوميدية درامية باللغة الإسبانية",
    "Spanish-language short films": "أفلام قصيرة باللغة الإسبانية",
    "Spanish-language sports comedy films": "أفلام رياضية كوميدية باللغة الإسبانية",
    "Spanish-language sports films": "أفلام رياضية باللغة الإسبانية",
    "Spanish-language thriller films": "أفلام إثارة باللغة الإسبانية",
    "Spanish-language war films": "أفلام حربية باللغة الإسبانية",
    "Swedish-language action films": "أفلام حركة باللغة السويدية",
    "Swedish-language adventure comedy films": "أفلام مغامرات كوميدية باللغة السويدية",
    "Swedish-language adventure films": "أفلام مغامرات باللغة السويدية",
    "Swedish-language biographical films": "أفلام سير ذاتية باللغة السويدية",
    "Swedish-language comedy-drama films": "أفلام كوميدية درامية باللغة السويدية",
    "Swedish-language crime films": "أفلام جريمة باللغة السويدية",
    "Swedish-language documentary films": "أفلام وثائقية باللغة السويدية",
    "Swedish-language erotic drama films": "أفلام إغرائية درامية باللغة السويدية",
    "Swedish-language erotic films": "أفلام إغرائية باللغة السويدية",
    "Swedish-language historical drama films": "أفلام تاريخية درامية باللغة السويدية",
    "Swedish-language historical films": "أفلام تاريخية باللغة السويدية",
    "Swedish-language horror films": "أفلام رعب باللغة السويدية",
    "Swedish-language musical films": "أفلام موسيقية باللغة السويدية",
    "Swedish-language mystery films": "أفلام غموض باللغة السويدية",
    "Swedish-language mystery thriller films": "أفلام غموض إثارة باللغة السويدية",
    "Swedish-language romance films": "أفلام رومانسية باللغة السويدية",
    "Swedish-language sports films": "أفلام رياضية باللغة السويدية",
    "Swedish-language thriller films": "أفلام إثارة باللغة السويدية",
    "Tamil-language action adventure films": "أفلام حركة مغامرات باللغة التاميلية",
    "Tamil-language action comedy films": "أفلام حركة كوميدية باللغة التاميلية",
    "Tamil-language action drama films": "أفلام حركة درامية باللغة التاميلية",
    "Tamil-language action films": "أفلام حركة باللغة التاميلية",
    "Tamil-language adventure films": "أفلام مغامرات باللغة التاميلية",
    "Tamil-language biographical films": "أفلام سير ذاتية باللغة التاميلية",
    "Tamil-language comedy horror films": "أفلام كوميدية رعب باللغة التاميلية",
    "Tamil-language comedy-drama films": "أفلام كوميدية درامية باللغة التاميلية",
    "Tamil-language crime action films": "أفلام جريمة حركة باللغة التاميلية",
    "Tamil-language crime films": "أفلام جريمة باللغة التاميلية",
    "Tamil-language fantasy films": "أفلام فانتازيا باللغة التاميلية",
    "Tamil-language historical drama films": "أفلام تاريخية درامية باللغة التاميلية",
    "Tamil-language historical films": "أفلام تاريخية باللغة التاميلية",
    "Tamil-language horror films": "أفلام رعب باللغة التاميلية",
    "Tamil-language mystery thriller films": "أفلام غموض إثارة باللغة التاميلية",
    "Tamil-language romance films": "أفلام رومانسية باللغة التاميلية",
    "Tamil-language romantic thriller films": "أفلام رومانسية إثارة باللغة التاميلية",
    "Tamil-language thriller films": "أفلام إثارة باللغة التاميلية",
    "Tamil-language war films": "أفلام حربية باللغة التاميلية",
    "Telugu-language action comedy films": "أفلام حركة كوميدية باللغة التيلوغوية",
    "Telugu-language action films": "أفلام حركة باللغة التيلوغوية",
    "Telugu-language biographical films": "أفلام سير ذاتية باللغة التيلوغوية",
    "Telugu-language comedy-drama films": "أفلام كوميدية درامية باللغة التيلوغوية",
    "Telugu-language crime films": "أفلام جريمة باللغة التيلوغوية",
    "Telugu-language fantasy films": "أفلام فانتازيا باللغة التيلوغوية",
    "Telugu-language musical films": "أفلام موسيقية باللغة التيلوغوية",
    "Telugu-language romance films": "أفلام رومانسية باللغة التيلوغوية",
    "Telugu-language thriller films": "أفلام إثارة باللغة التيلوغوية",
    "Turkish-language action adventure films": "أفلام حركة مغامرات باللغة التركية",
    "Turkish-language action comedy films": "أفلام حركة كوميدية باللغة التركية",
    "Turkish-language action films": "أفلام حركة باللغة التركية",
    "Turkish-language adventure films": "أفلام مغامرات باللغة التركية",
    "Turkish-language biographical films": "أفلام سير ذاتية باللغة التركية",
    "Turkish-language comedy horror films": "أفلام كوميدية رعب باللغة التركية",
    "Turkish-language comedy-drama films": "أفلام كوميدية درامية باللغة التركية",
    "Turkish-language crime films": "أفلام جريمة باللغة التركية",
    "Turkish-language documentary films": "أفلام وثائقية باللغة التركية",
    "Turkish-language historical comedy films": "أفلام تاريخية كوميدية باللغة التركية",
    "Turkish-language historical films": "أفلام تاريخية باللغة التركية",
    "Turkish-language horror films": "أفلام رعب باللغة التركية",
    "Turkish-language romance films": "أفلام رومانسية باللغة التركية",
    "Turkish-language thriller films": "أفلام إثارة باللغة التركية",
    "Turkish-language war films": "أفلام حربية باللغة التركية",
    "Urdu-language historical films": "أفلام تاريخية باللغة الأردية",
    "Urdu-language musical films": "أفلام موسيقية باللغة الأردية",
    "Urdu-language romance films": "أفلام رومانسية باللغة الأردية",
}


to_test = [
    ("test_language_films", test_data),
]


@pytest.mark.parametrize("category, expected", test_data_0.items(), ids=test_data_0.keys())
@pytest.mark.fast
def test_language_films_0(category: str, expected: str) -> None:
    label2 = resolve_languages_labels(category)
    assert label2 == expected


@pytest.mark.parametrize("category, expected", test_data.items(), ids=test_data.keys())
@pytest.mark.fast
def test_language_films(category: str, expected: str) -> None:
    label2 = resolve_languages_labels(category)
    assert label2 == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_languages_labels)
    dump_diff(diff_result, name)

    # dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
