import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar
from ArWikiCats.new_resolvers.countries_names_resolvers.medalists_resolvers import resolve_countries_names_medalists

test_data = {
    "african games bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الإفريقية من اليمن",
    "african games competitors for yemen": "منافسون في الألعاب الإفريقية من اليمن",
    "african games gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الإفريقية من اليمن",
    "african games medalists for yemen": "فائزون بميداليات الألعاب الإفريقية من اليمن",
    "african games medallists for yemen": "فائزون بميداليات الألعاب الإفريقية من اليمن",
    "african games silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الإفريقية من اليمن",
    "asian beach games bronze medalists for yemen": "فائزون بميداليات برونزية في دورة الألعاب الآسيوية الشاطئية من اليمن",
    "asian beach games competitors for yemen": "منافسون في دورة الألعاب الآسيوية الشاطئية من اليمن",
    "asian beach games gold medalists for yemen": "فائزون بميداليات ذهبية في دورة الألعاب الآسيوية الشاطئية من اليمن",
    "asian beach games medalists for yemen": "فائزون بميداليات دورة الألعاب الآسيوية الشاطئية من اليمن",
    "asian beach games medallists for yemen": "فائزون بميداليات دورة الألعاب الآسيوية الشاطئية من اليمن",
    "asian beach games silver medalists for yemen": "فائزون بميداليات فضية في دورة الألعاب الآسيوية الشاطئية من اليمن",
    "asian games bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الآسيوية من اليمن",
    "asian games competitors for yemen": "منافسون في الألعاب الآسيوية من اليمن",
    "asian games gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الآسيوية من اليمن",
    "asian games medalists for yemen": "فائزون بميداليات الألعاب الآسيوية من اليمن",
    "asian games medallists for yemen": "فائزون بميداليات الألعاب الآسيوية من اليمن",
    "asian games silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الآسيوية من اليمن",
    "asian indoor games bronze medalists for yemen": "فائزون بميداليات برونزية في دورة الألعاب الآسيوية داخل الصالات من اليمن",
    "asian indoor games competitors for yemen": "منافسون في دورة الألعاب الآسيوية داخل الصالات من اليمن",
    "asian indoor games gold medalists for yemen": "فائزون بميداليات ذهبية في دورة الألعاب الآسيوية داخل الصالات من اليمن",
    "asian indoor games medalists for yemen": "فائزون بميداليات دورة الألعاب الآسيوية داخل الصالات من اليمن",
    "asian indoor games medallists for yemen": "فائزون بميداليات دورة الألعاب الآسيوية داخل الصالات من اليمن",
    "asian indoor games silver medalists for yemen": "فائزون بميداليات فضية في دورة الألعاب الآسيوية داخل الصالات من اليمن",
    "asian para games bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب البارالمبية الآسيوية من اليمن",
    "asian para games competitors for yemen": "منافسون في الألعاب البارالمبية الآسيوية من اليمن",
    "asian para games gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب البارالمبية الآسيوية من اليمن",
    "asian para games medalists for yemen": "فائزون بميداليات الألعاب البارالمبية الآسيوية من اليمن",
    "asian para games medallists for yemen": "فائزون بميداليات الألعاب البارالمبية الآسيوية من اليمن",
    "asian para games silver medalists for yemen": "فائزون بميداليات فضية في الألعاب البارالمبية الآسيوية من اليمن",
    "asian summer games bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الآسيوية الصيفية من اليمن",
    "asian summer games competitors for yemen": "منافسون في الألعاب الآسيوية الصيفية من اليمن",
    "asian summer games gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الآسيوية الصيفية من اليمن",
    "asian summer games medalists for yemen": "فائزون بميداليات الألعاب الآسيوية الصيفية من اليمن",
    "asian summer games medallists for yemen": "فائزون بميداليات الألعاب الآسيوية الصيفية من اليمن",
    "asian summer games silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الآسيوية الصيفية من اليمن",
    "asian winter games bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الآسيوية الشتوية من اليمن",
    "asian winter games competitors for yemen": "منافسون في الألعاب الآسيوية الشتوية من اليمن",
    "asian winter games gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الآسيوية الشتوية من اليمن",
    "asian winter games medalists for yemen": "فائزون بميداليات الألعاب الآسيوية الشتوية من اليمن",
    "asian winter games medallists for yemen": "فائزون بميداليات الألعاب الآسيوية الشتوية من اليمن",
    "asian winter games silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الآسيوية الشتوية من اليمن",
    "bolivarian games bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب البوليفارية من اليمن",
    "bolivarian games competitors for yemen": "منافسون في الألعاب البوليفارية من اليمن",
    "bolivarian games gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب البوليفارية من اليمن",
    "bolivarian games medalists for yemen": "فائزون بميداليات الألعاب البوليفارية من اليمن",
    "bolivarian games medallists for yemen": "فائزون بميداليات الألعاب البوليفارية من اليمن",
    "bolivarian games silver medalists for yemen": "فائزون بميداليات فضية في الألعاب البوليفارية من اليمن",
    "central american and caribbean games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب أمريكا الوسطى والكاريبي من اليمن",
    "central american and caribbean games competitors for yemen": "منافسون في ألعاب أمريكا الوسطى والكاريبي من اليمن",
    "central american and caribbean games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب أمريكا الوسطى والكاريبي من اليمن",
    "central american and caribbean games medalists for yemen": "فائزون بميداليات ألعاب أمريكا الوسطى والكاريبي من اليمن",
    "central american and caribbean games medallists for yemen": "فائزون بميداليات ألعاب أمريكا الوسطى والكاريبي من اليمن",
    "central american and caribbean games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب أمريكا الوسطى والكاريبي من اليمن",
    "central american games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب أمريكا الوسطى من اليمن",
    "central american games competitors for yemen": "منافسون في ألعاب أمريكا الوسطى من اليمن",
    "central american games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب أمريكا الوسطى من اليمن",
    "central american games medalists for yemen": "فائزون بميداليات ألعاب أمريكا الوسطى من اليمن",
    "central american games medallists for yemen": "فائزون بميداليات ألعاب أمريكا الوسطى من اليمن",
    "central american games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب أمريكا الوسطى من اليمن",
    "commonwealth games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب الكومنولث من اليمن",
    "commonwealth games competitors for yemen": "منافسون في ألعاب الكومنولث من اليمن",
    "commonwealth games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب الكومنولث من اليمن",
    "commonwealth games medalists for yemen": "فائزون بميداليات ألعاب الكومنولث من اليمن",
    "commonwealth games medallists for yemen": "فائزون بميداليات ألعاب الكومنولث من اليمن",
    "commonwealth games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب الكومنولث من اليمن",
    "commonwealth youth games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب الكومنولث الشبابية من اليمن",
    "commonwealth youth games competitors for yemen": "منافسون في ألعاب الكومنولث الشبابية من اليمن",
    "commonwealth youth games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب الكومنولث الشبابية من اليمن",
    "commonwealth youth games medalists for yemen": "فائزون بميداليات ألعاب الكومنولث الشبابية من اليمن",
    "commonwealth youth games medallists for yemen": "فائزون بميداليات ألعاب الكومنولث الشبابية من اليمن",
    "commonwealth youth games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب الكومنولث الشبابية من اليمن",
    "deaflympic games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب ديفلمبياد من اليمن",
    "deaflympic games competitors for yemen": "منافسون في ألعاب ديفلمبياد من اليمن",
    "deaflympic games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب ديفلمبياد من اليمن",
    "deaflympic games medalists for yemen": "فائزون بميداليات ألعاب ديفلمبياد من اليمن",
    "deaflympic games medallists for yemen": "فائزون بميداليات ألعاب ديفلمبياد من اليمن",
    "deaflympic games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب ديفلمبياد من اليمن",
    "european games bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الأوروبية من اليمن",
    "european games competitors for yemen": "منافسون في الألعاب الأوروبية من اليمن",
    "european games gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الأوروبية من اليمن",
    "european games medalists for yemen": "فائزون بميداليات الألعاب الأوروبية من اليمن",
    "european games medallists for yemen": "فائزون بميداليات الألعاب الأوروبية من اليمن",
    "european games silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الأوروبية من اليمن",
    "european youth olympic bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الأولمبية الشبابية الأوروبية من اليمن",
    "european youth olympic competitors for yemen": "منافسون في الألعاب الأولمبية الشبابية الأوروبية من اليمن",
    "european youth olympic gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية الأوروبية من اليمن",
    "european youth olympic medalists for yemen": "فائزون بميداليات الألعاب الأولمبية الشبابية الأوروبية من اليمن",
    "european youth olympic medallists for yemen": "فائزون بميداليات الألعاب الأولمبية الشبابية الأوروبية من اليمن",
    "european youth olympic silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الأولمبية الشبابية الأوروبية من اليمن",
    "european youth olympic winter bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الأولمبية الشبابية الأوروبية الشتوية من اليمن",
    "european youth olympic winter competitors for yemen": "منافسون في الألعاب الأولمبية الشبابية الأوروبية الشتوية من اليمن",
    "european youth olympic winter gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية الأوروبية الشتوية من اليمن",
    "european youth olympic winter medalists for yemen": "فائزون بميداليات الألعاب الأولمبية الشبابية الأوروبية الشتوية من اليمن",
    "european youth olympic winter medallists for yemen": "فائزون بميداليات الألعاب الأولمبية الشبابية الأوروبية الشتوية من اليمن",
    "european youth olympic winter silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الأولمبية الشبابية الأوروبية الشتوية من اليمن",
    "fis nordic world ski championships bronze medalists for yemen": "فائزون بميداليات برونزية في بطولة العالم للتزلج النوردي على الثلج من اليمن",
    "fis nordic world ski championships competitors for yemen": "منافسون في بطولة العالم للتزلج النوردي على الثلج من اليمن",
    "fis nordic world ski championships gold medalists for yemen": "فائزون بميداليات ذهبية في بطولة العالم للتزلج النوردي على الثلج من اليمن",
    "fis nordic world ski championships medalists for yemen": "فائزون بميداليات بطولة العالم للتزلج النوردي على الثلج من اليمن",
    "fis nordic world ski championships medallists for yemen": "فائزون بميداليات بطولة العالم للتزلج النوردي على الثلج من اليمن",
    "fis nordic world ski championships silver medalists for yemen": "فائزون بميداليات فضية في بطولة العالم للتزلج النوردي على الثلج من اليمن",
    "friendship games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب الصداقة من اليمن",
    "friendship games competitors for yemen": "منافسون في ألعاب الصداقة من اليمن",
    "friendship games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب الصداقة من اليمن",
    "friendship games medalists for yemen": "فائزون بميداليات ألعاب الصداقة من اليمن",
    "friendship games medallists for yemen": "فائزون بميداليات ألعاب الصداقة من اليمن",
    "friendship games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب الصداقة من اليمن",
    "goodwill games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب النوايا الحسنة من اليمن",
    "goodwill games competitors for yemen": "منافسون في ألعاب النوايا الحسنة من اليمن",
    "goodwill games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب النوايا الحسنة من اليمن",
    "goodwill games medalists for yemen": "فائزون بميداليات ألعاب النوايا الحسنة من اليمن",
    "goodwill games medallists for yemen": "فائزون بميداليات ألعاب النوايا الحسنة من اليمن",
    "goodwill games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب النوايا الحسنة من اليمن",
    "islamic solidarity games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب التضامن الإسلامي من اليمن",
    "islamic solidarity games competitors for yemen": "منافسون في ألعاب التضامن الإسلامي من اليمن",
    "islamic solidarity games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب التضامن الإسلامي من اليمن",
    "islamic solidarity games medalists for yemen": "فائزون بميداليات ألعاب التضامن الإسلامي من اليمن",
    "islamic solidarity games medallists for yemen": "فائزون بميداليات ألعاب التضامن الإسلامي من اليمن",
    "islamic solidarity games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب التضامن الإسلامي من اليمن",
    "maccabiah games bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب المكابيه من اليمن",
    "maccabiah games competitors for yemen": "منافسون في الألعاب المكابيه من اليمن",
    "maccabiah games gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب المكابيه من اليمن",
    "maccabiah games medalists for yemen": "فائزون بميداليات الألعاب المكابيه من اليمن",
    "maccabiah games medallists for yemen": "فائزون بميداليات الألعاب المكابيه من اليمن",
    "maccabiah games silver medalists for yemen": "فائزون بميداليات فضية في الألعاب المكابيه من اليمن",
    "mediterranean games bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب المتوسطية من اليمن",
    "mediterranean games competitors for yemen": "منافسون في الألعاب المتوسطية من اليمن",
    "mediterranean games gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب المتوسطية من اليمن",
    "mediterranean games medalists for yemen": "فائزون بميداليات الألعاب المتوسطية من اليمن",
    "mediterranean games medallists for yemen": "فائزون بميداليات الألعاب المتوسطية من اليمن",
    "mediterranean games silver medalists for yemen": "فائزون بميداليات فضية في الألعاب المتوسطية من اليمن",
    "micronesian games bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الميكرونيزية من اليمن",
    "micronesian games competitors for yemen": "منافسون في الألعاب الميكرونيزية من اليمن",
    "micronesian games gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الميكرونيزية من اليمن",
    "micronesian games medalists for yemen": "فائزون بميداليات الألعاب الميكرونيزية من اليمن",
    "micronesian games medallists for yemen": "فائزون بميداليات الألعاب الميكرونيزية من اليمن",
    "micronesian games silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الميكرونيزية من اليمن",
    "military world games bronze medalists for yemen": "فائزون بميداليات برونزية في دورة الألعاب العسكرية من اليمن",
    "military world games competitors for yemen": "منافسون في دورة الألعاب العسكرية من اليمن",
    "military world games gold medalists for yemen": "فائزون بميداليات ذهبية في دورة الألعاب العسكرية من اليمن",
    "military world games medalists for yemen": "فائزون بميداليات دورة الألعاب العسكرية من اليمن",
    "military world games medallists for yemen": "فائزون بميداليات دورة الألعاب العسكرية من اليمن",
    "military world games silver medalists for yemen": "فائزون بميداليات فضية في دورة الألعاب العسكرية من اليمن",
    "olympic bronze medalists for yemen": "فائزون بميداليات برونزية أولمبية من اليمن",
    "olympic competitors for yemen": "منافسون أولمبيون من اليمن",
    "olympic gold medalists for yemen": "فائزون بميداليات ذهبية أولمبية من اليمن",
    "olympic medalists for yemen": "فائزون بميداليات أولمبية من اليمن",
    "olympic silver medalists for yemen": "فائزون بميداليات فضية أولمبية من اليمن",
    "olympics competitors for yemen": "منافسون أولمبيون من اليمن",
    "olympics medalists for yemen": "فائزون بميداليات أولمبية من اليمن",
    "olympics medallists for yemen": "فائزون بميداليات أولمبية من اليمن",
    "pan american games bronze medalists for yemen": "فائزون بميداليات برونزية في دورة الألعاب الأمريكية من اليمن",
    "pan american games competitors for yemen": "منافسون في دورة الألعاب الأمريكية من اليمن",
    "pan american games gold medalists for yemen": "فائزون بميداليات ذهبية في دورة الألعاب الأمريكية من اليمن",
    "pan american games medalists for yemen": "فائزون بميداليات دورة الألعاب الأمريكية من اليمن",
    "pan american games medallists for yemen": "فائزون بميداليات دورة الألعاب الأمريكية من اليمن",
    "pan american games silver medalists for yemen": "فائزون بميداليات فضية في دورة الألعاب الأمريكية من اليمن",
    "pan arab games bronze medalists for yemen": "فائزون بميداليات برونزية في دورة الألعاب العربية من اليمن",
    "pan arab games competitors for yemen": "منافسون في دورة الألعاب العربية من اليمن",
    "pan arab games gold medalists for yemen": "فائزون بميداليات ذهبية في دورة الألعاب العربية من اليمن",
    "pan arab games medalists for yemen": "فائزون بميداليات دورة الألعاب العربية من اليمن",
    "pan arab games medallists for yemen": "فائزون بميداليات دورة الألعاب العربية من اليمن",
    "pan arab games silver medalists for yemen": "فائزون بميداليات فضية في دورة الألعاب العربية من اليمن",
    "pan asian games bronze medalists for yemen": "فائزون بميداليات برونزية في دورة الألعاب الآسيوية من اليمن",
    "pan asian games competitors for yemen": "منافسون في دورة الألعاب الآسيوية من اليمن",
    "pan asian games gold medalists for yemen": "فائزون بميداليات ذهبية في دورة الألعاب الآسيوية من اليمن",
    "pan asian games medalists for yemen": "فائزون بميداليات دورة الألعاب الآسيوية من اليمن",
    "pan asian games medallists for yemen": "فائزون بميداليات دورة الألعاب الآسيوية من اليمن",
    "pan asian games silver medalists for yemen": "فائزون بميداليات فضية في دورة الألعاب الآسيوية من اليمن",
    "paralympic bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب البارالمبية من اليمن",
    "paralympic gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب البارالمبية من اليمن",
    "paralympic medalists for yemen": "فائزون بميداليات الألعاب البارالمبية من اليمن",
    "paralympic medallists for yemen": "فائزون بميداليات الألعاب البارالمبية من اليمن",
    "paralympic silver medalists for yemen": "فائزون بميداليات فضية في الألعاب البارالمبية من اليمن",
    "paralympics bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب البارالمبية من اليمن",
    "paralympics competitors for yemen": "منافسون في الألعاب البارالمبية من اليمن",
    "paralympics gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب البارالمبية من اليمن",
    "paralympics medalists for yemen": "فائزون بميداليات الألعاب البارالمبية من اليمن",
    "paralympics medallists for yemen": "فائزون بميداليات الألعاب البارالمبية من اليمن",
    "paralympics silver medalists for yemen": "فائزون بميداليات فضية في الألعاب البارالمبية من اليمن",
    "parapan american games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب بارابان الأمريكية من اليمن",
    "parapan american games competitors for yemen": "منافسون في ألعاب بارابان الأمريكية من اليمن",
    "parapan american games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب بارابان الأمريكية من اليمن",
    "parapan american games medalists for yemen": "فائزون بميداليات ألعاب بارابان الأمريكية من اليمن",
    "parapan american games medallists for yemen": "فائزون بميداليات ألعاب بارابان الأمريكية من اليمن",
    "parapan american games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب بارابان الأمريكية من اليمن",
    "sea games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب البحر من اليمن",
    "sea games competitors for yemen": "منافسون في ألعاب البحر من اليمن",
    "sea games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب البحر من اليمن",
    "sea games medalists for yemen": "فائزون بميداليات ألعاب البحر من اليمن",
    "sea games medallists for yemen": "فائزون بميداليات ألعاب البحر من اليمن",
    "sea games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب البحر من اليمن",
    "south american games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب أمريكا الجنوبية من اليمن",
    "south american games competitors for yemen": "منافسون في ألعاب أمريكا الجنوبية من اليمن",
    "south american games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب أمريكا الجنوبية من اليمن",
    "south american games medalists for yemen": "فائزون بميداليات ألعاب أمريكا الجنوبية من اليمن",
    "south american games medallists for yemen": "فائزون بميداليات ألعاب أمريكا الجنوبية من اليمن",
    "south american games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب أمريكا الجنوبية من اليمن",
    "south asian beach games bronze medalists for yemen": "فائزون بميداليات برونزية في دورة ألعاب جنوب أسيا الشاطئية من اليمن",
    "south asian beach games competitors for yemen": "منافسون في دورة ألعاب جنوب أسيا الشاطئية من اليمن",
    "south asian beach games gold medalists for yemen": "فائزون بميداليات ذهبية في دورة ألعاب جنوب أسيا الشاطئية من اليمن",
    "south asian beach games medalists for yemen": "فائزون بميداليات دورة ألعاب جنوب أسيا الشاطئية من اليمن",
    "south asian beach games medallists for yemen": "فائزون بميداليات دورة ألعاب جنوب أسيا الشاطئية من اليمن",
    "south asian beach games silver medalists for yemen": "فائزون بميداليات فضية في دورة ألعاب جنوب أسيا الشاطئية من اليمن",
    "south asian games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب جنوب أسيا من اليمن",
    "south asian games competitors for yemen": "منافسون في ألعاب جنوب أسيا من اليمن",
    "south asian games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب جنوب أسيا من اليمن",
    "south asian games medalists for yemen": "فائزون بميداليات ألعاب جنوب أسيا من اليمن",
    "south asian games medallists for yemen": "فائزون بميداليات ألعاب جنوب أسيا من اليمن",
    "south asian games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب جنوب أسيا من اليمن",
    "south asian winter games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب جنوب آسيا الشتوية من اليمن",
    "south asian winter games competitors for yemen": "منافسون في ألعاب جنوب آسيا الشتوية من اليمن",
    "south asian winter games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب جنوب آسيا الشتوية من اليمن",
    "south asian winter games medalists for yemen": "فائزون بميداليات ألعاب جنوب آسيا الشتوية من اليمن",
    "south asian winter games medallists for yemen": "فائزون بميداليات ألعاب جنوب آسيا الشتوية من اليمن",
    "south asian winter games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب جنوب آسيا الشتوية من اليمن",
    "southeast asian games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب جنوب شرق آسيا من اليمن",
    "southeast asian games competitors for yemen": "منافسون في ألعاب جنوب شرق آسيا من اليمن",
    "southeast asian games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب جنوب شرق آسيا من اليمن",
    "southeast asian games medalists for yemen": "فائزون بميداليات ألعاب جنوب شرق آسيا من اليمن",
    "southeast asian games medallists for yemen": "فائزون بميداليات ألعاب جنوب شرق آسيا من اليمن",
    "southeast asian games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب جنوب شرق آسيا من اليمن",
    "summer olympics bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الأولمبية الصيفية من اليمن",
    "summer olympics gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الأولمبية الصيفية من اليمن",
    "summer olympics medalists for yemen": "فائزون بميداليات الألعاب الأولمبية الصيفية من اليمن",
    "summer olympics medallists for yemen": "فائزون بميداليات الألعاب الأولمبية الصيفية من اليمن",
    "summer olympics silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الأولمبية الصيفية من اليمن",
    "summer universiade bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الجامعية الصيفية من اليمن",
    "summer universiade competitors for yemen": "منافسون في الألعاب الجامعية الصيفية من اليمن",
    "summer universiade gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الجامعية الصيفية من اليمن",
    "summer universiade medalists for yemen": "فائزون بميداليات الألعاب الجامعية الصيفية من اليمن",
    "summer universiade medallists for yemen": "فائزون بميداليات الألعاب الجامعية الصيفية من اليمن",
    "summer universiade silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الجامعية الصيفية من اليمن",
    "summer world university games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب الجامعات العالمية الصيفية من اليمن",
    "summer world university games competitors for yemen": "منافسون في ألعاب الجامعات العالمية الصيفية من اليمن",
    "summer world university games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب الجامعات العالمية الصيفية من اليمن",
    "summer world university games medalists for yemen": "فائزون بميداليات ألعاب الجامعات العالمية الصيفية من اليمن",
    "summer world university games medallists for yemen": "فائزون بميداليات ألعاب الجامعات العالمية الصيفية من اليمن",
    "summer world university games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب الجامعات العالمية الصيفية من اليمن",
    "the universiade bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الجامعية من اليمن",
    "the universiade competitors for yemen": "منافسون في الألعاب الجامعية من اليمن",
    "the universiade gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الجامعية من اليمن",
    "the universiade medalists for yemen": "فائزون بميداليات الألعاب الجامعية من اليمن",
    "the universiade medallists for yemen": "فائزون بميداليات الألعاب الجامعية من اليمن",
    "the universiade silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الجامعية من اليمن",
    "universiade bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الجامعية من اليمن",
    "universiade competitors for yemen": "منافسون في الألعاب الجامعية من اليمن",
    "universiade gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الجامعية من اليمن",
    "universiade medalists for yemen": "فائزون بميداليات الألعاب الجامعية من اليمن",
    "universiade medallists for yemen": "فائزون بميداليات الألعاب الجامعية من اليمن",
    "universiade silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الجامعية من اليمن",
    "winter olympics bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الأولمبية الشتوية من اليمن",
    "winter olympics gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشتوية من اليمن",
    "winter olympics medalists for yemen": "فائزون بميداليات الألعاب الأولمبية الشتوية من اليمن",
    "winter olympics medallists for yemen": "فائزون بميداليات الألعاب الأولمبية الشتوية من اليمن",
    "winter olympics silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الأولمبية الشتوية من اليمن",
    "winter universiade bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الجامعية الشتوية من اليمن",
    "winter universiade competitors for yemen": "منافسون في الألعاب الجامعية الشتوية من اليمن",
    "winter universiade gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الجامعية الشتوية من اليمن",
    "winter universiade medalists for yemen": "فائزون بميداليات الألعاب الجامعية الشتوية من اليمن",
    "winter universiade medallists for yemen": "فائزون بميداليات الألعاب الجامعية الشتوية من اليمن",
    "winter universiade silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الجامعية الشتوية من اليمن",
    "winter world university games bronze medalists for yemen": "فائزون بميداليات برونزية في ألعاب الجامعات العالمية الشتوية من اليمن",
    "winter world university games competitors for yemen": "منافسون في ألعاب الجامعات العالمية الشتوية من اليمن",
    "winter world university games gold medalists for yemen": "فائزون بميداليات ذهبية في ألعاب الجامعات العالمية الشتوية من اليمن",
    "winter world university games medalists for yemen": "فائزون بميداليات ألعاب الجامعات العالمية الشتوية من اليمن",
    "winter world university games medallists for yemen": "فائزون بميداليات ألعاب الجامعات العالمية الشتوية من اليمن",
    "winter world university games silver medalists for yemen": "فائزون بميداليات فضية في ألعاب الجامعات العالمية الشتوية من اليمن",
    "world athletics indoor championships bronze medalists for yemen": "فائزون بميداليات برونزية في بطولة العالم لألعاب القوى داخل الصالات من اليمن",
    "world athletics indoor championships competitors for yemen": "منافسون في بطولة العالم لألعاب القوى داخل الصالات من اليمن",
    "world athletics indoor championships gold medalists for yemen": "فائزون بميداليات ذهبية في بطولة العالم لألعاب القوى داخل الصالات من اليمن",
    "world athletics indoor championships medalists for yemen": "فائزون بميداليات بطولة العالم لألعاب القوى داخل الصالات من اليمن",
    "world athletics indoor championships medallists for yemen": "فائزون بميداليات بطولة العالم لألعاب القوى داخل الصالات من اليمن",
    "world athletics indoor championships silver medalists for yemen": "فائزون بميداليات فضية في بطولة العالم لألعاب القوى داخل الصالات من اليمن",
    "world championships bronze medalists for yemen": "فائزون بميداليات برونزية في بطولات العالم من اليمن",
    "world championships competitors for yemen": "منافسون في بطولات العالم من اليمن",
    "world championships gold medalists for yemen": "فائزون بميداليات ذهبية في بطولات العالم من اليمن",
    "world championships medalists for yemen": "فائزون بميداليات بطولات العالم من اليمن",
    "world championships medallists for yemen": "فائزون بميداليات بطولات العالم من اليمن",
    "world championships silver medalists for yemen": "فائزون بميداليات فضية في بطولات العالم من اليمن",
    "youth olympic bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الأولمبية الشبابية من اليمن",
    "youth olympic competitors for yemen": "منافسون في الألعاب الأولمبية الشبابية من اليمن",
    "youth olympic gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية من اليمن",
    "youth olympic medalists for yemen": "فائزون بميداليات الألعاب الأولمبية الشبابية من اليمن",
    "youth olympic medallists for yemen": "فائزون بميداليات الألعاب الأولمبية الشبابية من اليمن",
    "youth olympic silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الأولمبية الشبابية من اليمن",
    "youth olympics bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الأولمبية الشبابية من اليمن",
    "youth olympics competitors for yemen": "منافسون في الألعاب الأولمبية الشبابية من اليمن",
    "youth olympics games bronze medalists for yemen": "فائزون بميداليات برونزية في الألعاب الأولمبية الشبابية من اليمن",
    "youth olympics games competitors for yemen": "منافسون في الألعاب الأولمبية الشبابية من اليمن",
    "youth olympics games gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية من اليمن",
    "youth olympics games medalists for yemen": "فائزون بميداليات الألعاب الأولمبية الشبابية من اليمن",
    "youth olympics games medallists for yemen": "فائزون بميداليات الألعاب الأولمبية الشبابية من اليمن",
    "youth olympics games silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الأولمبية الشبابية من اليمن",
    "youth olympics gold medalists for yemen": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية من اليمن",
    "youth olympics medalists for yemen": "فائزون بميداليات الألعاب الأولمبية الشبابية من اليمن",
    "youth olympics medallists for yemen": "فائزون بميداليات الألعاب الأولمبية الشبابية من اليمن",
    "paralympic competitors for yemen": "منافسون بارالمبيون من اليمن",
    "summer olympics competitors for yemen": "منافسون أولمبيون صيفيون من اليمن",
    "winter olympics competitors for yemen": "منافسون أولمبيون شتويون من اليمن",
    "youth olympics silver medalists for yemen": "فائزون بميداليات فضية في الألعاب الأولمبية الشبابية من اليمن",
}


@pytest.mark.parametrize("category, expected", test_data.items(), ids=test_data.keys())
@pytest.mark.fast
def test_olympic_event_translations_type_tables(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_olympic_event_translations_type_tables", test_data, resolve_label_ar),
]


@pytest.mark.parametrize("name,data, callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
