#!/usr/bin/python3
"""Integration tests for v3i translations resolvers validating country, year, and combined formatters."""

import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar
from ArWikiCats.new_resolvers.translations_resolvers_v3i.resolve_v3i import resolve_year_job_from_countries

test_data_standard = {
    "10th-century clergy from the Holy Roman Empire": "رجال دين من الإمبراطورية الرومانية المقدسة في القرن 10",
    "10th-century historians from the Fatimid Caliphate": "مؤرخون من الدولة الفاطمية في القرن 10",
    "10th-century Jews from al-Andalus": "يهود من الأندلس في القرن 10",
    "10th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 10",
    "10th-century people from Georgia (country)": "أشخاص من جورجيا في القرن 10",
    "10th-century people from the Abbasid Caliphate": "أشخاص من الدولة العباسية في القرن 10",
    "10th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 10",
    "10th-century people from West Francia": "أشخاص من مملكة الفرنجة الغربيين في القرن 10",
    "10th-century women from the Abbasid Caliphate": "نساء من الدولة العباسية في القرن 10",
    "10th-century women from the Holy Roman Empire": "نساء من الإمبراطورية الرومانية المقدسة في القرن 10",
    "10th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 10",
    "11th-century clergy from the Holy Roman Empire": "رجال دين من الإمبراطورية الرومانية المقدسة في القرن 11",
    "11th-century historians from the Abbasid Caliphate": "مؤرخون من الدولة العباسية في القرن 11",
    "11th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 11",
    "11th-century Jews from al-Andalus": "يهود من الأندلس في القرن 11",
    "11th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 11",
    "11th-century people from Bohemia": "أشخاص من بوهيميا في القرن 11",
    "11th-century people from Georgia (country)": "أشخاص من جورجيا في القرن 11",
    "11th-century people from Kievan Rus'": "أشخاص من كييف روس في القرن 11",
    "11th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 11",
    "11th-century women from Georgia (country)": "نساء من جورجيا في القرن 11",
    "11th-century women from Kievan Rus'": "نساء من كييف روس في القرن 11",
    "11th-century women from the Abbasid Caliphate": "نساء من الدولة العباسية في القرن 11",
    "11th-century women from the Holy Roman Empire": "نساء من الإمبراطورية الرومانية المقدسة في القرن 11",
    "11th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 11",
    "12th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 12",
    "12th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 12",
    "12th-century Jews from al-Andalus": "يهود من الأندلس في القرن 12",
    "12th-century Jews from the Abbasid Caliphate": "يهود من الدولة العباسية في القرن 12",
    "12th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 12",
    "12th-century people from Bohemia": "أشخاص من بوهيميا في القرن 12",
    "12th-century people from Georgia (country)": "أشخاص من جورجيا في القرن 12",
    "12th-century people from Kievan Rus'": "أشخاص من كييف روس في القرن 12",
    "12th-century people from the Crown of Aragon": "أشخاص من تاج أرغون في القرن 12",
    "12th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 12",
    "12th-century poets from Georgia (country)": "شعراء من جورجيا في القرن 12",
    "12th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 12",
    "12th-century women from Georgia (country)": "نساء من جورجيا في القرن 12",
    "12th-century women from Kievan Rus'": "نساء من كييف روس في القرن 12",
    "12th-century women from the Abbasid Caliphate": "نساء من الدولة العباسية في القرن 12",
    "12th-century women from the Holy Roman Empire": "نساء من الإمبراطورية الرومانية المقدسة في القرن 12",
    "12th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 12",
    "13th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 13",
    "13th-century people from Georgia (country)": "أشخاص من جورجيا في القرن 13",
    "13th-century people from the Crown of Aragon": "أشخاص من تاج أرغون في القرن 13",
    "13th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 13",
    "13th-century poets from Georgia (country)": "شعراء من جورجيا في القرن 13",
    "13th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 13",
    "13th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 13",
    "13th-century women from Bohemia": "نساء من بوهيميا في القرن 13",
    "13th-century women from Georgia (country)": "نساء من جورجيا في القرن 13",
    "13th-century women from the Abbasid Caliphate": "نساء من الدولة العباسية في القرن 13",
    "13th-century women from the Holy Roman Empire": "نساء من الإمبراطورية الرومانية المقدسة في القرن 13",
    "13th-century women from the Ottoman Empire": "نساء من الدولة العثمانية في القرن 13",
    "13th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 13",
    "14th-century artists from the Holy Roman Empire": "فنانون من الإمبراطورية الرومانية المقدسة في القرن 14",
    "14th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 14",
    "14th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 14",
    "14th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 14",
    "14th-century painters from the Holy Roman Empire": "رسامون من الإمبراطورية الرومانية المقدسة في القرن 14",
    "14th-century people from the Crown of Aragon": "أشخاص من تاج أرغون في القرن 14",
    "14th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 14",
    "14th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 14",
    "14th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 14",
    "14th-century women from Bohemia": "نساء من بوهيميا في القرن 14",
    "14th-century women from Georgia (country)": "نساء من جورجيا في القرن 14",
    "14th-century women from the Holy Roman Empire": "نساء من الإمبراطورية الرومانية المقدسة في القرن 14",
    "14th-century women from the Ottoman Empire": "نساء من الدولة العثمانية في القرن 14",
    "14th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 14",
    "15th-century artists from the Holy Roman Empire": "فنانون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century businesspeople from the Holy Roman Empire": "شخصيات أعمال من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century civil servants from the Ottoman Empire": "موظفو خدمة مدنية من الدولة العثمانية في القرن 15",
    "15th-century clergy from the Holy Roman Empire": "رجال دين من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 15",
    "15th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century historians from the Ottoman Empire": "مؤرخون من الدولة العثمانية في القرن 15",
    "15th-century Jews from the Ottoman Empire": "يهود من الدولة العثمانية في القرن 15",
    "15th-century jurists from the Holy Roman Empire": "حقوقيون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century mathematicians from the Holy Roman Empire": "رياضياتيون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century nobility from Bohemia": "نبلاء من بوهيميا في القرن 15",
    "15th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century painters from the Holy Roman Empire": "رسامون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century people from Georgia (country)": "أشخاص من جورجيا في القرن 15",
    "15th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century physicians from the Holy Roman Empire": "أطباء من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century scholars from the Holy Roman Empire": "دارسون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century scientists from the Ottoman Empire": "علماء من الدولة العثمانية في القرن 15",
    "15th-century sculptors from the Holy Roman Empire": "نحاتون من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century women from Bohemia": "نساء من بوهيميا في القرن 15",
    "15th-century women from the Holy Roman Empire": "نساء من الإمبراطورية الرومانية المقدسة في القرن 15",
    "15th-century women from the Ottoman Empire": "نساء من الدولة العثمانية في القرن 15",
    "15th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 15",
    "16th-century architects from the Holy Roman Empire": "معماريون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century artists from the Holy Roman Empire": "فنانون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century businesspeople from the Holy Roman Empire": "شخصيات أعمال من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century civil servants from the Ottoman Empire": "موظفو خدمة مدنية من الدولة العثمانية في القرن 16",
    "16th-century clergy from Bohemia": "رجال دين من بوهيميا في القرن 16",
    "16th-century criminals from the Holy Roman Empire": "مجرمون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 16",
    "16th-century educators from the Holy Roman Empire": "معلمون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century engineers from the Holy Roman Empire": "مهندسون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century engravers from the Holy Roman Empire": "نقاشون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century explorers from the Holy Roman Empire": "مستكشفون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century historians from the Ottoman Empire": "مؤرخون من الدولة العثمانية في القرن 16",
    "16th-century Jews from the Ottoman Empire": "يهود من الدولة العثمانية في القرن 16",
    "16th-century jurists from the Holy Roman Empire": "حقوقيون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century lawyers from the Holy Roman Empire": "محامون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century mathematicians from the Holy Roman Empire": "رياضياتيون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century musicians from the Holy Roman Empire": "موسيقيون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century nobility from Bohemia": "نبلاء من بوهيميا في القرن 16",
    "16th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century painters from the Holy Roman Empire": "رسامون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century people from New Spain": "أشخاص من إسبانيا الجديدة في القرن 16",
    "16th-century people from Safavid Iran": "أشخاص من إيران الصفوية في القرن 16",
    "16th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century philosophers from the Holy Roman Empire": "فلاسفة من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century physicians from the Holy Roman Empire": "أطباء من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century politicians from the Holy Roman Empire": "سياسيون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century rabbis from Bohemia": "حاخامات من بوهيميا في القرن 16",
    "16th-century scholars from the Holy Roman Empire": "دارسون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century sculptors from the Holy Roman Empire": "نحاتون من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century women from Bohemia": "نساء من بوهيميا في القرن 16",
    "16th-century women from Georgia (country)": "نساء من جورجيا في القرن 16",
    "16th-century women from the Holy Roman Empire": "نساء من الإمبراطورية الرومانية المقدسة في القرن 16",
    "16th-century women from the Ottoman Empire": "نساء من الدولة العثمانية في القرن 16",
    "16th-century writers from Safavid Iran": "كتاب من إيران الصفوية في القرن 16",
    "16th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 16",
    "17th-century artisans from the Holy Roman Empire": "حرفيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century artists from the Holy Roman Empire": "فنانون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century biologists from the Holy Roman Empire": "علماء أحياء من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century chemists from the Holy Roman Empire": "كيميائيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 17",
    "17th-century diplomats from the Holy Roman Empire": "دبلوماسيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century educators from the Holy Roman Empire": "معلمون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century explorers from the Holy Roman Empire": "مستكشفون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century historians from the Ottoman Empire": "مؤرخون من الدولة العثمانية في القرن 17",
    "17th-century Jews from the Ottoman Empire": "يهود من الدولة العثمانية في القرن 17",
    "17th-century jurists from the Holy Roman Empire": "حقوقيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century lawyers from the Holy Roman Empire": "محامون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century mathematicians from the Holy Roman Empire": "رياضياتيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century musicians from the Holy Roman Empire": "موسيقيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century naturalists from the Holy Roman Empire": "علماء طبيعة من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century nobility from Bohemia": "نبلاء من بوهيميا في القرن 17",
    "17th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century painters from the Holy Roman Empire": "رسامون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century people from Connecticut": "أشخاص من كونيتيكت في القرن 17",
    "17th-century people from Massachusetts": "أشخاص من ماساتشوستس في القرن 17",
    "17th-century people from New Spain": "أشخاص من إسبانيا الجديدة في القرن 17",
    "17th-century people from Safavid Iran": "أشخاص من إيران الصفوية في القرن 17",
    "17th-century people from the Dutch Empire": "أشخاص من الإمبراطورية الهولندية في القرن 17",
    "17th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century people from the Polish–Lithuanian Commonwealth": "أشخاص من الكومنولث البولندي الليتواني في القرن 17",
    "17th-century philosophers from the Holy Roman Empire": "فلاسفة من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century physicians from the Holy Roman Empire": "أطباء من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century poets from Bohemia": "شعراء من بوهيميا في القرن 17",
    "17th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century politicians from the Holy Roman Empire": "سياسيون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century publishers (people) from the Holy Roman Empire": "ناشرون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century scholars from the Holy Roman Empire": "دارسون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century scholars from the Ottoman Empire": "دارسون من الدولة العثمانية في القرن 17",
    "17th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century singers from the Holy Roman Empire": "مغنون من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century violinists from the Holy Roman Empire": "عازفو كمان من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century women from Bohemia": "نساء من بوهيميا في القرن 17",
    "17th-century women from Georgia (country)": "نساء من جورجيا في القرن 17",
    "17th-century women from the Holy Roman Empire": "نساء من الإمبراطورية الرومانية المقدسة في القرن 17",
    "17th-century women from the Ottoman Empire": "نساء من الدولة العثمانية في القرن 17",
    "17th-century writers from Safavid Iran": "كتاب من إيران الصفوية في القرن 17",
    "17th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 17",
    "18th-century actors from the Holy Roman Empire": "ممثلون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century artisans from the Holy Roman Empire": "حرفيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century artists from Bohemia": "فنانون من بوهيميا في القرن 18",
    "18th-century astronomers from the Russian Empire": "فلكيون من الإمبراطورية الروسية في القرن 18",
    "18th-century biologists from the Holy Roman Empire": "علماء أحياء من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century businesspeople from the Ottoman Empire": "شخصيات أعمال من الدولة العثمانية في القرن 18",
    "18th-century civil servants from the Ottoman Empire": "موظفو خدمة مدنية من الدولة العثمانية في القرن 18",
    "18th-century clergy from Bohemia": "رجال دين من بوهيميا في القرن 18",
    "18th-century clergy from the Russian Empire": "رجال دين من الإمبراطورية الروسية في القرن 18",
    "18th-century criminals from the Holy Roman Empire": "مجرمون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 18",
    "18th-century diplomats from the Holy Roman Empire": "دبلوماسيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century dramatists and playwrights from the Russian Empire": "كتاب دراما ومسرح من الإمبراطورية الروسية في القرن 18",
    "18th-century educators from the Holy Roman Empire": "معلمون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century educators from the Russian Empire": "معلمون من الإمبراطورية الروسية في القرن 18",
    "18th-century engineers from the Russian Empire": "مهندسون من الإمبراطورية الروسية في القرن 18",
    "18th-century explorers from the Holy Roman Empire": "مستكشفون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century explorers from the Russian Empire": "مستكشفون من الإمبراطورية الروسية في القرن 18",
    "18th-century historians from the Holy Roman Empire": "مؤرخون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century historians from the Ottoman Empire": "مؤرخون من الدولة العثمانية في القرن 18",
    "18th-century historians from the Russian Empire": "مؤرخون من الإمبراطورية الروسية في القرن 18",
    "18th-century Jews from the Ottoman Empire": "يهود من الدولة العثمانية في القرن 18",
    "18th-century Jews from the Russian Empire": "يهود من الإمبراطورية الروسية في القرن 18",
    "18th-century jurists from the Holy Roman Empire": "حقوقيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century lawyers from the Holy Roman Empire": "محامون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century male actors from the Holy Roman Empire": "ممثلون ذكور من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century male musicians from Bohemia": "موسيقيون ذكور من بوهيميا في القرن 18",
    "18th-century male musicians from the Holy Roman Empire": "موسيقيون ذكور من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century male musicians from the Russian Empire": "موسيقيون ذكور من الإمبراطورية الروسية في القرن 18",
    "18th-century male singers from the Holy Roman Empire": "مغنون ذكور من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century male writers from the Russian Empire": "كتاب ذكور من الإمبراطورية الروسية في القرن 18",
    "18th-century mathematicians from the Holy Roman Empire": "رياضياتيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century musicians from the Holy Roman Empire": "موسيقيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century naturalists from the Holy Roman Empire": "علماء طبيعة من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century nobility from Bohemia": "نبلاء من بوهيميا في القرن 18",
    "18th-century nobility from the Holy Roman Empire": "نبلاء من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century nobility from the Russian Empire": "نبلاء من الإمبراطورية الروسية في القرن 18",
    "18th-century non-fiction writers from the Russian Empire": "كتاب غير روائيين من الإمبراطورية الروسية في القرن 18",
    "18th-century painters from the Holy Roman Empire": "رسامون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century people from Connecticut": "أشخاص من كونيتيكت في القرن 18",
    "18th-century people from Delaware": "أشخاص من ديلاوير في القرن 18",
    "18th-century people from Maryland": "أشخاص من ماريلند في القرن 18",
    "18th-century people from Massachusetts": "أشخاص من ماساتشوستس في القرن 18",
    "18th-century people from New Jersey": "أشخاص من نيوجيرسي في القرن 18",
    "18th-century people from New Spain": "أشخاص من إسبانيا الجديدة في القرن 18",
    "18th-century people from New York (state)": "أشخاص من ولاية نيويورك في القرن 18",
    "18th-century people from Pennsylvania": "أشخاص من بنسلفانيا في القرن 18",
    "18th-century people from Safavid Iran": "أشخاص من إيران الصفوية في القرن 18",
    "18th-century people from South Carolina": "أشخاص من كارولاينا الجنوبية في القرن 18",
    "18th-century people from the Dutch Empire": "أشخاص من الإمبراطورية الهولندية في القرن 18",
    "18th-century people from the Holy Roman Empire": "أشخاص من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century people from the Polish–Lithuanian Commonwealth": "أشخاص من الكومنولث البولندي الليتواني في القرن 18",
    "18th-century people from the Russian Empire": "أشخاص من الإمبراطورية الروسية في القرن 18",
    "18th-century people from Virginia": "أشخاص من فرجينيا في القرن 18",
    "18th-century philosophers from the Holy Roman Empire": "فلاسفة من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century philosophers from the Russian Empire": "فلاسفة من الإمبراطورية الروسية في القرن 18",
    "18th-century physicians from the Holy Roman Empire": "أطباء من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century poets from Bohemia": "شعراء من بوهيميا في القرن 18",
    "18th-century poets from Georgia (country)": "شعراء من جورجيا في القرن 18",
    "18th-century poets from the Holy Roman Empire": "شعراء من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century politicians from the Holy Roman Empire": "سياسيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century publishers (people) from the Holy Roman Empire": "ناشرون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century rabbis from the Russian Empire": "حاخامات من الإمبراطورية الروسية في القرن 18",
    "18th-century scientists from the Holy Roman Empire": "علماء من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century sculptors from Bohemia": "نحاتون من بوهيميا في القرن 18",
    "18th-century sculptors from the Holy Roman Empire": "نحاتون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century singers from the Holy Roman Empire": "مغنون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century violinists from the Holy Roman Empire": "عازفو كمان من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century women from Bohemia": "نساء من بوهيميا في القرن 18",
    "18th-century women from the Holy Roman Empire": "نساء من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century women from the Ottoman Empire": "نساء من الدولة العثمانية في القرن 18",
    "18th-century women musicians from Bohemia": "موسيقيات من بوهيميا في القرن 18",
    "18th-century women musicians from the Russian Empire": "موسيقيات من الإمبراطورية الروسية في القرن 18",
    "18th-century women singers from the Holy Roman Empire": "مغنيات من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century women writers from the Russian Empire": "كاتبات من الإمبراطورية الروسية في القرن 18",
    "18th-century writers from Georgia (country)": "كتاب من جورجيا في القرن 18",
    "18th-century writers from Safavid Iran": "كتاب من إيران الصفوية في القرن 18",
    "18th-century writers from the Holy Roman Empire": "كتاب من الإمبراطورية الرومانية المقدسة في القرن 18",
    "18th-century writers from the Russian Empire": "كتاب من الإمبراطورية الروسية في القرن 18",
    "19th-century actors from the Ottoman Empire": "ممثلون من الدولة العثمانية في القرن 19",
    "19th-century actors from the Russian Empire": "ممثلون من الإمبراطورية الروسية في القرن 19",
    "19th-century biographers from the Russian Empire": "كتاب سيرة من الإمبراطورية الروسية في القرن 19",
    "19th-century chess players from the Russian Empire": "لاعبو شطرنج من الإمبراطورية الروسية في القرن 19",
    "19th-century civil servants from the Ottoman Empire": "موظفو خدمة مدنية من الدولة العثمانية في القرن 19",
    "19th-century classical pianists from the Russian Empire": "عازفو بيانو كلاسيكيون من الإمبراطورية الروسية في القرن 19",
    "19th-century clergy from Ottoman Iraq": "رجال دين من العراق العثماني في القرن 19",
    "19th-century clergy from the Ottoman Empire": "رجال دين من الدولة العثمانية في القرن 19",
    "19th-century clergy from the Russian Empire": "رجال دين من الإمبراطورية الروسية في القرن 19",
    "19th-century composers from the Russian Empire": "ملحنون من الإمبراطورية الروسية في القرن 19",
    "19th-century criminals from the Russian Empire": "مجرمون من الإمبراطورية الروسية في القرن 19",
    "19th-century dancers from the Russian Empire": "راقصون من الإمبراطورية الروسية في القرن 19",
    "19th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 19",
    "19th-century diarists from the Russian Empire": "كتاب يوميات من الإمبراطورية الروسية في القرن 19",
    "19th-century dramatists and playwrights from the Russian Empire": "كتاب دراما ومسرح من الإمبراطورية الروسية في القرن 19",
    "19th-century educators from Georgia (country)": "معلمون من جورجيا في القرن 19",
    "19th-century educators from the Ottoman Empire": "معلمون من الدولة العثمانية في القرن 19",
    "19th-century educators from the Russian Empire": "معلمون من الإمبراطورية الروسية في القرن 19",
    "19th-century engineers from the Russian Empire": "مهندسون من الإمبراطورية الروسية في القرن 19",
    "19th-century explorers from the Russian Empire": "مستكشفون من الإمبراطورية الروسية في القرن 19",
    "19th-century historians from Georgia (country)": "مؤرخون من جورجيا في القرن 19",
    "19th-century historians from the Ottoman Empire": "مؤرخون من الدولة العثمانية في القرن 19",
    "19th-century historians from the Russian Empire": "مؤرخون من الإمبراطورية الروسية في القرن 19",
    "19th-century illustrators from the Russian Empire": "رسامون توضيحيون من الإمبراطورية الروسية في القرن 19",
    "19th-century Jews from Ottoman Iraq": "يهود من العراق العثماني في القرن 19",
    "19th-century Jews from the Ottoman Empire": "يهود من الدولة العثمانية في القرن 19",
    "19th-century Jews from the Russian Empire": "يهود من الإمبراطورية الروسية في القرن 19",
    "19th-century journalists from the Ottoman Empire": "صحفيون من الدولة العثمانية في القرن 19",
    "19th-century journalists from the Russian Empire": "صحفيون من الإمبراطورية الروسية في القرن 19",
    "19th-century landowners from the Russian Empire": "حائزو أراضي من الإمبراطورية الروسية في القرن 19",
    "19th-century lawyers from the Russian Empire": "محامون من الإمبراطورية الروسية في القرن 19",
    "19th-century male actors from the Ottoman Empire": "ممثلون ذكور من الدولة العثمانية في القرن 19",
    "19th-century male musicians from the Russian Empire": "موسيقيون ذكور من الإمبراطورية الروسية في القرن 19",
    "19th-century male singers from the Russian Empire": "مغنون ذكور من الإمبراطورية الروسية في القرن 19",
    "19th-century memoirists from the Russian Empire": "كتاب مذكرات من الإمبراطورية الروسية في القرن 19",
    "19th-century musicians from the Ottoman Empire": "موسيقيون من الدولة العثمانية في القرن 19",
    "19th-century nobility from the Russian Empire": "نبلاء من الإمبراطورية الروسية في القرن 19",
    "19th-century people from Alabama": "أشخاص من ألاباما في القرن 19",
    "19th-century people from Arizona": "أشخاص من أريزونا في القرن 19",
    "19th-century people from Arkansas": "أشخاص من أركنساس في القرن 19",
    "19th-century people from California": "أشخاص من كاليفورنيا في القرن 19",
    "19th-century people from Colorado": "أشخاص من كولورادو في القرن 19",
    "19th-century people from Connecticut": "أشخاص من كونيتيكت في القرن 19",
    "19th-century people from Delaware": "أشخاص من ديلاوير في القرن 19",
    "19th-century people from Florida": "أشخاص من فلوريدا في القرن 19",
    "19th-century people from Georgia (country)": "أشخاص من جورجيا في القرن 19",
    "19th-century people from Georgia (U.S. state)": "أشخاص من ولاية جورجيا في القرن 19",
    "19th-century people from Idaho": "أشخاص من أيداهو في القرن 19",
    "19th-century people from Indiana": "أشخاص من إنديانا في القرن 19",
    "19th-century people from Kansas": "أشخاص من كانساس في القرن 19",
    "19th-century people from Kentucky": "أشخاص من كنتاكي في القرن 19",
    "19th-century people from Louisiana": "أشخاص من لويزيانا في القرن 19",
    "19th-century people from Maine": "أشخاص من مين في القرن 19",
    "19th-century people from Maryland": "أشخاص من ماريلند في القرن 19",
    "19th-century people from Massachusetts": "أشخاص من ماساتشوستس في القرن 19",
    "19th-century people from Michigan": "أشخاص من ميشيغان في القرن 19",
    "19th-century people from Minnesota": "أشخاص من منيسوتا في القرن 19",
    "19th-century people from Mississippi": "أشخاص من مسيسيبي في القرن 19",
    "19th-century people from Missouri": "أشخاص من ميزوري في القرن 19",
    "19th-century people from Montana": "أشخاص من مونتانا في القرن 19",
    "19th-century people from Nebraska": "أشخاص من نبراسكا في القرن 19",
    "19th-century people from Nevada": "أشخاص من نيفادا في القرن 19",
    "19th-century people from New Jersey": "أشخاص من نيوجيرسي في القرن 19",
    "19th-century people from New York (state)": "أشخاص من ولاية نيويورك في القرن 19",
    "19th-century people from North Carolina": "أشخاص من كارولاينا الشمالية في القرن 19",
    "19th-century people from Ohio": "أشخاص من أوهايو في القرن 19",
    "19th-century people from Oklahoma": "أشخاص من أوكلاهوما في القرن 19",
    "19th-century people from Pennsylvania": "أشخاص من بنسلفانيا في القرن 19",
    "19th-century people from Rhode Island": "أشخاص من رود آيلاند في القرن 19",
    "19th-century people from South Carolina": "أشخاص من كارولاينا الجنوبية في القرن 19",
    "19th-century people from South Dakota": "أشخاص من داكوتا الجنوبية في القرن 19",
    "19th-century people from Tennessee": "أشخاص من تينيسي في القرن 19",
    "19th-century people from Texas": "أشخاص من تكساس في القرن 19",
    "19th-century people from the Russian Empire": "أشخاص من الإمبراطورية الروسية في القرن 19",
    "19th-century people from Vermont": "أشخاص من فيرمونت في القرن 19",
    "19th-century people from Virginia": "أشخاص من فرجينيا في القرن 19",
    "19th-century people from Washington (state)": "أشخاص من ولاية واشنطن في القرن 19",
    "19th-century people from Washington, D.C.": "أشخاص من واشنطن العاصمة في القرن 19",
    "19th-century people from Wisconsin": "أشخاص من ويسكونسن في القرن 19",
    "19th-century people from Wyoming": "أشخاص من وايومنغ في القرن 19",
    "19th-century photographers from the Ottoman Empire": "مصورون من الدولة العثمانية في القرن 19",
    "19th-century physicists from the Russian Empire": "فيزيائيون من الإمبراطورية الروسية في القرن 19",
    "19th-century rabbis from Ottoman Iraq": "حاخامات من العراق العثماني في القرن 19",
    "19th-century scientists from Georgia (country)": "علماء من جورجيا في القرن 19",
    "19th-century singers from the Russian Empire": "مغنون من الإمبراطورية الروسية في القرن 19",
    "19th-century women educators from Georgia (country)": "معلمات من جورجيا في القرن 19",
    "19th-century women musicians from the Russian Empire": "موسيقيات من الإمبراطورية الروسية في القرن 19",
    "19th-century women painters from the Russian Empire": "رسامات من الإمبراطورية الروسية في القرن 19",
    "19th-century women scientists from Georgia (country)": "عالمات من جورجيا في القرن 19",
    "19th-century writers from Georgia (country)": "كتاب من جورجيا في القرن 19",
    "19th-century writers from the Russian Empire": "كتاب من الإمبراطورية الروسية في القرن 19",
    "20th-century actors from the Ottoman Empire": "ممثلون من الدولة العثمانية في القرن 20",
    "20th-century architects from Georgia (country)": "معماريون من جورجيا في القرن 20",
    "20th-century artists from Northern Ireland": "فنانون من أيرلندا الشمالية في القرن 20",
    "20th-century autobiographers from Northern Ireland": "كتاب سيرة ذاتية من أيرلندا الشمالية في القرن 20",
    "20th-century bass guitarists from Northern Ireland": "عازفو غيتار باس من أيرلندا الشمالية في القرن 20",
    "20th-century biographers from Northern Ireland": "كتاب سيرة من أيرلندا الشمالية في القرن 20",
    "20th-century biologists from Northern Ireland": "علماء أحياء من أيرلندا الشمالية في القرن 20",
    "20th-century chemists from Northern Ireland": "كيميائيون من أيرلندا الشمالية في القرن 20",
    "20th-century clergy from Northern Ireland": "رجال دين من أيرلندا الشمالية في القرن 20",
    "20th-century clergy from the Ottoman Empire": "رجال دين من الدولة العثمانية في القرن 20",
    "20th-century comedians from Northern Ireland": "كوميديون من أيرلندا الشمالية في القرن 20",
    "20th-century composers from Northern Ireland": "ملحنون من أيرلندا الشمالية في القرن 20",
    "20th-century deaths from infectious disease": "وفيات بسبب أمراض معدية في القرن 20",
    "20th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 20",
    "20th-century dramatists and playwrights from Northern Ireland": "كتاب دراما ومسرح من أيرلندا الشمالية في القرن 20",
    "20th-century drummers from Northern Ireland": "طبالون من أيرلندا الشمالية في القرن 20",
    "20th-century educators from Georgia (country)": "معلمون من جورجيا في القرن 20",
    "20th-century educators from Northern Ireland": "معلمون من أيرلندا الشمالية في القرن 20",
    "20th-century folk musicians from Northern Ireland": "موسيقيو فولك من أيرلندا الشمالية في القرن 20",
    "20th-century guitarists from Northern Ireland": "عازفو قيثارة من أيرلندا الشمالية في القرن 20",
    "20th-century historians from Georgia (country)": "مؤرخون من جورجيا في القرن 20",
    "20th-century historians from Northern Ireland": "مؤرخون من أيرلندا الشمالية في القرن 20",
    "20th-century Jews from Georgia (country)": "يهود من جورجيا في القرن 20",
    "20th-century Jews from the Ottoman Empire": "يهود من الدولة العثمانية في القرن 20",
    "20th-century journalists from Northern Ireland": "صحفيون من أيرلندا الشمالية في القرن 20",
    "20th-century journalists from the Ottoman Empire": "صحفيون من الدولة العثمانية في القرن 20",
    "20th-century lawyers from Northern Ireland": "محامون من أيرلندا الشمالية في القرن 20",
    "20th-century male actors from the Ottoman Empire": "ممثلون ذكور من الدولة العثمانية في القرن 20",
    "20th-century male artists from Northern Ireland": "فنانون ذكور من أيرلندا الشمالية في القرن 20",
    "20th-century male composers from Northern Ireland": "ملحنون ذكور من أيرلندا الشمالية في القرن 20",
    "20th-century male musicians from Northern Ireland": "موسيقيون ذكور من أيرلندا الشمالية في القرن 20",
    "20th-century male singers from Northern Ireland": "مغنون ذكور من أيرلندا الشمالية في القرن 20",
    "20th-century male writers from Northern Ireland": "كتاب ذكور من أيرلندا الشمالية في القرن 20",
    "20th-century mathematicians from Northern Ireland": "رياضياتيون من أيرلندا الشمالية في القرن 20",
    "20th-century medical doctors from Northern Ireland": "أطباء من أيرلندا الشمالية في القرن 20",
    "20th-century memoirists from Northern Ireland": "كتاب مذكرات من أيرلندا الشمالية في القرن 20",
    "20th-century musicians from Georgia (country)": "موسيقيون من جورجيا في القرن 20",
    "20th-century musicians from Northern Ireland": "موسيقيون من أيرلندا الشمالية في القرن 20",
    "20th-century non-fiction writers from Northern Ireland": "كتاب غير روائيين من أيرلندا الشمالية في القرن 20",
    "20th-century novelists from Northern Ireland": "روائيون من أيرلندا الشمالية في القرن 20",
    "20th-century painters from Northern Ireland": "رسامون من أيرلندا الشمالية في القرن 20",
    "20th-century people from Alabama": "أشخاص من ألاباما في القرن 20",
    "20th-century people from Alaska": "أشخاص من ألاسكا في القرن 20",
    "20th-century people from Arizona": "أشخاص من أريزونا في القرن 20",
    "20th-century people from California": "أشخاص من كاليفورنيا في القرن 20",
    "20th-century people from Colorado": "أشخاص من كولورادو في القرن 20",
    "20th-century people from Connecticut": "أشخاص من كونيتيكت في القرن 20",
    "20th-century people from Delaware": "أشخاص من ديلاوير في القرن 20",
    "20th-century people from Florida": "أشخاص من فلوريدا في القرن 20",
    "20th-century people from Georgia (U.S. state)": "أشخاص من ولاية جورجيا في القرن 20",
    "20th-century people from Hawaii": "أشخاص من هاواي في القرن 20",
    "20th-century people from Idaho": "أشخاص من أيداهو في القرن 20",
    "20th-century people from Illinois": "أشخاص من إلينوي في القرن 20",
    "20th-century people from Indiana": "أشخاص من إنديانا في القرن 20",
    "20th-century people from Kansas": "أشخاص من كانساس في القرن 20",
    "20th-century people from Louisiana": "أشخاص من لويزيانا في القرن 20",
    "20th-century people from Maine": "أشخاص من مين في القرن 20",
    "20th-century people from Maryland": "أشخاص من ماريلند في القرن 20",
    "20th-century people from Massachusetts": "أشخاص من ماساتشوستس في القرن 20",
    "20th-century people from Minnesota": "أشخاص من منيسوتا في القرن 20",
    "20th-century people from Mississippi": "أشخاص من مسيسيبي في القرن 20",
    "20th-century people from Missouri": "أشخاص من ميزوري في القرن 20",
    "20th-century people from Montana": "أشخاص من مونتانا في القرن 20",
    "20th-century people from Nebraska": "أشخاص من نبراسكا في القرن 20",
    "20th-century people from Nevada": "أشخاص من نيفادا في القرن 20",
    "20th-century people from New Hampshire": "أشخاص من نيوهامشير في القرن 20",
    "20th-century people from New Jersey": "أشخاص من نيوجيرسي في القرن 20",
    "20th-century people from New York (state)": "أشخاص من ولاية نيويورك في القرن 20",
    "20th-century people from North Carolina": "أشخاص من كارولاينا الشمالية في القرن 20",
    "20th-century people from Northern Ireland": "أشخاص من أيرلندا الشمالية في القرن 20",
    "20th-century people from Ohio": "أشخاص من أوهايو في القرن 20",
    "20th-century people from Oklahoma": "أشخاص من أوكلاهوما في القرن 20",
    "20th-century people from Pennsylvania": "أشخاص من بنسلفانيا في القرن 20",
    "20th-century people from Rhode Island": "أشخاص من رود آيلاند في القرن 20",
    "20th-century people from South Carolina": "أشخاص من كارولاينا الجنوبية في القرن 20",
    "20th-century people from South Dakota": "أشخاص من داكوتا الجنوبية في القرن 20",
    "20th-century people from Tennessee": "أشخاص من تينيسي في القرن 20",
    "20th-century people from Texas": "أشخاص من تكساس في القرن 20",
    "20th-century people from Utah": "أشخاص من يوتا في القرن 20",
    "20th-century people from Vermont": "أشخاص من فيرمونت في القرن 20",
    "20th-century people from Virginia": "أشخاص من فرجينيا في القرن 20",
    "20th-century people from Washington (state)": "أشخاص من ولاية واشنطن في القرن 20",
    "20th-century people from Washington, D.C.": "أشخاص من واشنطن العاصمة في القرن 20",
    "20th-century people from West Virginia": "أشخاص من فرجينيا الغربية في القرن 20",
    "20th-century people from Wisconsin": "أشخاص من ويسكونسن في القرن 20",
    "20th-century people from Wyoming": "أشخاص من وايومنغ في القرن 20",
    "20th-century photographers from Northern Ireland": "مصورون من أيرلندا الشمالية في القرن 20",
    "20th-century physicists from Northern Ireland": "فيزيائيون من أيرلندا الشمالية في القرن 20",
    "20th-century poets from Georgia (country)": "شعراء من جورجيا في القرن 20",
    "20th-century poets from Northern Ireland": "شعراء من أيرلندا الشمالية في القرن 20",
    "20th-century politicians from Georgia (country)": "سياسيون من جورجيا في القرن 20",
    "20th-century politicians from Northern Ireland": "سياسيون من أيرلندا الشمالية في القرن 20",
    "20th-century rabbis from the Ottoman Empire": "حاخامات من الدولة العثمانية في القرن 20",
    "20th-century scientists from Georgia (country)": "علماء من جورجيا في القرن 20",
    "20th-century scientists from Northern Ireland": "علماء من أيرلندا الشمالية في القرن 20",
    "20th-century screenwriters from Northern Ireland": "كتاب سيناريو من أيرلندا الشمالية في القرن 20",
    "20th-century short story writers from Northern Ireland": "كتاب قصة قصيرة من أيرلندا الشمالية في القرن 20",
    "20th-century singer-songwriters from Northern Ireland": "مغنون وكتاب أغاني من أيرلندا الشمالية في القرن 20",
    "20th-century singers from Georgia (country)": "مغنون من جورجيا في القرن 20",
    "20th-century singers from Northern Ireland": "مغنون من أيرلندا الشمالية في القرن 20",
    "20th-century songwriters from Northern Ireland": "كتاب أغان من أيرلندا الشمالية في القرن 20",
    "20th-century sportsmen from Northern Ireland": "رياضيون رجال من أيرلندا الشمالية في القرن 20",
    "20th-century sportspeople from Northern Ireland": "رياضيون من أيرلندا الشمالية في القرن 20",
    "20th-century sportswomen from Northern Ireland": "رياضيات من أيرلندا الشمالية في القرن 20",
    "20th-century women artists from Northern Ireland": "فنانات من أيرلندا الشمالية في القرن 20",
    "20th-century women educators from Georgia (country)": "معلمات من جورجيا في القرن 20",
    "20th-century women educators from Northern Ireland": "معلمات من أيرلندا الشمالية في القرن 20",
    "20th-century women journalists from Northern Ireland": "صحفيات من أيرلندا الشمالية في القرن 20",
    "20th-century women lawyers from Northern Ireland": "محاميات من أيرلندا الشمالية في القرن 20",
    "20th-century women medical doctors from Northern Ireland": "طبيبات من أيرلندا الشمالية في القرن 20",
    "20th-century women musicians from Georgia (country)": "موسيقيات من جورجيا في القرن 20",
    "20th-century women musicians from Northern Ireland": "موسيقيات من أيرلندا الشمالية في القرن 20",
    "20th-century women politicians from Georgia (country)": "سياسيات من جورجيا في القرن 20",
    "20th-century women politicians from Northern Ireland": "سياسيات من أيرلندا الشمالية في القرن 20",
    "20th-century women scientists from Georgia (country)": "عالمات من جورجيا في القرن 20",
    "20th-century women scientists from Northern Ireland": "عالمات من أيرلندا الشمالية في القرن 20",
    "20th-century women singers from Georgia (country)": "مغنيات من جورجيا في القرن 20",
    "20th-century women singers from Northern Ireland": "مغنيات من أيرلندا الشمالية في القرن 20",
    "20th-century women writers from Georgia (country)": "كاتبات من جورجيا في القرن 20",
    "20th-century women writers from Northern Ireland": "كاتبات من أيرلندا الشمالية في القرن 20",
    "20th-century writers from Georgia (country)": "كتاب من جورجيا في القرن 20",
    "20th-century writers from Northern Ireland": "كتاب من أيرلندا الشمالية في القرن 20",
    "20th-century zoologists from Northern Ireland": "علماء حيوانات من أيرلندا الشمالية في القرن 20",
    "21st-century actors from Georgia (country)": "ممثلون من جورجيا في القرن 21",
    "21st-century artists from Northern Ireland": "فنانون من أيرلندا الشمالية في القرن 21",
    "21st-century autobiographers from Northern Ireland": "كتاب سيرة ذاتية من أيرلندا الشمالية في القرن 21",
    "21st-century bass guitarists from Northern Ireland": "عازفو غيتار باس من أيرلندا الشمالية في القرن 21",
    "21st-century biographers from Northern Ireland": "كتاب سيرة من أيرلندا الشمالية في القرن 21",
    "21st-century biologists from Northern Ireland": "علماء أحياء من أيرلندا الشمالية في القرن 21",
    "21st-century chemists from Northern Ireland": "كيميائيون من أيرلندا الشمالية في القرن 21",
    "21st-century clergy from Northern Ireland": "رجال دين من أيرلندا الشمالية في القرن 21",
    "21st-century comedians from Northern Ireland": "كوميديون من أيرلندا الشمالية في القرن 21",
    "21st-century composers from Northern Ireland": "ملحنون من أيرلندا الشمالية في القرن 21",
    "21st-century deaths from tuberculosis": "وفيات بسبب السل في القرن 21",
    "21st-century dramatists and playwrights from Northern Ireland": "كتاب دراما ومسرح من أيرلندا الشمالية في القرن 21",
    "21st-century drummers from Northern Ireland": "طبالون من أيرلندا الشمالية في القرن 21",
    "21st-century educators from Northern Ireland": "معلمون من أيرلندا الشمالية في القرن 21",
    "21st-century folk musicians from Northern Ireland": "موسيقيو فولك من أيرلندا الشمالية في القرن 21",
    "21st-century guitarists from Northern Ireland": "عازفو قيثارة من أيرلندا الشمالية في القرن 21",
    "21st-century historians from Georgia (country)": "مؤرخون من جورجيا في القرن 21",
    "21st-century historians from Northern Ireland": "مؤرخون من أيرلندا الشمالية في القرن 21",
    "21st-century Jews from Georgia (country)": "يهود من جورجيا في القرن 21",
    "21st-century journalists from Northern Ireland": "صحفيون من أيرلندا الشمالية في القرن 21",
    "21st-century lawyers from Northern Ireland": "محامون من أيرلندا الشمالية في القرن 21",
    "21st-century male composers from Northern Ireland": "ملحنون ذكور من أيرلندا الشمالية في القرن 21",
    "21st-century male musicians from Northern Ireland": "موسيقيون ذكور من أيرلندا الشمالية في القرن 21",
    "21st-century male singers from Northern Ireland": "مغنون ذكور من أيرلندا الشمالية في القرن 21",
    "21st-century male writers from Northern Ireland": "كتاب ذكور من أيرلندا الشمالية في القرن 21",
    "21st-century mathematicians from Northern Ireland": "رياضياتيون من أيرلندا الشمالية في القرن 21",
    "21st-century memoirists from Northern Ireland": "كتاب مذكرات من أيرلندا الشمالية في القرن 21",
    "21st-century musicians from Northern Ireland": "موسيقيون من أيرلندا الشمالية في القرن 21",
    "21st-century non-fiction writers from Northern Ireland": "كتاب غير روائيين من أيرلندا الشمالية في القرن 21",
    "21st-century novelists from Northern Ireland": "روائيون من أيرلندا الشمالية في القرن 21",
    "21st-century opera singers from Georgia (country)": "مغنو أوبرا من جورجيا في القرن 21",
    "21st-century people from Alabama": "أشخاص من ألاباما في القرن 21",
    "21st-century people from Alaska": "أشخاص من ألاسكا في القرن 21",
    "21st-century people from Arizona": "أشخاص من أريزونا في القرن 21",
    "21st-century people from California": "أشخاص من كاليفورنيا في القرن 21",
    "21st-century people from Connecticut": "أشخاص من كونيتيكت في القرن 21",
    "21st-century people from Delaware": "أشخاص من ديلاوير في القرن 21",
    "21st-century people from Florida": "أشخاص من فلوريدا في القرن 21",
    "21st-century people from Georgia (country)": "أشخاص من جورجيا في القرن 21",
    "21st-century people from Georgia (U.S. state)": "أشخاص من ولاية جورجيا في القرن 21",
    "21st-century people from Idaho": "أشخاص من أيداهو في القرن 21",
    "21st-century people from Illinois": "أشخاص من إلينوي في القرن 21",
    "21st-century people from Indiana": "أشخاص من إنديانا في القرن 21",
    "21st-century people from Louisiana": "أشخاص من لويزيانا في القرن 21",
    "21st-century people from Maine": "أشخاص من مين في القرن 21",
    "21st-century people from Maryland": "أشخاص من ماريلند في القرن 21",
    "21st-century people from Michigan": "أشخاص من ميشيغان في القرن 21",
    "21st-century people from Minnesota": "أشخاص من منيسوتا في القرن 21",
    "21st-century people from New Jersey": "أشخاص من نيوجيرسي في القرن 21",
    "21st-century people from North Carolina": "أشخاص من كارولاينا الشمالية في القرن 21",
    "21st-century people from Northern Ireland": "أشخاص من أيرلندا الشمالية في القرن 21",
    "21st-century people from Oklahoma": "أشخاص من أوكلاهوما في القرن 21",
    "21st-century people from Pennsylvania": "أشخاص من بنسلفانيا في القرن 21",
    "21st-century people from Rhode Island": "أشخاص من رود آيلاند في القرن 21",
    "21st-century people from South Carolina": "أشخاص من كارولاينا الجنوبية في القرن 21",
    "21st-century people from South Dakota": "أشخاص من داكوتا الجنوبية في القرن 21",
    "21st-century people from Tennessee": "أشخاص من تينيسي في القرن 21",
    "21st-century people from Texas": "أشخاص من تكساس في القرن 21",
    "21st-century people from Utah": "أشخاص من يوتا في القرن 21",
    "21st-century people from Washington (state)": "أشخاص من ولاية واشنطن في القرن 21",
    "21st-century people from Washington, D.C.": "أشخاص من واشنطن العاصمة في القرن 21",
    "21st-century people from Wisconsin": "أشخاص من ويسكونسن في القرن 21",
    "21st-century photographers from Northern Ireland": "مصورون من أيرلندا الشمالية في القرن 21",
    "21st-century physicists from Northern Ireland": "فيزيائيون من أيرلندا الشمالية في القرن 21",
    "21st-century poets from Georgia (country)": "شعراء من جورجيا في القرن 21",
    "21st-century poets from Northern Ireland": "شعراء من أيرلندا الشمالية في القرن 21",
    "21st-century politicians from Northern Ireland": "سياسيون من أيرلندا الشمالية في القرن 21",
    "21st-century scientists from Georgia (country)": "علماء من جورجيا في القرن 21",
    "21st-century scientists from Northern Ireland": "علماء من أيرلندا الشمالية في القرن 21",
    "21st-century screenwriters from Northern Ireland": "كتاب سيناريو من أيرلندا الشمالية في القرن 21",
    "21st-century short story writers from Northern Ireland": "كتاب قصة قصيرة من أيرلندا الشمالية في القرن 21",
    "21st-century singer-songwriters from Northern Ireland": "مغنون وكتاب أغاني من أيرلندا الشمالية في القرن 21",
    "21st-century singers from Northern Ireland": "مغنون من أيرلندا الشمالية في القرن 21",
    "21st-century songwriters from Northern Ireland": "كتاب أغان من أيرلندا الشمالية في القرن 21",
    "21st-century sportsmen from Georgia (country)": "رياضيون رجال من جورجيا في القرن 21",
    "21st-century sportsmen from Northern Ireland": "رياضيون رجال من أيرلندا الشمالية في القرن 21",
    "21st-century sportspeople from Georgia (country)": "رياضيون من جورجيا في القرن 21",
    "21st-century sportspeople from Northern Ireland": "رياضيون من أيرلندا الشمالية في القرن 21",
    "21st-century sportswomen from Georgia (country)": "رياضيات من جورجيا في القرن 21",
    "21st-century sportswomen from Northern Ireland": "رياضيات من أيرلندا الشمالية في القرن 21",
    "21st-century women artists from Northern Ireland": "فنانات من أيرلندا الشمالية في القرن 21",
    "21st-century women composers from Northern Ireland": "ملحنات من أيرلندا الشمالية في القرن 21",
    "21st-century women journalists from Northern Ireland": "صحفيات من أيرلندا الشمالية في القرن 21",
    "21st-century women lawyers from Northern Ireland": "محاميات من أيرلندا الشمالية في القرن 21",
    "21st-century women musicians from Georgia (country)": "موسيقيات من جورجيا في القرن 21",
    "21st-century women opera singers from Georgia (country)": "مغنيات أوبرا من جورجيا في القرن 21",
    "21st-century women politicians from Georgia (country)": "سياسيات من جورجيا في القرن 21",
    "21st-century women politicians from Northern Ireland": "سياسيات من أيرلندا الشمالية في القرن 21",
    "21st-century women scientists from Northern Ireland": "عالمات من أيرلندا الشمالية في القرن 21",
    "21st-century women singers from Georgia (country)": "مغنيات من جورجيا في القرن 21",
    "21st-century women writers from Northern Ireland": "كاتبات من أيرلندا الشمالية في القرن 21",
    "21st-century writers from Georgia (country)": "كتاب من جورجيا في القرن 21",
    "21st-century writers from Northern Ireland": "كتاب من أيرلندا الشمالية في القرن 21",
    "21st-century zoologists from Northern Ireland": "علماء حيوانات من أيرلندا الشمالية في القرن 21",
    "7th-century deaths from tuberculosis": "وفيات بسبب السل في القرن 7",
    "8th-century historians from the Abbasid Caliphate": "مؤرخون من الدولة العباسية في القرن 8",
    "8th-century Jews from the Abbasid Caliphate": "يهود من الدولة العباسية في القرن 8",
    "8th-century people from the Abbasid Caliphate": "أشخاص من الدولة العباسية في القرن 8",
    "9th-century historians from al-Andalus": "مؤرخون من الأندلس في القرن 9",
    "9th-century historians from the Abbasid Caliphate": "مؤرخون من الدولة العباسية في القرن 9",
    "9th-century Jews from al-Andalus": "يهود من الأندلس في القرن 9",
    "9th-century Jews from the Abbasid Caliphate": "يهود من الدولة العباسية في القرن 9",
    "9th-century people from East Francia": "أشخاص من مملكة الفرنجة الشرقيين في القرن 9",
    "9th-century people from the Abbasid Caliphate": "أشخاص من الدولة العباسية في القرن 9",
    "9th-century people from West Francia": "أشخاص من مملكة الفرنجة الغربيين في القرن 9",
}


@pytest.mark.parametrize("category,expected", test_data_standard.items(), ids=test_data_standard.keys())
@pytest.mark.slow
def test_resolve_v3i_new_1(category: str, expected: str) -> None:
    """Test resolve year job from countries function for test_data_standard."""
    result1 = resolve_year_job_from_countries(category)
    assert result1 == expected

    result2 = resolve_label_ar(category)
    assert result2 == expected


to_test = [
    ("test_resolve_v3i_new_1", test_data_standard, resolve_year_job_from_countries),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    # dump_same_and_not_same(data, diff_result, name, just_dump=True)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
