#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

test_1 = {
    "Category:21st-century New Zealand non-fiction writers": "تصنيف:كتاب غير روائيين نيوزيلنديون في القرن 21",
    "Category:20th-century New Zealand non-fiction writers": "تصنيف:كتاب غير روائيين نيوزيلنديون في القرن 20",
    "Category:New Zealand non-fiction writers": "تصنيف:كتاب غير روائيين نيوزيلنديون",
    "Category:New Zealand non-fiction writers by century": "تصنيف:كتاب غير روائيين نيوزيلنديون حسب القرن",
    "Category:New Zealand non-fiction books": "تصنيف:كتب نيوزيلندية غير خيالية",
}

data_empty_result = {
    "Category:Academicians of non-governmental academies based in Russia": "x",
    "Category:Advisory non-departmental public bodies of the Scottish Government": "x",
    "Category:AfC submissions declined as a non-notable academic topic": "x",
    "Category:AfC submissions declined as a non-notable athletic topic": "x",
    "Category:AfC submissions declined as a non-notable biography": "x",
    "Category:AfC submissions declined as a non-notable book": "x",
    "Category:AfC submissions declined as a non-notable event": "x",
    "Category:AfC submissions declined as a non-notable film": "x",
    "Category:AfC submissions declined as a non-notable musical topic": "x",
    "Category:AfC submissions declined as a non-notable organization": "x",
    "Category:AfC submissions declined as non-notable web content": "x",
    "Category:AfC submissions declined as non-notable": "x",
    "Category:AfC submissions rejected as non-notable": "x",
    "Category:Africa territory (non-sovereign) templates": "x",
    "Category:Akron Firestone Non-Skids coaches": "x",
    "Category:Akron Firestone Non-Skids players": "x",
    "Category:Akron Firestone Non-Skids seasons": "x",
    "Category:Akron Firestone Non-Skids": "x",
    "Category:Album articles with non-standard infoboxes": "x",
    "Category:All articles with improper non-free content": "x",
    "Category:All non-free logos": "x",
    "Category:All non-free media": "x",
    "Category:American non-commissioned personnel": "x",
    "Category:Animal testing on non-human primates": "x",
    "Category:Anthems of non-sovereign states": "x",
    "Category:Articles containing Bantayanon-language text": "x",
    "Category:Articles containing Bantoanon-language text": "x",
    "Category:Articles containing Butuanon-language text": "x",
    "Category:Articles containing Capiznon-language text": "x",
    "Category:Articles containing Cuyonon-language text": "x",
    "Category:Articles containing Higaonon-language text": "x",
    "Category:Articles containing Hiligaynon-language text": "x",
    "Category:Articles containing Malaynon-language text": "x",
    "Category:Articles containing non-English-language text": "x",
    "Category:Articles containing Northern Sorsoganon-language text": "x",
    "Category:Articles containing Ratagnon-language text": "x",
    "Category:Articles containing Romblomanon-language text": "x",
    "Category:Articles containing Southern Sorsoganon-language text": "x",
    "Category:Articles containing Surigaonon-language text": "x",
    "Category:Articles containing Tandaganon-language text": "x",
    "Category:Articles containing Western Subanon-language text": "x",
    "Category:Articles needing non-English script or text": "x",
    "Category:Articles with excessive non-free audio content": "x",
    "Category:Articles with improper non-free content": "x",
    "Category:Articles with non-English-language CS1 sources": "x",
    "Category:Articles with non-English-language sources": "x",
    "Category:Articles with non-HTML file bare URLs for citations": "x",
    "Category:Asia territory (non-sovereign) templates": "x",
    "Category:Association football player non-biographical articles": "x",
    "Category:Australian non-commissioned personnel": "x",
    "Category:Bollywood Hungama movie template using non-numeric ID": "x",
    "Category:Bollywood Hungama person template using non-numeric ID": "x",
    "Category:Bosnia and Herzegovina non-alcoholic drinks": "x",
    "Category:British non-commissioned personnel": "x",
    "Category:Buddhism articles needing non-English scripting support & specialist attention": "x",
    "Category:Candidates for speedy deletion as dependent on a non-existent page": "x",
    "Category:Cannon-launched guided projectiles": "x",
    "Category:Chairpersons of non-governmental organizations": "x",
    "Category:Chinese people by non-city prefecture-level division": "x",
    "Category:Christian non-aligned Scouting organizations": "x",
    "Category:Citation Style 1 templates using non-standard parameters": "x",
    "Category:Class masks with non-standard classes": "x",
    "Category:Closed non-builders": "x",
    "Category:Club of Committed Non-Party Members politicians": "x",
    "Category:Coats of arms of non-metropolitan district councils": "x",
    "Category:Cometary object redirects (non-primary)": "x",
    "Category:Completed non-free use rationale logo transclusions": "x",
    "Category:Conversion of non-Christian religious buildings and structures into churches": "x",
    "Category:Cue sports articles with good non-English versions": "x",
    "Category:Deaths from non-Hodgkin lymphoma": "x",
    "Category:Defunct non-departmental public bodies of the United Kingdom government": "x",
    "Category:Defunct non-English-language newspapers published in the United States": "x",
    "Category:Drugs with non-standard legal status": "x",
    "Category:Drugs with non-standard pregnancy category": "x",
    "Category:Editnotices with unsalted non-existent targets": "x",
    "Category:Educational technology non-profits": "x",
    "Category:English non-league football articles by importance": "x",
    "Category:English non-league football articles by quality": "x",
    "Category:English non-League football club squad templates": "x",
    "Category:English non-league football task force articles": "x",
    "Category:English non-league football task force": "x",
    "Category:English non-league team of the year navigational boxes": "x",
    "Category:Episode lists with a non-matching set of numbered parameters": "x",
    "Category:Episode lists with non-compliant line colors": "x",
    "Category:Europe territory (non-sovereign) templates": "x",
    "Category:Executive non-departmental public bodies of the Scottish Government": "x",
    "Category:Experimental drugs developed for non-alcoholic fatty liver disease": "x",
    "Category:Experimental non-hallucinogens": "x",
    "Category:Fiction redirect categories with non-existent parent categories": "x",
    "Category:Fictional non-commissioned officers": "x",
    "Category:Fictional United States Army non-commissioned officers": "x",
    "Category:First secretaries in non-national subdivisions of the Soviet Union": "x",
    "Category:FootballFacts.ru template using non-numeric ID": "x",
    "Category:Former evangelical non-denominational churches": "x",
    "Category:Former non-metropolitan counties": "x",
    "Category:Former non-metropolitan district councils of England": "x",
    "Category:Former non-metropolitan districts of Avon": "x",
    "Category:Former non-metropolitan districts of Bedfordshire": "x",
    "Category:Former non-metropolitan districts of Buckinghamshire": "x",
    "Category:Former non-metropolitan districts of Cheshire": "x",
    "Category:Former non-metropolitan districts of Cornwall": "x",
    "Category:Former non-metropolitan districts of Cumbria": "x",
    "Category:Former non-metropolitan districts of Dorset": "x",
    "Category:Former non-metropolitan districts of Durham": "x",
    "Category:Former non-metropolitan districts of East Sussex": "x",
    "Category:Former non-metropolitan districts of Hereford and Worcester": "x",
    "Category:Former non-metropolitan districts of Humberside": "x",
    "Category:Former non-metropolitan districts of Kent": "x",
    "Category:Former non-metropolitan districts of North Yorkshire": "x",
    "Category:Former non-metropolitan districts of Northamptonshire": "x",
    "Category:Former non-metropolitan districts of Northumberland": "x",
    "Category:Former non-metropolitan districts of Shropshire": "x",
    "Category:Former non-metropolitan districts of Somerset": "x",
    "Category:Former non-metropolitan districts of Suffolk": "x",
    "Category:Former non-metropolitan districts of the Isle of Wight": "x",
    "Category:Former non-metropolitan districts of Wiltshire": "x",
    "Category:Former non-metropolitan districts": "x",
    "Category:Formula One non-championship races": "x",
    "Category:Hash function (non-cryptographic)": "x",
    "Category:Heads of government of non-sovereign entities": "x",
    "Category:High-importance English non-league football articles": "x",
    "Category:High-importance Non-tropical storm articles": "x",
    "Category:Hockey Australia template using non-numeric ID": "x",
    "Category:Idioms from non-English cultures": "x",
    "Category:Infobox drug articles with non-default infobox title": "x",
    "Category:Infobox rugby biography with non-numeric numeric parameters": "x",
    "Category:Infobox U.S. county using a non-standard time zone": "x",
    "Category:Infobox U.S. county using a non-standard timezone": "x",
    "Category:International Emmy Award for Best Non-Scripted Entertainment winners": "x",
    "Category:Irish non-subscribing Presbyterian ministers": "x",
    "Category:Japan in non-Japanese culture": "x",
    "Category:Jctint template using non-numeric parameter values": "x",
    "Category:Law enforcement non-governmental organizations in the United States": "x",
    "Category:Leaders of the Non-Partisan Solidarity Union": "x",
    "Category:Lists by population (non-human)": "x",
    "Category:Lists of aircraft in non-standard formats": "x",
    "Category:Lists of non-sovereign nations": "x",
    "Category:Low-importance English non-league football articles": "x",
    "Category:Low-importance Non-tropical storm articles": "x",
    "Category:Metropolitan and non-metropolitan counties": "x",
    "Category:Mid-importance English non-league football articles": "x",
    "Category:Mid-importance Non-tropical storm articles": "x",
    "Category:Minor planet object redirects (non-primary)": "x",
    "Category:Monthly clean-up category (Articles with improper non-free content) counter": "x",
    "Category:Montreal Shamrocks (non-NHA) players": "x",
    "Category:Non-Aggression Pact (band) albums": "x",
    "Category:Non-aggression pacts": "x",
    "Category:Non-alcoholic drink logos": "x",
    "Category:Non-alcoholic drinks": "x",
    "Category:Non-alcoholic fatty liver disease": "x",
    "Category:Non-alcoholic mixed drinks": "x",
    "Category:Non-Aligned Movement people": "x",
    "Category:Non-Aligned Movement Summits": "x",
    "Category:Non-Aligned Movement": "x",
    "Category:Non-aligned Scouting organizations in Canada": "x",
    "Category:Non-aligned Scouting organizations in the United States": "x",
    "Category:Non-aligned Scouting organizations": "x",
    "Category:Non-alternating knots and links": "x",
    "Category:Non-Arab companions of the Prophet": "x",
    "Category:Non-Arabic-language mass media in Algeria": "x",
    "Category:Non-Arabic-language mass media in Egypt": "x",
    "Category:Non-Arabic-language mass media in Lebanon": "x",
    "Category:Non-Arabic-language mass media in Morocco": "x",
    "Category:Non-Arabic-language mass media in Tunisia": "x",
    "Category:Non-Arabic-language newspapers published in Algeria": "x",
    "Category:Non-Arabic-language newspapers published in Egypt": "x",
    "Category:Non-Arabic-language newspapers published in Lebanon": "x",
    "Category:Non-Arabic-language newspapers published in Morocco": "x",
    "Category:Non-Arabic-language newspapers published in Tunisia": "x",
    "Category:Non-articles using infobox website with unknown parameters": "x",
    "Category:Non-associative algebra": "x",
    "Category:Non-associative algebras": "x",
    "Category:Non-benzenoid aromatic carbocycles": "x",
    "Category:Non-British Royal Air Force personnel of World War II": "x",
    "Category:Non-cabinet ministers of Sri Lanka": "x",
    "Category:Non-canon Doctor Who episodes": "x",
    "Category:Non-cardinals elected pope": "x",
    "Category:Non-Chalcedonian Christians": "x",
    "Category:Non-Chalcedonianism": "x",
    "Category:Non-cinematic Western (genre) films": "x",
    "Category:Non-citizen suffrage": "x",
    "Category:Non-clerical religious clothing": "x",
    "Category:Non-coding DNA": "x",
    "Category:Non-coding RNA": "x",
    "Category:Non-combat internal explosions on warships": "x",
    "Category:Non-combat naval accidents of the United States": "x",
    "Category:Non-combat naval accidents": "x",
    "Category:Non-combatant evacuation operations": "x",
    "Category:Non-combatant military personnel of the American Civil War": "x",
    "Category:Non-combatant military personnel": "x",
    "Category:Non-commercial": "x",
    "Category:Non-commissioned air force personnel": "x",
    "Category:Non-commissioned army personnel": "x",
    "Category:Non-commissioned officers": "x",
    "Category:Non-commissioned personnel": "x",
    "Category:Non-conformist Sunni jurisprudence": "x",
    "Category:Non-conformists of the 1550s": "x",
    "Category:Non-conformists": "x",
    "Category:Non-cooperative games": "x",
    "Category:Non-coordinating anions": "x",
    "Category:Non-dairy yogurts": "x",
    "Category:Non-Darwinian evolution": "x",
    "Category:Non-deaf sign languages": "x",
    "Category:Non-denominational Evangelical churches in the United States": "x",
    "Category:Non-denominational Evangelical churches": "x",
    "Category:Non-denominational Evangelical multisite churches in the United States": "x",
    "Category:Non-denominational Evangelical multisite churches": "x",
    "Category:Non-denominational Evangelical unions": "x",
    "Category:Non-denominational Judaism": "x",
    "Category:Non-departmental public bodies of the Northern Ireland Executive": "x",
    "Category:Non-departmental public bodies of the United Kingdom government": "x",
    "Category:Non-diocesan Anglican bishops": "x",
    "Category:Non-Disney Mickey Mouse-media": "x",
    "Category:Non-dynastic kings of Macedonia (ancient kingdom)": "x",
    "Category:Non-dynastic pharaohs": "x",
    "Category:Non-empty disambiguation categories": "x",
    "Category:Non-English user warning templates": "x",
    "Category:Non-English welcome messages": "x",
    "Category:Non-English works based on the Encyclopædia Britannica": "x",
    "Category:Non-English-based programming languages": "x",
    "Category:Non-English-language broadcasting in the United States": "x",
    "Category:Non-English-language magazines published in the United Kingdom": "x",
    "Category:Non-English-language magazines published in the United States": "x",
    "Category:Non-English-language mass media in Alabama": "x",
    "Category:Non-English-language mass media in Arizona": "x",
    "Category:Non-English-language mass media in Arkansas": "x",
    "Category:Non-English-language mass media in California": "x",
    "Category:Non-English-language mass media in Colorado": "x",
    "Category:Non-English-language mass media in Connecticut": "x",
    "Category:Non-English-language mass media in Delaware": "x",
    "Category:Non-English-language mass media in Florida": "x",
    "Category:Non-English-language mass media in Georgia (U.S. state)": "x",
    "Category:Non-English-language mass media in Hawaii": "x",
    "Category:Non-English-language mass media in Illinois": "x",
    "Category:Non-English-language mass media in Indiana": "x",
    "Category:Non-English-language mass media in Iowa": "x",
    "Category:Non-English-language mass media in Kansas": "x",
    "Category:Non-English-language mass media in Kentucky": "x",
    "Category:Non-English-language mass media in Louisiana": "x",
    "Category:Non-English-language mass media in Maine": "x",
    "Category:Non-English-language mass media in Maryland": "x",
    "Category:Non-English-language mass media in Massachusetts": "x",
    "Category:Non-English-language mass media in Michigan": "x",
    "Category:Non-English-language mass media in Minnesota": "x",
    "Category:Non-English-language mass media in Missouri": "x",
    "Category:Non-English-language mass media in Nebraska": "x",
    "Category:Non-English-language mass media in Nevada": "x",
    "Category:Non-English-language mass media in New Jersey": "x",
    "Category:Non-English-language mass media in New Mexico": "x",
    "Category:Non-English-language mass media in New York (state)": "x",
    "Category:Non-English-language mass media in North Carolina": "x",
    "Category:Non-English-language mass media in North Dakota": "x",
    "Category:Non-English-language mass media in Ohio": "x",
    "Category:Non-English-language mass media in Oklahoma": "x",
    "Category:Non-English-language mass media in Oregon": "x",
    "Category:Non-English-language mass media in Pennsylvania": "x",
    "Category:Non-English-language mass media in Rhode Island": "x",
    "Category:Non-English-language mass media in South Carolina": "x",
    "Category:Non-English-language mass media in South Dakota": "x",
    "Category:Non-English-language mass media in Tennessee": "x",
    "Category:Non-English-language mass media in Texas": "x",
    "Category:Non-English-language mass media in the United Kingdom": "x",
    "Category:Non-English-language mass media in the United States by state": "x",
    "Category:Non-English-language mass media in the United States": "x",
    "Category:Non-English-language mass media in Utah": "x",
    "Category:Non-English-language mass media in Virginia": "x",
    "Category:Non-English-language mass media in Washington (state)": "x",
    "Category:Non-English-language mass media in Wisconsin": "x",
    "Category:Non-English-language newspapers published in Arizona": "x",
    "Category:Non-English-language newspapers published in Australia": "x",
    "Category:Non-English-language newspapers published in California": "x",
    "Category:Non-English-language newspapers published in Colorado": "x",
    "Category:Non-English-language newspapers published in Connecticut": "x",
    "Category:Non-English-language newspapers published in Florida": "x",
    "Category:Non-English-language newspapers published in Georgia (U.S. state)": "x",
    "Category:Non-English-language newspapers published in Illinois": "x",
    "Category:Non-English-language newspapers published in Iowa": "x",
    "Category:Non-English-language newspapers published in Kansas": "x",
    "Category:Non-English-language newspapers published in Louisiana": "x",
    "Category:Non-English-language newspapers published in Maine": "x",
    "Category:Non-English-language newspapers published in Maryland": "x",
    "Category:Non-English-language newspapers published in Massachusetts": "x",
    "Category:Non-English-language newspapers published in Michigan": "x",
    "Category:Non-English-language newspapers published in Minnesota": "x",
    "Category:Non-English-language newspapers published in Missouri": "x",
    "Category:Non-English-language newspapers published in Nebraska": "x",
    "Category:Non-English-language newspapers published in Nevada": "x",
    "Category:Non-English-language newspapers published in New Jersey": "x",
    "Category:Non-English-language newspapers published in New Mexico": "x",
    "Category:Non-English-language newspapers published in New York (state)": "x",
    "Category:Non-English-language newspapers published in North Carolina": "x",
    "Category:Non-English-language newspapers published in North Dakota": "x",
    "Category:Non-English-language newspapers published in Ohio": "x",
    "Category:Non-English-language newspapers published in Oregon": "x",
    "Category:Non-English-language newspapers published in Pennsylvania": "x",
    "Category:Non-English-language newspapers published in South Dakota": "x",
    "Category:Non-English-language newspapers published in Texas": "x",
    "Category:Non-English-language newspapers published in the United States by state": "x",
    "Category:Non-English-language newspapers published in the United States": "x",
    "Category:Non-English-language newspapers published in Washington (state)": "x",
    "Category:Non-English-language newspapers published in Wisconsin": "x",
    "Category:Non-English-language radio stations in Alabama": "x",
    "Category:Non-English-language radio stations in Arizona": "x",
    "Category:Non-English-language radio stations in Arkansas": "x",
    "Category:Non-English-language radio stations in California": "x",
    "Category:Non-English-language radio stations in Colorado": "x",
    "Category:Non-English-language radio stations in Connecticut": "x",
    "Category:Non-English-language radio stations in Delaware": "x",
    "Category:Non-English-language radio stations in Florida": "x",
    "Category:Non-English-language radio stations in Georgia (U.S. state)": "x",
    "Category:Non-English-language radio stations in Hawaii": "x",
    "Category:Non-English-language radio stations in Illinois": "x",
    "Category:Non-English-language radio stations in Indiana": "x",
    "Category:Non-English-language radio stations in Kansas": "x",
    "Category:Non-English-language radio stations in Kentucky": "x",
    "Category:Non-English-language radio stations in Louisiana": "x",
    "Category:Non-English-language radio stations in Maryland": "x",
    "Category:Non-English-language radio stations in Massachusetts": "x",
    "Category:Non-English-language radio stations in Minnesota": "x",
    "Category:Non-English-language radio stations in Missouri": "x",
    "Category:Non-English-language radio stations in New Jersey": "x",
    "Category:Non-English-language radio stations in New Mexico": "x",
    "Category:Non-English-language radio stations in New York (state)": "x",
    "Category:Non-English-language radio stations in North Carolina": "x",
    "Category:Non-English-language radio stations in Ohio": "x",
    "Category:Non-English-language radio stations in Oklahoma": "x",
    "Category:Non-English-language radio stations in Oregon": "x",
    "Category:Non-English-language radio stations in Pennsylvania": "x",
    "Category:Non-English-language radio stations in Rhode Island": "x",
    "Category:Non-English-language radio stations in South Carolina": "x",
    "Category:Non-English-language radio stations in Tennessee": "x",
    "Category:Non-English-language radio stations in Texas": "x",
    "Category:Non-English-language radio stations in the United States by state": "x",
    "Category:Non-English-language radio stations in Utah": "x",
    "Category:Non-English-language radio stations in Washington (state)": "x",
    "Category:Non-English-language radio stations in Wisconsin": "x",
    "Category:Non-English-language television stations in California": "x",
    "Category:Non-English-language television stations in Florida": "x",
    "Category:Non-Euclidean geometry": "x",
    "Category:Non-fatal shootings": "x",
    "Category:Non-ferrous metallurgical works in the United Kingdom": "x",
    "Category:Non-FIFA football competitions": "x",
    "Category:Non-food crop diseases": "x",
    "Category:Non-food crops": "x",
    "Category:Non-free Analog Science Fiction and Fact magazine covers": "x",
    "Category:Non-free architectural works": "x",
    "Category:Non-free audio samples by artist": "x",
    "Category:Non-free bandy logos": "x",
    "Category:Non-free Black Mask magazine covers": "x",
    "Category:Non-free character artwork": "x",
    "Category:Non-free computer icons": "x",
    "Category:Non-free destroyed architecture": "x",
    "Category:Non-free Disney logos": "x",
    "Category:Non-free Dragon magazine covers": "x",
    "Category:Non-free Dungeon magazine covers": "x",
    "Category:Non-free Entertainment Weekly magazine covers": "x",
    "Category:Non-free Esquire magazine covers": "x",
    "Category:Non-free Fantastic Universe magazine covers": "x",
    "Category:Non-free Far Eastern Economic Review magazine covers": "x",
    "Category:Non-free former or old logos": "x",
    "Category:Non-free Fortune magazine covers": "x",
    "Category:Non-free Galaxy Science Fiction magazine covers": "x",
    "Category:Non-free GQ magazine covers": "x",
    "Category:Non-free graffiti with NFUR stated": "x",
    "Category:Non-free graffiti": "x",
    "Category:Non-free Heavy Metal magazine covers": "x",
    "Category:Non-free Life magazine covers": "x",
    "Category:Non-free logos": "x",
    "Category:Non-free Maclean's magazine covers": "x",
    "Category:Non-free Mad magazine covers": "x",
    "Category:Non-free magazine covers by title": "x",
    "Category:Non-free magazine covers": "x",
    "Category:Non-free media with non-commercial and no derivative works licenses": "x",
    "Category:Non-free Men's Health magazine covers": "x",
    "Category:Non-free music samples": "x",
    "Category:Non-free musical interface audio": "x",
    "Category:Non-free Mystery Scene magazine covers": "x",
    "Category:Non-free National Geographic magazine covers": "x",
    "Category:Non-free newspaper covers": "x",
    "Category:Non-free Newsweek magazine covers": "x",
    "Category:Non-free Penthouse magazine covers": "x",
    "Category:Non-free People magazine covers": "x",
    "Category:Non-free pictures of tornadoes": "x",
    "Category:Non-free Playbill magazine covers": "x",
    "Category:Non-free Playboy magazine covers": "x",
    "Category:Non-free Popular Electronics magazine covers": "x",
    "Category:Non-free posters": "x",
    "Category:Non-free proposed architecture": "x",
    "Category:Non-free Radio Times magazine covers": "x",
    "Category:Non-free rationale as na": "x",
    "Category:Non-free Redbook magazine covers": "x",
    "Category:Non-free Rolling Stone magazine covers": "x",
    "Category:Non-free school logos": "x",
    "Category:Non-free screenshots": "x",
    "Category:Non-free sheet music": "x",
    "Category:Non-free Sports Illustrated magazine covers": "x",
    "Category:Non-free Startling Stories magazine covers": "x",
    "Category:Non-free SVGs requiring file size reduction": "x",
    "Category:Non-free symbols": "x",
    "Category:Non-free The Atlantic magazine covers": "x",
    "Category:Non-free The Economist magazine covers": "x",
    "Category:Non-free The Magazine of Fantasy & Science Fiction magazine covers": "x",
    "Category:Non-free The New York Times Magazine magazine covers": "x",
    "Category:Non-free The New Yorker magazine covers": "x",
    "Category:Non-free The Saturday Evening Post magazine covers": "x",
    "Category:Non-free The Shadow magazine covers": "x",
    "Category:Non-free The Strand Magazine magazine covers": "x",
    "Category:Non-free Time magazine covers": "x",
    "Category:Non-free TV Guide magazine covers": "x",
    "Category:Non-free university technical college logos": "x",
    "Category:Non-free Unknown magazine covers": "x",
    "Category:Non-free use rationale templates": "x",
    "Category:Non-free Vanity Fair magazine covers": "x",
    "Category:Non-free Venture Science Fiction magazine covers": "x",
    "Category:Non-free video samples": "x",
    "Category:Non-free Vogue magazine covers": "x",
    "Category:Non-free Wired magazine covers": "x",
    "Category:Non-freeway toll roads": "x",
    "Category:Non-French-language magazines published in France": "x",
    "Category:Non-French-language newspapers published in France": "x",
    "Category:Non-fungible tokens": "x",
    "Category:Non-games": "x",
    "Category:Non-German units of the Wehrmacht": "x",
    "Category:Non-governmental academies based in Russia": "x",
    "Category:Non-governmental elections": "x",
    "Category:Non-governmental organizations": "x",
    "Category:Non-hallucinogenic 5-HT2A receptor agonists": "x",
    "Category:Non-Hebrew-language mass media in Israel": "x",
    "Category:Non-Hebrew-language newspapers published in Israel": "x",
    "Category:Non-Hodgkin lymphoma": "x",
    "Category:Non-human celestial navigation": "x",
    "Category:Non-human primate astronauts of the American space program": "x",
    "Category:Non-hunting areas of Thailand": "x",
    "Category:Non-idiophonic interruptive free aerophones": "x",
    "Category:Non-impact printing": "x",
    "Category:Non-Inscrits MEPs": "x",
    "Category:Non-institutional bodies of the European Union": "x",
    "Category:Non-international England cricketers": "x",
    "Category:Non-invented electrical components": "x",
    "Category:Non-ionic surfactants": "x",
    "Category:Non-Islamic Islam studies literature": "x",
    "Category:Non-ISO Language user templates": "x",
    "Category:Non-jamming knots": "x",
    "Category:Non-League football": "x",
    "Category:Non-lethal firearms of Russia": "x",
    "Category:Non-lethal firearms": "x",
    "Category:Non-lethal projectiles": "x",
    "Category:Non-lethal weapons": "x",
    "Category:Non-mainspace quotation templates": "x",
    "Category:Non-metropolitan district councils of England": "x",
    "Category:Non-military counterinsurgency organizations": "x",
    "Category:Non-military counterterrorist organizations": "x",
    "Category:Non-military rank insignia": "x",
    "Category:Non-ministerial departments of the Government of the United Kingdom": "x",
    "Category:Non-ministerial departments of the Scottish Government": "x",
    "Category:Non-ministerial departments of the Welsh Government": "x",
    "Category:Non-native Tamil poets": "x",
    "Category:Non-Neutral Independents politicians": "x",
    "Category:Non-Newtonian fluids": "x",
    "Category:Non-nucleophilic bases": "x",
    "Category:Non-nucleoside reverse transcriptase inhibitors": "x",
    "Category:Non-operating common carrier freight railroads in the United States": "x",
    "Category:Non-oxide glasses": "x",
    "Category:Non-Pama-Nyungan languages": "x",
    "Category:Non-parametric statistics": "x",
    "Category:Non-Partisan Association councillors": "x",
    "Category:Non-partisan elections": "x",
    "Category:Non-Partisan Solidarity Union Members of the Legislative Yuan": "x",
    "Category:Non-Partisan Solidarity Union politicians": "x",
    "Category:Non-Partisan Solidarity Union": "x",
    "Category:Non-passenger multiple units": "x",
    "Category:Non-periodic comets": "x",
    "Category:Non-petroleum based lubricants": "x",
    "Category:Non-plant crops": "x",
    "Category:Non-practicing entities": "x",
    "Category:Non-profit academic publishers": "x",
    "Category:Non-profit architecture organizations based in the United States": "x",
    "Category:Non-profit corporations": "x",
    "Category:Non-profit executives": "x",
    "Category:Non-profit institutes based in the United States": "x",
    "Category:Non-profit microfinance organizations based in North America": "x",
    "Category:Non-profit microfinance organizations": "x",
    "Category:Non-profit organisations based in Victoria (state)": "x",
    "Category:Non-profit organizations based in the New Orleans metropolitan area": "x",
    "Category:Non-profit organizations listed in Russia as foreign agents": "x",
    "Category:Non-profit youth organizations based in the United States": "x",
    "Category:Non-proliferation treaties": "x",
    "Category:Non-proportional multi-winner electoral systems": "x",
    "Category:Non-protein ion channel toxins": "x",
    "Category:Non-proteinogenic amino acids": "x",
    "Category:Non-public museums in the United States": "x",
    "Category:Non-public museums": "x",
    "Category:Non-pulmonic consonants": "x",
    "Category:Non-railway predecessors of railway companies": "x",
    "Category:Non-receptor tyrosine kinase inhibitors": "x",
    "Category:Non-registered political parties in Romania": "x",
    "Category:Non-religious Israeli communities": "x",
    "Category:Non-religious Israeli settlements": "x",
    "Category:Non-renewable resources": "x",
    "Category:Non-rocket spacelaunch": "x",
    "Category:Non-Romanian-language newspapers published in Romania": "x",
    "Category:Non-School institutions of the University of Cambridge": "x",
    "Category:Non-sexuality": "x",
    "Category:Non-SI metric units": "x",
    "Category:Non-sovereign monarchy": "x",
    "Category:Non-Spanish classical guitars": "x",
    "Category:Non-standard discography infoboxes": "x",
    "Category:Non-standard positional numeral systems": "x",
    "Category:Non-Status Indians": "x",
    "Category:Non-stoichiometric compounds": "x",
    "Category:Non-store retailing": "x",
    "Category:Non-subject-matter-related article-talk header templates": "x",
    "Category:Non-Summit": "x",
    "Category:Non-tariff barriers to trade": "x",
    "Category:Non-terminally differentiated (blast) cells": "x",
    "Category:Non-theatrical film production companies": "x",
    "Category:Non-Thoroughbred racehorses": "x",
    "Category:Non-timber forest products": "x",
    "Category:Non-tobacco nicotine products": "x",
    "Category:Non-tonal languages in tonal families": "x",
    "Category:Non-tricolorable knots and links": "x",
    "Category:Non-tropical storm articles by importance": "x",
    "Category:Non-tropical storm articles by quality": "x",
    "Category:Non-tropical storms articles needing expert attention": "x",
    "Category:Non-tropical storms templates": "x",
    "Category:Non-U.S. alumni of the Command and General Staff College": "x",
    "Category:Non-uniform random numbers": "x",
    "Category:North America territory (non-sovereign) templates": "x",
    "Category:Observances on non-Gregorian calendars": "x",
    "Category:Oceania territory (non-sovereign) templates": "x",
    "Category:OlyCatMenWomen on non-category page": "x",
    "Category:OlyCatMenWomen on non-Olympic page": "x",
    "Category:One Piece non-free media": "x",
    "Category:Open non-builders": "x",
    "Category:People from Thonon-les-Bains": "x",
    "Category:People from Tournon-sur-Rhône": "x",
    "Category:People with non-domiciled status in the United Kingdom": "x",
    "Category:Personnel of the Non-Combatant Corps": "x",
    "Category:Probability distributions with non-finite variance": "x",
    "Category:Regulation of non-governmental organizations": "x",
    "Category:Restricted titles (non-leading number sign)": "x",
    "Category:Secretaries-general of the Non-Aligned Movement": "x",
    "Category:Senescence in non-human organisms": "x",
    "Category:Ships sunk by non-combat internal explosions": "x",
    "Category:Singaporean Non-constituency Members of Parliament": "x",
    "Category:Snooker non-ranking competitions": "x",
    "Category:Soccerbase template using non-numeric ID": "x",
    "Category:Song articles with infoboxes with non-standard extra track listings": "x",
    "Category:Songs written by Marla Cannon-Goodman": "x",
    "Category:South America territory (non-sovereign) templates": "x",
    "Category:sports-people from Thonon-les-Bains": "x",
    "Category:Sri Lankan non-commissioned personnel": "x",
    "Category:SS non-commissioned officers": "x",
    "Category:Swedish non-commissioned personnel": "x",
    "Category:Tamil scholars of non-Tamil background": "x",
    "Category:Television non-maintenance tracking categories": "x",
    "Category:Theories of non-biological ageing": "x",
    "Category:Timelines of historically non-Chinese states in China": "x",
    "Category:Tonal languages in non-tonal families": "x",
    "Category:Top-importance English non-league football articles": "x",
    "Category:Top-importance Non-tropical storm articles": "x",
    "Category:Tribute albums to non-musicians": "x",
    "Category:Turkish non-commissioned personnel": "x",
    "Category:Unassessed English non-league football articles": "x",
    "Category:Unassessed Non-tropical storm articles": "x",
    "Category:Union army non-commissioned officers": "x",
    "Category:United States Air Force non-commissioned officers": "x",
    "Category:United States Army Air Forces non-commissioned officers": "x",
    "Category:United States Army non-commissioned officers": "x",
    "Category:United States Coast Guard non-commissioned officers": "x",
    "Category:United States Marine Corps non-commissioned officers": "x",
    "Category:United States Navy non-commissioned officers": "x",
    "Category:Unknown-importance English non-league football articles": "x",
    "Category:Unknown-importance Non-tropical storm articles": "x",
    "Category:Usage of portal image for non-existent portal": "x",
    "Category:Video games featuring non-playable protagonists": "x",
    "Category:Violent non-state actor incidents by country": "x",
    "Category:Violent non-state actor incidents in Africa": "x",
    "Category:Violent non-state actor incidents in Asia": "x",
    "Category:Violent non-state actor incidents in Europe": "x",
    "Category:Violent non-state actor incidents in Italy": "x",
    "Category:Violent non-state actor incidents in Mexico": "x",
    "Category:Violent non-state actor incidents in Nigeria": "x",
    "Category:Violent non-state actor incidents in North America": "x",
    "Category:Violent non-state actor incidents in South America": "x",
    "Category:Violent non-state actor incidents in the United Kingdom": "x",
    "Category:Violent non-state actor incidents in the United States": "x",
    "Category:Violent non-state actor incidents": "x",
    "Category:Violent non-state actors": "x",
    "Category:Winter Olympics by year category navigation — non-matching parameters": "x",
    "Category:Women heads of government of non-sovereign entities": "x",
}

non_fiction_empty = {
    "Category:New Zealand non-fiction literary awards": "x",
    "Category:New Zealand women non-fiction writers": "x",
    "Category:Abortion in non-fiction": "x",
    "Category:American non-fiction children's writers": "x",
    "Category:American non-fiction literary awards": "x",
    "Category:American non-fiction outdoors writers": "x",
    "Category:Arabic non-fiction books": "x",
    "Category:Arabic non-fiction literature": "x",
    "Category:Aromanian non-fiction writers": "x",
    "Category:Australian non-fiction book awards": "x",
    "Category:Bisexual non-fiction books": "x",
    "Category:Bosnian War in non-fiction": "x",
    "Category:British non-fiction literary awards": "x",
    "Category:British non-fiction outdoors writers": "x",
    "Category:Canadian non-fiction literary awards": "x",
    "Category:Children's non-fiction books": "x",
    "Category:Children's non-fiction writers": "x",
    "Category:Collaborative non-fiction books": "x",
    "Category:Collaborative non-fiction": "x",
    "Category:Dutch-language non-fiction books": "x",
    "Category:English non-fiction outdoors writers": "x",
    "Category:English-language non-fiction books": "x",
    "Category:Environmental non-fiction books": "x",
    "Category:French non-fiction outdoors writers": "x",
    "Category:French-language Canadian non-fiction writers": "x",
    "Category:French-language non-fiction books": "x",
    "Category:Gay non-fiction books": "x",
    "Category:German non-fiction literary awards": "x",
    "Category:German-language non-fiction books": "x",
    "Category:Governor General's Award–winning non-fiction books": "x",
    "Category:Governor General's Award–winning non-fiction writers": "x",
    "Category:Hugo Award for Best Non-Fiction Book–winning works": "x",
    "Category:Intersex non-fiction": "x",
    "Category:LDS non-fiction": "x",
    "Category:Lesbian non-fiction books": "x",
    "Category:LGBTQ non-fiction books": "x",
    "Category:Non-fiction book stub templates": "x",
    "Category:Non-fiction books about American prostitution": "x",
    "Category:Non-fiction books about American slavery": "x",
    "Category:Non-fiction books about artificial intelligence": "x",
    "Category:Non-fiction books about autism": "x",
    "Category:Non-fiction books about British prostitution": "x",
    "Category:Non-fiction books about Canadian prostitution": "x",
    "Category:Non-fiction books about cannibalism": "x",
    "Category:Non-fiction books about Colombian drug cartels": "x",
    "Category:Non-fiction books about consumerism": "x",
    "Category:Non-fiction books about contract killers": "x",
    "Category:Non-fiction books about elephants": "x",
    "Category:Non-fiction books about gangsters": "x",
    "Category:Non-fiction books about geisha": "x",
    "Category:Non-fiction books about guerrilla warfare": "x",
    "Category:Non-fiction books about horror": "x",
    "Category:Non-fiction books about Italian-American organized crime": "x",
    "Category:Non-fiction books about jihadism": "x",
    "Category:Non-fiction books about MDMA": "x",
    "Category:Non-fiction books about Mexican drug cartels": "x",
    "Category:Non-fiction books about mobsters": "x",
    "Category:Non-fiction books about musical theatre": "x",
    "Category:Non-fiction books about Native Americans": "x",
    "Category:Non-fiction books about outlaws of the American Old West": "x",
    "Category:Non-fiction books about piracy": "x",
    "Category:Non-fiction books about prostitution": "x",
    "Category:Non-fiction books about public relations": "x",
    "Category:Non-fiction books about same-sex sexuality": "x",
    "Category:Non-fiction books about Soviet repression": "x",
    "Category:Non-fiction books about submarine warfare": "x",
    "Category:Non-fiction books about the 1550 Bangladesh genocide": "x",
    "Category:Non-fiction books about the Armenian genocide": "x",
    "Category:Non-fiction books about the Central Intelligence Agency": "x",
    "Category:Non-fiction books about the French Connection": "x",
    "Category:Non-fiction books about the Great Depression": "x",
    "Category:Non-fiction books about the Great Game": "x",
    "Category:Non-fiction books about the Great Recession": "x",
    "Category:Non-fiction books about the Holodomor": "x",
    "Category:Non-fiction books about the illegal drug trade": "x",
    "Category:Non-fiction books about The Simpsons": "x",
    "Category:Non-fiction books about the subprime mortgage crisis": "x",
    "Category:Non-fiction books about the United States Marine Corps": "x",
    "Category:Non-fiction books about United States intelligence agencies": "x",
    "Category:Non-fiction books by discipline": "x",
    "Category:Non-fiction books by Norman Mailer": "x",
    "Category:Non-fiction books by William Boyd (writer)": "x",
    "Category:Non-fiction by Walter Scott": "x",
    "Category:Non-fiction Cyberpunk media": "x",
    "Category:Non-fiction genres": "x",
    "Category:Non-fiction literary awards": "x",
    "Category:Non-fiction literature about abortion": "x",
    "Category:Non-fiction literature by country": "x",
    "Category:Non-fiction literature from Georgia (country)": "x",
    "Category:Non-fiction literature from Northern Ireland": "x",
    "Category:Non-fiction literature": "x",
    "Category:Non-fiction novels of investigative journalism": "x",
    "Category:Non-fiction outdoors writers": "x",
    "Category:Non-fiction works about the Bosnian genocide": "x",
    "Category:Non-fiction works about the United States Marine Corps": "x",
    "Category:Non-fiction works about the United States military": "x",
    "Category:Non-fiction works by creator": "x",
    "Category:Non-fiction works by Elizabeth Gaskell": "x",
    "Category:Non-fiction writers about the French Connection": "x",
    "Category:Non-fiction": "x",
    "Category:Obsessive–compulsive disorder in non-fiction literature": "x",
    "Category:Siege of Sarajevo in non-fiction": "x",
    "Category:Spanish-language non-fiction books": "x",
    "Category:Sámi non-fiction writers": "x",
    "Category:Transgender non-fiction books": "x",
    "Category:Urdu-language non-fiction literature": "x",
    "Category:Writers by non-fiction genre": "x",
    "Category:Writers by non-fiction subject area": "",
}

to_test = [
    ("test_data_empty_result", data_empty_result),
    ("test_non_fiction_empty", non_fiction_empty),
]


@pytest.mark.parametrize("category, expected", test_1.items(), ids=test_1.keys())
@pytest.mark.fast
def test_data_empty_result(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", non_fiction_empty.items(), ids=non_fiction_empty.keys())
@pytest.mark.skip2
def test_non_fiction_empty(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.skip2
def test_non_dump(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
