"""Comprehensive pytest suite for move_years module."""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.fix.mv_years import move_by_in, move_years_first

move_years_first_data = {
    "عقد 1910 في بابوا غينيا الجديدة": "بابوا غينيا الجديدة في عقد 1910",
    "2016 في بابوا غينيا الجديدة حسب الشهر": "بابوا غينيا الجديدة في 2016 حسب الشهر",
    "1330 في كرة قدم دولية للرجال": "كرة قدم دولية للرجال في 1330",
    "2023 في أقاليم ما وراء البحار البريطانية": "أقاليم ما وراء البحار البريطانية في 2023",
    "عقد 1880 في الأفلام حسب البلد": "الأفلام في عقد 1880 حسب البلد",
    "عقد 1880 في أفلام حسب البلد": "أفلام في عقد 1880 حسب البلد",
    "1994–95 في اتحاد الرجبي الأوروبي": "اتحاد الرجبي الأوروبي في 1994–95",
    "1994–95 في اتحاد الرجبي الأوروبي حسب البلد": "اتحاد الرجبي الأوروبي في 1994–95 حسب البلد",
    "عقد 2000 في السينما الأمريكية": "السينما الأمريكية في عقد 2000",
    "2006 في رياضة أيرلندية شمالية": "رياضة أيرلندية شمالية في 2006",
    "2006 في رياضة كورية شمالية": "رياضة كورية شمالية في 2006",
    "2017 في كرة القدم الإماراتية": "كرة القدم الإماراتية في 2017",
    "الألفية 10 في الخيال": "الخيال في الألفية 10",
    "عقد 1270 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1270",
    "عقد 2000 في الولايات المتحدة حسب الولاية": "الولايات المتحدة في عقد 2000 حسب الولاية",
    "القرن 21 في التشيك": "التشيك في القرن 21",
    "القرن 21 في قطر": "قطر في القرن 21",
    "1433 في بوتان": "بوتان في 1433",
    "1448 في البرتغال": "البرتغال في 1448",
    "القرن 10 في آسيا": "آسيا في القرن 10",
    "القرن 10 في آيسلندا": "آيسلندا في القرن 10",
    "القرن 10 في أرمينيا": "أرمينيا في القرن 10",
    "القرن 10 في ألمانيا": "ألمانيا في القرن 10",
    "القرن 10 في أمريكا الجنوبية": "أمريكا الجنوبية في القرن 10",
    "القرن 10 في أمريكا الشمالية": "أمريكا الشمالية في القرن 10",
    "القرن 10 في أوروبا": "أوروبا في القرن 10",
    "القرن 10 في أوقيانوسيا": "أوقيانوسيا في القرن 10",
    "القرن 10 في أوكرانيا": "أوكرانيا في القرن 10",
    "القرن 10 في أيرلندا": "أيرلندا في القرن 10",
    "القرن 10 في إسبانيا": "إسبانيا في القرن 10",
    "القرن 10 في إسكتلندا": "إسكتلندا في القرن 10",
    "القرن 10 في إفريقيا": "إفريقيا في القرن 10",
    "القرن 10 في إنجلترا": "إنجلترا في القرن 10",
    "القرن 10 في إندونيسيا": "إندونيسيا في القرن 10",
    "القرن 10 في إيران": "إيران في القرن 10",
    "القرن 10 في إيطاليا": "إيطاليا في القرن 10",
    "القرن 10 في الأندلس": "الأندلس في القرن 10",
    "القرن 10 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في القرن 10",
    "القرن 10 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في القرن 10",
    "القرن 10 في البرتغال": "البرتغال في القرن 10",
    "القرن 10 في التاريخ الاقتصادي": "التاريخ الاقتصادي في القرن 10",
    "القرن 10 في التبت": "التبت في القرن 10",
    "القرن 10 في الدنمارك": "الدنمارك في القرن 10",
    "القرن 10 في الدولة البابوية": "الدولة البابوية في القرن 10",
    "القرن 10 في الدولة العباسية": "الدولة العباسية في القرن 10",
    "القرن 10 في الدولة الفاطمية": "الدولة الفاطمية في القرن 10",
    "القرن 10 في السويد": "السويد في القرن 10",
    "القرن 10 في الشرق الأوسط": "الشرق الأوسط في القرن 10",
    "القرن 10 في الصين": "الصين في القرن 10",
    "القرن 10 في الطب": "الطب في القرن 10",
    "القرن 10 في العراق": "العراق في القرن 10",
    "القرن 10 في الفنون": "الفنون في القرن 10",
    "القرن 10 في المجر": "المجر في القرن 10",
    "القرن 10 في المغرب": "المغرب في القرن 10",
    "القرن 10 في النرويج": "النرويج في القرن 10",
    "القرن 10 في الهند": "الهند في القرن 10",
    "القرن 10 في اليابان": "اليابان في القرن 10",
    "القرن 10 في اليمن": "اليمن في القرن 10",
    "القرن 10 في اليونان": "اليونان في القرن 10",
    "القرن 10 في بريطانيا العظمى": "بريطانيا العظمى في القرن 10",
    "القرن 10 في بلجيكا": "بلجيكا في القرن 10",
    "القرن 10 في بلغاريا": "بلغاريا في القرن 10",
    "القرن 10 في بورما": "بورما في القرن 10",
    "القرن 10 في بولندا": "بولندا في القرن 10",
    "القرن 10 في بوهيميا": "بوهيميا في القرن 10",
    "القرن 10 في تايلاند": "تايلاند في القرن 10",
    "القرن 10 في تركيا": "تركيا في القرن 10",
    "القرن 10 في تونغا": "تونغا في القرن 10",
    "القرن 10 في جرينلاند": "جرينلاند في القرن 10",
    "القرن 10 في جمهورية البندقية": "جمهورية البندقية في القرن 10",
    "القرن 10 في جنوب شرق آسيا": "جنوب شرق آسيا في القرن 10",
    "القرن 10 في جورجيا": "جورجيا في القرن 10",
    "القرن 10 في روسيا": "روسيا في القرن 10",
    "القرن 10 في رومانيا": "رومانيا في القرن 10",
    "القرن 10 في سريلانكا": "سريلانكا في القرن 10",
    "القرن 10 في سكونا (السويد)": "سكونا (السويد) في القرن 10",
    "القرن 10 في سوريا": "سوريا في القرن 10",
    "القرن 10 في صربيا": "صربيا في القرن 10",
    "القرن 10 في فرنسا": "فرنسا في القرن 10",
    "القرن 10 في فيتنام": "فيتنام في القرن 10",
    "القرن 10 في كرواتيا": "كرواتيا في القرن 10",
    "القرن 10 في كمبوديا": "كمبوديا في القرن 10",
    "القرن 10 في كوريا": "كوريا في القرن 10",
    "القرن 10 في كييف روس": "كييف روس في القرن 10",
    "القرن 10 في مايا": "مايا في القرن 10",
    "القرن 10 في مصر": "مصر في القرن 10",
    "القرن 10 في مملكة الفرنجة الشرقيين": "مملكة الفرنجة الشرقيين في القرن 10",
    "القرن 10 في مملكة الفرنجة الغربيين": "مملكة الفرنجة الغربيين في القرن 10",
    "القرن 10 في مملكة ليون": "مملكة ليون في القرن 10",
    "القرن 10 في منغوليا": "منغوليا في القرن 10",
    "القرن 10 في نيبال": "نيبال في القرن 10",
    "القرن 10 في ويلز": "ويلز في القرن 10",
    "القرن 10 ق م في آشور": "آشور في القرن 10 ق م",
    "القرن 10 ق م في الصين": "الصين في القرن 10 ق م",
    "القرن 12 في اليمن": "اليمن في القرن 12",
    "القرن 12 في اليونان": "اليونان في القرن 12",
    "القرن 12 في بريطانيا العظمى": "بريطانيا العظمى في القرن 12",
    "القرن 12 في بلجيكا": "بلجيكا في القرن 12",
    "القرن 12 في بلغاريا": "بلغاريا في القرن 12",
    "القرن 12 في بورما": "بورما في القرن 12",
    "القرن 12 في بولندا": "بولندا في القرن 12",
    "القرن 12 في بوهيميا": "بوهيميا في القرن 12",
    "القرن 12 في تايلاند": "تايلاند في القرن 12",
    "القرن 12 في تركيا": "تركيا في القرن 12",
    "القرن 12 في جزيرة مان": "جزيرة مان في القرن 12",
    "القرن 12 في جمهورية البندقية": "جمهورية البندقية في القرن 12",
    "القرن 12 في جمهورية جنوة": "جمهورية جنوة في القرن 12",
    "القرن 12 في جنوب شرق آسيا": "جنوب شرق آسيا في القرن 12",
    "القرن 12 في جورجيا": "جورجيا في القرن 12",
    "القرن 12 في روسيا": "روسيا في القرن 12",
    "القرن 12 في رومانيا": "رومانيا في القرن 12",
    "القرن 12 في سريلانكا": "سريلانكا في القرن 12",
    "القرن 12 في سكونا (السويد)": "سكونا (السويد) في القرن 12",
    "القرن 12 في سلاجقة الروم": "سلاجقة الروم في القرن 12",
    "القرن 12 في سوريا": "سوريا في القرن 12",
    "القرن 12 في صربيا": "صربيا في القرن 12",
    "القرن 12 في فنلندا": "فنلندا في القرن 12",
    "القرن 12 في فيتنام": "فيتنام في القرن 12",
    "القرن 12 في قبرص": "قبرص في القرن 12",
    "القرن 12 في كرواتيا": "كرواتيا في القرن 12",
    "القرن 12 في كمبوديا": "كمبوديا في القرن 12",
    "القرن 12 في كوريا": "كوريا في القرن 12",
    "القرن 12 في كييف روس": "كييف روس في القرن 12",
    "القرن 12 في لندن": "لندن في القرن 12",
    "القرن 12 في مالطا": "مالطا في القرن 12",
    "القرن 12 في ماليزيا": "ماليزيا في القرن 12",
    "القرن 12 في مايا": "مايا في القرن 12",
    "القرن 12 في مصر": "مصر في القرن 12",
    "القرن 12 في مملكة جورجيا": "مملكة جورجيا في القرن 12",
    "القرن 12 في مملكة صقلية": "مملكة صقلية في القرن 12",
    "القرن 12 في مملكة ليون": "مملكة ليون في القرن 12",
    "القرن 12 في أرغون": "أرغون في القرن 12",
    "القرن 12 في منغوليا": "منغوليا في القرن 12",
    "القرن 12 في نيبال": "نيبال في القرن 12",
    "القرن 12 في نيجيريا": "نيجيريا في القرن 12",
    "القرن 12 في هولندا": "هولندا في القرن 12",
    "القرن 12 في يورك": "يورك في القرن 12",
    "القرن 12 في يوركشاير": "يوركشاير في القرن 12",
    "القرن 12 ق م في الصين": "الصين في القرن 12 ق م",
    "القرن 12 ق م في اليونان": "اليونان في القرن 12 ق م",
    "القرن 12 ق م في مصر": "مصر في القرن 12 ق م",
    "القرن 13 في أندورا": "أندورا في القرن 13",
    "القرن 13 في قبرص": "قبرص في القرن 13",
    "القرن 13 في كتالونيا": "كتالونيا في القرن 13",
    "عقد 0 في الإمبراطورية الرومانية": "الإمبراطورية الرومانية في عقد 0",
    "عقد 0 ق م في الإمبراطورية الرومانية": "الإمبراطورية الرومانية في عقد 0 ق م",
    "عقد 10 في الإمبراطورية الرومانية": "الإمبراطورية الرومانية في عقد 10",
    "عقد 10 ق م في الإمبراطورية الرومانية": "الإمبراطورية الرومانية في عقد 10 ق م",
    "عقد 100 في الإمبراطورية الرومانية": "الإمبراطورية الرومانية في عقد 100",
    "عقد 1000 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1000",
    "عقد 1000 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1000",
    "عقد 1000 في الفنون": "الفنون في عقد 1000",
    "عقد 1000 في اليابان": "اليابان في عقد 1000",
    "عقد 1010 في فرنسا": "فرنسا في عقد 1010",
    "عقد 1020 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1020",
    "عقد 1020 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1020",
    "عقد 1020 في الفنون": "الفنون في عقد 1020",
    "عقد 1020 في اليابان": "اليابان في عقد 1020",
    "عقد 1020 في فرنسا": "فرنسا في عقد 1020",
    "عقد 1030 في آسيا": "آسيا في عقد 1030",
    "عقد 1030 في أوروبا": "أوروبا في عقد 1030",
    "عقد 1030 في إنجلترا": "إنجلترا في عقد 1030",
    "عقد 1030 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1030",
    "عقد 1030 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1030",
    "عقد 1030 في الفنون": "الفنون في عقد 1030",
    "عقد 1030 في اليابان": "اليابان في عقد 1030",
    "عقد 1030 في فرنسا": "فرنسا في عقد 1030",
    "عقد 1050 في آسيا": "آسيا في عقد 1050",
    "عقد 1050 في إسكتلندا": "إسكتلندا في عقد 1050",
    "عقد 1050 في إنجلترا": "إنجلترا في عقد 1050",
    "عقد 1050 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1050",
    "عقد 1050 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1050",
    "عقد 1050 في الفنون": "الفنون في عقد 1050",
    "عقد 1050 في اليابان": "اليابان في عقد 1050",
    "عقد 1050 في فرنسا": "فرنسا في عقد 1050",
    "عقد 1070 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1070",
    "عقد 1070 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1070",
    "عقد 1070 في الفنون": "الفنون في عقد 1070",
    "عقد 1070 في اليابان": "اليابان في عقد 1070",
    "عقد 1070 في فرنسا": "فرنسا في عقد 1070",
    "عقد 1080 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1080",
    "عقد 1080 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1080",
    "عقد 1080 في الفنون": "الفنون في عقد 1080",
    "عقد 1080 في اليابان": "اليابان في عقد 1080",
    "عقد 1080 في فرنسا": "فرنسا في عقد 1080",
    "عقد 1090 في إسكتلندا": "إسكتلندا في عقد 1090",
    "عقد 1090 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1090",
    "عقد 1090 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1090",
    "عقد 1090 في الفنون": "الفنون في عقد 1090",
    "عقد 1090 في اليابان": "اليابان في عقد 1090",
    "عقد 1090 في فرنسا": "فرنسا في عقد 1090",
    "عقد 1090 في مملكة القدس": "مملكة القدس في عقد 1090",
    "عقد 1410 في البرتغال": "البرتغال في عقد 1410",
    "عقد 1410 في ويلز": "ويلز في عقد 1410",
    "عقد 1420 في أمريكا الشمالية": "أمريكا الشمالية في عقد 1420",
    "عقد 1420 في أيرلندا": "أيرلندا في عقد 1420",
    "عقد 1420 في الأراضي المنخفضة البورغندية": "الأراضي المنخفضة البورغندية في عقد 1420",
    "عقد 1420 في الإمبراطورية البيزنطية": "الإمبراطورية البيزنطية في عقد 1420",
    "عقد 1420 في الإمبراطورية الرومانية المقدسة": "الإمبراطورية الرومانية المقدسة في عقد 1420",
    "عقد 1420 في الدنمارك": "الدنمارك في عقد 1420",
    "عقد 1420 في الدولة العثمانية": "الدولة العثمانية في عقد 1420",
    "عقد 1420 في الشرق الأوسط": "الشرق الأوسط في عقد 1420",
    "عقد 1420 في اليابان": "اليابان في عقد 1420",
    "عقد 1420 في فرنسا": "فرنسا في عقد 1420",
    "عقد 1430 في أيرلندا": "أيرلندا في عقد 1430",
    "عقد 1430 في الأراضي المنخفضة البورغندية": "الأراضي المنخفضة البورغندية في عقد 1430",
    "عقد 1430 في الدنمارك": "الدنمارك في عقد 1430",
    "عقد 1430 في بوتان": "بوتان في عقد 1430",
}
move_by_in_data = {
    "أمريكيون حسب المهنة في القرن 20": "أمريكيون في القرن 20 حسب المهنة",
    "ملكيون حسب البلد في القرن 20": "ملكيون في القرن 20 حسب البلد",
    "ممثلون حسب الدين في القرن 19": "ممثلون في القرن 19 حسب الدين",
    "أشخاص حسب الدين في القرن 19": "أشخاص في القرن 19 حسب الدين",
    "كتاب غير روائيين حسب الجنسية في القرن 20": "كتاب غير روائيين في القرن 20 حسب الجنسية",
    "موسيقيون حسب الآلة من أيرلندا الشمالية في القرن 20": "موسيقيون في القرن 20 حسب الآلة من أيرلندا الشمالية",
    "آسيويون حسب الجنسية في القرن 10": "آسيويون في القرن 10 حسب الجنسية",
    "آسيويون حسب الجنسية في القرن 11": "آسيويون في القرن 11 حسب الجنسية",
    "آسيويون حسب الجنسية في القرن 12": "آسيويون في القرن 12 حسب الجنسية",
    "أساقفة حسب الجنسية في القرن 10": "أساقفة في القرن 10 حسب الجنسية",
    "أساقفة حسب الجنسية في القرن 11": "أساقفة في القرن 11 حسب الجنسية",
    "أساقفة حسب الجنسية في القرن 12": "أساقفة في القرن 12 حسب الجنسية",
    "أساقفة كاثوليك رومان حسب الجنسية في القرن 11": "أساقفة كاثوليك رومان في القرن 11 حسب الجنسية",
    "أشخاص حسب الجنسية في القرن 10 ق م": "أشخاص في القرن 10 ق م حسب الجنسية",
    "أشخاص حسب الجنسية في القرن 10": "أشخاص في القرن 10 حسب الجنسية",
    "أشخاص حسب الجنسية في القرن 11 ق م": "أشخاص في القرن 11 ق م حسب الجنسية",
    "أشخاص حسب الجنسية في القرن 11": "أشخاص في القرن 11 حسب الجنسية",
    "أشخاص حسب الجنسية في القرن 13 ق م": "أشخاص في القرن 13 ق م حسب الجنسية",
    "أشخاص حسب الجنسية والمهنة في القرن 10": "أشخاص في القرن 10 حسب الجنسية والمهنة",
    "أشخاص حسب الجنسية والمهنة في القرن 11": "أشخاص في القرن 11 حسب الجنسية والمهنة",
    "أشخاص حسب الدين في القرن 10": "أشخاص في القرن 10 حسب الدين",
    "أشخاص حسب الدين في القرن 11": "أشخاص في القرن 11 حسب الدين",
    "أشخاص حسب القارة في القرن 10": "أشخاص في القرن 10 حسب القارة",
    "أشخاص حسب القارة في القرن 11": "أشخاص في القرن 11 حسب القارة",
    "أشخاص حسب القارة في القرن 12": "أشخاص في القرن 12 حسب القارة",
    "أشخاص حسب المهنة في القرن 10 ق م": "أشخاص في القرن 10 ق م حسب المهنة",
    "أشخاص حسب المهنة في القرن 10": "أشخاص في القرن 10 حسب المهنة",
    "أشخاص حسب المهنة في القرن 11": "أشخاص في القرن 11 حسب المهنة",
    "أشخاص حسب المهنة والجنسية في القرن 10": "أشخاص في القرن 10 حسب المهنة والجنسية",
    "أشخاص حسب المهنة والجنسية في القرن 11": "أشخاص في القرن 11 حسب المهنة والجنسية",
    "أشخاص حسب النزاع في القرن 10": "أشخاص في القرن 10 حسب النزاع",
    "أشخاص حسب النزاع في القرن 11": "أشخاص في القرن 11 حسب النزاع",
    "أشخاص حسب النزاع في القرن 12": "أشخاص في القرن 12 حسب النزاع",
    "أفارقة حسب الجنسية في القرن 10": "أفارقة في القرن 10 حسب الجنسية",
    "أفارقة حسب الجنسية في القرن 11": "أفارقة في القرن 11 حسب الجنسية",
    "أفارقة حسب الجنسية في القرن 12": "أفارقة في القرن 12 حسب الجنسية",
    "ألمان حسب المهنة في القرن 13": "ألمان في القرن 13 حسب المهنة",
    "أوروبيون حسب الجنسية في القرن 10": "أوروبيون في القرن 10 حسب الجنسية",
    "أوروبيون حسب الجنسية في القرن 11": "أوروبيون في القرن 11 حسب الجنسية",
    "أوروبيون حسب الجنسية في القرن 12": "أوروبيون في القرن 12 حسب الجنسية",
    "إسبان حسب المهنة في القرن 10": "إسبان في القرن 10 حسب المهنة",
    "إسبان حسب المهنة في القرن 11": "إسبان في القرن 11 حسب المهنة",
    "إسبان حسب المهنة في القرن 12": "إسبان في القرن 12 حسب المهنة",
    "إسكتلنديون حسب المهنة في القرن 12": "إسكتلنديون في القرن 12 حسب المهنة",
    "إنجليز حسب المهنة في القرن 10": "إنجليز في القرن 10 حسب المهنة",
    "إنجليز حسب المهنة في القرن 11": "إنجليز في القرن 11 حسب المهنة",
    "إنجليز حسب المهنة في القرن 12": "إنجليز في القرن 12 حسب المهنة",
    "إيطاليون حسب المهنة في القرن 11": "إيطاليون في القرن 11 حسب المهنة",
    "إيطاليون حسب المهنة في القرن 12": "إيطاليون في القرن 12 حسب المهنة",
    "التاريخ العسكري حسب البلد في القرن 13": "التاريخ العسكري في القرن 13 حسب البلد",
    "المرأة حسب الجنسية في القرن 10 ق م": "المرأة في القرن 10 ق م حسب الجنسية",
    "المرأة حسب الجنسية في القرن 10": "المرأة في القرن 10 حسب الجنسية",
    "المرأة حسب الجنسية في القرن 11 ق م": "المرأة في القرن 11 ق م حسب الجنسية",
    "المرأة حسب الجنسية في القرن 11": "المرأة في القرن 11 حسب الجنسية",
    "المرأة حسب الجنسية في القرن 12 ق م": "المرأة في القرن 12 ق م حسب الجنسية",
    "المرأة حسب الجنسية في القرن 12": "المرأة في القرن 12 حسب الجنسية",
    "المرأة حسب الجنسية في القرن 13 ق م": "المرأة في القرن 13 ق م حسب الجنسية",
    "المرأة حسب المهنة في القرن 10": "المرأة في القرن 10 حسب المهنة",
    "المرأة حسب المهنة في القرن 11": "المرأة في القرن 11 حسب المهنة",
    "المرأة حسب المهنة في القرن 12": "المرأة في القرن 12 حسب المهنة",
    "رياضياتيون حسب الجنسية في القرن 11": "رياضياتيون في القرن 11 حسب الجنسية",
    "رياضياتيون حسب الجنسية في القرن 12": "رياضياتيون في القرن 12 حسب الجنسية",
    "رياضياتيون حسب الجنسية في القرن 13": "رياضياتيون في القرن 13 حسب الجنسية",
    "شخصيات أعمال حسب الجنسية في القرن 13": "شخصيات أعمال في القرن 13 حسب الجنسية",
    "صينيون حسب المهنة في القرن 10": "صينيون في القرن 10 حسب المهنة",
    "صينيون حسب المهنة في القرن 11": "صينيون في القرن 11 حسب المهنة",
    "صينيون حسب المهنة في القرن 12": "صينيون في القرن 12 حسب المهنة",
    "عقود حسب البلد في القرن 10": "عقود في القرن 10 حسب البلد",
    "عقود حسب البلد في القرن 11": "عقود في القرن 11 حسب البلد",
    "علماء حسب الجنسية في القرن 12": "علماء في القرن 12 حسب الجنسية",
    "فرنسيون حسب المهنة في القرن 12": "فرنسيون في القرن 12 حسب المهنة",
    "فلاسفة حسب الجنسية في القرن 10": "فلاسفة في القرن 10 حسب الجنسية",
    "فلاسفة حسب الجنسية في القرن 11": "فلاسفة في القرن 11 حسب الجنسية",
    "فلاسفة حسب الجنسية في القرن 12": "فلاسفة في القرن 12 حسب الجنسية",
    "فلكيون حسب الجنسية في القرن 13": "فلكيون في القرن 13 حسب الجنسية",
    "فنانون حسب الجنسية في القرن 10": "فنانون في القرن 10 حسب الجنسية",
    "فنانون حسب الجنسية في القرن 11": "فنانون في القرن 11 حسب الجنسية",
    "فنانون حسب الجنسية في القرن 12": "فنانون في القرن 12 حسب الجنسية",
    "كنائس حسب البلد في القرن 10": "كنائس في القرن 10 حسب البلد",
    "كنائس حسب البلد في القرن 11": "كنائس في القرن 11 حسب البلد",
    "كنائس حسب البلد في القرن 12": "كنائس في القرن 12 حسب البلد",
    "كوريون حسب المهنة في القرن 10": "كوريون في القرن 10 حسب المهنة",
    "كوريون حسب المهنة في القرن 11": "كوريون في القرن 11 حسب المهنة",
    "كوريون حسب المهنة في القرن 12": "كوريون في القرن 12 حسب المهنة",
    "مؤرخون حسب الجنسية في القرن 10": "مؤرخون في القرن 10 حسب الجنسية",
    "مؤرخون حسب الجنسية في القرن 11": "مؤرخون في القرن 11 حسب الجنسية",
    "مؤرخون حسب الجنسية في القرن 12": "مؤرخون في القرن 12 حسب الجنسية",
    "مؤرخون حسب الجنسية في القرن 13": "مؤرخون في القرن 13 حسب الجنسية",
    "مبان كنائس رومانية كاثوليكية حسب البلد في القرن 11": "مبان كنائس رومانية كاثوليكية في القرن 11 حسب البلد",
    "مبان كنائس رومانية كاثوليكية حسب البلد في القرن 12": "مبان كنائس رومانية كاثوليكية في القرن 12 حسب البلد",
    "مبان ومنشآت دينية حسب البلد في القرن 12": "مبان ومنشآت دينية في القرن 12 حسب البلد",
    "ملكيون حسب البلد في القرن 10": "ملكيون في القرن 10 حسب البلد",
    "ملكيون حسب البلد في القرن 11": "ملكيون في القرن 11 حسب البلد",
    "ملكيون حسب البلد في القرن 12": "ملكيون في القرن 12 حسب البلد",
    "موسيقيون حسب الجنسية في القرن 11": "موسيقيون في القرن 11 حسب الجنسية",
    "موسيقيون حسب الجنسية في القرن 12": "موسيقيون في القرن 12 حسب الجنسية",
    "هنود حسب المهنة في القرن 10": "هنود في القرن 10 حسب المهنة",
    "هنود حسب المهنة في القرن 11": "هنود في القرن 11 حسب المهنة",
    "هنود حسب المهنة في القرن 12": "هنود في القرن 12 حسب المهنة",
    "يابانيون حسب المهنة في القرن 10": "يابانيون في القرن 10 حسب المهنة",
    "يابانيون حسب المهنة في القرن 11": "يابانيون في القرن 11 حسب المهنة",
    "يابانيون حسب المهنة في القرن 12": "يابانيون في القرن 12 حسب المهنة",
    "يهود حسب الجنسية في القرن 11": "يهود في القرن 11 حسب الجنسية",
    "يهود حسب الجنسية في القرن 12": "يهود في القرن 12 حسب الجنسية",
    "يونانيون حسب المهنة في القرن 10": "يونانيون في القرن 10 حسب المهنة",
    "يونانيون حسب المهنة في القرن 11": "يونانيون في القرن 11 حسب المهنة",
    "يونانيون حسب المهنة في القرن 13": "يونانيون في القرن 13 حسب المهنة",
}

to_test = [
    ("test_move_years_first", move_years_first_data, move_years_first),
    ("test_move_by_in", move_by_in_data, move_by_in),
]


@pytest.mark.parametrize("category, expected", move_years_first_data.items(), ids=move_years_first_data.keys())
@pytest.mark.fast
def test_move_years_first(category: str, expected: str) -> None:
    label = move_years_first(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", move_by_in_data.items(), ids=move_by_in_data.keys())
@pytest.mark.fast
def test_move_by_in(category: str, expected: str) -> None:
    label = move_by_in(category)
    assert label == expected


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
