#
import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar

test_c_musicians_1 = {
    "LGBTQ classical musicians": "موسيقيون كلاسيكيون مثليون",
    "Classical musicians with disabilities": "موسيقيون كلاسيكيون بإعاقات",
    "Croatian classical musicians by instrument": "موسيقيون كلاسيكيون كروات حسب الآلة",
    "Croatian classical musicians": "موسيقيون كلاسيكيون كروات",
    "Families of classical musicians": "عائلات موسيقيون كلاسيكيون",
}

test_c_musicians_3 = {
    "16th-century classical musicians": "موسيقيون كلاسيكيون في القرن 16",
    "17th-century classical musicians": "موسيقيون كلاسيكيون في القرن 17",
    "18th-century classical musicians": "موسيقيون كلاسيكيون في القرن 18",
    "19th-century classical musicians": "موسيقيون كلاسيكيون في القرن 19",
    "20th-century classical musicians from Northern Ireland": "موسيقيون كلاسيكيون من أيرلندا الشمالية في القرن 20",
    "20th-century classical musicians": "موسيقيون كلاسيكيون في القرن 20",
    "21st-century classical musicians from Northern Ireland": "موسيقيون كلاسيكيون من أيرلندا الشمالية في القرن 21",
    "21st-century classical musicians": "موسيقيون كلاسيكيون في القرن 21",
    "Albanian classical musicians": "موسيقيون كلاسيكيون ألبان",
    "Algerian classical musicians": "موسيقيون كلاسيكيون جزائريون",
    "American classical musicians by instrument": "موسيقيون كلاسيكيون أمريكيون حسب الآلة",
    "American classical musicians by state": "موسيقيون كلاسيكيون أمريكيون حسب الولاية",
    "American classical musicians of Asian descent": "موسيقيون كلاسيكيون أمريكيون من أصل آسيوي",
    "American classical musicians of Chinese descent": "موسيقيون كلاسيكيون أمريكيون من أصل صيني",
    "American classical musicians of Japanese descent": "موسيقيون كلاسيكيون أمريكيون من أصل ياباني",
    "American classical musicians of Korean descent": "موسيقيون كلاسيكيون أمريكيون من أصل كوري",
    "American classical musicians": "موسيقيون كلاسيكيون أمريكيون",
    "American contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون أمريكيون",
    "Argentine classical musicians by instrument": "موسيقيون كلاسيكيون أرجنتينيون حسب الآلة",
    "Argentine classical musicians": "موسيقيون كلاسيكيون أرجنتينيون",
    "Australian classical musicians by instrument": "موسيقيون كلاسيكيون أستراليون حسب الآلة",
    "Australian classical musicians": "موسيقيون كلاسيكيون أستراليون",
    "Austrian classical musicians by instrument": "موسيقيون كلاسيكيون نمساويون حسب الآلة",
    "Austrian classical musicians": "موسيقيون كلاسيكيون نمساويون",
    "Azerbaijani classical musicians by instrument": "موسيقيون كلاسيكيون أذربيجانيون حسب الآلة",
    "Azerbaijani classical musicians": "موسيقيون كلاسيكيون أذربيجانيون",
    "Belgian classical musicians by instrument": "موسيقيون كلاسيكيون بلجيكيون حسب الآلة",
    "Belgian classical musicians": "موسيقيون كلاسيكيون بلجيكيون",
    "Bolivian classical musicians by instrument": "موسيقيون كلاسيكيون بوليفيون حسب الآلة",
    "Bolivian classical musicians": "موسيقيون كلاسيكيون بوليفيون",
    "Bosnia and Herzegovina classical musicians": "موسيقيون كلاسيكيون بوسنيون",
    "Brazilian classical musicians by instrument": "موسيقيون كلاسيكيون برازيليون حسب الآلة",
    "Brazilian classical musicians": "موسيقيون كلاسيكيون برازيليون",
    "British classical musicians by instrument": "موسيقيون كلاسيكيون بريطانيون حسب الآلة",
    "British classical musicians": "موسيقيون كلاسيكيون بريطانيون",
    "British contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون بريطانيون",
    "Bulgarian classical musicians by instrument": "موسيقيون كلاسيكيون بلغاريون حسب الآلة",
    "Bulgarian classical musicians": "موسيقيون كلاسيكيون بلغاريون",
    "Canadian classical musicians by instrument": "موسيقيون كلاسيكيون كنديون حسب الآلة",
    "Canadian classical musicians": "موسيقيون كلاسيكيون كنديون",
    "Canadian contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون كنديون",
    "Child classical musicians": "موسيقيون كلاسيكيون أطفال",
    "Chilean classical musicians": "موسيقيون كلاسيكيون تشيليون",
    "Chinese classical musicians by instrument": "موسيقيون كلاسيكيون صينيون حسب الآلة",
    "Chinese classical musicians": "موسيقيون كلاسيكيون صينيون",
    "Classical musicians by ethnicity": "موسيقيون كلاسيكيون حسب المجموعة العرقية",
    "Classical musicians by genre": "موسيقيون كلاسيكيون حسب النوع الفني",
    "Classical musicians by instrument and nationality": "موسيقيون كلاسيكيون حسب الآلة والجنسية",
    "Classical musicians by instrument": "موسيقيون كلاسيكيون حسب الآلة",
    "Classical musicians by nationality and instrument": "موسيقيون كلاسيكيون حسب الجنسية والآلة",
    "Classical musicians by nationality": "موسيقيون كلاسيكيون حسب الجنسية",
    "Classical musicians from Arkansas": "موسيقيون كلاسيكيون من أركنساس",
    "Classical musicians from California": "موسيقيون كلاسيكيون من كاليفورنيا",
    "Classical musicians from Catalonia": "موسيقيون كلاسيكيون من كتالونيا",
    "Classical musicians from Colorado": "موسيقيون كلاسيكيون من كولورادو",
    "Classical musicians from Connecticut": "موسيقيون كلاسيكيون من كونيتيكت",
    "Classical musicians from Florida": "موسيقيون كلاسيكيون من فلوريدا",
    "Classical musicians from Georgia (country) by instrument": "موسيقيون كلاسيكيون من جورجيا حسب الآلة",
    "Classical musicians from Georgia (country)": "موسيقيون كلاسيكيون من جورجيا",
    "Classical musicians from Georgia (U.S. state)": "موسيقيون كلاسيكيون من ولاية جورجيا",
    "Classical musicians from Illinois": "موسيقيون كلاسيكيون من إلينوي",
    "Classical musicians from Indiana": "موسيقيون كلاسيكيون من إنديانا",
    "Classical musicians from Iowa": "موسيقيون كلاسيكيون من آيوا",
    "Classical musicians from Kansas": "موسيقيون كلاسيكيون من كانساس",
    "Classical musicians from Louisiana": "موسيقيون كلاسيكيون من لويزيانا",
    "Classical musicians from Maryland": "موسيقيون كلاسيكيون من ماريلند",
    "Classical musicians from Massachusetts": "موسيقيون كلاسيكيون من ماساتشوستس",
    "Classical musicians from Michigan": "موسيقيون كلاسيكيون من ميشيغان",
    "Classical musicians from Minnesota": "موسيقيون كلاسيكيون من منيسوتا",
    "Classical musicians from Mississippi": "موسيقيون كلاسيكيون من مسيسيبي",
    "Classical musicians from Missouri": "موسيقيون كلاسيكيون من ميزوري",
    "Classical musicians from Nebraska": "موسيقيون كلاسيكيون من نبراسكا",
    "Classical musicians from New Jersey": "موسيقيون كلاسيكيون من نيوجيرسي",
    "Classical musicians from New York (state)": "موسيقيون كلاسيكيون من ولاية نيويورك",
    "Classical musicians from North Carolina": "موسيقيون كلاسيكيون من كارولاينا الشمالية",
    "Classical musicians from Northern Ireland by instrument": "موسيقيون كلاسيكيون من أيرلندا الشمالية حسب الآلة",
    "Classical musicians from Northern Ireland": "موسيقيون كلاسيكيون من أيرلندا الشمالية",
    "Classical musicians from Ohio": "موسيقيون كلاسيكيون من أوهايو",
    "Classical musicians from Oklahoma": "موسيقيون كلاسيكيون من أوكلاهوما",
    "Classical musicians from Pennsylvania": "موسيقيون كلاسيكيون من بنسلفانيا",
    "Classical musicians from Rhode Island": "موسيقيون كلاسيكيون من رود آيلاند",
    "Classical musicians from South Carolina": "موسيقيون كلاسيكيون من كارولاينا الجنوبية",
    "Classical musicians from South Dakota": "موسيقيون كلاسيكيون من داكوتا الجنوبية",
    "Classical musicians from Tennessee": "موسيقيون كلاسيكيون من تينيسي",
    "Classical musicians from Texas": "موسيقيون كلاسيكيون من تكساس",
    "Classical musicians from Vermont": "موسيقيون كلاسيكيون من فيرمونت",
    "Classical musicians from Virginia": "موسيقيون كلاسيكيون من فرجينيا",
    "Classical musicians from Washington, D.C.": "موسيقيون كلاسيكيون من واشنطن العاصمة",
    "Classical musicians from Wisconsin": "موسيقيون كلاسيكيون من ويسكونسن",
    "Classical musicians": "موسيقيون كلاسيكيون",
    "Colombian classical musicians by instrument": "موسيقيون كلاسيكيون كولومبيون حسب الآلة",
    "Colombian classical musicians": "موسيقيون كلاسيكيون كولومبيون",
    "Contemporary classical musicians by nationality": "موسيقيون كلاسيكيون معاصرون حسب الجنسية",
    "Contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون",
    "Cuban classical musicians": "موسيقيون كلاسيكيون كوبيون",
    "Czech classical musicians by instrument": "موسيقيون كلاسيكيون تشيكيون حسب الآلة",
    "Czech classical musicians": "موسيقيون كلاسيكيون تشيكيون",
    "Czechoslovak classical musicians": "موسيقيون كلاسيكيون تشيكوسلوفاكيون",
    "Danish classical musicians by instrument": "موسيقيون كلاسيكيون دنماركيون حسب الآلة",
    "Danish classical musicians": "موسيقيون كلاسيكيون دنماركيون",
    "Deaf classical musicians": "موسيقيون كلاسيكيون صم",
    "Dutch classical musicians by instrument": "موسيقيون كلاسيكيون هولنديون حسب الآلة",
    "Dutch classical musicians": "موسيقيون كلاسيكيون هولنديون",
    "Ecuadorian classical musicians by instrument": "موسيقيون كلاسيكيون إكوادوريون حسب الآلة",
    "Ecuadorian classical musicians": "موسيقيون كلاسيكيون إكوادوريون",
    "Egyptian classical musicians": "موسيقيون كلاسيكيون مصريون",
    "English classical musicians by instrument": "موسيقيون كلاسيكيون إنجليز حسب الآلة",
    "English classical musicians": "موسيقيون كلاسيكيون إنجليز",
    "English contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون إنجليز",
    "Estonian classical musicians by instrument": "موسيقيون كلاسيكيون إستونيون حسب الآلة",
    "Estonian classical musicians": "موسيقيون كلاسيكيون إستونيون",
    "Filipino classical musicians by instrument": "موسيقيون كلاسيكيون فلبينيون حسب الآلة",
    "Filipino classical musicians": "موسيقيون كلاسيكيون فلبينيون",
    "Finnish classical musicians by instrument": "موسيقيون كلاسيكيون فنلنديون حسب الآلة",
    "Finnish classical musicians": "موسيقيون كلاسيكيون فنلنديون",
    "French classical musicians by instrument": "موسيقيون كلاسيكيون فرنسيون حسب الآلة",
    "French classical musicians": "موسيقيون كلاسيكيون فرنسيون",
    "German classical musicians by instrument": "موسيقيون كلاسيكيون ألمان حسب الآلة",
    "German classical musicians": "موسيقيون كلاسيكيون ألمان",
    "German contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون ألمان",
    "Greek classical musicians by instrument": "موسيقيون كلاسيكيون يونانيون حسب الآلة",
    "Greek classical musicians": "موسيقيون كلاسيكيون يونانيون",
    "Guatemalan classical musicians": "موسيقيون كلاسيكيون غواتيماليون",
    "Haitian classical musicians": "موسيقيون كلاسيكيون هايتيون",
    "Hong Kong classical musicians": "موسيقيون كلاسيكيون هونغ كونغيون",
    "Hungarian classical musicians by instrument": "موسيقيون كلاسيكيون مجريون حسب الآلة",
    "Hungarian classical musicians": "موسيقيون كلاسيكيون مجريون",
    "Indian women classical musicians": "موسيقيات كلاسيكيات هنديات",
    "Iranian classical musicians": "موسيقيون كلاسيكيون إيرانيون",
    "Irish classical musicians by instrument": "موسيقيون كلاسيكيون أيرلنديون حسب الآلة",
    "Irish classical musicians": "موسيقيون كلاسيكيون أيرلنديون",
    "Israeli classical musicians by instrument": "موسيقيون كلاسيكيون إسرائيليون حسب الآلة",
    "Israeli classical musicians": "موسيقيون كلاسيكيون إسرائيليون",
    "Italian classical musicians by instrument": "موسيقيون كلاسيكيون إيطاليون حسب الآلة",
    "Italian classical musicians": "موسيقيون كلاسيكيون إيطاليون",
    "Japanese classical musicians by instrument": "موسيقيون كلاسيكيون يابانيون حسب الآلة",
    "Japanese classical musicians": "موسيقيون كلاسيكيون يابانيون",
    "Japanese contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون يابانيون",
    "Jewish American classical musicians": "موسيقيون كلاسيكيون أمريكيون يهود",
    "Jewish classical musicians": "موسيقيون كلاسيكيون يهود",
    "Korean classical musicians": "موسيقيون كلاسيكيون كوريون",
    "Latvian classical musicians by instrument": "موسيقيون كلاسيكيون لاتفيون حسب الآلة",
    "Latvian classical musicians": "موسيقيون كلاسيكيون لاتفيون",
    "Lebanese classical musicians by instrument": "موسيقيون كلاسيكيون لبنانيون حسب الآلة",
    "Lebanese classical musicians": "موسيقيون كلاسيكيون لبنانيون",
    "Lithuanian classical musicians by instrument": "موسيقيون كلاسيكيون ليتوانيون حسب الآلة",
    "Lithuanian classical musicians": "موسيقيون كلاسيكيون ليتوانيون",
    "Maltese classical musicians": "موسيقيون كلاسيكيون مالطيون",
    "Mexican classical musicians by instrument": "موسيقيون كلاسيكيون مكسيكيون حسب الآلة",
    "Mexican classical musicians": "موسيقيون كلاسيكيون مكسيكيون",
    "New Zealand classical musicians by instrument": "موسيقيون كلاسيكيون نيوزيلنديون حسب الآلة",
    "New Zealand classical musicians": "موسيقيون كلاسيكيون نيوزيلنديون",
    "Norwegian classical musicians by instrument": "موسيقيون كلاسيكيون نرويجيون حسب الآلة",
    "Norwegian classical musicians": "موسيقيون كلاسيكيون نرويجيون",
    "Norwegian contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون نرويجيون",
    "Pakistani classical musicians": "موسيقيون كلاسيكيون باكستانيون",
    "Peruvian classical musicians": "موسيقيون كلاسيكيون بيرويون",
    "Polish classical musicians by instrument": "موسيقيون كلاسيكيون بولنديون حسب الآلة",
    "Polish classical musicians": "موسيقيون كلاسيكيون بولنديون",
    "Portuguese classical musicians by instrument": "موسيقيون كلاسيكيون برتغاليون حسب الآلة",
    "Portuguese classical musicians": "موسيقيون كلاسيكيون برتغاليون",
    "Puerto Rican classical musicians": "موسيقيون كلاسيكيون بورتوريكيون",
    "Russian classical musicians by instrument": "موسيقيون كلاسيكيون روس حسب الآلة",
    "Russian classical musicians": "موسيقيون كلاسيكيون روس",
    "Scottish classical musicians by instrument": "موسيقيون كلاسيكيون إسكتلنديون حسب الآلة",
    "Scottish classical musicians": "موسيقيون كلاسيكيون إسكتلنديون",
    "Serbian classical musicians by instrument": "موسيقيون كلاسيكيون صرب حسب الآلة",
    "Serbian classical musicians": "موسيقيون كلاسيكيون صرب",
    "Singaporean classical musicians by instrument": "موسيقيون كلاسيكيون سنغافوريون حسب الآلة",
    "Singaporean classical musicians": "موسيقيون كلاسيكيون سنغافوريون",
    "Slovak classical musicians": "موسيقيون كلاسيكيون سلوفاكيون",
    "Slovenian classical musicians": "موسيقيون كلاسيكيون سلوفينيون",
    "South Korean classical musicians by instrument": "موسيقيون كلاسيكيون كوريون جنوبيون حسب الآلة",
    "South Korean classical musicians": "موسيقيون كلاسيكيون كوريون جنوبيون",
    "Soviet classical musicians": "موسيقيون كلاسيكيون سوفيت",
    "Spanish classical musicians by instrument": "موسيقيون كلاسيكيون إسبان حسب الآلة",
    "Spanish classical musicians": "موسيقيون كلاسيكيون إسبان",
    "Swedish classical musicians by instrument": "موسيقيون كلاسيكيون سويديون حسب الآلة",
    "Swedish classical musicians": "موسيقيون كلاسيكيون سويديون",
    "Swiss classical musicians by instrument": "موسيقيون كلاسيكيون سويسريون حسب الآلة",
    "Swiss classical musicians": "موسيقيون كلاسيكيون سويسريون",
    "Taiwanese classical musicians": "موسيقيون كلاسيكيون تايوانيون",
    "Turkish classical musicians by instrument": "موسيقيون كلاسيكيون أتراك حسب الآلة",
    "Turkish classical musicians": "موسيقيون كلاسيكيون أتراك",
    "Ukrainian classical musicians by instrument": "موسيقيون كلاسيكيون أوكرانيون حسب الآلة",
    "Ukrainian classical musicians": "موسيقيون كلاسيكيون أوكرانيون",
    "Uruguayan classical musicians by instrument": "موسيقيون كلاسيكيون أوروغويانيون حسب الآلة",
    "Uruguayan classical musicians": "موسيقيون كلاسيكيون أوروغويانيون",
    "Venezuelan classical musicians by instrument": "موسيقيون كلاسيكيون فنزويليون حسب الآلة",
    "Venezuelan classical musicians": "موسيقيون كلاسيكيون فنزويليون",
    "Welsh classical musicians by instrument": "موسيقيون كلاسيكيون ويلزيون حسب الآلة",
    "Welsh classical musicians": "موسيقيون كلاسيكيون ويلزيون",
}

test_c_musicians_4 = {
    "18th-century British classical musicians": "موسيقيون كلاسيكيون بريطانيون في القرن 18",
    "18th-century Irish classical musicians": "موسيقيون كلاسيكيون أيرلنديون في القرن 18",
    "19th-century British classical musicians": "موسيقيون كلاسيكيون بريطانيون في القرن 19",
    "19th-century Irish classical musicians": "موسيقيون كلاسيكيون أيرلنديون في القرن 19",
    "20th-century American classical musicians": "موسيقيون كلاسيكيون أمريكيون في القرن 20",
    "20th-century Argentine classical musicians": "موسيقيون كلاسيكيون أرجنتينيون في القرن 20",
    "20th-century Armenian classical musicians": "موسيقيون كلاسيكيون أرمن في القرن 20",
    "20th-century Australian classical musicians": "موسيقيون كلاسيكيون أستراليون في القرن 20",
    "20th-century Austrian classical musicians": "موسيقيون كلاسيكيون نمساويون في القرن 20",
    "20th-century Belgian classical musicians": "موسيقيون كلاسيكيون بلجيكيون في القرن 20",
    "20th-century British classical musicians": "موسيقيون كلاسيكيون بريطانيون في القرن 20",
    "20th-century Canadian classical musicians": "موسيقيون كلاسيكيون كنديون في القرن 20",
    "20th-century classical musicians by nationality": "موسيقيون كلاسيكيون في القرن 20 حسب الجنسية",
    "20th-century Czech classical musicians": "موسيقيون كلاسيكيون تشيكيون في القرن 20",
    "20th-century Danish classical musicians": "موسيقيون كلاسيكيون دنماركيون في القرن 20",
    "20th-century Dutch classical musicians": "موسيقيون كلاسيكيون هولنديون في القرن 20",
    "20th-century English classical musicians": "موسيقيون كلاسيكيون إنجليز في القرن 20",
    "20th-century French classical musicians": "موسيقيون كلاسيكيون فرنسيون في القرن 20",
    "20th-century German classical musicians": "موسيقيون كلاسيكيون ألمان في القرن 20",
    "20th-century Hungarian classical musicians": "موسيقيون كلاسيكيون مجريون في القرن 20",
    "20th-century Irish classical musicians": "موسيقيون كلاسيكيون أيرلنديون في القرن 20",
    "20th-century Italian classical musicians": "موسيقيون كلاسيكيون إيطاليون في القرن 20",
    "20th-century Japanese classical musicians": "موسيقيون كلاسيكيون يابانيون في القرن 20",
    "20th-century Norwegian classical musicians": "موسيقيون كلاسيكيون نرويجيون في القرن 20",
    "20th-century Polish classical musicians": "موسيقيون كلاسيكيون بولنديون في القرن 20",
    "20th-century Russian classical musicians": "موسيقيون كلاسيكيون روس في القرن 20",
    "20th-century Spanish classical musicians": "موسيقيون كلاسيكيون إسبان في القرن 20",
    "20th-century Swedish classical musicians": "موسيقيون كلاسيكيون سويديون في القرن 20",
    "20th-century Swiss classical musicians": "موسيقيون كلاسيكيون سويسريون في القرن 20",
    "20th-century Turkish classical musicians": "موسيقيون كلاسيكيون أتراك في القرن 20",
    "21st-century American classical musicians": "موسيقيون كلاسيكيون أمريكيون في القرن 21",
    "21st-century British classical musicians": "موسيقيون كلاسيكيون بريطانيون في القرن 21",
    "21st-century French classical musicians": "موسيقيون كلاسيكيون فرنسيون في القرن 21",
    "21st-century German classical musicians": "موسيقيون كلاسيكيون ألمان في القرن 21",
    "21st-century Irish classical musicians": "موسيقيون كلاسيكيون أيرلنديون في القرن 21",
    "21st-century Japanese classical musicians": "موسيقيون كلاسيكيون يابانيون في القرن 21",
    "21st-century Norwegian classical musicians": "موسيقيون كلاسيكيون نرويجيون في القرن 21",
    "21st-century Russian classical musicians": "موسيقيون كلاسيكيون روس في القرن 21",
    "African-American classical musicians": "موسيقيون كلاسيكيون أمريكيون أفارقة",
    "American classical musicians by ethnicity": "موسيقيون كلاسيكيون أمريكيون حسب المجموعة العرقية",
    "American classical musicians of Indian descent": "موسيقيون كلاسيكيون أمريكيون من أصل هندي",
    "American male classical musicians": "موسيقيون كلاسيكيون ذكور أمريكيون",
    "American women classical musicians": "موسيقيات كلاسيكيات أمريكيات",
    "Armenian classical musicians by instrument": "موسيقيون كلاسيكيون أرمن حسب الآلة",
    "Armenian classical musicians": "موسيقيون كلاسيكيون أرمن",
    "Basque classical musicians": "موسيقيون كلاسيكيون باسكيون",
    "Belarusian classical musicians": "موسيقيون كلاسيكيون بيلاروسيون",
    "Blind classical musicians": "موسيقيون كلاسيكيون مكفوفون",
    "Canadian women classical musicians": "موسيقيات كلاسيكيات كنديات",
    "Classical musicians by century": "موسيقيون كلاسيكيون حسب القرن",
    "Classical musicians from Arizona": "موسيقيون كلاسيكيون من أريزونا",
    "Classical musicians from Maine": "موسيقيون كلاسيكيون من مين",
    "Classical musicians from Nevada": "موسيقيون كلاسيكيون من نيفادا",
    "Classical musicians from North Dakota": "موسيقيون كلاسيكيون من داكوتا الشمالية",
    "Classical musicians from Oregon": "موسيقيون كلاسيكيون من أوريغن",
    "Classical musicians from Washington (state)": "موسيقيون كلاسيكيون من ولاية واشنطن",
    "Classical musicians from West Virginia": "موسيقيون كلاسيكيون من فرجينيا الغربية",
    "French contemporary classical musicians": "موسيقيون كلاسيكيون معاصرون فرنسيون",
    "Icelandic classical musicians by instrument": "موسيقيون كلاسيكيون آيسلنديون حسب الآلة",
    "Icelandic classical musicians": "موسيقيون كلاسيكيون آيسلنديون",
    "Indian classical musicians of Bengal": "موسيقيون كلاسيكيون هنود في البنغال",
    "Indian classical musicians": "موسيقيون كلاسيكيون هنود",
    "Indian male classical musicians": "موسيقيون كلاسيكيون ذكور هنود",
    "Irish women classical musicians": "موسيقيات كلاسيكيات أيرلنديات",
    "Luxembourgian classical musicians": "موسيقيون كلاسيكيون لوكسمبورغيون",
    "Moldovan classical musicians": "موسيقيون كلاسيكيون مولدوفيون",
    "Paraguayan classical musicians": "موسيقيون كلاسيكيون بارغوايانيون",
    "Romanian classical musicians by instrument": "موسيقيون كلاسيكيون رومان حسب الآلة",
    "Romanian classical musicians": "موسيقيون كلاسيكيون رومان",
    "Uzbekistani classical musicians": "موسيقيون كلاسيكيون أوزبكستانيون",
    "Women classical musicians by nationality": "موسيقيات كلاسيكيات حسب الجنسية",
    "Yugoslav classical musicians": "موسيقيون كلاسيكيون يوغسلافيون",
}

to_test = [
    ("test_classical_musicians_3", test_c_musicians_3),
    ("test_classical_musicians_4", test_c_musicians_4),
]


@pytest.mark.parametrize("category, expected", test_c_musicians_3.items(), ids=test_c_musicians_3.keys())
@pytest.mark.fast
def test_classical_musicians_3(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    # dump_same_and_not_same(data, diff_result, name, True)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
