"""
Tests
"""

import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats.new_resolvers.reslove_all import new_resolvers_all

test_data_not_for_2018_bot = {
    "weightlifters": "رباعون",
    "judoka": "لاعبو جودو",
    "pan-africanists": "وحدويون أفارقة",
    "swimmers": "سباحون",
    "football players": "لاعبو كرة قدم",
    "athletes": "لاعبو قوى",
    "competitors": "منافسون",
    "cross-country skiers": "متزحلقون ريفيون",
}

te4_2018_Jobs_data = {
    "european sports coaches": "مدربو رياضة أوروبيون",
    "albanian sports coaches": "مدربو رياضة ألبان",
    # "macedonian expatriate female footballers": "لاعبات كرة قدم مقدونيات مغتربات",
    "afghan competitors": "منافسون أفغان",
    "african tennis players": "لاعبو كرة مضرب أفارقة",
    "albanian male tennis players": "لاعبو كرة مضرب ذكور ألبان",
    "albanian physicians": "أطباء ألبان",
    "albanian writers": "كتاب ألبان",
    "algerian expatriate sports-people": "رياضيون جزائريون مغتربون",
    "american agronomists": "مهندسون زراعيون أمريكيون",
    "american artists": "فنانون أمريكيون",
    "american basketball players": "لاعبو كرة سلة أمريكيون",
    "american bluegrass musicians": "موسيقيو بلوغراس أمريكيون",
    "american cricketers": "لاعبو كريكت أمريكيون",
    "american expatriates": "أمريكيون مغتربون",
    "american explorers": "مستكشفون أمريكيون",
    "american female athletes": "لاعبات قوى أمريكيات",
    "american folk musicians": "موسيقيو فولك أمريكيون",
    "american gospel singers": "مغنو غوسبل أمريكيون",
    "american novelists": "روائيون أمريكيون",
    "american playback singers": "مغنو أفلام أمريكيون",
    "american women folk singers": "مغنيات فولك أمريكيات",
    "american women geographers": "جغرافيات أمريكيات",
    "american women guitarists": "عازفات قيثارة أمريكيات",
    "angolan radio journalists": "صحفيو راديو أنغوليون",
    "argentine expatriate sports-people": "رياضيون أرجنتينيون مغتربون",
    "argentine expatriates": "أرجنتينيون مغتربون",
    "argentine industrial designers": "مصممون صناعيون أرجنتينيون",
    "armenian cross-country skiers": "متزحلقون ريفيون أرمن",
    "armenian expatriate sports-people": "رياضيون أرمن مغتربون",
    "asian politicians": "سياسيون آسيويون",
    "australian comedy writers": "كتاب كوميديا أستراليون",
    "australian expatriate sports-people": "رياضيون أستراليون مغتربون",
    "australian heavy metal singers": "مغنو هيفي ميتال أستراليون",
    "australian male sculptors": "نحاتون ذكور أستراليون",
    "australian male sprinters": "عداؤون سريعون ذكور أستراليون",
    "australian oncologists": "أطباء أورام أستراليون",
    "australian science writers": "كتاب علم أستراليون",
    "austrian classical violinists": "عازفو كمان كلاسيكيون نمساويون",
    "austrian film directors": "مخرجو أفلام نمساويون",
    "austrian pianists": "عازفو بيانو نمساويون",
    "austrian religious workers": "عمال دينيون نمساويون",
    "azerbaijani judges": "قضاة أذربيجانيون",
    "azerbaijani logicians": "منطقيون أذربيجانيون",
    "bangladeshi women artists": "فنانات بنغلاديشيات",
    "belarusian computer programmers": "مبرمجون بيلاروسيون",
    "belarusian female tennis players": "لاعبات كرة مضرب بيلاروسيات",
    "belarusian science fiction writers": "كتاب خيال علمي بيلاروسيون",
    "belizean expatriates": "بليزيون مغتربون",
    "beninese male boxers": "ملاكمون ذكور بنينيون",
    "bissau-guinean expatriate sports-people": "رياضيون غينيون بيساويون مغتربون",
    "bolivian expatriate sports-people": "رياضيون بوليفيون مغتربون",
    "bolivian lawyers": "محامون بوليفيون",
    "bolivian pianists": "عازفو بيانو بوليفيون",
    "bosnia and herzegovina artists": "فنانون بوسنيون",
    "bosnia and herzegovina female judoka": "لاعبات جودو بوسنيات",
    "brazilian artists": "فنانون برازيليون",
    "brazilian eugenicists": "علماء برازيليون متخصصون في تحسين النسل",
    "brazilian graphic novelists": "روائيو رويات مصورة برازيليون",
    "brazilian heavy metal guitarists": "عازفو قيثارة هيفي ميتال برازيليون",
    "british cardinals": "كرادلة بريطانيون",
    "british conceptual artists": "فنانون تصويريون بريطانيون",
    "british disability rights activists": "بريطانيون ناشطون في حقوق الإعاقة",
    "british emigrants": "بريطانيون مهاجرون",
    "british engineers": "مهندسون بريطانيون",
    "british expatriate field hockey players": "لاعبو هوكي ميدان بريطانيون مغتربون",
    "british expatriate sports-people": "رياضيون بريطانيون مغتربون",
    "british military personnel": "أفراد عسكريون بريطانيون",
    "british music industry executives": "مدراء صناعة الموسيقى بريطانيون",
    "bulgarian actors": "ممثلون بلغاريون",
    "bulgarian male opera singers": "مغنو أوبرا ذكور بلغاريون",
    "bulgarian priests": "كهنة بلغاريون",
    "bulgarian producers": "منتجون بلغاريون",
    "burkinabe expatriates": "بوركينابيون مغتربون",
    "burkinabe theatre people": "مسرحيون بوركينابيون",
    "cambodian radio journalists": "صحفيو راديو كمبوديون",
    "cameroonian communists": "شيوعيون كاميرونيون",
    "canadian expatriate ice hockey players": "لاعبو هوكي جليد كنديون مغتربون",
    "canadian expatriate sports-people": "رياضيون كنديون مغتربون",
    "canadian expatriates": "كنديون مغتربون",
    "canadian folk rock musicians": "موسيقيو فولك روك كنديون",
    "canadian ice dancers": "راقصو جليد كنديون",
    "canadian male biathletes": "لاعبو بياثلون ذكور كنديون",
    "canadian male kickboxers": "مقاتلو كيك بوكسنغ ذكور كنديون",
    "canadian musicians": "موسيقيون كنديون",
    "canadian sports businesspeople": "شخصيات أعمال رياضيون كنديون",
    "canadian sportsmen": "رياضيون رجال كنديون",
    "cape verdean essayists": "كتاب مقالات أخضريون",
    "cape verdean football managers": "مدربو كرة قدم أخضريون",
    "chechen rebels": "متمردون شيشانيون",
    "chilean expatriates": "تشيليون مغتربون",
    "chilean freestyle skiers": "ممارسو تزلج حر تشيليون",
    "chilean short story writers": "كتاب قصة قصيرة تشيليون",
    "chinese automotive engineers": "مهندسو سيارات صينيون",
    "chinese emigrants": "صينيون مهاجرون",
    "chinese expatriate sports-people": "رياضيون صينيون مغتربون",
    "chinese gamblers": "مقامرون صينيون",
    "chinese stage actors": "ممثلو مسرح صينيون",
    "chinese urban planners": "مخططون حضريون صينيون",
    "colombian composers": "ملحنون كولومبيون",
    "colombian expatriate sports-people": "رياضيون كولومبيون مغتربون",
    "colombian folk singers": "مغنو فولك كولومبيون",
    "croatian baroque composers": "ملحنو باروك كروات",
    "croatian emigrants": "كروات مهاجرون",
    "croatian endocrinologists": "أطباء غدد صماء كروات",
    "croatian expatriates": "كروات مغتربون",
    "cuban poets": "شعراء كوبيون",
    "cypriot emigrants": "قبرصيون مهاجرون",
    "cypriot rugby union players": "لاعبو اتحاد رجبي قبرصيون",
    "czech painters": "رسامون تشيكيون",
    "czechoslovak ice hockey coaches": "مدربو هوكي جليد تشيكوسلوفاكيون",
    "danish ceramists": "خزفيون دنماركيون",
    "danish musicians": "موسيقيون دنماركيون",
    "democratic-republic-of-congo expatriate sports-people": "رياضيون كونغويون ديمقراطيون مغتربون",
    "dutch surveyors": "مساحون هولنديون",
    "egyptian female sport shooters": "لاعبات رماية مصريات",
    "egyptian lawyers": "محامون مصريون",
    "egyptian male sport shooters": "لاعبو رماية ذكور مصريون",
    "egyptian sport shooters": "لاعبو رماية مصريون",
    "english artists": "فنانون إنجليز",
    "english book and manuscript collectors": "جامعو كتب ومقتنيات إنجليز",
    "english cartographers": "علماء رسم خرائط إنجليز",
    "english expatriates": "إنجليز مغتربون",
    "english singer-songwriters": "مغنون وكتاب أغاني إنجليز",
    "english women": "إنجليزيات",
    "equatoguinean female footballers": "لاعبات كرة قدم غينيات استوائيات",
    "equatoguinean women": "غينيات استوائيات",
    "estonian astrologers": "منجمون إستونيون",
    "estonian motorcycle racers": "متسابقو دراجات نارية إستونيون",
    "estonian racing drivers": "سائقو سيارات سباق إستونيون",
    "estonian screenwriters": "كتاب سيناريو إستونيون",
    "ethiopian basketball players": "لاعبو كرة سلة إثيوبيون",
    "ethiopian people imprisoned abroad": "إثيوبيون مسجونون في الخارج",
    "fijian football managers": "مدربو كرة قدم فيجيون",
    "fijian long jumpers": "لاعبو قفز طويل فيجيون",
    "filipino newspaper people": "شخصيات صحف فلبينيون",
    "finnish expatriate sports-people": "رياضيون فنلنديون مغتربون",
    "finnish expatriates": "فنلنديون مغتربون",
    "finnish women archaeologists": "عالمات آثار فنلنديات",
    "finnish women's ice hockey defencemen": "مدافعات هوكي جليد فنلنديات",
    "french male painters": "رسامون ذكور فرنسيون",
    "french male singer-songwriters": "مغنون وكتاب أغاني ذكور فرنسيون",
    "french scholars-of-islam": "فرنسيون باحثون عن الإسلام",
    "french sportsmen": "رياضيون رجال فرنسيون",
    "french women performance artists": "فنانات أدائيات فرنسيات",
    "german advertising executives": "مدراء إعلانات ألمان",
    "german emigrants": "ألمان مهاجرون",
    "german expatriate sports-people": "رياضيون ألمان مغتربون",
    "german expatriates": "ألمان مغتربون",
    "german footballers": "لاعبو كرة قدم ألمان",
    "german male pianists": "عازفو بيانو ذكور ألمان",
    "german women civil servants": "موظفات خدمة مدنية ألمانيات",
    "ghanaian expatriates": "غانيون مغتربون",
    "ghanaian women editors": "محررات غانيات",
    "greek expatriates": "يونانيون مغتربون",
    "greek female prostitutes": "داعرات يونانيات",
    "greek male dancers": "راقصون ذكور يونانيون",
    "greek prisoners": "مسجونون يونانيون",
    "greek slaves": "عبيد يونانيون",
    "greek sports-people": "رياضيون يونانيون",
    "greek women writers": "كاتبات يونانيات",
    "haitian expatriate sports-people": "رياضيون هايتيون مغتربون",
    "haitian officials": "مسؤولون هايتيون",
    "honduran economists": "اقتصاديون هندوراسيون",
    "honduran women poets": "شاعرات هندوراسيات",
    "hong kong female rowers": "مجدفات هونغ كونغيات",
    "hungarian flautists": "عازفو فولت مجريون",
    "hungarian male opera singers": "مغنو أوبرا ذكور مجريون",
    "icelandic actresses": "ممثلات آيسلنديات",
    "icelandic emigrants": "آيسلنديون مهاجرون",
    "indian cricketers": "لاعبو كريكت هنود",
    "indian explorers": "مستكشفون هنود",
    "indian muslim missionaries": "مبشرون مسلمون هنود",
    "indian politicians": "سياسيون هنود",
    "indian scholars": "دارسون هنود",
    "indian translators": "مترجمون هنود",
    "indian women flautists": "عازفات فولت هنديات",
    "indian women lawyers": "محاميات هنديات",
    "indian women writers": "كاتبات هنديات",
    "iranian criminals": "مجرمون إيرانيون",
    "iranian photographers": "مصورون إيرانيون",
    "iranian poets": "شعراء إيرانيون",
    "irish female sailors (sport)": "بحارات رياضيات أيرلنديات",
    "irish male musicians": "موسيقيون ذكور أيرلنديون",
    "irish women aviators": "طيارات أيرلنديات",
    "irish women fashion designers": "مصممات أزياء أيرلنديات",
    "israeli agronomists": "مهندسون زراعيون إسرائيليون",
    "israeli artists": "فنانون إسرائيليون",
    "israeli criminals": "مجرمون إسرائيليون",
    "israeli expatriate sports-people": "رياضيون إسرائيليون مغتربون",
    "israeli male stage actors": "ممثلو مسرح ذكور إسرائيليون",
    "italian emigrants": "إيطاليون مهاجرون",
    "italian male mixed martial artists": "مقاتلو فنون قتالية مختلطة ذكور إيطاليون",
    "italian medical historians": "مؤرخون طبيون إيطاليون",
    "italian military personnel": "أفراد عسكريون إيطاليون",
    "italian physicians": "أطباء إيطاليون",
    "italian rowers": "مجدفون إيطاليون",
    "italian women librarians": "أمينات مكتبات إيطاليات",
    "italian writers": "كتاب إيطاليون",
    "ivorian expatriate sports-people": "رياضيون إيفواريون مغتربون",
    "ivorian writers": "كتاب إيفواريون",
    "jamaican expatriate sports-people": "رياضيون جامايكيون مغتربون",
    "jamaican expatriates": "جامايكيون مغتربون",
    "jamaican women poets": "شاعرات جامايكيات",
    "japanese prisoners": "مسجونون يابانيون",
    "japanese social scientists": "مختصون بالعلوم الاجتماعية يابانيون",
    "jordanian equestrians": "فرسان خيول أردنيون",
    "jordanian expatriate sports-people": "رياضيون أردنيون مغتربون",
    "kazakhstani artists": "فنانون كازاخستانيون",
    "kazakhstani expatriates": "كازاخستانيون مغتربون",
    "kazakhstani football referees": "حكام كرة قدم كازاخستانيون",
    "korean scientists": "علماء كوريون",
    "kosovan pianists": "عازفو بيانو كوسوفيون",
    "kosovan victims of crime": "ضحايا جرائم كوسوفيون",
    "kuwaiti female cyclists": "دراجات كويتيات",
    "kuwaiti nationalists": "قوميون كويتيون",
    "kuwaiti women writers": "كاتبات كويتيات",
    "latvian expatriate sports-people": "رياضيون لاتفيون مغتربون",
    "latvian kickboxers": "مقاتلو كيك بوكسنغ لاتفيون",
    "lithuanian children": "أطفال ليتوانيون",
    "lithuanian expatriates": "ليتوانيون مغتربون",
    "luxembourgian cross-country skiers": "متزحلقون ريفيون لوكسمبورغيون",
    "macedonian male taekwondo practitioners": "لاعبو تايكوندو ذكور مقدونيون",
    "malaysian expatriates": "ماليزيون مغتربون",
    "malian artists": "فنانون ماليون",
    "maltese artisans": "حرفيون مالطيون",
    "maltese christian missionaries": "مبشرون مسيحيون مالطيون",
    "mexican actresses": "ممثلات مكسيكيات",
    "mexican comedians": "كوميديون مكسيكيون",
    "mexican crime fiction writers": "كتاب خيال الجريمة مكسيكيون",
    "mexican expatriates": "مكسيكيون مغتربون",
    "moldovan expatriates": "مولدوفيون مغتربون",
    "mongolian cross-country skiers": "متزحلقون ريفيون منغوليون",
    "mongolian female skiers": "متزحلقات منغوليات",
    "moravian bishops": "أساقفة مورافيون",
    "moroccan expatriate sports-people": "رياضيون مغاربة مغتربون",
    "moroccan male mixed martial artists": "مقاتلو فنون قتالية مختلطة ذكور مغاربة",
    "namibian long jumpers": "لاعبو قفز طويل ناميبيون",
    "nepalese clergy": "رجال دين نيباليون",
    "nepalese cross-country skiers": "متزحلقون ريفيون نيباليون",
    "nigerian expatriate sports-people": "رياضيون نيجيريون مغتربون",
    "nigerian musicians": "موسيقيون نيجيريون",
    "north korean women athletes": "لاعبات قوى كوريات شماليات",
    "norwegian artists": "فنانون نرويجيون",
    "norwegian botanists": "علماء نباتات نرويجيون",
    "norwegian expatriates": "نرويجيون مغتربون",
    "omani politicians": "سياسيون عمانيون",
    "pakistani expatriate actors": "ممثلون باكستانيون مغتربون",
    "pakistani pop singers": "مغنو بوب باكستانيون",
    "panamanian anti-communists": "بنميون مناهضون للشيوعية",
    "panamanian expatriates": "بنميون مغتربون",
    "paraguayan male actors": "ممثلون ذكور بارغوايانيون",
    "paraguayan singers": "مغنون بارغوايانيون",
    "paraguayan surgeons": "جراحون بارغوايانيون",
    "peruvian female freestyle swimmers": "سباحات تزلج حر بيرويات",
    "peruvian women": "بيرويات",
    "polish contraltos": "كونترالتويون بولنديون",
    "polish emigrants": "بولنديون مهاجرون",
    "polish expatriate sports-people": "رياضيون بولنديون مغتربون",
    "polish fascists": "فاشيون بولنديون",
    "polish magazine founders": "مؤسسو مجلات بولنديون",
    "polish rock singers": "مغنو روك بولنديون",
    "polish screenwriters": "كتاب سيناريو بولنديون",
    "polish sports executives and administrators": "مسيرون رياضيون بولنديون",
    "polish sportswomen": "رياضيات بولنديات",
    "portuguese composers": "ملحنون برتغاليون",
    "portuguese expatriate sports-people": "رياضيون برتغاليون مغتربون",
    "portuguese monarchs": "ملكيون برتغاليون",
    "portuguese poets": "شعراء برتغاليون",
    "prussian military personnel": "أفراد عسكريون بروسيون",
    "puerto rican equestrians": "فرسان خيول بورتوريكيون",
    "puerto rican rhythmic gymnasts": "لاعبو جمباز إيقاعي بورتوريكيون",
    "puerto rican sportsmen": "رياضيون رجال بورتوريكيون",
    "puerto rican women": "بورتوريكيات",
    "republic-of-congo expatriate sports-people": "رياضيون كونغويون مغتربون",
    "roman governors": "حكام رومان",
    "romanian geodesists": "جيوديسيون رومان",
    "romanian women radio presenters": "مذيعات راديو رومانيات",
    "russian artists": "فنانون روس",
    "russian botanists": "علماء نباتات روس",
    "russian expatriate sports-people": "رياضيون روس مغتربون",
    "russian expatriates": "روس مغتربون",
    "russian male voice actors": "ممثلو أداء صوتي ذكور روس",
    "salvadoran sportswomen": "رياضيات سلفادوريات",
    "saudiarabian astronauts": "رواد فضاء سعوديون",
    "scottish expatriates": "إسكتلنديون مغتربون",
    "scottish fashion designers": "مصممو أزياء إسكتلنديون",
    "scottish male golfers": "لاعبو غولف ذكور إسكتلنديون",
    "scottish women civil servants": "موظفات خدمة مدنية إسكتلنديات",
    "senegalese expatriate sports-people": "رياضيون سنغاليون مغتربون",
    "serbian expatriates": "صرب مغتربون",
    "serbian journalists": "صحفيون صرب",
    "serbian muay thai practitioners": "ممارسو موياي تاي صرب",
    "serbian political philosophers": "فلاسفة سياسيون صرب",
    "sierra leonean expatriate sports-people": "رياضيون سيراليونيون مغتربون",
    "sierra leonean lawyers": "محامون سيراليونيون",
    "singaporean artists": "فنانون سنغافوريون",
    "slovak expatriate sports-people": "رياضيون سلوفاكيون مغتربون",
    "slovak jazz singers": "مغنو جاز سلوفاكيون",
    "slovak musicians": "موسيقيون سلوفاكيون",
    "slovak sports-people": "رياضيون سلوفاكيون",
    "slovenian explorers": "مستكشفون سلوفينيون",
    "slovenian football referees": "حكام كرة قدم سلوفينيون",
    "south american pan-africanists": "وحدويون أفارقة أمريكيون جنوبيون",
    "south korean expatriates": "كوريون جنوبيون مغتربون",
    "south korean male biathletes": "لاعبو بياثلون ذكور كوريون جنوبيون",
    "south korean songwriters": "كتاب أغان كوريون جنوبيون",
    "south sudanese expatriate sports-people": "رياضيون سودانيون جنوبيون مغتربون",
    "soviet biochemists": "كيميائيون حيويون سوفيت",
    "soviet filmmakers": "صانعو أفلام سوفيت",
    "soviet male figure skaters": "متزلجون فنيون ذكور سوفيت",
    "soviet theatre people": "مسرحيون سوفيت",
    "spanish composers": "ملحنون إسبان",
    "spanish graphic novelists": "روائيو رويات مصورة إسبان",
    "spanish journalists": "صحفيون إسبان",
    "spanish male biographers": "كتاب سيرة ذكور إسبان",
    "spanish nuns": "راهبات إسبانيات",
    "spanish philosophers": "فلاسفة إسبان",
    "spanish women fashion designers": "مصممات أزياء إسبانيات",
    "sri lankan emigrants": "سريلانكيون مهاجرون",
    "sri lankan male kabaddi players": "لاعبو كابادي ذكور سريلانكيون",
    "sri lankan mechanical engineers": "مهندسو ميكانيك سريلانكيون",
    "sri lankan military personnel": "أفراد عسكريون سريلانكيون",
    "sri lankan television actresses": "ممثلات تلفزيون سريلانكيات",
    "swedish artists": "فنانون سويديون",
    "swedish badminton players": "لاعبو تنس ريشة سويديون",
    "swedish dancers": "راقصون سويديون",
    "swedish expatriates": "سويديون مغتربون",
    "swedish inventors": "مخترعون سويديون",
    "swedish male archers": "نبالون ذكور سويديون",
    "swedish women guitarists": "عازفات قيثارة سويديات",
    "swiss emigrants": "سويسريون مهاجرون",
    "swiss expatriate sports-people": "رياضيون سويسريون مغتربون",
    "swiss lugers": "زاحفون ثلجيون سويسريون",
    "swiss murder victims": "ضحايا قتل سويسريون",
    "swiss radio actors": "ممثلو راديو سويسريون",
    "swiss rowers": "مجدفون سويسريون",
    "syrian female table tennis players": "لاعبات كرة طاولة سوريات",
    "taiwanese catholics": "كاثوليك تايوانيون",
    "taiwanese emigrants": "تايوانيون مهاجرون",
    "taiwanese female cyclists": "دراجات تايوانيات",
    "taiwanese politicians": "سياسيون تايوانيون",
    "tanzanian expatriate sports-people": "رياضيون تنزانيون مغتربون",
    "thai lesbians": "سحاقيات تايلنديات",
    "togolese bishops": "أساقفة توغويون",
    "togolese expatriate sports-people": "رياضيون توغويون مغتربون",
    "togolese female footballers": "لاعبات كرة قدم توغويات",
    "tongan rugby league coaches": "مدربو دوري رجبي تونغانيون",
    "trinidad and tobago rugby union players": "لاعبو اتحاد رجبي ترنيداديون",
    "tunisian male fencers": "مبارزون ذكور تونسيون",
    "turkish women athletes": "لاعبات قوى تركيات",
    "ukrainian artists": "فنانون أوكرانيون",
    "ukrainian expatriate sports-people": "رياضيون أوكرانيون مغتربون",
    "ukrainian female pair skaters": "متزلجات فنيات على الجليد أوكرانيات",
    "uruguayan actors": "ممثلون أوروغويانيون",
    "uruguayan dramatists and playwrights": "كتاب دراما ومسرح أوروغويانيون",
    "uruguayan dramatists": "دراميون أوروغويانيون",
    "uzbekistani environmentalists": "بيئيون أوزبكستانيون",
    "venezuelan emigrants": "فنزويليون مهاجرون",
    "venezuelan expatriate sports-people": "رياضيون فنزويليون مغتربون",
    "venezuelan male poets": "شعراء ذكور فنزويليون",
    "venezuelan surgeons": "جراحون فنزويليون",
    "vietnamese female freestyle swimmers": "سباحات تزلج حر فيتناميات",
    "vietnamese sports-people": "رياضيون فيتناميون",
    "welsh athletes": "لاعبو قوى ويلزيون",
    "welsh classical scholars": "باحثون كلاسيكيون ويلزيون",
    "welsh clergy": "رجال دين ويلزيون",
    "welsh comedians": "كوميديون ويلزيون",
    "welsh expatriate footballers": "لاعبو كرة قدم ويلزيون مغتربون",
    "welsh expatriates": "ويلزيون مغتربون",
    "welsh jazz composers": "ملحنو جاز ويلزيون",
    "welsh musicians": "موسيقيون ويلزيون",
    "welsh satirists": "كتاب هجائيون ويلزيون",
    "welsh sports businesspeople": "شخصيات أعمال رياضيون ويلزيون",
    "yugoslav sprinters": "عداؤون سريعون يوغسلافيون",
    "zambian emigrants": "زامبيون مهاجرون",
    "zambian writers": "كتاب زامبيون",
    "zimbabwean expatriates": "زيمبابويون مغتربون",
    "zimbabwean marxists": "ماركسيون زيمبابويون",
}

data_fast = {
    "afghan diplomats": "دبلوماسيون أفغان",
    "afghan emigrants": "أفغان مهاجرون",
    "afghan expatriates": "أفغان مغتربون",
    "american award winners": "حائزو جوائز أمريكيون",
    "american basketball coaches": "مدربو كرة سلة أمريكيون",
    "american cinema editors": "محررون سينمائون أمريكيون",
    "american nuclear medicine physicians": "أطباء طب نووي أمريكيون",
    "argentine multi-instrumentalists": "عازفون على عدة آلات أرجنتينيون",
    "argentine songwriters": "كتاب أغان أرجنتينيون",
    "australian internet celebrities": "مشاهير إنترنت أستراليون",
    "belgian athletics coaches": "مدربو ألعاب قوى بلجيكيون",
    "british editorial cartoonists": "محررون كارتونيون بريطانيون",
    "british television chefs": "طباخو تلفاز بريطانيون",
    "canadian nuclear medicine physicians": "أطباء طب نووي كنديون",
    "croatian nuclear medicine physicians": "أطباء طب نووي كروات",
    "dutch explorers": "مستكشفون هولنديون",
    "egyptian oncologists": "أطباء أورام مصريون",
    "european women": "أوروبيات",
    "german nuclear medicine physicians": "أطباء طب نووي ألمان",
    "icelandic male athletes": "لاعبو قوى ذكور آيسلنديون",
    "icelandic male runners": "عداؤون ذكور آيسلنديون",
    "icelandic male steeplechase runners": "عداؤو موانع ذكور آيسلنديون",
    "iranian nuclear medicine physicians": "أطباء طب نووي إيرانيون",
    "irish football managers": "مدربو كرة قدم أيرلنديون",
    "italian defectors": "إيطاليون منشقون",
    "ivorian emigrants": "إيفواريون مهاجرون",
    "ivorian expatriates": "إيفواريون مغتربون",
    "moroccan competitors": "منافسون مغاربة",
    "moroccan male middle-distance runners": "عداؤو مسافات متوسطة ذكور مغاربة",
    "norwegian figure skaters": "متزلجون فنيون نرويجيون",
    "norwegian male pair skaters": "متزلجون فنيون على الجليد ذكور نرويجيون",
    "norwegian male single skaters": "متزلجون فرديون ذكور نرويجيون",
    "norwegian pair skaters": "متزلجون فنيون على الجليد نرويجيون",
    "norwegian short track speed skaters": "متزلجون على مسار قصير نرويجيون",
    "pakistani psychiatrists": "أطباء نفسيون باكستانيون",
    "peruvian television actors": "ممثلو تلفزيون بيرويون",
    "polish women": "بولنديات",
    "portuguese healthcare managers": "مدراء رعاية صحية برتغاليون",
    "republic-of ireland football managers": "مدربو كرة قدم أيرلنديون",
    "swedish oncologists": "أطباء أورام سويديون",
    "turkish expatriate sports-people": "رياضيون أتراك مغتربون",
}


@pytest.mark.parametrize("category, expected_key", te4_2018_Jobs_data.items(), ids=te4_2018_Jobs_data.keys())
@pytest.mark.slow
def test_te4_2018_Jobs_data(category: str, expected_key: str) -> None:
    label1 = new_resolvers_all(category)
    assert label1 == expected_key

    # label2 = new_resolvers_all(category)
    # assert label2 == expected_key


@pytest.mark.parametrize("category, expected_key", data_fast.items(), ids=data_fast.keys())
@pytest.mark.fast
def test_data_fast(category: str, expected_key: str) -> None:
    label1 = new_resolvers_all(category)
    assert label1 == expected_key

    # label2 = new_resolvers_all(category)
    # assert label2 == expected_key


to_test = [
    ("test_data_not_for_2018_bot_m", test_data_not_for_2018_bot, new_resolvers_all),
    ("te4_2018_Jobs_data", te4_2018_Jobs_data, new_resolvers_all),
    ("te4_2018_data_fast", data_fast, new_resolvers_all),
]


@pytest.mark.parametrize("name,data, callback", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)

    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
