"""Mappings for gender specific mixed keys."""

from ...helps import len_print
from ..companies import companies_data

structures_data = {
    "energy companies": "شركات طاقة",
    "energy infrastructure": "بنية تحتية طاقة",
    "renewable resource companies": "شركات موارد متجددة",
    "electric power infrastructure": "بنية تحتية طاقة كهربائية",
    "hydroelectric power stations": "محطات طاقة كهرمائية",
    "mining disasters": "كوارث التعدين",
    "non-renewable resource companies": "شركات موارد غير متجددة",
    "energy companies of": "شركات طاقة في",
    "chemical companies": "شركات كيميائية",
    "renewable energy power stations": "محطات طاقة متجددة",
    "energy power stations": "محطات طاقة",
    "gas companies": "شركات غاز",
    "gas companies of": "شركات غاز في",
    "mining companies": "شركات التعدين",
    "oil and gas companies": "شركات النفط والغاز",
    "gas pipelines": "خطوط أنابيب غاز",
    "natural gas pipelines": "خطوط أنابيب غاز طبيعي",
    "electric power companies": "شركات طاقة كهربائية",
    "oil and gas companies of": "شركات النفط والغاز في",
    "electric power companies of": "شركات طاقة كهربائية في",
    "mining companies of": "شركات التعدين في",
    "oil fields": "حقول نفطية",
    "solar power stations": "محطات طاقة شمسية",
    "nuclear power stations": "محطات طاقة نووية",
    "coal mining": "تعدين الفحم",
    "mobile phone companies": "شركات هاتف محمول",
    "fossil fuel power stations": "محطات طاقة وقود أحفوري",
    "mobile phone companies of": "شركات هاتف محمول في",
    "oil pipelines": "خطوط أنابيب نفطية",
    "gas fields": "حقول غاز",
    "nuclear technology": "تقانة نووية",
    "oil refineries": "مصافي نفطية",
    "natural gas fields": "حقول غاز طبيعي",
    "chemical companies of": "شركات كيميائية في",
    "proposed renewable energy power stations": "محطات طاقة متجددة مقترحة",
    "petroleum industry": "صناعة بترولية",
    "oil companies": "شركات نفطية",
    "coal companies": "شركات الفحم",
    "oil companies of": "شركات نفطية في",
    "gold mining": "تعدين الذهب",
    "coal companies of": "شركات الفحم في",
    "hydroelectric power plants": "محطات طاقة كهرمائية",
    "mining museums": "متاحف التعدين",
    "gas stations": "محطات غاز",
    "geothermal energy": "طاقة حرارية جوفية",
    "nuclear power plants": "محطات طاقة نووية",
    "copper mining": "تعدين النحاس",
    "geothermal power stations": "محطات طاقة حرارية جوفية",
    "coal fields": "حقول الفحم",
    "natural gas companies": "شركات غاز طبيعي",
    "nuclear energy": "طاقة نووية",
    "photovoltaic power stations": "محطات طاقة كهروضوئية",
    "solar energy": "طاقة شمسية",
    "natural gas companies of": "شركات غاز طبيعي في",
    "chemical industry": "صناعة كيميائية",
    "renewable energy companies": "شركات طاقة متجددة",
    "biofuel power stations": "محطات طاقة وقود حيوي",
    "renewable energy companies of": "شركات طاقة متجددة في",
    "energy industry": "صناعة طاقة",
    "oil industry": "صناعة نفطية",
    "oil and gas fields": "حقول النفط والغاز",
    "former nuclear power stations": "محطات طاقة نووية سابقة",
    "petroleum infrastructure": "بنية تحتية بترولية",
    "electrical engineering companies": "شركات هندسة كهربائية",
    "chemical technology": "تقانة كيميائية",
    "gas industry": "صناعة غاز",
    "condiment companies": "شركات توابل",
    "electrical engineering companies of": "شركات هندسة كهربائية في",
    "nuclear bunkers": "مخابئ نووية",
    "natural gas industry": "صناعة غاز طبيعي",
    "condiment companies of": "شركات توابل في",
    "natural gas infrastructure": "بنية تحتية غاز طبيعي",
    "gas infrastructure": "بنية تحتية غاز",
    "proposed solar power stations": "محطات طاقة شمسية مقترحة",
    "coal industry": "صناعة الفحم",
    "energy organizations": "منظمات طاقة",
    "nuclear organizations": "منظمات نووية",
    "bauxite mining": "تعدين البوكسيت",
    "energy technology": "تقانة طاقة",
    "mobile phone industry": "صناعة هاتف محمول",
    "chemical structures": "منشآت كيميائية",
    "petroleum geology": "جيولوجيا بترولية",
    "renewable energy organizations": "منظمات طاقة متجددة",
    "nuclear facilities": "مرافق نووية",
    "oil shale companies": "شركات صخر زيتي",
    "oil shale mining": "تعدين صخر زيتي",
    "proposed nuclear power stations": "محطات طاقة نووية مقترحة",
    "petroleum buildings": "مبان بترولية",
    "petroleum buildings and structures": "مبان ومنشآت بترولية",
    "energy issues": "قضايا طاقة",
    "nuclear issues": "قضايا نووية",
    "petroleum politics": "سياسة بترولية",
    "chemical energy": "طاقة كيميائية",
    "coal museums": "متاحف الفحم",
    "energy agencies": "وكالات طاقة",
    "energy museums": "متاحف طاقة",
    "former biofuel power stations": "محطات طاقة وقود حيوي سابقة",
    "electric infrastructure": "بنية تحتية قدرة",
    "mining industry": "صناعة التعدين",
    "nuclear industry": "صناعة نووية",
    "oil and gas industry": "صناعة النفط والغاز",
    "oil shale companies of": "شركات صخر زيتي في",
    "oil shale technology": "تقانة صخر زيتي",
    "renewable energy technology": "تقانة طاقة متجددة",
    "chemical disasters": "كوارث كيميائية",
    "coal infrastructure": "بنية تحتية الفحم",
    "coal organizations": "منظمات الفحم",
    "coal technology": "تقانة الفحم",
    "copper industry": "صناعة النحاس",
    "electrical engineering organizations": "منظمات هندسة كهربائية",
    "electric fields": "حقول قدرة",
    "electric power industry": "صناعة طاقة كهربائية",
    "electric power industry organizations": "منظمات صناعة طاقة كهربائية",
    "energy industry organizations": "منظمات صناعة طاقة",
    "former hydroelectric power stations": "محطات طاقة كهرمائية سابقة",
    "gas museums": "متاحف غاز",
    "gold fields": "حقول الذهب",
    "gold industry": "صناعة الذهب",
    "gold museums": "متاحف الذهب",
    "governmental nuclear organizations": "منظمات نووية حكومية",
    "natural gas power stations": "محطات طاقة غاز طبيعي",
    "gas power stations": "محطات طاقة غاز",
    "nuclear disasters": "كوارث نووية",
    "mining organizations": "منظمات التعدين",
    "natural gas organizations": "منظمات غاز طبيعي",
    "gas organizations": "منظمات غاز",
    "natural gas technology": "تقانة غاز طبيعي",
    "gas technology": "تقانة غاز",
    "non-renewable energy companies": "شركات طاقة غير متجددة",
    "nuclear companies": "شركات نووية",
    "nuclear companies of": "شركات نووية في",
    "nuclear industry organizations": "منظمات صناعة نووية",
    "nuclear organization": "منظمات نووية",
    "oil infrastructure": "بنية تحتية نفطية",
    "oil shale geology": "جيولوجيا صخر زيتي",
    "oil shale infrastructure": "بنية تحتية صخر زيتي",
    "electric industry": "صناعة قدرة",
    "electric stations": "محطات قدرة",
    "petroleum museums": "متاحف بترولية",
    "petroleum organizations": "منظمات بترولية",
    "petroleum technology": "تقانة بترولية",
    "energy organization": "منظمات طاقة",
    "proposed biofuel power stations": "محطات طاقة وقود حيوي مقترحة",
    "proposed fossil fuel power stations": "محطات طاقة وقود أحفوري مقترحة",
    "proposed geothermal power stations": "محطات طاقة حرارية جوفية مقترحة",
    "proposed hydroelectric power stations": "محطات طاقة كهرمائية مقترحة",
    "renewable energy power plants": "محطات طاقة متجددة",
    "energy power plants": "محطات طاقة",
    "energy facilities": "مرافق طاقة",
}


religious_entries = {
    "bahá'í buildings and structures": "مبان ومنشآت بهائية",
    "bahá'í buildings": "مبان بهائية",
    "bahá'í educational institutions": "هيئات تعليمية بهائية",
    "bahá'í educational": "تعليمية بهائية",
    "bahá'í institutions": "مؤسسات بهائية",
    "buddhist buildings and structures": "مبان ومنشآت بوذية",
    "buddhist buildings": "مبان بوذية",
    "buddhist charities": "جمعيات خيرية بوذية",
    "buddhist communities": "مجتمعات بوذية",
    "buddhist culture": "ثقافة بوذية",
    "buddhist educational institutions": "هيئات تعليمية بوذية",
    "buddhist educational": "تعليمية بوذية",
    "buddhist festivals": "مهرجانات بوذية",
    "buddhist movements": "حركات بوذية",
    "buddhist museums": "متاحف بوذية",
    "buddhist orders": "أخويات بوذية",
    "buddhist organisations": "منظمات بوذية",
    "buddhist organization": "منظمات بوذية",
    "buddhist organizations": "منظمات بوذية",
    "buddhist religious occupations": "مهن دينية بوذية",
    "buddhist schools": "مدارس بوذية",
    "buddhist temples": "معابد بوذية",
    "buddhist women's organizations": "منظمات نسائية بوذية",
    "buddhist youth organizations": "منظمات شبابية بوذية",
    "christian buildings and structures": "مبان ومنشآت مسيحية",
    "christian buildings": "مبان مسيحية",
    "christian charities": "جمعيات خيرية مسيحية",
    "christian communities": "مجتمعات مسيحية",
    "christian culture": "ثقافة مسيحية",
    "christian denominations": "طوائف مسيحية",
    "christian educational institutions": "هيئات تعليمية مسيحية",
    "christian educational": "تعليمية مسيحية",
    "christian festivals": "مهرجانات مسيحية",
    "christian groups": "مجموعات مسيحية",
    "christian movements": "حركات مسيحية",
    "christian museums": "متاحف مسيحية",
    "christian orders": "أخويات مسيحية",
    "christian organisations": "منظمات مسيحية",
    "christian organization": "منظمات مسيحية",
    "christian religious occupations": "مهن دينية مسيحية",
    "christian schools": "مدارس مسيحية",
    "christian societies": "جمعيات مسيحية",
    "christian student organizations": "منظمات طلابية مسيحية",
    "christian women's organizations": "منظمات نسائية مسيحية",
    "christian youth organizations": "منظمات شبابية مسيحية",
    "hindu buildings and structures": "مبان ومنشآت هندوسية",
    "hindu buildings": "مبان هندوسية",
    "hindu communities": "مجتمعات هندوسية",
    "hindu culture": "ثقافة هندوسية",
    "hindu denominations": "طوائف هندوسية",
    "hindu educational institutions": "هيئات تعليمية هندوسية",
    "hindu educational": "تعليمية هندوسية",
    "hindu festivals": "مهرجانات هندوسية",
    "hindu groups": "مجموعات هندوسية",
    "hindu movements": "حركات هندوسية",
    "hindu organisations": "منظمات هندوسية",
    "hindu organizations": "منظمات هندوسية",
    "hindu religious orders": "أخويات دينية هندوسية",
    "hindu schools": "مدارس هندوسية",
    "hindu temples": "معابد هندوسية",
    "islamic awards": "جوائز إسلامية",
    "islamic banks": "بنوك إسلامية",
    "islamic buildings and structures": "مبان ومنشآت إسلامية",
    "islamic buildings": "مبان إسلامية",
    "islamic charities": "جمعيات خيرية إسلامية",
    "islamic culture": "ثقافة إسلامية",
    "islamic educational institutions": "هيئات تعليمية إسلامية",
    "islamic educational": "تعليمية إسلامية",
    "islamic festivals": "مهرجانات إسلامية",
    "islamic movements": "حركات إسلامية",
    "islamic museums": "متاحف إسلامية",
    "islamic orders": "أخويات إسلامية",
    "islamic organisations": "منظمات إسلامية",
    "islamic organization": "منظمات إسلامية",
    "islamic organizations": "منظمات إسلامية",
    "islamic politics": "سياسة إسلامية",
    "islamic religious occupations": "مهن دينية إسلامية",
    "islamic schools": "مدارس إسلامية",
    "islamic youth organizations": "منظمات شبابية إسلامية",
    "jain communities": "مجتمعات جاينية",
    "jain culture": "ثقافة جاينية",
    "jain festivals": "مهرجانات جاينية",
    "jain organisations": "منظمات جاينية",
    "jain religious occupations": "مهن دينية جاينية",
    "jain temples": "معابد جاينية",
    "jewish buildings and structures": "مبان ومنشآت يهودية",
    "jewish buildings": "مبان يهودية",
    "jewish charities": "جمعيات خيرية يهودية",
    "jewish clubs": "نوادي يهودية",
    "jewish communities": "مجتمعات يهودية",
    "jewish culture": "ثقافة يهودية",
    "jewish educational institutions": "هيئات تعليمية يهودية",
    "jewish educational": "تعليمية يهودية",
    "jewish federations": "اتحادات يهودية",
    "jewish festivals": "مهرجانات يهودية",
    "jewish groups": "مجموعات يهودية",
    "jewish institutions": "مؤسسات يهودية",
    "jewish movements": "حركات يهودية",
    "jewish museums": "متاحف يهودية",
    "jewish organisations": "منظمات يهودية",
    "jewish organization": "منظمات يهودية",
    "jewish religious occupations": "مهن دينية يهودية",
    "jewish schools": "مدارس يهودية",
    "jewish services": "خدمات يهودية",
    "jewish women's organizations": "منظمات نسائية يهودية",
    "jewish youth organizations": "منظمات شبابية يهودية",
    "masonic buildings": "مبان ماسونية",
    "masonic culture": "ثقافة ماسونية",
    "masonic educational institutions": "هيئات تعليمية ماسونية",
    "masonic educational": "تعليمية ماسونية",
    "masonic museums": "متاحف ماسونية",
    "masonic organizations": "منظمات ماسونية",
    "masonic youth organizations": "منظمات شبابية ماسونية",
    "new religious movements": "حركات دينية جديدة",
    "new thought denominations": "طوائف فكر جديد",
    "new thought organizations": "منظمات فكر جديد",
    "political party founders": "مؤسسو أحزاب سياسية",
    "protestant buildings and structures": "مبان ومنشآت بروتستانتية",
    "protestant buildings": "مبان بروتستانتية",
    "protestant denominations": "طوائف بروتستانتية",
    "protestant educational institutions": "هيئات تعليمية بروتستانتية",
    "protestant educational": "تعليمية بروتستانتية",
    "protestant orders": "أخويات بروتستانتية",
    "protestant organizations": "منظمات بروتستانتية",
    "protestant schools": "مدارس بروتستانتية",
    "religious academies": "أكاديميات دينية",
    "religious awards": "جوائز دينية",
    "religious building and structure": "مبان ومنشآت دينية",
    "religious buildings and structures": "مبان ومنشآت دينية",
    "religious buildings": "مبان دينية",
    "religious charities": "جمعيات خيرية دينية",
    "religious communities": "مجتمعات دينية",
    "religious corporations": "مؤسسات تجارية دينية",
    "religious culture": "ثقافة دينية",
    "religious denominations": "طوائف دينية",
    "religious educational institutions": "هيئات تعليمية دينية",
    "religious educational": "تعليمية دينية",
    "religious festivals": "مهرجانات دينية",
    "religious groups": "مجموعات دينية",
    "religious movements": "حركات دينية",
    "religious museums": "متاحف دينية",
    "religious occupations": "مهن دينية",
    "religious orders": "أخويات دينية",
    "religious organisations": "منظمات دينية",
    "religious organization": "منظمات دينية",
    "religious organizations": "منظمات دينية",
    "religious schools": "مدارس دينية",
    "religious service organizations": "منظمات خدمية دينية",
    "religious temples": "معابد دينية",
    "scientology organization": "منظمات سينتولوجيا",
    "scientology organizations": "منظمات سينتولوجيا",
    "sikh communities": "مجتمعات سيخية",
    "sikh culture": "ثقافة سيخية",
    "sikh festivals": "مهرجانات سيخية",
    "sikh groups": "مجموعات سيخية",
    "sikh organisations": "منظمات سيخية",
    "sikh organizations": "منظمات سيخية",
    "sikh politics": "سياسة سيخية",
    "spiritualist communities": "مجتمعات روحانية",
    "spiritualist organizations": "منظمات روحانية",
    "taoist buildings and structures": "مبان ومنشآت طاوية",
    "taoist buildings": "مبان طاوية",
    "taoist communities": "مجتمعات طاوية",
    "taoist culture": "ثقافة طاوية",
    "taoist festivals": "مهرجانات طاوية",
    "taoist organizations": "منظمات طاوية",
    "taoist schools": "مدارس طاوية",
    "taoist temples": "معابد طاوية",
    "unitarian universalist organizations": "منظمات توحيدية عالمية",
    "zoroastrian culture": "ثقافة زرادشتية",
    "zoroastrian festivals": "مهرجانات زرادشتية",
    "zoroastrian organizations": "منظمات زرادشتية",
}

films_data = {
    "educational organizations": "منظمات تعليمية",
    "religious organizations": "منظمات دينية",
    "sports organizations": "منظمات رياضية",
    "student organizations": "منظمات طلاب",
    "political organizations": "منظمات سياسية",
    "political organisations": "منظمات سياسية",
    "lgbtq culture": "ثقافة إل جي بي تي كيو",
    "religious organisations": "منظمات دينية",
    "sports organisations": "منظمات رياضية",
    "educational organisations": "منظمات تعليمية",
    "sex industry": "صناعة جنسية",
    "music organisations": "منظمات موسيقية",
    "music organizations": "منظمات موسيقية",
    "internet culture": "ثقافة إنترنت",
    "music industry": "صناعة موسيقية",
    "television companies": "شركات تلفزيونية",
    "aviation organisations": "منظمات طيران",
    "feminist organisations": "منظمات نسوية",
    "feminist organizations": "منظمات نسوية",
    "lgbtq organisations": "منظمات إل جي بي تي كيو",
    "lgbtq organizations": "منظمات إل جي بي تي كيو",
    "aviation organizations": "منظمات طيران",
    "student organisations": "منظمات طلاب",
    "sports companies": "شركات رياضية",
    "military occupations": "مهن عسكرية",
    "dance companies": "شركات رقص",
    "television organizations": "منظمات تلفزيونية",
    "sports culture": "ثقافة رياضية",
    "music companies": "شركات موسيقية",
    "legal organizations": "منظمات قانونية",
    "military research": "أبحاث عسكرية",
    "legal organisations": "منظمات قانونية",
    "internet technology": "تقانة إنترنت",
    "educational technology": "تقانة تعليمية",
    "television organisations": "منظمات تلفزيونية",
    "military organizations": "منظمات عسكرية",
    "aviation organization": "منظمات طيران",
    "maritime organization": "منظمات بحرية",
    "religious occupations": "مهن دينية",
    "science organizations": "منظمات علمية",
    "legal issues": "قضايا قانونية",
    "maritime culture": "ثقافة بحرية",
    "student culture": "ثقافة طلاب",
    "science research": "أبحاث علمية",
    "propaganda organizations": "منظمات دعائية",
    "propaganda organisations": "منظمات دعائية",
    "maritime organisations": "منظمات بحرية",
    "military culture": "ثقافة عسكرية",
    "aviation companies": "شركات طيران",
    "criminal organization": "منظمات جنائية",
    "dance organizations": "منظمات رقص",
    "political culture": "ثقافة سياسية",
    "historical research": "أبحاث تاريخية",
    "television technology": "تقانة تلفزيونية",
    "military organization": "منظمات عسكرية",
    "school organizations": "منظمات مدرسية",
    "legal occupations": "مهن قانونية",
    "criminal organizations": "منظمات جنائية",
    "political organization": "منظمات سياسية",
    "educational research": "أبحاث تعليمية",
    "military technology": "تقانة عسكرية",
    "anime industry": "صناعة أنمي",
    "internet companies": "شركات إنترنت",
    "independent agencies": "وكالات مستقلة",
    "maritime disasters": "كوارث بحرية",
    "maritime organizations": "منظمات بحرية",
    "martial arts organizations": "منظمات فنون قتال",
    "science occupations": "مهن علمية",
    "religious organization": "منظمات دينية",
    "independent research": "أبحاث مستقلة",
    "aviation industry": "صناعة طيران",
    "aviation technology": "تقانة طيران",
    "black culture": "ثقافة سوداء",
    "maritime industry": "صناعة بحرية",
    "lgbtq issues": "قضايا إل جي بي تي كيو",
    "political research": "أبحاث سياسية",
    "sports agencies": "وكالات رياضية",
    "school research": "أبحاث مدرسية",
    "fiction organizations": "منظمات خيالية",
    "legal research": "أبحاث قانونية",
    "lgbtq-related organizations": "منظمات متعلقة بإل جي بي تي كيو",
    "science companies": "شركات علمية",
    "martial arts culture": "ثقافة فنون قتال",
    "music technology": "تقانة موسيقية",
    "school organisations": "منظمات مدرسية",
    "religious culture": "ثقافة دينية",
    "sound technology": "تقانة ناطقة",
    "sports occupations": "مهن رياضية",
    "sports organization": "منظمات رياضية",
    "western culture": "ثقافة غرب أمريكية",
    "anime companies": "شركات أنمي",
    "science technology": "تقانة علمية",
    "aviation culture": "ثقافة طيران",
    "aviation research": "أبحاث طيران",
    "sports industry": "صناعة رياضية",
    "christmas organizations": "منظمات عيد الميلاد",
    "war organizations": "منظمات حربية",
    "cyberpunk culture": "ثقافة سايبربانك",
    "dance culture": "ثقافة رقص",
    "dance occupations": "مهن رقص",
    "dance organisations": "منظمات رقص",
    "dance research": "أبحاث رقص",
    "astronomical research": "أبحاث فلكية",
    "school organization": "منظمات مدرسية",
    "interactive technology": "تقانة تفاعلية",
    "science organisations": "منظمات علمية",
    "fantasy organizations": "منظمات فانتازيا",
    "detective agencies": "وكالات مباحث",
    "historical agencies": "وكالات تاريخية",
    "historical organisations": "منظمات تاريخية",
    "martial arts organization": "منظمات فنون قتال",
    "lgbt culture": "ثقافة إل جي بي تي",
    "lgbt organisations": "منظمات إل جي بي تي",
    "lgbtq organization": "منظمات إل جي بي تي كيو",
    "maritime companies": "شركات بحرية",
    "aviation occupations": "مهن طيران",
    "action organizations": "منظمات حركة",
    "science industry": "صناعة علمية",
    "musical culture": "ثقافة موسيقية",
    "music organization": "منظمات موسيقية",
    "environment research": "أبحاث بيئية",
    "naval research": "أبحاث بحرية عسكرية",
    "political issues": "قضايا سياسية",
    "political occupations": "مهن سياسية",
    "science fiction culture": "ثقافة خيال علمي",
    "fiction culture": "ثقافة خيالية",
    "science fiction organizations": "منظمات خيال علمي",
    "science organization": "منظمات علمية",
    "sports technology": "تقانة رياضية",
    "children's research": "أبحاث أطفال",
    "television issues": "قضايا تلفزيونية",
    "television industry": "صناعة تلفزيونية",
    "television occupations": "مهن تلفزيونية",
    "reality companies": "شركات واقعية",
    "reality organizations": "منظمات واقعية",
    "nautical research": "أبحاث بحرية",
}

RELIGIOUS_FEMALE_KEYS: dict[str, str] = {
    "masonic": "ماسونية",
    "islamic": "إسلامية",
    "neopagan religious": "وثنية جديدة",
    "political party": "أحزاب سياسية",
    "jain": "جاينية",
    "new thought": "فكر جديد",
    "jewish": "يهودية",
    "protestant": "بروتستانتية",
    "sikh": "سيخية",
    "scientology": "سينتولوجيا",
    "spiritualist": "روحانية",
    "taoist": "طاوية",
    "buddhist": "بوذية",
    "unitarian universalist": "توحيدية عالمية",
    "hindu": "هندوسية",
    "christian": "مسيحية",
    "religious": "دينية",
    "zoroastrian": "زرادشتية",
    "bahá'í": "بهائية",
}

FEMALE_SUFFIXES: dict[str, str] = {
    "occupations": "مهن",
    "religious occupations": "مهن دينية",
    "academies": "أكاديميات",
    "agencies": "وكالات",
    "associations": "جمعيات",
    "awards": "جوائز",
    "bridge": "جسور",
    "buildings": "مبان",
    "bunkers": "مخابئ",
    "centers": "مراكز",
    "charities": "جمعيات خيرية",
    "children's charities": "جمعيات خيرية للأطفال",
    "clubs": "نوادي",
    "communities": "مجتمعات",
    "companies": "شركات",
    "consulting": "استشارات",
    "corporations": "مؤسسات تجارية",
    "culture": "ثقافة",
    "denominations": "طوائف",
    "disciplines": "تخصصات",
    "educational institutions": "هيئات تعليمية",
    "educational": "تعليمية",
    "facilities": "مرافق",
    "federations": "اتحادات",
    "festivals": "مهرجانات",
    "genital integrity": "سلامة الأعضاء التناسلية",
    "groups": "مجموعات",
    "ideologies": "أيديولوجيات",
    "installations": "منشآت",
    "institutions": "مؤسسات",
    "issues": "قضايا",
    "learned and professional societies": "جمعيات علمية ومهنية",
    "learned societies": "جمعيات علمية",
    "men's organizations": "منظمات رجالية",
    "movements and organisations": "حركات ومنظمات",
    "movements and organizations": "حركات ومنظمات",
    "movements": "حركات",
    "museums": "متاحف",
    "non-profit organizations": "منظمات غير ربحية",
    "non-profit publishers": "ناشرون غير ربحيون",
    "orders": "أخويات",
    "organisations": "منظمات",
    "organization": "منظمات",
    "organizations": "منظمات",
    "parks": "متنزهات",
    "pornography": "إباحية",
    "professional societies": "جمعيات مهنية",
    "religions": "ديانات",
    "religious orders": "أخويات دينية",
    "research": "أبحاث",
    "schools": "مدارس",
    "service organizations": "منظمات خدمية",
    "services": "خدمات",
    "societies": "جمعيات",
    "specialisms": "تخصصات",
    "student organizations": "منظمات طلابية",
    "utilities": "مرافق",
    "women's organizations": "منظمات نسائية",
    "youth organizations": "منظمات شبابية",
}

POP3_KEYS: dict[str, dict[str, str]] = {
    "healthcare": {"male": "", "female": "رعاية صحية"},
    "school": {"male": "", "female": "مدارس"},
    "theatres": {"male": "", "female": "مسارح"},
    "towers": {"male": "", "female": "أبراج"},
    "windmills": {"male": "", "female": "طواحين الهواء"},
    "veterans": {"male": "", "female": "قدامى المحاربين"},
    "transport": {"male": "", "female": "النقل"},
    "hotel": {"male": "", "female": "فنادق"},
    "fire": {"male": "", "female": "الإطفاء"},
    "major league baseball": {"male": "", "female": "دوري كرة القاعدة الرئيسي"},
    "veterans and descendants": {"male": "", "female": "أحفاد وقدامى المحاربين"},
    "transportation": {"male": "", "female": "نقل"},
    "shopping malls": {"male": "", "female": "مراكز تسوق"},
    "law enforcement": {"male": "", "female": "تطبيق القانون"},
    "dams": {"male": "", "female": "سدود"},
    "hospital": {"male": "", "female": "مستشفيات"},
    "airports": {"male": "", "female": "مطارات"},
    "casinos": {"male": "", "female": "كازينوهات"},
    "university and college": {"male": "", "female": "جامعات وكليات"},
    "colleges and universities": {"male": "", "female": "كليات وجامعات"},
    "university": {"male": "", "female": "جامعات"},
    "universities": {"male": "", "female": "جامعات"},
    "college": {"male": "", "female": "كليات"},
    "colleges": {"male": "", "female": "كليات"},
    "educational": {"male": "تعليمي", "female": "تعليمية"},
    "masonic": {"male": "ماسوني", "female": "ماسونية"},
    "office": {"male": "إداري", "female": "إدارية"},
    "religious": {"male": "ديني", "female": "دينية"},
    "residential": {"male": "سكني", "female": "سكنية"},
    "agricultural": {"male": "زراعي", "female": "زراعية"},
    "air defence": {"male": "دفاع جوي", "female": "دفاع جوية"},
    "anarchism": {"male": "لاسلطوي", "female": "لاسلطوية"},
    "anarchist": {"male": "لاسلطوي", "female": "لاسلطوية"},
    "anti-revisionist": {"male": "مناهض للتحريف", "female": "مناهضة للتحريفية"},
    "arts": {"male": "فني", "female": "فنية"},
    "astronomical": {"male": "فلكي", "female": "فلكية"},
    "chemical": {"male": "كيميائي", "female": "كيميائية"},
    "christian": {"male": "مسيحي", "female": "مسيحية"},
    "commercial": {"male": "تجاري", "female": "تجارية"},
    "constitutional": {"male": "دستوري", "female": "دستورية"},
    "consultative": {"male": "إستشاري", "female": "إستشارية"},
    "cultural": {"male": "ثقافي", "female": "ثقافية"},
    "defense": {"male": "دفاعي", "female": "دفاعية"},
    "economic": {"male": "اقتصادي", "female": "اقتصادية"},
    "environmental": {"male": "بيئي", "female": "بيئية"},
    "fraternal": {"male": "أخوي", "female": "أخوية"},
    "government": {"male": "حكومي", "female": "حكومية"},
    "industrial": {"male": "صناعي", "female": "صناعية"},
    "legal": {"male": "قانوني", "female": "قانونية"},
    "legislative": {"male": "تشريعي", "female": "تشريعية"},
    "logistics": {"male": "لوجستي", "female": "لوجستية"},
    "maritime": {"male": "بحري", "female": "بحرية"},
    "medical and health": {"male": "طبي وصحي", "female": "طبية وصحية"},
    "medical": {"male": "طبي", "female": "طبية"},
    "military": {"male": "عسكري", "female": "عسكرية"},
    "naval": {"male": "عسكرية بحري", "female": "عسكرية بحرية"},
    "paramilitary": {"male": "شبه عسكري", "female": "شبه عسكرية"},
    "political": {"male": "سياسي", "female": "سياسية"},
    "realist": {"male": "واقعي", "female": "واقعية"},
    "research": {"male": "بحثي", "female": "بحثية"},
    "strategy": {"male": "استراتيجي", "female": "استراتيجية"},
    "student": {"male": "طلابي", "female": "طلابية"},
    "training": {"male": "تدريبي", "female": "تدريبية"},
    "warfare": {"male": "حربي", "female": "حربية"},
    "youth": {"male": "شبابي", "female": "شبابية"},
}

FEMALE_EXPANSIONS: dict[str, str] = {
    "defunct {base} stations": "محطات {label} سابقة",
    "{base} ttelevision networks": "شبكات تلفزيونية {label}",
    "{base} television stations": "محطات تلفزيونية {label}",
    "{base} superfund sites": "مواقع استجابة بيئية شاملة {label}",
    "{base} stations": "محطات {label}",
    "{base} responses": "استجابات {label}",
    "{base} censorship": "رقابة {label}",
    "{base} communications": "اتصالات {label}",
    "{base} animals": "حيوانات {label}",
    "{base} philosophy": "فلسفة {label}",
    "{base} migration": "هجرة {label}",
    "{base} think tanks": "مؤسسات فكر ورأي {label}",
    "{base} positions": "مراكز {label}",
    "{base} accidents-and-incidents": "حوادث {label}",
    "{base} accidents and incidents": "حوادث {label}",
    "{base} accidents or incidents": "حوادث {label}",
    "{base} accidents": "حوادث {label}",
    "{base} incidents": "حوادث {label}",
    "{base} software": "برمجيات {label}",
    "{base} databases": "قواعد بيانات {label}",
    "{base} controversies": "خلافات {label}",
    "{base} agencies": "وكالات {label}",
    "{base} units and formations": "وحدات وتشكيلات {label}",
    "{base} squadrons‎": "أسراب {label}",
    "{base} ideologies": "أيديولوجيات {label}",
    "{base} occupations": "مهن {label}",
    "{base} organisations": "منظمات {label}",
    "{base} organizations": "منظمات {label}",
    "{base} organization": "منظمات {label}",
    "{base} facilities": "مرافق {label}",
    "{base} bunkers": "مخابئ {label}",
    "{base} research facilities": "مرافق بحثية {label}",
    "{base} training facilities": "مرافق تدريب {label}",
    "{base} industrial facilities": "مرافق صناعية {label}",
    "{base} warfare facilities": "مرافق حربية {label}",
    "{base} logistics": "لوجستية {label}",
    "{base} research": "أبحاث {label}",
    "{base} industry": "صناعة {label}",
    "{base} technology": "تقانة {label}",
    "{base} disasters": "كوارث {label}",
    "{base} writing": "كتابات {label}",
    "{base} issues": "قضايا {label}",
    "{base} rights": "حقوق {label}",
    "{base} communities": "مجتمعات {label}",
    "{base} culture": "ثقافة {label}",
    "{base} underground culture": "ثقافة باطنية {label}",
    "{base} companies of": "شركات {label} في",
    "{base} companies": "شركات {label}",
    "{base} firms of": "شركات {label} في",
    "{base} firms": "شركات {label}",
    "{base} museums": "متاحف {label}",
    "{base} politics": "سياسة {label}",
    "{base} banks": "بنوك {label}",
    "{base} buildings": "مبان {label}",
    "{base} structures": "منشآت {label}",
    "{base} installations": "منشآت {label}",
    "{base} building and structure": "مبان ومنشآت {label}",
    "{base} buildings and structures": "مبان ومنشآت {label}",
}


def build_female_keys() -> dict[str, str]:
    """Return the expanded mapping used for female-labelled categories."""
    data = {}
    for base, labels in POP3_KEYS.items():
        if labels.get("female"):
            lowered = base.lower()
            for template, translation in FEMALE_EXPANSIONS.items():
                data[template.format(base=lowered)] = translation.format(label=labels.get("female"))

    data.update(structures_data)
    data.update(companies_data)

    for suffix, translation in FEMALE_SUFFIXES.items():
        data[f"lgbt {suffix}"] = f"{translation} مثلية"
        data[f"secessionist {suffix}"] = f"{translation} انفصالية"
        data[f"defunct secessionist {suffix}"] = f"{translation} انفصالية سابقة"

    return data


New_female_keys: dict[str, str] = build_female_keys()
New_female_keys.update(films_data)

__all__ = [
    "New_female_keys",
    "RELIGIOUS_FEMALE_KEYS",
]

len_print.data_len(
    "female_keys.py",
    {
        "films_data": films_data,
        "New_female_keys": New_female_keys,
        "RELIGIOUS_FEMALE_KEYS": RELIGIOUS_FEMALE_KEYS,
        "religious_entries": religious_entries,
    },
)
