#
import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar

test_c_composers_0 = {
    "LGBTQ classical composers": "ملحنون كلاسيكيون مثليون",
    "Italian classical composers of church music": "ملحنو كلاسيكية إيطاليون في موسيقى مسيحية",
    "German classical composers of church music": "ملحنو كلاسيكية ألمان في موسيقى مسيحية",
    "English classical composers of church music": "ملحنو كلاسيكية إنجليز في موسيقى مسيحية",
    "Classical composers of church music": "ملحنون كلاسيكيون من موسيقى مسيحية",
    "American male classical composers": "ملحنون كلاسيكيون أمريكيون",
    "Australian male classical composers": "ملحنون كلاسيكيون أستراليون",
    "Austrian male classical composers": "ملحنون كلاسيكيون نمساويون",
    "Belgian male classical composers": "ملحنون كلاسيكيون بلجيكيون",
    "British male classical composers": "ملحنون كلاسيكيون بريطانيون",
    "Chinese male classical composers": "ملحنون كلاسيكيون صينيون",
    "Czech male classical composers": "ملحنون كلاسيكيون تشيكيون",
    "Danish male classical composers": "ملحنون كلاسيكيون دنماركيون",
    "Dutch male classical composers": "ملحنون كلاسيكيون هولنديون",
    "English male classical composers": "ملحنون كلاسيكيون إنجليز",
    "French male classical composers": "ملحنون كلاسيكيون فرنسيون",
    "German male classical composers": "ملحنون كلاسيكيون ألمان",
    "Irish male classical composers": "ملحنون كلاسيكيون أيرلنديون",
    "Italian male classical composers": "ملحنون كلاسيكيون إيطاليون",
    "Japanese male classical composers": "ملحنون كلاسيكيون يابانيون",
    "Mexican male classical composers": "ملحنون كلاسيكيون مكسيكيون",
    "Polish male classical composers": "ملحنون كلاسيكيون بولنديون",
    "Russian male classical composers": "ملحنون كلاسيكيون روس",
    "Soviet male classical composers": "ملحنون كلاسيكيون سوفيت",
    "Spanish male classical composers": "ملحنون كلاسيكيون إسبان",
    "Mexican classical composers": "ملحنون وملحنات كلاسيكيون مكسيكيون",
    "Polish classical composers": "ملحنون وملحنات كلاسيكيون بولنديون",
    "Russian classical composers": "ملحنون وملحنات كلاسيكيون روس",
    "Soviet classical composers": "ملحنون وملحنات كلاسيكيون سوفيت",
    "Spanish classical composers": "ملحنون وملحنات كلاسيكيون إسبان",
    "German classical composers": "ملحنون وملحنات كلاسيكيون ألمان",
    "Irish classical composers": "ملحنون وملحنات كلاسيكيون أيرلنديون",
    "Italian classical composers": "ملحنون وملحنات كلاسيكيون إيطاليون",
    "Japanese classical composers": "ملحنون وملحنات كلاسيكيون يابانيون",
    "English classical composers": "ملحنون وملحنات كلاسيكيون إنجليز",
    "French classical composers": "ملحنون وملحنات كلاسيكيون فرنسيون",
    "Czech classical composers": "ملحنون وملحنات كلاسيكيون تشيكيون",
    "Dutch classical composers": "ملحنون وملحنات كلاسيكيون هولنديون",
    "Chinese classical composers": "ملحنون وملحنات كلاسيكيون صينيون",
    "Belgian classical composers": "ملحنون وملحنات كلاسيكيون بلجيكيون",
    "British classical composers": "ملحنون وملحنات كلاسيكيون بريطانيون",
    "Australian classical composers": "ملحنون وملحنات كلاسيكيون أستراليون",
    "Austrian classical composers": "ملحنون وملحنات كلاسيكيون نمساويون",
    "American classical composers": "ملحنون وملحنات كلاسيكيون أمريكيون",
}

test_c_composers_3 = {
    "16th-century classical composers": "ملحنون كلاسيكيون في القرن 16",
    "17th-century classical composers": "ملحنون كلاسيكيون في القرن 17",
    "18th-century classical composers from Bohemia": "ملحنون كلاسيكيون من بوهيميا في القرن 18",
    "18th-century classical composers from the Holy Roman Empire": "ملحنون كلاسيكيون من الإمبراطورية الرومانية المقدسة في القرن 18",
    "19th-century classical composers from the Russian Empire": "ملحنون كلاسيكيون من الإمبراطورية الروسية في القرن 19",
    "20th-century classical composers from Northern Ireland": "ملحنون كلاسيكيون من أيرلندا الشمالية في القرن 20",
    "21st-century classical composers from Northern Ireland": "ملحنون كلاسيكيون من أيرلندا الشمالية في القرن 21",
    "African-American male classical composers": "ملحنون كلاسيكيون ذكور أمريكيون أفارقة",
    "African-American women classical composers": "ملحنات كلاسيكيات أمريكيات إفريقيات",
    "American contemporary classical composers": "ملحنون كلاسيكيون معاصرون أمريكيون",
    "American women classical composers": "ملحنات كلاسيكيات أمريكيات",
    "Argentine classical composers": "ملحنون كلاسيكيون أرجنتينيون",
    "Armenian classical composers": "ملحنون كلاسيكيون أرمن",
    "Australian women classical composers": "ملحنات كلاسيكيات أستراليات",
    "Austrian women classical composers": "ملحنات كلاسيكيات نمساويات",
    "Azerbaijani classical composers": "ملحنون كلاسيكيون أذربيجانيون",
    "Brazilian classical composers": "ملحنون كلاسيكيون برازيليون",
    "British contemporary classical composers": "ملحنون كلاسيكيون معاصرون بريطانيون",
    "British women classical composers": "ملحنات كلاسيكيات بريطانيات",
    "Bulgarian classical composers": "ملحنون كلاسيكيون بلغاريون",
    "Canadian classical composers": "ملحنون كلاسيكيون كنديون",
    "Canadian contemporary classical composers": "ملحنون كلاسيكيون معاصرون كنديون",
    "Canadian male classical composers": "ملحنون كلاسيكيون ذكور كنديون",
    "Chilean classical composers": "ملحنون كلاسيكيون تشيليون",
    "Chinese women classical composers": "ملحنات كلاسيكيات صينيات",
    "Classical composers from Catalonia": "ملحنون كلاسيكيون من كتالونيا",
    "Classical composers from Georgia (country)": "ملحنون كلاسيكيون من جورجيا",
    "Classical composers from Northern Ireland": "ملحنون كلاسيكيون من أيرلندا الشمالية",
    "Contemporary classical composers": "ملحنون كلاسيكيون معاصرون",
    "Contemporary classical composers by nationality": "ملحنون كلاسيكيون معاصرون حسب الجنسية",
    "Cuban classical composers": "ملحنون كلاسيكيون كوبيون",
    "Dutch women classical composers": "ملحنات كلاسيكيات هولنديات",
    "English contemporary classical composers": "ملحنون كلاسيكيون معاصرون إنجليز",
    "Estonian classical composers": "ملحنون كلاسيكيون إستونيون",
    "Filipino classical composers": "ملحنون كلاسيكيون فلبينيون",
    "Finnish classical composers": "ملحنون كلاسيكيون فنلنديون",
    "Finnish male classical composers": "ملحنون كلاسيكيون ذكور فنلنديون",
    "Finnish women classical composers": "ملحنات كلاسيكيات فنلنديات",
    "French women classical composers": "ملحنات كلاسيكيات فرنسيات",
    "German contemporary classical composers": "ملحنون كلاسيكيون معاصرون ألمان",
    "German women classical composers": "ملحنات كلاسيكيات ألمانيات",
    "Greek classical composers": "ملحنون كلاسيكيون يونانيون",
    "Guatemalan classical composers": "ملحنون كلاسيكيون غواتيماليون",
    "Hungarian classical composers": "ملحنون كلاسيكيون مجريون",
    "Hungarian male classical composers": "ملحنون كلاسيكيون ذكور مجريون",
    "Indian classical composers": "ملحنون كلاسيكيون هنود",
    "Iranian classical composers": "ملحنون كلاسيكيون إيرانيون",
    "Irish women classical composers": "ملحنات كلاسيكيات أيرلنديات",
    "Israeli classical composers": "ملحنون كلاسيكيون إسرائيليون",
    "Italian women classical composers": "ملحنات كلاسيكيات إيطاليات",
    "Japanese contemporary classical composers": "ملحنون كلاسيكيون معاصرون يابانيون",
    "Japanese women classical composers": "ملحنات كلاسيكيات يابانيات",
    "Jewish American classical composers": "ملحنون كلاسيكيون أمريكيون يهود",
    "Jewish classical composers": "ملحنون كلاسيكيون يهود",
    "Lebanese classical composers": "ملحنون كلاسيكيون لبنانيون",
    "Lithuanian classical composers": "ملحنون كلاسيكيون ليتوانيون",
    "Male classical composers from Northern Ireland": "ملحنون كلاسيكيون ذكور من أيرلندا الشمالية",
    "Maltese classical composers": "ملحنون كلاسيكيون مالطيون",
    "Mexican women classical composers": "ملحنات كلاسيكيات مكسيكيات",
    "New Zealand classical composers": "ملحنون كلاسيكيون نيوزيلنديون",
    "Norwegian classical composers": "ملحنون كلاسيكيون نرويجيون",
    "Norwegian contemporary classical composers": "ملحنون كلاسيكيون معاصرون نرويجيون",
    "Norwegian male classical composers": "ملحنون كلاسيكيون ذكور نرويجيون",
    "Peruvian classical composers": "ملحنون كلاسيكيون بيرويون",
    "Portuguese classical composers": "ملحنون كلاسيكيون برتغاليون",
    "Portuguese male classical composers": "ملحنون كلاسيكيون ذكور برتغاليون",
    "Russian women classical composers": "ملحنات كلاسيكيات روسيات",
    "Scottish classical composers": "ملحنون كلاسيكيون إسكتلنديون",
    "Serbian classical composers": "ملحنون كلاسيكيون صرب",
    "Slovak classical composers": "ملحنون كلاسيكيون سلوفاكيون",
    "South Korean classical composers": "ملحنون كلاسيكيون كوريون جنوبيون",
    "Soviet women classical composers": "ملحنات كلاسيكيات سوفيتيات",
    "Spanish women classical composers": "ملحنات كلاسيكيات إسبانيات",
    "Swedish classical composers": "ملحنون كلاسيكيون سويديون",
    "Swedish male classical composers": "ملحنون كلاسيكيون ذكور سويديون",
    "Swedish women classical composers": "ملحنات كلاسيكيات سويديات",
    "Swiss classical composers": "ملحنون كلاسيكيون سويسريون",
    "Swiss male classical composers": "ملحنون كلاسيكيون ذكور سويسريون",
    "Taiwanese classical composers": "ملحنون كلاسيكيون تايوانيون",
    "Turkish classical composers": "ملحنون كلاسيكيون أتراك",
    "Ukrainian classical composers": "ملحنون كلاسيكيون أوكرانيون",
    "Venezuelan classical composers": "ملحنون كلاسيكيون فنزويليون",
    "Venezuelan women classical composers": "ملحنات كلاسيكيات فنزويليات",
    "Welsh classical composers": "ملحنون كلاسيكيون ويلزيون",
    "Welsh male classical composers": "ملحنون كلاسيكيون ذكور ويلزيون",
    "Women classical composers": "ملحنات كلاسيكيات",
    "Works by British classical composers": "أعمال ملحنون كلاسيكيون بريطانيون",
}

test_c_composers_1 = {
    "17th-century English classical composers": "ملحنون كلاسيكيون إنجليز في القرن 17",
    "17th-century French classical composers": "ملحنون كلاسيكيون فرنسيون في القرن 17",
    "17th-century German classical composers": "ملحنون كلاسيكيون ألمان في القرن 17",
    "17th-century Portuguese classical composers": "ملحنون كلاسيكيون برتغاليون في القرن 17",
    "17th-century Spanish classical composers": "ملحنون كلاسيكيون إسبان في القرن 17",
    "18th-century Austrian classical composers": "ملحنون كلاسيكيون نمساويون في القرن 18",
    "18th-century British classical composers": "ملحنون كلاسيكيون بريطانيون في القرن 18",
    "18th-century classical composers": "ملحنون كلاسيكيون في القرن 18",
    "18th-century French classical composers": "ملحنون كلاسيكيون فرنسيون في القرن 18",
    "18th-century German classical composers": "ملحنون كلاسيكيون ألمان في القرن 18",
    "18th-century Irish classical composers": "ملحنون كلاسيكيون أيرلنديون في القرن 18",
    "18th-century Italian classical composers": "ملحنون كلاسيكيون إيطاليون في القرن 18",
    "18th-century Spanish classical composers": "ملحنون كلاسيكيون إسبان في القرن 18",
    "19th-century American classical composers": "ملحنون كلاسيكيون أمريكيون في القرن 19",
    "19th-century Austrian classical composers": "ملحنون كلاسيكيون نمساويون في القرن 19",
    "19th-century Belgian classical composers": "ملحنون كلاسيكيون بلجيكيون في القرن 19",
    "19th-century British classical composers": "ملحنون كلاسيكيون بريطانيون في القرن 19",
    "19th-century Czech classical composers": "ملحنون كلاسيكيون تشيكيون في القرن 19",
    "19th-century Danish classical composers": "ملحنون كلاسيكيون دنماركيون في القرن 19",
    "19th-century English classical composers": "ملحنون كلاسيكيون إنجليز في القرن 19",
    "19th-century French classical composers": "ملحنون كلاسيكيون فرنسيون في القرن 19",
    "19th-century German classical composers": "ملحنون كلاسيكيون ألمان في القرن 19",
    "19th-century Hungarian classical composers": "ملحنون كلاسيكيون مجريون في القرن 19",
    "19th-century Irish classical composers": "ملحنون كلاسيكيون أيرلنديون في القرن 19",
    "19th-century Italian classical composers": "ملحنون كلاسيكيون إيطاليون في القرن 19",
    "19th-century Norwegian classical composers": "ملحنون كلاسيكيون نرويجيون في القرن 19",
    "19th-century Polish classical composers": "ملحنون كلاسيكيون بولنديون في القرن 19",
    "19th-century Spanish classical composers": "ملحنون كلاسيكيون إسبان في القرن 19",
    "19th-century Swedish classical composers": "ملحنون كلاسيكيون سويديون في القرن 19",
    "20th-century American classical composers": "ملحنون كلاسيكيون أمريكيون في القرن 20",
    "20th-century Argentine classical composers": "ملحنون كلاسيكيون أرجنتينيون في القرن 20",
    "20th-century Armenian classical composers": "ملحنون كلاسيكيون أرمن في القرن 20",
    "20th-century Australian classical composers": "ملحنون كلاسيكيون أستراليون في القرن 20",
    "20th-century Austrian classical composers": "ملحنون كلاسيكيون نمساويون في القرن 20",
    "20th-century Belgian classical composers": "ملحنون كلاسيكيون بلجيكيون في القرن 20",
    "20th-century Brazilian classical composers": "ملحنون كلاسيكيون برازيليون في القرن 20",
    "20th-century British classical composers": "ملحنون كلاسيكيون بريطانيون في القرن 20",
    "20th-century Bulgarian classical composers": "ملحنون كلاسيكيون بلغاريون في القرن 20",
    "20th-century Canadian classical composers": "ملحنون كلاسيكيون كنديون في القرن 20",
    "20th-century Chilean classical composers": "ملحنون كلاسيكيون تشيليون في القرن 20",
    "20th-century Chinese classical composers": "ملحنون كلاسيكيون صينيون في القرن 20",
    "20th-century Cuban classical composers": "ملحنون كلاسيكيون كوبيون في القرن 20",
    "20th-century Czech classical composers": "ملحنون كلاسيكيون تشيكيون في القرن 20",
    "20th-century Danish classical composers": "ملحنون كلاسيكيون دنماركيون في القرن 20",
    "20th-century Dutch classical composers": "ملحنون كلاسيكيون هولنديون في القرن 20",
    "20th-century Egyptian classical composers": "ملحنون كلاسيكيون مصريون في القرن 20",
    "20th-century English classical composers": "ملحنون كلاسيكيون إنجليز في القرن 20",
    "20th-century Estonian classical composers": "ملحنون كلاسيكيون إستونيون في القرن 20",
    "20th-century Finnish classical composers": "ملحنون كلاسيكيون فنلنديون في القرن 20",
    "20th-century French classical composers": "ملحنون كلاسيكيون فرنسيون في القرن 20",
    "20th-century German classical composers": "ملحنون كلاسيكيون ألمان في القرن 20",
    "20th-century Greek classical composers": "ملحنون كلاسيكيون يونانيون في القرن 20",
    "20th-century Hungarian classical composers": "ملحنون كلاسيكيون مجريون في القرن 20",
    "20th-century Irish classical composers": "ملحنون كلاسيكيون أيرلنديون في القرن 20",
    "20th-century Israeli classical composers": "ملحنون كلاسيكيون إسرائيليون في القرن 20",
    "20th-century Italian classical composers": "ملحنون كلاسيكيون إيطاليون في القرن 20",
    "20th-century Japanese classical composers": "ملحنون كلاسيكيون يابانيون في القرن 20",
    "20th-century Lithuanian classical composers": "ملحنون كلاسيكيون ليتوانيون في القرن 20",
    "20th-century Luxembourgian classical composers": "ملحنون كلاسيكيون لوكسمبورغيون في القرن 20",
    "20th-century Mexican classical composers": "ملحنون كلاسيكيون مكسيكيون في القرن 20",
    "20th-century New Zealand classical composers": "ملحنون كلاسيكيون نيوزيلنديون في القرن 20",
    "20th-century Norwegian classical composers": "ملحنون كلاسيكيون نرويجيون في القرن 20",
    "20th-century Polish classical composers": "ملحنون كلاسيكيون بولنديون في القرن 20",
    "20th-century Portuguese classical composers": "ملحنون كلاسيكيون برتغاليون في القرن 20",
    "20th-century Romanian classical composers": "ملحنون كلاسيكيون رومان في القرن 20",
    "20th-century Russian classical composers": "ملحنون كلاسيكيون روس في القرن 20",
    "20th-century Scottish classical composers": "ملحنون كلاسيكيون إسكتلنديون في القرن 20",
    "20th-century South Korean classical composers": "ملحنون كلاسيكيون كوريون جنوبيون في القرن 20",
    "20th-century Spanish classical composers": "ملحنون كلاسيكيون إسبان في القرن 20",
    "20th-century Swedish classical composers": "ملحنون كلاسيكيون سويديون في القرن 20",
    "20th-century Swiss classical composers": "ملحنون كلاسيكيون سويسريون في القرن 20",
    "20th-century Taiwanese classical composers": "ملحنون كلاسيكيون تايوانيون في القرن 20",
    "20th-century Turkish classical composers": "ملحنون كلاسيكيون أتراك في القرن 20",
    "20th-century Ukrainian classical composers": "ملحنون كلاسيكيون أوكرانيون في القرن 20",
    "20th-century Venezuelan classical composers": "ملحنون كلاسيكيون فنزويليون في القرن 20",
    "21st-century American classical composers": "ملحنون كلاسيكيون أمريكيون في القرن 21",
    "21st-century Argentine classical composers": "ملحنون كلاسيكيون أرجنتينيون في القرن 21",
    "21st-century Australian classical composers": "ملحنون كلاسيكيون أستراليون في القرن 21",
    "21st-century Austrian classical composers": "ملحنون كلاسيكيون نمساويون في القرن 21",
    "21st-century Belgian classical composers": "ملحنون كلاسيكيون بلجيكيون في القرن 21",
    "21st-century Brazilian classical composers": "ملحنون كلاسيكيون برازيليون في القرن 21",
    "21st-century British classical composers": "ملحنون كلاسيكيون بريطانيون في القرن 21",
    "21st-century Canadian classical composers": "ملحنون كلاسيكيون كنديون في القرن 21",
    "21st-century Chinese classical composers": "ملحنون كلاسيكيون صينيون في القرن 21",
    "21st-century Czech classical composers": "ملحنون كلاسيكيون تشيكيون في القرن 21",
    "21st-century Danish classical composers": "ملحنون كلاسيكيون دنماركيون في القرن 21",
    "21st-century Dutch classical composers": "ملحنون كلاسيكيون هولنديون في القرن 21",
    "21st-century English classical composers": "ملحنون كلاسيكيون إنجليز في القرن 21",
    "21st-century Estonian classical composers": "ملحنون كلاسيكيون إستونيون في القرن 21",
    "21st-century Finnish classical composers": "ملحنون كلاسيكيون فنلنديون في القرن 21",
    "21st-century French classical composers": "ملحنون كلاسيكيون فرنسيون في القرن 21",
    "21st-century German classical composers": "ملحنون كلاسيكيون ألمان في القرن 21",
    "21st-century Greek classical composers": "ملحنون كلاسيكيون يونانيون في القرن 21",
    "21st-century Indian classical composers": "ملحنون كلاسيكيون هنود في القرن 21",
    "21st-century Irish classical composers": "ملحنون كلاسيكيون أيرلنديون في القرن 21",
    "21st-century Israeli classical composers": "ملحنون كلاسيكيون إسرائيليون في القرن 21",
    "21st-century Italian classical composers": "ملحنون كلاسيكيون إيطاليون في القرن 21",
    "21st-century Japanese classical composers": "ملحنون كلاسيكيون يابانيون في القرن 21",
    "21st-century Mexican classical composers": "ملحنون كلاسيكيون مكسيكيون في القرن 21",
    "21st-century New Zealand classical composers": "ملحنون كلاسيكيون نيوزيلنديون في القرن 21",
    "21st-century Norwegian classical composers": "ملحنون كلاسيكيون نرويجيون في القرن 21",
    "21st-century Polish classical composers": "ملحنون كلاسيكيون بولنديون في القرن 21",
    "21st-century Romanian classical composers": "ملحنون كلاسيكيون رومان في القرن 21",
    "21st-century Russian classical composers": "ملحنون كلاسيكيون روس في القرن 21",
    "21st-century Spanish classical composers": "ملحنون كلاسيكيون إسبان في القرن 21",
    "21st-century Swedish classical composers": "ملحنون كلاسيكيون سويديون في القرن 21",
    "21st-century Swiss classical composers": "ملحنون كلاسيكيون سويسريون في القرن 21",
    "21st-century Venezuelan classical composers": "ملحنون كلاسيكيون فنزويليون في القرن 21",
    "African-American classical composers": "ملحنون كلاسيكيون أمريكيون أفارقة",
    "Argentine women classical composers": "ملحنات كلاسيكيات أرجنتينيات",
    "Basque classical composers": "ملحنون كلاسيكيون باسكيون",
    "Belarusian classical composers": "ملحنون كلاسيكيون بيلاروسيون",
    "Brazilian women classical composers": "ملحنات كلاسيكيات برازيليات",
    "Bulgarian women classical composers": "ملحنات كلاسيكيات بلغاريات",
    "Canadian women classical composers": "ملحنات كلاسيكيات كنديات",
    "Chilean women classical composers": "ملحنات كلاسيكيات تشيليات",
    "Classical composers by century": "ملحنون كلاسيكيون حسب القرن",
    "Classical composers from Bohemia": "ملحنون كلاسيكيون من بوهيميا",
    "Classical composers from the Russian Empire": "ملحنون كلاسيكيون من الإمبراطورية الروسية",
    "Classical composers of African descent": "ملحنون كلاسيكيون من أصل إفريقي",
    "Cuban women classical composers": "ملحنات كلاسيكيات كوبيات",
    "Czech women classical composers": "ملحنات كلاسيكيات تشيكيات",
    "Danish women classical composers": "ملحنات كلاسيكيات دنماركيات",
    "Egyptian classical composers": "ملحنون كلاسيكيون مصريون",
    "English women classical composers": "ملحنات كلاسيكيات إنجليزيات",
    "French contemporary classical composers": "ملحنون كلاسيكيون معاصرون فرنسيون",
    "Icelandic classical composers": "ملحنون كلاسيكيون آيسلنديون",
    "Icelandic women classical composers": "ملحنات كلاسيكيات آيسلنديات",
    "Israeli women classical composers": "ملحنات كلاسيكيات إسرائيليات",
    "Lebanese women classical composers": "ملحنات كلاسيكيات لبنانيات",
    "Luxembourgian classical composers": "ملحنون كلاسيكيون لوكسمبورغيون",
    "Male classical composers": "ملحنون كلاسيكيون ذكور",
    "Moldovan classical composers": "ملحنون كلاسيكيون مولدوفيون",
    "New Zealand women classical composers": "ملحنات كلاسيكيات نيوزيلنديات",
    "Norwegian women classical composers": "ملحنات كلاسيكيات نرويجيات",
    "Polish women classical composers": "ملحنات كلاسيكيات بولنديات",
    "Portuguese women classical composers": "ملحنات كلاسيكيات برتغاليات",
    "Romanian classical composers": "ملحنون كلاسيكيون رومان",
    "Romanian women classical composers": "ملحنات كلاسيكيات رومانيات",
    "Scottish women classical composers": "ملحنات كلاسيكيات إسكتلنديات",
    "Ukrainian women classical composers": "ملحنات كلاسيكيات أوكرانيات",
    "Welsh women classical composers": "ملحنات كلاسيكيات ويلزيات",
    "Women classical composers by nationality": "ملحنات كلاسيكيات حسب الجنسية",
}

test_c_composers_male = {
    "Romanian male classical composers": "ملحنون كلاسيكيون ذكور رومان",
    "Scottish male classical composers": "ملحنون كلاسيكيون ذكور إسكتلنديون",
    "Ukrainian male classical composers": "ملحنون كلاسيكيون ذكور أوكرانيون",
    "Lithuanian male classical composers": "ملحنون كلاسيكيون ذكور ليتوانيون",
    "Male classical composers by nationality": "ملحنون كلاسيكيون ذكور حسب الجنسية",
    "Male classical composers from Bohemia": "ملحنون كلاسيكيون ذكور من بوهيميا",
    "Greek male classical composers": "ملحنون كلاسيكيون ذكور يونانيون",
    "Israeli male classical composers": "ملحنون كلاسيكيون ذكور إسرائيليون",
    "Estonian male classical composers": "ملحنون كلاسيكيون ذكور إستونيون",
    "Egyptian male classical composers": "ملحنون كلاسيكيون ذكور مصريون",
    "Cuban male classical composers": "ملحنون كلاسيكيون ذكور كوبيون",
    "Argentine male classical composers": "ملحنون كلاسيكيون ذكور أرجنتينيون",
    "Armenian male classical composers": "ملحنون كلاسيكيون ذكور أرمن",
    "Brazilian male classical composers": "ملحنون كلاسيكيون ذكور برازيليون",
    "Bulgarian male classical composers": "ملحنون كلاسيكيون ذكور بلغاريون",
    "Chilean male classical composers": "ملحنون كلاسيكيون ذكور تشيليون",
}


to_test = [
    ("test_classical_composers_1", test_c_composers_1),
    ("test_classical_composers_3", test_c_composers_3),
    ("test_classical_composers_4", test_c_composers_male),
]


@pytest.mark.parametrize("category, expected", test_c_composers_1.items(), ids=test_c_composers_1.keys())
@pytest.mark.fast
def test_classical_composers_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    # dump_diff_text (expected, diff_result, name)
    # dump_same_and_not_same(data, diff_result, name, True)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
