#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data_1 = {
    "Category:Non-fiction books about Indigenous peoples of the Americas": "تصنيف:كتب غير خيالية عن شعوب الأمريكتين الأصليين",
    "Category:Zimbabwean non-fiction writers": "تصنيف:كتاب غير روائيين زيمبابويون",
    "Category:10th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 10",
    "Category:11th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 11",
    "Category:11th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 11",
    "Category:12th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 12",
    "Category:12th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 12",
    "Category:13th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 13",
    "Category:13th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 13",
    "Category:14th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 14",
    "Category:14th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 14",
    "Category:15th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 15",
    "Category:15th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 15",
    "Category:16th-century Danish non-fiction writers": "تصنيف:كتاب غير روائيين دنماركيون في القرن 16",
    "Category:16th-century English non-fiction writers": "تصنيف:كتاب غير روائيين إنجليز في القرن 16",
    "Category:16th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 16",
    "Category:16th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 16",
    "Category:17th-century American non-fiction writers": "تصنيف:كتاب غير روائيين أمريكيون في القرن 17",
    "Category:17th-century Danish non-fiction writers": "تصنيف:كتاب غير روائيين دنماركيون في القرن 17",
    "Category:17th-century English non-fiction writers": "تصنيف:كتاب غير روائيين إنجليز في القرن 17",
    "Category:17th-century French non-fiction writers": "تصنيف:كتاب غير روائيين فرنسيون في القرن 17",
    "Category:17th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 17",
    "Category:17th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 17",
    "Category:18th-century American non-fiction writers": "تصنيف:كتاب غير روائيين أمريكيون في القرن 18",
    "Category:18th-century British non-fiction writers": "تصنيف:كتاب غير روائيين بريطانيون في القرن 18",
    "Category:18th-century Canadian non-fiction writers": "تصنيف:كتاب غير روائيين كنديون في القرن 18",
    "Category:18th-century English non-fiction writers": "تصنيف:كتاب غير روائيين إنجليز في القرن 18",
    "Category:18th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 18",
    "Category:18th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 18",
    "Category:19th-century American non-fiction writers": "تصنيف:كتاب غير روائيين أمريكيون في القرن 19",
    "Category:19th-century British non-fiction writers": "تصنيف:كتاب غير روائيين بريطانيون في القرن 19",
    "Category:19th-century Canadian non-fiction writers": "تصنيف:كتاب غير روائيين كنديون في القرن 19",
    "Category:19th-century English non-fiction writers": "تصنيف:كتاب غير روائيين إنجليز في القرن 19",
    "Category:19th-century French non-fiction writers": "تصنيف:كتاب غير روائيين فرنسيون في القرن 19",
    "Category:19th-century German non-fiction writers": "تصنيف:كتاب غير روائيين ألمان في القرن 19",
    "Category:19th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 19",
    "Category:19th-century Irish non-fiction writers": "تصنيف:كتاب غير روائيين أيرلنديون في القرن 19",
    "Category:19th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 19",
    "Category:19th-century non-fiction writers by nationality": "تصنيف:كتاب غير روائيين حسب الجنسية في القرن 19",
    "Category:19th-century non-fiction writers from the Russian Empire": "تصنيف:كتاب غير روائيين روس في القرن 19",
    "Category:20th-century American non-fiction writers": "تصنيف:كتاب غير روائيين أمريكيون في القرن 20",
    "Category:20th-century Australian non-fiction writers": "تصنيف:كتاب غير روائيين أستراليون في القرن 20",
    "Category:20th-century Belgian non-fiction writers": "تصنيف:كتاب غير روائيين بلجيكيون في القرن 20",
    "Category:20th-century British non-fiction writers": "تصنيف:كتاب غير روائيين بريطانيون في القرن 20",
    "Category:20th-century Canadian non-fiction writers": "تصنيف:كتاب غير روائيين كنديون في القرن 20",
    "Category:20th-century Chilean non-fiction writers": "تصنيف:كتاب غير روائيين تشيليون في القرن 20",
    "Category:20th-century Croatian non-fiction writers": "تصنيف:كتاب غير روائيين كروات في القرن 20",
    "Category:20th-century Danish non-fiction writers": "تصنيف:كتاب غير روائيين دنماركيون في القرن 20",
    "Category:20th-century Dutch non-fiction writers": "تصنيف:كتاب غير روائيين هولنديون في القرن 20",
    "Category:20th-century English non-fiction writers": "تصنيف:كتاب غير روائيين إنجليز في القرن 20",
    "Category:20th-century French non-fiction writers": "تصنيف:كتاب غير روائيين فرنسيون في القرن 20",
    "Category:20th-century German non-fiction writers": "تصنيف:كتاب غير روائيين ألمان في القرن 20",
    "Category:20th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 20",
    "Category:20th-century Irish non-fiction writers": "تصنيف:كتاب غير روائيين أيرلنديون في القرن 20",
    "Category:20th-century Israeli non-fiction writers": "تصنيف:كتاب غير روائيين إسرائيليون في القرن 20",
    "Category:20th-century Italian non-fiction writers": "تصنيف:كتاب غير روائيين إيطاليون في القرن 20",
    "Category:20th-century Lithuanian non-fiction writers": "تصنيف:كتاب غير روائيين ليتوانيون في القرن 20",
    "Category:20th-century Norwegian non-fiction writers": "تصنيف:كتاب غير روائيين نرويجيون في القرن 20",
    "Category:20th-century Polish non-fiction writers": "تصنيف:كتاب غير روائيين بولنديون في القرن 20",
    "Category:20th-century Russian non-fiction writers": "تصنيف:كتاب غير روائيين روس في القرن 20",
    "Category:20th-century Swedish non-fiction writers": "تصنيف:كتاب غير روائيين سويديون في القرن 20",
    "Category:20th-century Swiss non-fiction writers": "تصنيف:كتاب غير روائيين سويسريون في القرن 20",
    "Category:20th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 20",
    "Category:20th-century non-fiction writers by nationality": "تصنيف:كتاب غير روائيين حسب الجنسية في القرن 20",
    "Category:21st-century American non-fiction writers": "تصنيف:كتاب غير روائيين أمريكيون في القرن 21",
    "Category:21st-century Australian non-fiction writers": "تصنيف:كتاب غير روائيين أستراليون في القرن 21",
    "Category:21st-century Belgian non-fiction writers": "تصنيف:كتاب غير روائيين بلجيكيون في القرن 21",
    "Category:21st-century British non-fiction writers": "تصنيف:كتاب غير روائيين بريطانيون في القرن 21",
    "Category:21st-century Canadian non-fiction writers": "تصنيف:كتاب غير روائيين كنديون في القرن 21",
    "Category:21st-century Chilean non-fiction writers": "تصنيف:كتاب غير روائيين تشيليون في القرن 21",
    "Category:21st-century Croatian non-fiction writers": "تصنيف:كتاب غير روائيين كروات في القرن 21",
    "Category:21st-century Danish non-fiction writers": "تصنيف:كتاب غير روائيين دنماركيون في القرن 21",
    "Category:21st-century Dutch non-fiction writers": "تصنيف:كتاب غير روائيين هولنديون في القرن 21",
    "Category:21st-century English non-fiction writers": "تصنيف:كتاب غير روائيين إنجليز في القرن 21",
    "Category:21st-century Finnish non-fiction writers": "تصنيف:كتاب غير روائيين فنلنديون في القرن 21",
    "Category:21st-century French non-fiction writers": "تصنيف:كتاب غير روائيين فرنسيون في القرن 21",
    "Category:21st-century German non-fiction writers": "تصنيف:كتاب غير روائيين ألمان في القرن 21",
    "Category:21st-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 21",
    "Category:21st-century Irish non-fiction writers": "تصنيف:كتاب غير روائيين أيرلنديون في القرن 21",
    "Category:21st-century Israeli non-fiction writers": "تصنيف:كتاب غير روائيين إسرائيليون في القرن 21",
    "Category:21st-century Italian non-fiction writers": "تصنيف:كتاب غير روائيين إيطاليون في القرن 21",
    "Category:21st-century Polish non-fiction writers": "تصنيف:كتاب غير روائيين بولنديون في القرن 21",
    "Category:21st-century Russian non-fiction writers": "تصنيف:كتاب غير روائيين روس في القرن 21",
    "Category:21st-century Scottish non-fiction writers": "تصنيف:كتاب غير روائيين إسكتلنديون في القرن 21",
    "Category:21st-century Spanish non-fiction writers": "تصنيف:كتاب غير روائيين إسبان في القرن 21",
    "Category:21st-century Swiss non-fiction writers": "تصنيف:كتاب غير روائيين سويسريون في القرن 21",
    "Category:21st-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 21",
    "Category:21st-century non-fiction writers by nationality": "تصنيف:كتاب غير روائيين حسب الجنسية في القرن 21",
    "Category:21st-century non-fiction writers from Northern Ireland": "تصنيف:كتاب غير روائيين من أيرلندا الشمالية في القرن 21",
    "Category:2nd-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 2",
    "Category:2nd-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 2",
    "Category:3rd-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 3",
    "Category:3rd-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 3",
    "Category:4th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 4",
    "Category:4th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 4",
    "Category:5th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 5",
    "Category:5th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 5",
    "Category:6th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 6",
    "Category:6th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 6",
    "Category:7th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 7",
    "Category:7th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 7",
    "Category:8th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 8",
    "Category:8th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 8",
    "Category:9th-century Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 9",
    "Category:9th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 9",
    "Category:African-American non-fiction writers": "تصنيف:كتاب غير روائيين أفارقة أمريكيون",
    "Category:Albanian non-fiction writers": "تصنيف:كتاب غير روائيين ألبان",
    "Category:American male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور أمريكيون",
    "Category:American non-fiction crime writers": "تصنيف:كتاب جريمة غير روائيين أمريكيون",
    "Category:American non-fiction environmental writers": "تصنيف:كتاب بيئة غير روائيين أمريكيون",
    "Category:American non-fiction writers": "تصنيف:كتاب غير روائيين أمريكيون",
    "Category:American non-fiction writers by century": "تصنيف:كتاب غير روائيين أمريكيون حسب القرن",
    "Category:Angolan non-fiction writers": "تصنيف:كتاب غير روائيين أنغوليون",
    "Category:Arab non-fiction writers": "تصنيف:كتاب غير روائيين عرب",
    "Category:Argentine non-fiction writers": "تصنيف:كتاب غير روائيين أرجنتينيون",
    "Category:Armenian non-fiction writers": "تصنيف:كتاب غير روائيين أرمن",
    "Category:Australian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور أستراليون",
    "Category:Australian non-fiction crime writers": "تصنيف:كتاب جريمة غير روائيين أستراليون",
    "Category:Australian non-fiction writers": "تصنيف:كتاب غير روائيين أستراليون",
    "Category:Austrian non-fiction writers": "تصنيف:كتاب غير روائيين نمساويون",
    "Category:Azerbaijani non-fiction writers": "تصنيف:كتاب غير روائيين أذربيجانيون",
    "Category:Bangladeshi non-fiction writers": "تصنيف:كتاب غير روائيين بنغلاديشيون",
    "Category:Belarusian non-fiction writers": "تصنيف:كتاب غير روائيين بيلاروسيون",
    "Category:Belgian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بلجيكيون",
    "Category:Belgian non-fiction writers": "تصنيف:كتاب غير روائيين بلجيكيون",
    "Category:Belgian non-fiction writers by century": "تصنيف:كتاب غير روائيين بلجيكيون حسب القرن",
    "Category:Beninese non-fiction writers": "تصنيف:كتاب غير روائيين بنينيون",
    "Category:Bermudian non-fiction writers": "تصنيف:كتاب غير روائيين برموديون",
    "Category:Bolivian non-fiction writers": "تصنيف:كتاب غير روائيين بوليفيون",
    "Category:Bosnia and Herzegovina non-fiction writers": "تصنيف:كتاب غير روائيين بوسنيون",
    "Category:Botswana non-fiction writers": "تصنيف:كتاب غير روائيين بوتسوانيون",
    "Category:Brazilian non-fiction writers": "تصنيف:كتاب غير روائيين برازيليون",
    "Category:British male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بريطانيون",
    "Category:British non-fiction crime writers": "تصنيف:كتاب جريمة غير روائيين بريطانيون",
    "Category:British non-fiction writers": "تصنيف:كتاب غير روائيين بريطانيون",
    "Category:British non-fiction writers by century": "تصنيف:كتاب غير روائيين بريطانيون حسب القرن",
    "Category:Burkinabe non-fiction writers": "تصنيف:كتاب غير روائيين بوركينابيون",
    "Category:Burkinabé non-fiction writers": "تصنيف:كتاب غير روائيين بوركينابيون",
    "Category:Burmese non-fiction writers": "تصنيف:كتاب غير روائيين بورميون",
    "Category:Cameroonian non-fiction writers": "تصنيف:كتاب كاميرونيون غير روائيين",
    "Category:Canadian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور كنديون",
    "Category:Canadian non-fiction writers": "تصنيف:كتاب غير روائيين كنديون",
    "Category:Canadian non-fiction writers by century": "تصنيف:كتاب غير روائيين كنديون حسب القرن",
    "Category:Canadian non-fiction writers in French": "تصنيف:كتاب غير روائيين كنديون في الفرنسية",
    "Category:Central African Republic non-fiction writers": "تصنيف:كتاب غير روائيين أفارقة أوسطيون",
    "Category:Chadian non-fiction writers": "تصنيف:كتاب غير روائيين تشاديون",
    "Category:Chilean non-fiction writers": "تصنيف:كتاب غير روائيين تشيليون",
    "Category:Chinese non-fiction writers": "تصنيف:كتاب غير روائيين صينيون",
    "Category:Colombian non-fiction writers": "تصنيف:كتاب غير روائيين كولومبيون",
    "Category:Croatian non-fiction writers by century": "تصنيف:كتاب غير روائيين كروات حسب القرن",
    "Category:Cuban non-fiction writers": "تصنيف:كتاب غير روائيين كوبيون",
    "Category:Cypriot non-fiction writers": "تصنيف:كتاب غير روائيين قبرصيون",
    "Category:Czech non-fiction writers": "تصنيف:كتاب غير روائيين تشيكيون",
    "Category:Danish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور دنماركيون",
    "Category:Danish non-fiction writers": "تصنيف:كتاب غير روائيين دنماركيون",
    "Category:Danish non-fiction writers by century": "تصنيف:كتاب غير روائيين دنماركيون حسب القرن",
    "Category:Democratic republic of congo non-fiction writers": "تصنيف:كتاب غير روائيين كونغويون ديمقراطيون",
    "Category:Dutch non-fiction writers": "تصنيف:كتاب غير روائيين هولنديون",
    "Category:Dutch non-fiction writers by century": "تصنيف:كتاب غير روائيين هولنديون حسب القرن",
    "Category:Egyptian non-fiction writers": "تصنيف:كتاب غير روائيين مصريون",
    "Category:Emirati non-fiction writers": "تصنيف:كتاب غير روائيين إماراتيون",
    "Category:English male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إنجليز",
    "Category:English non-fiction crime writers": "تصنيف:كتاب جريمة غير روائيين إنجليز",
    "Category:English non-fiction writers by century": "تصنيف:كتاب غير روائيين إنجليز حسب القرن",
    "Category:Eritrean non-fiction writers": "تصنيف:كتاب غير روائيين إريتريون",
    "Category:Estonian non-fiction writers": "تصنيف:كتاب غير روائيين إستونيون",
    "Category:Ethiopian non-fiction writers": "تصنيف:كتاب غير روائيين إثيوبيون",
    "Category:Filipino non-fiction writers": "تصنيف:كتاب غير روائيين فلبينيون",
    "Category:Finnish non-fiction writers": "تصنيف:كتاب غير روائيين فنلنديون",
    "Category:Finnish non-fiction writers by century": "تصنيف:كتاب غير روائيين فنلنديون حسب القرن",
    "Category:French male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور فرنسيون",
    "Category:French non-fiction writers": "تصنيف:كتاب غير روائيين فرنسيون",
    "Category:French non-fiction writers by century": "تصنيف:كتاب غير روائيين فرنسيون حسب القرن",
    "Category:Gambian non-fiction writers": "تصنيف:كتاب غير روائيين غامبيون",
    "Category:German male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور ألمان",
    "Category:German non-fiction writers": "تصنيف:كتاب غير روائيين ألمان",
    "Category:German non-fiction writers by century": "تصنيف:كتاب غير روائيين ألمان حسب القرن",
    "Category:Ghanaian non-fiction writers": "تصنيف:كتاب غير روائيين غانيون",
    "Category:Greek non-fiction writers": "تصنيف:كتاب غير روائيين يونانيون",
    "Category:Guadeloupean non-fiction writers": "تصنيف:كتاب غير روائيين غواديلوبيون",
    "Category:Guyanese non-fiction writers": "تصنيف:كتاب غير روائيين غيانيون",
    "Category:Haitian non-fiction writers": "تصنيف:كتاب غير روائيين هايتيون",
    "Category:Hungarian non-fiction writers": "تصنيف:كتاب غير روائيين مجريون",
    "Category:Icelandic non-fiction writers": "تصنيف:كتاب غير روائيين آيسلنديون",
    "Category:Indian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور هنود",
    "Category:Indian non-fiction environmental writers": "تصنيف:كتاب بيئة غير روائيين هنود",
    "Category:Indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود",
    "Category:Indian non-fiction writers by century": "تصنيف:كتاب غير روائيين هنود حسب القرن",
    "Category:Indonesian non-fiction writers": "تصنيف:كتاب غير روائيين إندونيسيون",
    "Category:Iranian non-fiction writers": "تصنيف:كتاب غير روائيين إيرانيون",
    "Category:Iraqi non-fiction writers": "تصنيف:كتاب غير روائيين عراقيون",
    "Category:Irish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور أيرلنديون",
    "Category:Irish non-fiction writers": "تصنيف:كتاب غير روائيين أيرلنديون",
    "Category:Irish non-fiction writers by century": "تصنيف:كتاب غير روائيين أيرلنديون حسب القرن",
    "Category:Israeli non-fiction writers": "تصنيف:كتاب غير روائيين إسرائيليون",
    "Category:Israeli non-fiction writers by century": "تصنيف:كتاب غير روائيين إسرائيليون حسب القرن",
    "Category:Italian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إيطاليون",
    "Category:Italian non-fiction writers": "تصنيف:كتاب غير روائيين إيطاليون",
    "Category:Italian non-fiction writers by century": "تصنيف:كتاب غير روائيين إيطاليون حسب القرن",
    "Category:Jamaican non-fiction writers": "تصنيف:كتاب غير روائيين جامايكيون",
    "Category:Japanese non-fiction writers": "تصنيف:كتاب غير روائيين يابانيون",
    "Category:Japanese non-fiction writers by century": "تصنيف:كتاب غير روائيين يابانيون حسب القرن",
    "Category:Jewish American non-fiction writers": "تصنيف:كتاب غير روائيين أمريكيون يهود",
    "Category:Jewish non-fiction writers": "تصنيف:كتاب غير روائيين يهود",
    "Category:Kenyan non-fiction writers": "تصنيف:كتاب غير روائيين كينيون",
    "Category:Korean non-fiction writers": "تصنيف:كتاب غير روائيين كوريون",
    "Category:Kosovan non-fiction writers": "تصنيف:كتاب غير روائيين كوسوفيون",
    "Category:Kuwaiti non-fiction writers": "تصنيف:كتاب غير روائيين كويتيون",
    "Category:Latvian non-fiction writers": "تصنيف:كتاب غير روائيين لاتفيون",
    "Category:Lebanese non-fiction writers": "تصنيف:كتاب غير روائيين لبنانيون",
    "Category:Liberian non-fiction writers": "تصنيف:كتاب غير روائيين ليبيريون",
    "Category:Libyan non-fiction writers": "تصنيف:كتاب غير روائيين ليبيون",
    "Category:Lithuanian non-fiction writers": "تصنيف:كتاب غير روائيين ليتوانيون",
    "Category:Luxembourgian non-fiction writers": "تصنيف:كتاب غير روائيين لوكسمبورغيون",
    "Category:Macedonian non-fiction writers": "تصنيف:كتاب غير روائيين مقدونيون",
    "Category:Malawian non-fiction writers": "تصنيف:كتاب غير روائيين ملاويون",
    "Category:Malaysian non-fiction writers": "تصنيف:كتاب غير روائيين ماليزيون",
    "Category:Male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور",
    "Category:Male non-fiction writers by nationality": "تصنيف:كتاب غير روائيين ذكور حسب الجنسية",
    "Category:Male non-fiction writers from Northern Ireland": "تصنيف:كتاب غير روائيين ذكور من أيرلندا الشمالية",
    "Category:Malian non-fiction writers": "تصنيف:كتاب غير روائيين ماليون",
    "Category:Maltese non-fiction writers": "تصنيف:كتاب غير روائيين مالطيون",
    "Category:Mauritian non-fiction writers": "تصنيف:كتاب غير روائيين موريشيوسيون",
    "Category:Mexican non-fiction writers": "تصنيف:كتاب غير روائيين مكسيكيون",
    "Category:Moroccan non-fiction writers": "تصنيف:كتاب غير روائيين مغاربة",
    "Category:Mozambican non-fiction writers": "تصنيف:كتاب غير روائيين موزمبيقيون",
    "Category:Namibian non-fiction writers": "تصنيف:كتاب غير روائيين ناميبيون",
    "Category:Nigerian non-fiction writers": "تصنيف:كتاب غير روائيين نيجيريون",
    "Category:Non-fiction crime writers": "تصنيف:كتاب جريمة غير روائيين",
    "Category:Non-fiction environmental writers": "تصنيف:كتاب بيئة غير روائيين",
    "Category:Non-fiction writers": "تصنيف:كتاب غير روائيين",
    "Category:Non-fiction writers about organized crime in Italy": "تصنيف:كتاب غير روائيين عن الجريمة المنظمة في إيطاليا",
    "Category:Non-fiction writers about organized crime in the United States": "تصنيف:كتاب غير روائيين عن الجريمة المنظمة في الولايات المتحدة",
    "Category:Non-fiction writers about the French Connection": "تصنيف:كتاب غير روائيين عن الرابط الفرنسي",
    "Category:Non-fiction writers by century": "تصنيف:كتاب غير روائيين حسب القرن",
    "Category:Non-fiction writers by century and nationality": "تصنيف:كتاب غير روائيين حسب القرن والجنسية",
    "Category:Non-fiction writers by nationality": "تصنيف:كتاب غير روائيين حسب الجنسية",
    "Category:Non-fiction writers by nationality and century": "تصنيف:كتاب غير روائيين حسب الجنسية والقرن",
    "Category:Non-fiction writers from Cornwall": "تصنيف:كتاب غير روائيين من كورنوال",
    "Category:Non-fiction writers from Georgia (country)": "تصنيف:كتاب غير روائيين من جورجيا",
    "Category:Non-fiction writers from Northern Ireland": "تصنيف:كتاب غير روائيين من أيرلندا الشمالية",
    "Category:Non-fiction writers from the Ottoman Empire": "تصنيف:كتاب غير روائيين من الدولة العثمانية",
    "Category:Non-fiction writers from the Russian Empire": "تصنيف:كتاب غير روائيين من الإمبراطورية الروسية",
    "Category:Norwegian non-fiction writers": "تصنيف:كتاب غير روائيين نرويجيون",
    "Category:Norwegian non-fiction writers by century": "تصنيف:كتاب غير روائيين نرويجيون حسب القرن",
    "Category:Pakistani non-fiction writers": "تصنيف:كتاب غير روائيين باكستانيون",
    "Category:Pakistani non-fiction writers by century": "تصنيف:كتاب غير روائيين باكستانيون حسب القرن",
    "Category:Palestinian non-fiction writers": "تصنيف:كتاب غير روائيين فلسطينيون",
    "Category:Paraguayan non-fiction writers": "تصنيف:كتاب غير روائيين باراغوايانيون",
    "Category:Peruvian non-fiction writers": "تصنيف:كتاب غير روائيين بيرويون",
    "Category:Polish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بولنديون",
    "Category:Polish non-fiction writers": "تصنيف:كتاب غير روائيين بولنديون",
    "Category:Portuguese non-fiction writers": "تصنيف:كتاب غير روائيين برتغاليون",
    "Category:Puerto Rican non-fiction writers": "تصنيف:كتاب غير روائيين بورتوريكيون",
    "Category:Qatari non-fiction writers": "تصنيف:كتاب غير روائيين قطريون",
    "Category:Romanian non-fiction writers": "تصنيف:كتاب غير روائيين رومان",
    "Category:Russian non-fiction writers": "تصنيف:كتاب غير روائيين روس",
    "Category:Russian non-fiction writers by century": "تصنيف:كتاب غير روائيين روس حسب القرن",
    "Category:Rwandan non-fiction writers": "تصنيف:كتاب غير روائيين روانديون",
    "Category:Sahrawi non-fiction writers": "تصنيف:كتاب غير روائيين صحراويون",
    "Category:Saudi Arabian non-fiction writers": "تصنيف:كتاب غير روائيين سعوديون",
    "Category:Scottish non-fiction writers": "تصنيف:كتاب غير روائيين إسكتلنديون",
    "Category:Scottish non-fiction writers by century": "تصنيف:كتاب غير روائيين إسكتلنديون حسب القرن",
    "Category:Senegalese non-fiction writers": "تصنيف:كتاب غير روائيين سنغاليون",
    "Category:Serbian non-fiction writers": "تصنيف:كتاب غير روائيين صرب",
    "Category:Sierra Leonean non-fiction writers": "تصنيف:كتاب غير روائيين سيراليونيون",
    "Category:Singaporean non-fiction writers": "تصنيف:كتاب غير روائيين سنغافوريون",
    "Category:Slovak non-fiction writers": "تصنيف:كتاب غير روائيين سلوفاكيون",
    "Category:Slovenian non-fiction writers": "تصنيف:كتاب غير روائيين سلوفينيون",
    "Category:Somalian non-fiction writers": "تصنيف:كتاب غير روائيين صوماليون",
    "Category:South Korean non-fiction writers": "تصنيف:كتاب غير روائيين كوريون جنوبيون",
    "Category:Soviet non-fiction writers": "تصنيف:كتاب غير روائيين سوفيت",
    "Category:Spanish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إسبان",
    "Category:Spanish non-fiction writers": "تصنيف:كتاب غير روائيين إسبان",
    "Category:Spanish non-fiction writers by century": "تصنيف:كتاب غير روائيين إسبان حسب القرن",
    "Category:Sri Lankan non-fiction writers": "تصنيف:كتاب غير روائيين سريلانكيون",
    "Category:Sudanese non-fiction writers": "تصنيف:كتاب غير روائيين سودانيون",
    "Category:Swedish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور سويديون",
    "Category:Swedish non-fiction writers": "تصنيف:كتاب غير روائيين سويديون",
    "Category:Swedish non-fiction writers by century": "تصنيف:كتاب غير روائيين سويديون حسب القرن",
    "Category:Swiss non-fiction writers": "تصنيف:كتاب غير روائيين سويسريون",
    "Category:Swiss non-fiction writers by century": "تصنيف:كتاب غير روائيين سويسريون حسب القرن",
    "Category:Syrian non-fiction writers": "تصنيف:كتاب غير روائيين سوريون",
    "Category:Taiwanese non-fiction writers": "تصنيف:كتاب غير روائيين تايوانيون",
    "Category:Tajikistani non-fiction writers": "تصنيف:كتاب غير روائيين طاجيك",
    "Category:Tanzanian non-fiction writers": "تصنيف:كتاب غير روائيين تنزانيون",
    "Category:Thai non-fiction writers": "تصنيف:كتاب غير روائيين تايلنديون",
    "Category:Togolese non-fiction writers": "تصنيف:كتاب توغويون غير روائيين",
    "Category:Trinidad and Tobago non-fiction writers": "تصنيف:كتاب غير روائيين ترنيداديون",
    "Category:Tunisian non-fiction writers": "تصنيف:كتاب غير روائيين تونسيون",
    "Category:Turkish Cypriot non-fiction writers": "تصنيف:كتاب غير روائيين قبرصيون شماليون",
    "Category:Turkish non-fiction writers": "تصنيف:كتاب غير روائيين أتراك",
    "Category:Ugandan non-fiction writers": "تصنيف:كتاب غير روائيين أوغنديون",
    "Category:Ukrainian non-fiction writers": "تصنيف:كتاب غير روائيين أوكرانيون",
    "Category:Uruguayan non-fiction writers": "تصنيف:كتاب غير روائيين أوروغويانيون",
    "Category:Venezuelan non-fiction writers": "تصنيف:كتاب غير روائيين فنزويليون",
    "Category:Vietnamese non-fiction writers": "تصنيف:كتاب غير روائيين فيتناميون",
    "Category:Yemeni non-fiction writers": "تصنيف:كتاب غير روائيين يمنيون",
    "Category:Yugoslav non-fiction writers": "تصنيف:كتاب غير روائيين يوغسلافيون",
    "Category:Zambian non-fiction writers": "تصنيف:كتاب غير روائيين زامبيون",
}
to_test = [
    ("text_non_fiction", data_1),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.skip2
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    diff_result2 = {x: v for x, v in diff_result.items() if v}
    # dump_diff(diff_result2, name)

    expected2 = {x: v for x, v in expected.items() if v and x in diff_result2}
    # dump_diff(expected2, f"{name}_expected")

    save3 = [f"* [[:{v}]]>[[:{diff_result2[x]}]]" for x, v in expected.items() if v and x in diff_result2]
    dump_diff(save3, f"{name}_d", _sort=False)

    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
