#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {
    "Category:Jewish American non-fiction writers": "تصنيف:كتاب غير روائيين أمريكيون يهود",
    "Category:Non-fiction books about the United States Army": "تصنيف:كتب غير خيالية عن القوات المسلحة الأمريكية",
    "Category:Non-fiction works about the United States Army": "تصنيف:أعمال غير خيالية عن القوات المسلحة الأمريكية",
    "category:non-fiction writers from northern ireland": "تصنيف:كتاب غير روائيين من أيرلندا الشمالية",
    "category:non-fiction writers from russian empire": "تصنيف:كتاب غير روائيين من الإمبراطورية الروسية",
    "category:1550 non-fiction books": "تصنيف:كتب غير خيالية 1550",
    "category:1550s non-fiction books": "تصنيف:كتب غير خيالية عقد 1550",
    "category:20th-century american non-fiction writers": "تصنيف:كتاب غير روائيين أمريكيون في القرن 20",
    "category:20th-century australian non-fiction writers": "تصنيف:كتاب غير روائيين أستراليون في القرن 20",
    "category:20th-century austrian non-fiction writers": "تصنيف:كتاب غير روائيين نمساويون في القرن 20",
    "category:20th-century bangladeshi non-fiction writers": "تصنيف:كتاب غير روائيين بنغلاديشيون في القرن 20",
    "category:20th-century belgian non-fiction writers": "تصنيف:كتاب غير روائيين بلجيكيون في القرن 20",
    "category:20th-century brazilian non-fiction writers": "تصنيف:كتاب غير روائيين برازيليون في القرن 20",
    "category:20th-century british non-fiction writers": "تصنيف:كتاب غير روائيين بريطانيون في القرن 20",
    "category:20th-century canadian non-fiction writers": "تصنيف:كتاب غير روائيين كنديون في القرن 20",
    "category:20th-century chilean non-fiction writers": "تصنيف:كتاب غير روائيين تشيليون في القرن 20",
    "category:20th-century chinese non-fiction writers": "تصنيف:كتاب غير روائيين صينيون في القرن 20",
    "category:20th-century croatian non-fiction writers": "تصنيف:كتاب غير روائيين كروات في القرن 20",
    "category:20th-century czech non-fiction writers": "تصنيف:كتاب غير روائيين تشيكيون في القرن 20",
    "category:20th-century danish non-fiction writers": "تصنيف:كتاب غير روائيين دنماركيون في القرن 20",
    "category:20th-century dutch non-fiction writers": "تصنيف:كتاب غير روائيين هولنديون في القرن 20",
    "category:20th-century egyptian non-fiction writers": "تصنيف:كتاب غير روائيين مصريون في القرن 20",
    "category:20th-century english non-fiction writers": "تصنيف:كتاب غير روائيين إنجليز في القرن 20",
    "category:20th-century finnish non-fiction writers": "تصنيف:كتاب غير روائيين فنلنديون في القرن 20",
    "category:20th-century french non-fiction writers": "تصنيف:كتاب غير روائيين فرنسيون في القرن 20",
    "category:20th-century german non-fiction writers": "تصنيف:كتاب غير روائيين ألمان في القرن 20",
    "category:20th-century greek non-fiction writers": "تصنيف:كتاب غير روائيين يونانيون في القرن 20",
    "category:20th-century indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 20",
    "category:20th-century irish non-fiction writers": "تصنيف:كتاب غير روائيين أيرلنديون في القرن 20",
    "category:20th-century israeli non-fiction writers": "تصنيف:كتاب غير روائيين إسرائيليون في القرن 20",
    "category:20th-century italian non-fiction writers": "تصنيف:كتاب غير روائيين إيطاليون في القرن 20",
    "category:20th-century japanese non-fiction writers": "تصنيف:كتاب غير روائيين يابانيون في القرن 20",
    "category:20th-century lithuanian non-fiction writers": "تصنيف:كتاب غير روائيين ليتوانيون في القرن 20",
    "category:20th-century mexican non-fiction writers": "تصنيف:كتاب غير روائيين مكسيكيون في القرن 20",
    "category:20th-century non-fiction books": "تصنيف:كتب غير خيالية القرن 20",
    "category:20th-century non-fiction writers by nationality": "تصنيف:كتاب غير روائيين في القرن 20 حسب الجنسية",
    "category:20th-century non-fiction writers from northern ireland": "تصنيف:كتاب غير روائيين من أيرلندا الشمالية في القرن 20",
    "category:20th-century non-fiction writers from russian empire": "تصنيف:كتاب غير روائيين من الإمبراطورية الروسية في القرن 20",
    "category:20th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 20",
    "category:20th-century norwegian non-fiction writers": "تصنيف:كتاب غير روائيين نرويجيون في القرن 20",
    "category:20th-century polish non-fiction writers": "تصنيف:كتاب غير روائيين بولنديون في القرن 20",
    "category:20th-century portuguese non-fiction writers": "تصنيف:كتاب غير روائيين برتغاليون في القرن 20",
    "category:20th-century puerto rican non-fiction writers": "تصنيف:كتاب غير روائيين بورتوريكيون في القرن 20",
    "category:20th-century russian non-fiction writers": "تصنيف:كتاب غير روائيين روس في القرن 20",
    "category:20th-century scottish non-fiction writers": "تصنيف:كتاب غير روائيين إسكتلنديون في القرن 20",
    "category:20th-century south korean non-fiction writers": "تصنيف:كتاب غير روائيين كوريون جنوبيون في القرن 20",
    "category:20th-century spanish non-fiction writers": "تصنيف:كتاب غير روائيين إسبان في القرن 20",
    "category:20th-century swedish non-fiction writers": "تصنيف:كتاب غير روائيين سويديون في القرن 20",
    "category:20th-century swiss non-fiction writers": "تصنيف:كتاب غير روائيين سويسريون في القرن 20",
    "category:20th-century turkish non-fiction writers": "تصنيف:كتاب غير روائيين أتراك في القرن 20",
    "category:20th-century welsh non-fiction writers": "تصنيف:كتاب غير روائيين ويلزيون في القرن 20",
    "category:2nd-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 2",
    "category:3rd-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 3",
    "category:4th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 4",
    "category:5th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 5",
    "category:6th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 6",
    "category:7th-century indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 7",
    "category:7th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 7",
    "category:8th-century indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 8",
    "category:8th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 8",
    "category:9th-century indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود في القرن 9",
    "category:9th-century non-fiction writers": "تصنيف:كتاب غير روائيين في القرن 9",
    "category:academic journals published by non-profit organisations of united kingdom": "تصنيف:نشرات دورية أكاديمية نشرتها منظمات غير ربحية في المملكة المتحدة",
    "category:academic journals published by non-profit organizations of brazil": "تصنيف:نشرات دورية أكاديمية نشرتها منظمات غير ربحية في البرازيل",
    "category:academic journals published by non-profit organizations of canada": "تصنيف:نشرات دورية أكاديمية نشرتها منظمات غير ربحية في كندا",
    "category:academic journals published by non-profit organizations of chile": "تصنيف:نشرات دورية أكاديمية نشرتها منظمات غير ربحية في تشيلي",
    "category:academic journals published by non-profit organizations of colombia": "تصنيف:نشرات دورية أكاديمية نشرتها منظمات غير ربحية في كولومبيا",
    "category:academic journals published by non-profit organizations of costa rica": "تصنيف:نشرات دورية أكاديمية نشرتها منظمات غير ربحية في كوستاريكا",
    "category:academic journals published by non-profit organizations of united states": "تصنيف:نشرات دورية أكاديمية نشرتها منظمات غير ربحية في الولايات المتحدة",
    "category:academic journals published by non-profit organizations": "تصنيف:نشرات دورية أكاديمية نشرتها منظمات غير ربحية",
    "category:academic journals published by non-profit publishers": "تصنيف:نشرات دورية أكاديمية نشرتها ناشرون غير ربحيون",
    "category:african-american non-fiction writers": "تصنيف:كتاب غير روائيين أمريكيون أفارقة",
    "category:albanian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور ألبان",
    "category:albanian non-fiction writers": "تصنيف:كتاب غير روائيين ألبان",
    "category:algerian non-fiction writers": "تصنيف:كتاب غير روائيين جزائريون",
    "category:american male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور أمريكيون",
    "category:american non-fiction books by writer": "تصنيف:كتب أمريكية غير خيالية حسب الكاتب",
    "category:american non-fiction books": "تصنيف:كتب أمريكية غير خيالية",
    "category:american non-fiction crime writers": "تصنيف:كتاب جريمة غير روائيين أمريكيون",
    "category:american non-fiction environmental writers": "تصنيف:كتاب بيئة غير روائيين أمريكيون",
    "category:american non-fiction writers by century": "تصنيف:كتاب غير روائيين أمريكيون حسب القرن",
    "category:american non-fiction writers": "تصنيف:كتاب غير روائيين أمريكيون",
    "category:american women non-fiction writers": "تصنيف:كاتبات غير روائيات أمريكيات",
    "category:angolan non-fiction writers": "تصنيف:كتاب غير روائيين أنغوليون",
    "category:arab non-fiction writers": "تصنيف:كتاب غير روائيين عرب",
    "category:argentine male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور أرجنتينيون",
    "category:argentine non-fiction books": "تصنيف:كتب أرجنتينية غير خيالية",
    "category:argentine non-fiction writers": "تصنيف:كتاب غير روائيين أرجنتينيون",
    "category:argentine women non-fiction writers": "تصنيف:كاتبات غير روائيات أرجنتينيات",
    "category:armenian non-fiction writers": "تصنيف:كتاب غير روائيين أرمن",
    "category:australian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور أستراليون",
    "category:australian non-fiction books": "تصنيف:كتب أسترالية غير خيالية",
    "category:australian non-fiction crime writers": "تصنيف:كتاب جريمة غير روائيين أستراليون",
    "category:australian non-fiction writers by century": "تصنيف:كتاب غير روائيين أستراليون حسب القرن",
    "category:australian non-fiction writers": "تصنيف:كتاب غير روائيين أستراليون",
    "category:australian women non-fiction writers": "تصنيف:كاتبات غير روائيات أستراليات",
    "category:austrian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور نمساويون",
    "category:austrian non-fiction books": "تصنيف:كتب نمساوية غير خيالية",
    "category:austrian non-fiction writers": "تصنيف:كتاب غير روائيين نمساويون",
    "category:austrian women non-fiction writers": "تصنيف:كاتبات غير روائيات نمساويات",
    "category:azerbaijani non-fiction books": "تصنيف:كتب أذربيجانية غير خيالية",
    "category:azerbaijani non-fiction writers": "تصنيف:كتاب غير روائيين أذربيجانيون",
    "category:bahraini non-fiction writers": "تصنيف:كتاب غير روائيين بحرينيون",
    "category:bangladeshi non-fiction books": "تصنيف:كتب بنغلاديشية غير خيالية",
    "category:bangladeshi non-fiction writers": "تصنيف:كتاب غير روائيين بنغلاديشيون",
    "category:belarusian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بيلاروسيون",
    "category:belarusian non-fiction writers": "تصنيف:كتاب غير روائيين بيلاروسيون",
    "category:belgian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بلجيكيون",
    "category:belgian non-fiction writers by century": "تصنيف:كتاب غير روائيين بلجيكيون حسب القرن",
    "category:belgian non-fiction writers": "تصنيف:كتاب غير روائيين بلجيكيون",
    "category:beninese non-fiction writers": "تصنيف:كتاب غير روائيين بنينيون",
    "category:bermudian non-fiction writers": "تصنيف:كتاب غير روائيين برموديون",
    "category:bolivian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بوليفيون",
    "category:bolivian non-fiction writers": "تصنيف:كتاب غير روائيين بوليفيون",
    "category:bosnia and herzegovina non-fiction writers": "تصنيف:كتاب غير روائيين بوسنيون",
    "category:botswana non-fiction writers": "تصنيف:كتاب غير روائيين بوتسوانيون",
    "category:brazilian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور برازيليون",
    "category:brazilian non-fiction books": "تصنيف:كتب برازيلية غير خيالية",
    "category:brazilian non-fiction writers by century": "تصنيف:كتاب غير روائيين برازيليون حسب القرن",
    "category:brazilian non-fiction writers": "تصنيف:كتاب غير روائيين برازيليون",
    "category:brazilian women non-fiction writers": "تصنيف:كاتبات غير روائيات برازيليات",
    "category:british male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بريطانيون",
    "category:british non-fiction books": "تصنيف:كتب بريطانية غير خيالية",
    "category:british non-fiction crime writers": "تصنيف:كتاب جريمة غير روائيين بريطانيون",
    "category:british non-fiction environmental writers": "تصنيف:كتاب بيئة غير روائيين بريطانيون",
    "category:british non-fiction writers by century": "تصنيف:كتاب غير روائيين بريطانيون حسب القرن",
    "category:british non-fiction writers": "تصنيف:كتاب غير روائيين بريطانيون",
    "category:british women non-fiction writers": "تصنيف:كاتبات غير روائيات بريطانيات",
    "category:bulgarian non-fiction writers": "تصنيف:كتاب غير روائيين بلغاريون",
    "category:burkinabe non-fiction writers": "تصنيف:كتاب غير روائيين بوركينابيون",
    "category:burmese non-fiction writers": "تصنيف:كتاب غير روائيين بورميون",
    "category:burundian non-fiction writers": "تصنيف:كتاب غير روائيين بورونديون",
    "category:cameroonian non-fiction writers": "تصنيف:كتاب غير روائيين كاميرونيون",
    "category:canadian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور كنديون",
    "category:canadian non-fiction books": "تصنيف:كتب كندية غير خيالية",
    "category:canadian non-fiction writers by century": "تصنيف:كتاب غير روائيين كنديون حسب القرن",
    "category:canadian non-fiction writers": "تصنيف:كتاب غير روائيين كنديون",
    "category:canadian women non-fiction writers": "تصنيف:كاتبات غير روائيات كنديات",
    "category:cape verdean non-fiction writers": "تصنيف:كتاب غير روائيين أخضريون",
    "category:central african republic non-fiction writers": "تصنيف:كتاب غير روائيين أفارقة أوسطيون",
    "category:chadian non-fiction writers": "تصنيف:كتاب غير روائيين تشاديون",
    "category:chilean male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور تشيليون",
    "category:chilean non-fiction writers": "تصنيف:كتاب غير روائيين تشيليون",
    "category:chinese male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور صينيون",
    "category:chinese non-fiction books": "تصنيف:كتب صينية غير خيالية",
    "category:chinese non-fiction writers": "تصنيف:كتاب غير روائيين صينيون",
    "category:chinese women non-fiction writers": "تصنيف:كاتبات غير روائيات صينيات",
    "category:colombian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور كولومبيون",
    "category:colombian non-fiction books": "تصنيف:كتب كولومبية غير خيالية",
    "category:colombian non-fiction writers": "تصنيف:كتاب غير روائيين كولومبيون",
    "category:comorian non-fiction writers": "تصنيف:كتاب غير روائيين قمريون",
    "category:croatian non-fiction writers by century": "تصنيف:كتاب غير روائيين كروات حسب القرن",
    "category:croatian non-fiction writers": "تصنيف:كتاب غير روائيين كروات",
    "category:cuban male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور كوبيون",
    "category:cuban non-fiction writers": "تصنيف:كتاب غير روائيين كوبيون",
    "category:cypriot non-fiction writers": "تصنيف:كتاب غير روائيين قبرصيون",
    "category:czech male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور تشيكيون",
    "category:czech non-fiction writers by century": "تصنيف:كتاب غير روائيين تشيكيون حسب القرن",
    "category:czech non-fiction writers": "تصنيف:كتاب غير روائيين تشيكيون",
    "category:czech women non-fiction writers": "تصنيف:كاتبات غير روائيات تشيكيات",
    "category:danish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور دنماركيون",
    "category:danish non-fiction books": "تصنيف:كتب دنماركية غير خيالية",
    "category:danish non-fiction writers by century": "تصنيف:كتاب غير روائيين دنماركيون حسب القرن",
    "category:danish non-fiction writers": "تصنيف:كتاب غير روائيين دنماركيون",
    "category:danish women non-fiction writers": "تصنيف:كاتبات غير روائيات دنماركيات",
    "category:defunct non-profit organizations based in united states": "تصنيف:منظمات غير ربحية سابقة مقرها في الولايات المتحدة",
    "category:democratic republic of congo non-fiction writers": "تصنيف:كتاب غير روائيين كونغويون ديمقراطيون",
    "category:dutch male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور هولنديون",
    "category:dutch non-fiction books": "تصنيف:كتب هولندية غير خيالية",
    "category:dutch non-fiction writers by century": "تصنيف:كتاب غير روائيين هولنديون حسب القرن",
    "category:dutch non-fiction writers": "تصنيف:كتاب غير روائيين هولنديون",
    "category:dutch women non-fiction writers": "تصنيف:كاتبات غير روائيات هولنديات",
    "category:economy of lebanon-related lists": "تصنيف:اقتصاد قوائم متعلقة بلبنان",
    "category:egyptian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور مصريون",
    "category:egyptian non-fiction books": "تصنيف:كتب مصرية غير خيالية",
    "category:egyptian non-fiction writers": "تصنيف:كتاب غير روائيين مصريون",
    "category:egyptian women non-fiction writers": "تصنيف:كاتبات غير روائيات مصريات",
    "category:emirati non-fiction books": "تصنيف:كتب إماراتية غير خيالية",
    "category:emirati non-fiction writers": "تصنيف:كتاب غير روائيين إماراتيون",
    "category:english male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إنجليز",
    "category:english non-fiction books": "تصنيف:كتب إنجليزية غير خيالية",
    "category:english non-fiction crime writers": "تصنيف:كتاب جريمة غير روائيين إنجليز",
    "category:english non-fiction writers by century": "تصنيف:كتاب غير روائيين إنجليز حسب القرن",
    "category:english non-fiction writers": "تصنيف:كتاب غير روائيين إنجليز",
    "category:english women non-fiction writers": "تصنيف:كاتبات غير روائيات إنجليزيات",
    "category:eritrean non-fiction writers": "تصنيف:كتاب غير روائيين إريتريون",
    "category:estonian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إستونيون",
    "category:estonian non-fiction books": "تصنيف:كتب إستونية غير خيالية",
    "category:estonian non-fiction writers": "تصنيف:كتاب غير روائيين إستونيون",
    "category:estonian women non-fiction writers": "تصنيف:كاتبات غير روائيات إستونيات",
    "category:ethiopian non-fiction writers": "تصنيف:كتاب غير روائيين إثيوبيون",
    "category:filipino non-fiction writers": "تصنيف:كتاب غير روائيين فلبينيون",
    "category:films based on non-fiction books about organized crime": "تصنيف:أفلام مبنية على كتب غير خيالية عن جريمة منظمة",
    "category:films based on non-fiction books": "تصنيف:أفلام مبنية على كتب غير خيالية",
    "category:finnish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور فنلنديون",
    "category:finnish non-fiction books": "تصنيف:كتب فنلندية غير خيالية",
    "category:finnish non-fiction writers by century": "تصنيف:كتاب غير روائيين فنلنديون حسب القرن",
    "category:finnish non-fiction writers": "تصنيف:كتاب غير روائيين فنلنديون",
    "category:finnish women non-fiction writers": "تصنيف:كاتبات غير روائيات فنلنديات",
    "category:french male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور فرنسيون",
    "category:french non-fiction books": "تصنيف:كتب فرنسية غير خيالية",
    "category:french non-fiction writers by century": "تصنيف:كتاب غير روائيين فرنسيون حسب القرن",
    "category:french non-fiction writers": "تصنيف:كتاب غير روائيين فرنسيون",
    "category:french women non-fiction writers": "تصنيف:كاتبات غير روائيات فرنسيات",
    "category:gabonese non-fiction writers": "تصنيف:كتاب غير روائيين غابونيون",
    "category:gambian non-fiction writers": "تصنيف:كتاب غير روائيين غامبيون",
    "category:german male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور ألمان",
    "category:german non-fiction books": "تصنيف:كتب ألمانية غير خيالية",
    "category:german non-fiction writers by century": "تصنيف:كتاب غير روائيين ألمان حسب القرن",
    "category:german non-fiction writers": "تصنيف:كتاب غير روائيين ألمان",
    "category:german women non-fiction writers": "تصنيف:كاتبات غير روائيات ألمانيات",
    "category:ghanaian non-fiction writers": "تصنيف:كتاب غير روائيين غانيون",
    "category:gibraltarian non-fiction writers": "تصنيف:كتاب غير روائيين جبل طارقيون",
    "category:greek male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور يونانيون",
    "category:greek non-fiction writers by century": "تصنيف:كتاب غير روائيين يونانيون حسب القرن",
    "category:greek non-fiction writers": "تصنيف:كتاب غير روائيين يونانيون",
    "category:greek women non-fiction writers": "تصنيف:كاتبات غير روائيات يونانيات",
    "category:greenlandic non-fiction writers": "تصنيف:كتاب غير روائيين جرينلانديون",
    "category:guadeloupean non-fiction writers": "تصنيف:كتاب غير روائيين غواديلوبيون",
    "category:guyanese non-fiction writers": "تصنيف:كتاب غير روائيين غيانيون",
    "category:haitian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور هايتيون",
    "category:haitian non-fiction writers": "تصنيف:كتاب غير روائيين هايتيون",
    "category:hong kong non-fiction books": "تصنيف:كتب هونغ كونغية غير خيالية",
    "category:hungarian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور مجريون",
    "category:hungarian non-fiction writers": "تصنيف:كتاب غير روائيين مجريون",
    "category:hungarian women non-fiction writers": "تصنيف:كاتبات غير روائيات مجريات",
    "category:icelandic non-fiction writers": "تصنيف:كتاب غير روائيين آيسلنديون",
    "category:indian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور هنود",
    "category:indian non-fiction books": "تصنيف:كتب هندية غير خيالية",
    "category:indian non-fiction environmental writers": "تصنيف:كتاب بيئة غير روائيين هنود",
    "category:indian non-fiction writers by century": "تصنيف:كتاب غير روائيين هنود حسب القرن",
    "category:indian non-fiction writers": "تصنيف:كتاب غير روائيين هنود",
    "category:indian women non-fiction writers": "تصنيف:كاتبات غير روائيات هنديات",
    "category:indonesian non-fiction books": "تصنيف:كتب إندونيسية غير خيالية",
    "category:indonesian non-fiction writers": "تصنيف:كتاب غير روائيين إندونيسيون",
    "category:international non-profit organizations": "تصنيف:منظمات غير ربحية دولية",
    "category:iranian non-fiction writers": "تصنيف:كتاب غير روائيين إيرانيون",
    "category:iraqi non-fiction books": "تصنيف:كتب عراقية غير خيالية",
    "category:iraqi non-fiction writers": "تصنيف:كتاب غير روائيين عراقيون",
    "category:irish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور أيرلنديون",
    "category:irish non-fiction books": "تصنيف:كتب أيرلندية غير خيالية",
    "category:irish non-fiction writers by century": "تصنيف:كتاب غير روائيين أيرلنديون حسب القرن",
    "category:irish non-fiction writers": "تصنيف:كتاب غير روائيين أيرلنديون",
    "category:irish women non-fiction writers": "تصنيف:كاتبات غير روائيات أيرلنديات",
    "category:israeli male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إسرائيليون",
    "category:israeli non-fiction books": "تصنيف:كتب إسرائيلية غير خيالية",
    "category:israeli non-fiction writers by century": "تصنيف:كتاب غير روائيين إسرائيليون حسب القرن",
    "category:israeli non-fiction writers": "تصنيف:كتاب غير روائيين إسرائيليون",
    "category:israeli women non-fiction writers": "تصنيف:كاتبات غير روائيات إسرائيليات",
    "category:italian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إيطاليون",
    "category:italian non-fiction books": "تصنيف:كتب إيطالية غير خيالية",
    "category:italian non-fiction writers by century": "تصنيف:كتاب غير روائيين إيطاليون حسب القرن",
    "category:italian non-fiction writers": "تصنيف:كتاب غير روائيين إيطاليون",
    "category:italian women non-fiction writers": "تصنيف:كاتبات غير روائيات إيطاليات",
    "category:ivorian non-fiction writers": "تصنيف:كتاب غير روائيين إيفواريون",
    "category:jamaican male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور جامايكيون",
    "category:jamaican non-fiction writers": "تصنيف:كتاب غير روائيين جامايكيون",
    "category:japanese male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور يابانيون",
    "category:japanese non-fiction books": "تصنيف:كتب يابانية غير خيالية",
    "category:japanese non-fiction writers by century": "تصنيف:كتاب غير روائيين يابانيون حسب القرن",
    "category:japanese non-fiction writers": "تصنيف:كتاب غير روائيين يابانيون",
    "category:japanese women non-fiction writers": "تصنيف:كاتبات غير روائيات يابانيات",
    "category:jewish non-fiction writers by nationality": "تصنيف:كتاب غير روائيين يهود حسب الجنسية",
    "category:jewish non-fiction writers": "تصنيف:كتاب غير روائيين يهود",
    "category:jewish women non-fiction writers": "تصنيف:كاتبات غير روائيات يهوديات",
    "category:jordanian non-fiction writers": "تصنيف:كتاب غير روائيين أردنيون",
    "category:kenyan non-fiction writers": "تصنيف:كتاب غير روائيين كينيون",
    "category:korean non-fiction books": "تصنيف:كتب كورية غير خيالية",
    "category:korean non-fiction writers": "تصنيف:كتاب غير روائيين كوريون",
    "category:kosovan non-fiction writers": "تصنيف:كتاب غير روائيين كوسوفيون",
    "category:kuwaiti non-fiction writers": "تصنيف:كتاب غير روائيين كويتيون",
    "category:latvian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور لاتفيون",
    "category:latvian non-fiction writers": "تصنيف:كتاب غير روائيين لاتفيون",
    "category:latvian women non-fiction writers": "تصنيف:كاتبات غير روائيات لاتفيات",
    "category:lebanese non-fiction writers": "تصنيف:كتاب غير روائيين لبنانيون",
    "category:lebanon-related lists": "تصنيف:قوائم متعلقة بلبنان",
    "category:lesotho non-fiction writers": "تصنيف:كتاب غير روائيين ليسوتيون",
    "category:liberian non-fiction books": "تصنيف:كتب ليبيرية غير خيالية",
    "category:liberian non-fiction writers": "تصنيف:كتاب غير روائيين ليبيريون",
    "category:libyan non-fiction writers": "تصنيف:كتاب غير روائيين ليبيون",
    "category:lists of non-fiction books": "تصنيف:قوائم كتب غير خيالية",
    "category:lithuanian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور ليتوانيون",
    "category:lithuanian non-fiction writers": "تصنيف:كتاب غير روائيين ليتوانيون",
    "category:lithuanian women non-fiction writers": "تصنيف:كاتبات غير روائيات ليتوانيات",
    "category:luxembourgian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور لوكسمبورغيون",
    "category:luxembourgian non-fiction writers": "تصنيف:كتاب غير روائيين لوكسمبورغيون",
    "category:macedonian non-fiction writers": "تصنيف:كتاب غير روائيين مقدونيون",
    "category:malawian non-fiction writers": "تصنيف:كتاب غير روائيين ملاويون",
    "category:malaysian non-fiction books": "تصنيف:كتب ماليزية غير خيالية",
    "category:malaysian non-fiction writers": "تصنيف:كتاب غير روائيين ماليزيون",
    "category:maldivian non-fiction writers": "تصنيف:كتاب غير روائيين مالديفيون",
    "category:male non-fiction writers by nationality": "تصنيف:كتاب غير روائيين ذكور حسب الجنسية",
    "category:male non-fiction writers from northern ireland": "تصنيف:كتاب غير روائيين ذكور من أيرلندا الشمالية",
    "category:male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور",
    "category:malian non-fiction writers": "تصنيف:كتاب غير روائيين ماليون",
    "category:maltese non-fiction writers": "تصنيف:كتاب غير روائيين مالطيون",
    "category:mauritanian non-fiction writers": "تصنيف:كتاب غير روائيين موريتانيون",
    "category:mauritian non-fiction writers": "تصنيف:كتاب غير روائيين موريشيوسيون",
    "category:mexican male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور مكسيكيون",
    "category:mexican non-fiction books": "تصنيف:كتب مكسيكية غير خيالية",
    "category:mexican non-fiction writers by century": "تصنيف:كتاب غير روائيين مكسيكيون حسب القرن",
    "category:mexican non-fiction writers": "تصنيف:كتاب غير روائيين مكسيكيون",
    "category:mexican women non-fiction writers": "تصنيف:كاتبات غير روائيات مكسيكيات",
    "category:moldovan male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور مولدوفيون",
    "category:moldovan non-fiction writers": "تصنيف:كتاب غير روائيين مولدوفيون",
    "category:moroccan non-fiction writers": "تصنيف:كتاب غير روائيين مغاربة",
    "category:mozambican non-fiction writers": "تصنيف:كتاب غير روائيين موزمبيقيون",
    "category:namibian non-fiction writers": "تصنيف:كتاب غير روائيين ناميبيون",
    "category:nepalese non-fiction books": "تصنيف:كتب نيبالية غير خيالية",
    "category:nepalese non-fiction writers": "تصنيف:كتاب غير روائيين نيباليون",
    "category:nicaraguan non-fiction writers": "تصنيف:كتاب غير روائيين نيكاراغويون",
    "category:nigerian non-fiction books": "تصنيف:كتب نيجيرية غير خيالية",
    "category:nigerian non-fiction writers": "تصنيف:كتاب غير روائيين نيجيريون",
    "category:nigerien non-fiction writers": "تصنيف:كتاب غير روائيين نيجريون",
    "category:non-combat military accidents of united states": "تصنيف:حوادث عسكرية غير قتالية في الولايات المتحدة",
    "category:non-combat military accidents": "تصنيف:حوادث عسكرية غير قتالية",
    "category:non-combat military operations by country": "تصنيف:عمليات عسكرية غير قتالية حسب البلد",
    "category:non-combat military operations involving argentina": "تصنيف:عمليات عسكرية غير قتالية تشمل الأرجنتين",
    "category:non-combat military operations involving australia": "تصنيف:عمليات عسكرية غير قتالية تشمل أستراليا",
    "category:non-combat military operations involving canada": "تصنيف:عمليات عسكرية غير قتالية تشمل كندا",
    "category:non-combat military operations involving france": "تصنيف:عمليات عسكرية غير قتالية تشمل فرنسا",
    "category:non-combat military operations involving germany": "تصنيف:عمليات عسكرية غير قتالية تشمل ألمانيا",
    "category:non-combat military operations involving india": "تصنيف:عمليات عسكرية غير قتالية تشمل الهند",
    "category:non-combat military operations involving israel": "تصنيف:عمليات عسكرية غير قتالية تشمل إسرائيل",
    "category:non-combat military operations involving nepal": "تصنيف:عمليات عسكرية غير قتالية تشمل نيبال",
    "category:non-combat military operations involving new zealand": "تصنيف:عمليات عسكرية غير قتالية تشمل نيوزيلندا",
    "category:non-combat military operations involving pakistan": "تصنيف:عمليات عسكرية غير قتالية تشمل باكستان",
    "category:non-combat military operations involving south korea": "تصنيف:عمليات عسكرية غير قتالية تشمل كوريا الجنوبية",
    "category:non-combat military operations involving soviet union": "تصنيف:عمليات عسكرية غير قتالية تشمل الاتحاد السوفيتي",
    "category:non-combat military operations involving thailand": "تصنيف:عمليات عسكرية غير قتالية تشمل تايلاند",
    "category:non-combat military operations involving united kingdom": "تصنيف:عمليات عسكرية غير قتالية تشمل المملكة المتحدة",
    "category:non-combat military operations involving united states": "تصنيف:عمليات عسكرية غير قتالية تشمل الولايات المتحدة",
    "category:non-combat military operations": "تصنيف:عمليات عسكرية غير قتالية",
    "category:non-equilibrium thermodynamics": "تصنيف:ترموديناميك اللاتوازن",
    "category:non-fiction books about acting": "تصنيف:كتب غير خيالية عن التمثيل",
    "category:non-fiction books about advertising": "تصنيف:كتب غير خيالية عن الدعاية والإعلان",
    "category:non-fiction books about animals": "تصنيف:كتب غير خيالية عن حيوانات",
    "category:non-fiction books about assassination of john f. kennedy": "تصنيف:كتب غير خيالية عن اغتيال جون كينيدي",
    "category:non-fiction books about assassination of": "تصنيف:كتب غير خيالية عن اغتيال",
    "category:non-fiction books about ballet": "تصنيف:كتب غير خيالية عن باليه",
    "category:non-fiction books about bears": "تصنيف:كتب غير خيالية عن دبيات",
    "category:non-fiction books about birds": "تصنيف:كتب غير خيالية عن طيور",
    "category:non-fiction books about bosnian war": "تصنيف:كتب غير خيالية عن الحرب البوسنية",
    "category:non-fiction books about cancer": "تصنيف:كتب غير خيالية عن السرطان",
    "category:non-fiction books about cannabis": "تصنيف:كتب غير خيالية عن القنب",
    "category:non-fiction books about cats": "تصنيف:كتب غير خيالية عن القطط",
    "category:non-fiction books about civil rights movement": "تصنيف:كتب غير خيالية عن حركة الحقوق المدنية",
    "category:non-fiction books about crime in canada": "تصنيف:كتب غير خيالية عن جريمة في كندا",
    "category:non-fiction books about crime in united states": "تصنيف:كتب غير خيالية عن جريمة في الولايات المتحدة",
    "category:non-fiction books about crime": "تصنيف:كتب غير خيالية عن جريمة",
    "category:non-fiction books about criminals": "تصنيف:كتب غير خيالية عن مجرمون",
    "category:non-fiction books about dinosaurs": "تصنيف:كتب غير خيالية عن ديناصورات",
    "category:non-fiction books about diplomacy": "تصنيف:كتب غير خيالية عن الدبلوماسية",
    "category:non-fiction books about dogs": "تصنيف:كتب غير خيالية عن الكلاب",
    "category:non-fiction books about drug traffickers": "تصنيف:كتب غير خيالية عن تجار مخدرات",
    "category:non-fiction books about drugs": "تصنيف:كتب غير خيالية عن عقاقير",
    "category:non-fiction books about elections": "تصنيف:كتب غير خيالية عن انتخابات",
    "category:non-fiction books about espionage": "تصنيف:كتب غير خيالية عن التجسس",
    "category:non-fiction books about film directors and producers": "تصنيف:كتب غير خيالية عن مخرجو أفلام ومنتجون",
    "category:non-fiction books about gambling": "تصنيف:كتب غير خيالية عن مقامرة",
    "category:non-fiction books about gangs": "تصنيف:كتب غير خيالية عن عصابات",
    "category:non-fiction books about genocide": "تصنيف:كتب غير خيالية عن الإبادة الجماعية",
    "category:non-fiction books about godfather": "تصنيف:كتب غير خيالية عن العراب (فيلم)",
    "category:non-fiction books about gulag": "تصنيف:كتب غير خيالية عن غولاغ",
    "category:non-fiction books about immigration to europe": "تصنيف:كتب غير خيالية عن الهجرة إلى أوروبا",
    "category:non-fiction books about immigration to united states": "تصنيف:كتب غير خيالية عن الهجرة إلى الولايات المتحدة",
    "category:non-fiction books about immigration": "تصنيف:كتب غير خيالية عن الهجرة",
    "category:non-fiction books about indigenous peoples of americas": "تصنيف:كتب غير خيالية عن شعوب أصلية في الأمريكتين",
    "category:non-fiction books about italian-american culture": "تصنيف:كتب غير خيالية عن ثقافة أمريكية إيطالية",
    "category:non-fiction books about jack ripper": "تصنيف:كتب غير خيالية عن جاك السفاح",
    "category:non-fiction books about james bond": "تصنيف:كتب غير خيالية عن جيمس بوند",
    "category:non-fiction books about military history of united states": "تصنيف:كتب غير خيالية عن التاريخ العسكري الولايات المتحدة",
    "category:non-fiction books about mining": "تصنيف:كتب غير خيالية عن تعدين",
    "category:non-fiction books about murders in united states": "تصنيف:كتب غير خيالية عن جرائم قتل في الولايات المتحدة",
    "category:non-fiction books about murders": "تصنيف:كتب غير خيالية عن جرائم قتل",
    "category:non-fiction books about organized crime": "تصنيف:كتب غير خيالية عن جريمة منظمة",
    "category:non-fiction books about pablo escobar": "تصنيف:كتب غير خيالية عن بابلو إسكوبار",
    "category:non-fiction books about pornography": "تصنيف:كتب غير خيالية عن الإباحية",
    "category:non-fiction books about racism": "تصنيف:كتب غير خيالية عن عنصرية",
    "category:non-fiction books about richard ramirez": "تصنيف:كتب غير خيالية عن ريتشارد راميرز",
    "category:non-fiction books about royal air force": "تصنيف:كتب غير خيالية عن القوات الجوية الملكية",
    "category:non-fiction books about serial killers": "تصنيف:كتب غير خيالية عن قتلة متسلسلون",
    "category:non-fiction books about sexuality in christianity": "تصنيف:كتب غير خيالية عن الجنسانية في المسيحية",
    "category:non-fiction books about sexuality": "تصنيف:كتب غير خيالية عن الجنسانية",
    "category:non-fiction books about sicilian mafia": "تصنيف:كتب غير خيالية عن مافيا صقلية",
    "category:non-fiction books about slavery": "تصنيف:كتب غير خيالية عن العبودية",
    "category:non-fiction books about sudan": "تصنيف:كتب غير خيالية عن السودان",
    "category:non-fiction books about ted bundy": "تصنيف:كتب غير خيالية عن تيد بندي",
    "category:non-fiction books about theatre": "تصنيف:كتب غير خيالية عن المسرح",
    "category:non-fiction books about transport": "تصنيف:كتب غير خيالية عن نقل",
    "category:non-fiction books about turkey": "تصنيف:كتب غير خيالية عن تركيا",
    "category:non-fiction books about united states air force": "تصنيف:كتب غير خيالية عن القوات الجوية الأمريكية",
    "category:non-fiction books about united states navy": "تصنيف:كتب غير خيالية عن البحرية الأمريكية",
    "category:non-fiction books about unsolved murders in united states": "تصنيف:كتب غير خيالية عن جرائم قتل غير محلولة في الولايات المتحدة",
    "category:non-fiction books about unsolved murders": "تصنيف:كتب غير خيالية عن جرائم قتل غير محلولة",
    "category:non-fiction books about war": "تصنيف:كتب غير خيالية عن الحرب",
    "category:non-fiction books about women in war": "تصنيف:كتب غير خيالية عن المرأة في الحرب",
    "category:non-fiction books about women": "تصنيف:كتب غير خيالية عن المرأة",
    "category:non-fiction books adapted for other media": "تصنيف:كتب غير خيالية تم تحويلها إلى وسائط أخرى",
    "category:non-fiction books adapted into comics": "تصنيف:كتب غير خيالية تم تحويلها إلى قصص مصورة",
    "category:non-fiction books adapted into films": "تصنيف:كتب غير خيالية تم تحويلها إلى أفلام",
    "category:non-fiction books adapted into television shows": "تصنيف:كتب غير خيالية تم تحويلها إلى عروض تلفزيونية",
    "category:non-fiction books by country": "تصنيف:كتب غير خيالية حسب البلد",
    "category:non-fiction books by date": "تصنيف:كتب غير خيالية حسب التاريخ",
    "category:non-fiction books by decade": "تصنيف:كتب غير خيالية حسب العقد",
    "category:non-fiction books by gabriel garcía márquez": "تصنيف:كتب غير خيالية بواسطة غابرييل غارثيا ماركيث",
    "category:non-fiction books by h. p. lovecraft": "تصنيف:كتب غير خيالية بواسطة هوارد فيليبس لافكرافت",
    "category:non-fiction books by language": "تصنيف:كتب غير خيالية حسب اللغة",
    "category:non-fiction books by stephen king": "تصنيف:كتب غير خيالية بواسطة ستيفن كينغ",
    "category:non-fiction books by topic": "تصنيف:كتب غير خيالية حسب الموضوع",
    "category:non-fiction books by type": "تصنيف:كتب غير خيالية حسب الفئة",
    "category:non-fiction books by writer": "تصنيف:كتب غير خيالية حسب الكاتب",
    "category:non-fiction books by year": "تصنيف:كتب غير خيالية حسب السنة",
    "category:non-fiction books": "تصنيف:كتب غير خيالية",
    "category:non-fiction comic strips": "تصنيف:شرائط كومكس غير خيالية",
    "category:non-fiction comics": "تصنيف:قصص مصورة غير خيالية",
    "category:non-fiction crime writers": "تصنيف:كتاب جريمة غير روائيين",
    "category:non-fiction environmental writers": "تصنيف:كتاب بيئة غير روائيين",
    "category:non-fiction graphic novels": "تصنيف:روايات مصورة غير خيالية",
    "category:non-fiction novels about murders in united states": "تصنيف:روايات غير خيالية عن جرائم قتل في الولايات المتحدة",
    "category:non-fiction novels about murders": "تصنيف:روايات غير خيالية عن جرائم قتل",
    "category:non-fiction novels": "تصنيف:روايات غير خيالية",
    "category:non-fiction writers about organized crime in italy": "تصنيف:كتاب غير روائيين عن جريمة منظمة في إيطاليا",
    "category:non-fiction writers about organized crime in united states": "تصنيف:كتاب غير روائيين عن جريمة منظمة في الولايات المتحدة",
    "category:non-fiction writers about organized crime": "تصنيف:كتاب غير روائيين عن جريمة منظمة",
    "category:non-fiction writers by century and nationality": "تصنيف:كتاب غير روائيين حسب القرن والجنسية",
    "category:non-fiction writers by century": "تصنيف:كتاب غير روائيين حسب القرن",
    "category:non-fiction writers by ethnicity": "تصنيف:كتاب غير روائيين حسب المجموعة العرقية",
    "category:non-fiction writers by language": "تصنيف:كتاب غير روائيين حسب اللغة",
    "category:non-fiction writers by nationality and century": "تصنيف:كتاب غير روائيين حسب الجنسية والقرن",
    "category:non-fiction writers by nationality": "تصنيف:كتاب غير روائيين حسب الجنسية",
    "category:non-fiction writers from cornwall": "تصنيف:كتاب غير روائيين من كورنوال",
    "category:non-fiction writers from georgia (country)": "تصنيف:كتاب غير روائيين من جورجيا",
    "category:non-fiction writers from northern ireland by century": "تصنيف:كتاب غير روائيين من أيرلندا الشمالية حسب القرن",
    "category:non-fiction writers from ottoman empire": "تصنيف:كتاب غير روائيين من الدولة العثمانية",
    "category:non-fiction writers": "تصنيف:كتاب غير روائيين",
    "category:non-interventionism": "تصنيف:عدم التدخل",
    "category:non-interventionist parties": "تصنيف:أحزاب غير تدخلية",
    "category:non-metropolitan counties": "تصنيف:مقاطعات غير حضرية",
    "category:non-metropolitan districts of buckinghamshire": "تصنيف:ضواحي غير حضرية في باكينغهامشير",
    "category:non-metropolitan districts of cambridgeshire": "تصنيف:ضواحي غير حضرية في كامبريدجشير",
    "category:non-metropolitan districts of cumbria": "تصنيف:ضواحي غير حضرية في كمبريا",
    "category:non-metropolitan districts of derbyshire": "تصنيف:ضواحي غير حضرية في داربيشير",
    "category:non-metropolitan districts of devon": "تصنيف:ضواحي غير حضرية في ديفون",
    "category:non-metropolitan districts of dorset": "تصنيف:ضواحي غير حضرية في دورست",
    "category:non-metropolitan districts of east sussex": "تصنيف:ضواحي غير حضرية في شرق سوسكس",
    "category:non-metropolitan districts of essex": "تصنيف:ضواحي غير حضرية في إسكس",
    "category:non-metropolitan districts of gloucestershire": "تصنيف:ضواحي غير حضرية في غلوسترشير",
    "category:non-metropolitan districts of hampshire": "تصنيف:ضواحي غير حضرية في هامبشاير",
    "category:non-metropolitan districts of kent": "تصنيف:ضواحي غير حضرية في كنت",
    "category:non-metropolitan districts of lancashire": "تصنيف:ضواحي غير حضرية في لانكشير",
    "category:non-metropolitan districts of leicestershire": "تصنيف:ضواحي غير حضرية في ليسترشير",
    "category:non-metropolitan districts of lincolnshire": "تصنيف:ضواحي غير حضرية في لنكولنشاير",
    "category:non-metropolitan districts of norfolk": "تصنيف:ضواحي غير حضرية في نورفك",
    "category:non-metropolitan districts of north yorkshire": "تصنيف:ضواحي غير حضرية في شمال يوركشاير",
    "category:non-metropolitan districts of northamptonshire": "تصنيف:ضواحي غير حضرية في نورثهامبتونشاير",
    "category:non-metropolitan districts of nottinghamshire": "تصنيف:ضواحي غير حضرية في نوتنغهامشير",
    "category:non-metropolitan districts of oxfordshire": "تصنيف:ضواحي غير حضرية في أوكسفوردشاير",
    "category:non-metropolitan districts of somerset": "تصنيف:ضواحي غير حضرية في سومرست",
    "category:non-metropolitan districts of staffordshire": "تصنيف:ضواحي غير حضرية في ستافوردشاير",
    "category:non-metropolitan districts of suffolk": "تصنيف:ضواحي غير حضرية في سوفولك",
    "category:non-metropolitan districts of surrey": "تصنيف:ضواحي غير حضرية في سري",
    "category:non-metropolitan districts of warwickshire": "تصنيف:ضواحي غير حضرية في وركشير",
    "category:non-metropolitan districts of west sussex": "تصنيف:ضواحي غير حضرية في غرب ساسكس",
    "category:non-metropolitan districts of worcestershire": "تصنيف:ضواحي غير حضرية في رسيستيرشير",
    "category:non-metropolitan districts": "تصنيف:ضواحي غير حضرية",
    "category:non-narrative films": "تصنيف:أفلام غير سردية",
    "category:non-penetrative sex": "تصنيف:جنس خارجي",
    "category:non-profit organisations based in abu dhabi": "تصنيف:منظمات غير ربحية مقرها في أبو ظبي",
    "category:non-profit organisations based in afghanistan": "تصنيف:منظمات غير ربحية مقرها في أفغانستان",
    "category:non-profit organisations based in algeria": "تصنيف:منظمات غير ربحية مقرها في الجزائر",
    "category:non-profit organisations based in argentina": "تصنيف:منظمات غير ربحية مقرها في الأرجنتين",
    "category:non-profit organisations based in australia": "تصنيف:منظمات غير ربحية مقرها في أستراليا",
    "category:non-profit organisations based in australian capital territory": "تصنيف:منظمات غير ربحية مقرها في إقليم العاصمة الأسترالية",
    "category:non-profit organisations based in austria": "تصنيف:منظمات غير ربحية مقرها في النمسا",
    "category:non-profit organisations based in baden-württemberg": "تصنيف:منظمات غير ربحية مقرها في بادن-فورتمبيرغ",
    "category:non-profit organisations based in bahamas": "تصنيف:منظمات غير ربحية مقرها في باهاماس",
    "category:non-profit organisations based in bahrain": "تصنيف:منظمات غير ربحية مقرها في البحرين",
    "category:non-profit organisations based in bangladesh": "تصنيف:منظمات غير ربحية مقرها في بنغلاديش",
    "category:non-profit organisations based in barbados": "تصنيف:منظمات غير ربحية مقرها في بربادوس",
    "category:non-profit organisations based in bavaria": "تصنيف:منظمات غير ربحية مقرها في بافاريا",
    "category:non-profit organisations based in belgium": "تصنيف:منظمات غير ربحية مقرها في بلجيكا",
    "category:non-profit organisations based in belize": "تصنيف:منظمات غير ربحية مقرها في بليز",
    "category:non-profit organisations based in berlin": "تصنيف:منظمات غير ربحية مقرها في برلين",
    "category:non-profit organisations based in bhutan": "تصنيف:منظمات غير ربحية مقرها في بوتان",
    "category:non-profit organisations based in brazil": "تصنيف:منظمات غير ربحية مقرها في البرازيل",
    "category:non-profit organisations based in bremen (state)": "تصنيف:منظمات غير ربحية مقرها في ولاية بريمن",
    "category:non-profit organisations based in cambodia": "تصنيف:منظمات غير ربحية مقرها في كمبوديا",
    "category:non-profit organisations based in cayman islands": "تصنيف:منظمات غير ربحية مقرها في جزر كايمان",
    "category:non-profit organisations based in chile": "تصنيف:منظمات غير ربحية مقرها في تشيلي",
    "category:non-profit organisations based in colombia": "تصنيف:منظمات غير ربحية مقرها في كولومبيا",
    "category:non-profit organisations based in copenhagen": "تصنيف:منظمات غير ربحية مقرها في كوبنهاغن",
    "category:non-profit organisations based in cyprus": "تصنيف:منظمات غير ربحية مقرها في قبرص",
    "category:non-profit organisations based in democratic republic of congo": "تصنيف:منظمات غير ربحية مقرها في جمهورية الكونغو الديمقراطية",
    "category:non-profit organisations based in denmark": "تصنيف:منظمات غير ربحية مقرها في الدنمارك",
    "category:non-profit organisations based in ecuador": "تصنيف:منظمات غير ربحية مقرها في الإكوادور",
    "category:non-profit organisations based in egypt": "تصنيف:منظمات غير ربحية مقرها في مصر",
    "category:non-profit organisations based in england": "تصنيف:منظمات غير ربحية مقرها في إنجلترا",
    "category:non-profit organisations based in estonia": "تصنيف:منظمات غير ربحية مقرها في إستونيا",
    "category:non-profit organisations based in finland": "تصنيف:منظمات غير ربحية مقرها في فنلندا",
    "category:non-profit organisations based in france": "تصنيف:منظمات غير ربحية مقرها في فرنسا",
    "category:non-profit organisations based in germany": "تصنيف:منظمات غير ربحية مقرها في ألمانيا",
    "category:non-profit organisations based in ghana": "تصنيف:منظمات غير ربحية مقرها في غانا",
    "category:non-profit organisations based in hamburg": "تصنيف:منظمات غير ربحية مقرها في هامبورغ",
    "category:non-profit organisations based in hesse": "تصنيف:منظمات غير ربحية مقرها في هسن",
    "category:non-profit organisations based in hong kong": "تصنيف:منظمات غير ربحية مقرها في هونغ كونغ",
    "category:non-profit organisations based in hungary": "تصنيف:منظمات غير ربحية مقرها في المجر",
    "category:non-profit organisations based in india": "تصنيف:منظمات غير ربحية مقرها في الهند",
    "category:non-profit organisations based in iran": "تصنيف:منظمات غير ربحية مقرها في إيران",
    "category:non-profit organisations based in ireland": "تصنيف:منظمات غير ربحية مقرها في أيرلندا",
    "category:non-profit organisations based in italy": "تصنيف:منظمات غير ربحية مقرها في إيطاليا",
    "category:non-profit organisations based in jamaica": "تصنيف:منظمات غير ربحية مقرها في جامايكا",
    "category:non-profit organisations based in jersey": "تصنيف:منظمات غير ربحية مقرها في جيرزي",
    "category:non-profit organisations based in jordan": "تصنيف:منظمات غير ربحية مقرها في الأردن",
    "category:non-profit organisations based in karachi": "تصنيف:منظمات غير ربحية مقرها في كراتشي",
    "category:non-profit organisations based in kenya": "تصنيف:منظمات غير ربحية مقرها في كينيا",
    "category:non-profit organisations based in kosovo": "تصنيف:منظمات غير ربحية مقرها في كوسوفو",
    "category:non-profit organisations based in lahore": "تصنيف:منظمات غير ربحية مقرها في لاهور",
    "category:non-profit organisations based in latvia": "تصنيف:منظمات غير ربحية مقرها في لاتفيا",
    "category:non-profit organisations based in lebanon": "تصنيف:منظمات غير ربحية مقرها في لبنان",
    "category:non-profit organisations based in london": "تصنيف:منظمات غير ربحية مقرها في لندن",
    "category:non-profit organisations based in lower saxony": "تصنيف:منظمات غير ربحية مقرها في سكسونيا السفلى",
    "category:non-profit organisations based in luxembourg": "تصنيف:منظمات غير ربحية مقرها في لوكسمبورغ",
    "category:non-profit organisations based in madagascar": "تصنيف:منظمات غير ربحية مقرها في مدغشقر",
    "category:non-profit organisations based in malaysia": "تصنيف:منظمات غير ربحية مقرها في ماليزيا",
    "category:non-profit organisations based in maldives": "تصنيف:منظمات غير ربحية مقرها في جزر المالديف",
    "category:non-profit organisations based in mecklenburg-vorpommern": "تصنيف:منظمات غير ربحية مقرها في مكلنبورغ فوربومرن",
    "category:non-profit organisations based in moldova": "تصنيف:منظمات غير ربحية مقرها في مولدوفا",
    "category:non-profit organisations based in myanmar": "تصنيف:منظمات غير ربحية مقرها في ميانمار",
    "category:non-profit organisations based in namibia": "تصنيف:منظمات غير ربحية مقرها في ناميبيا",
    "category:non-profit organisations based in nepal": "تصنيف:منظمات غير ربحية مقرها في نيبال",
    "category:non-profit organisations based in netherlands": "تصنيف:منظمات غير ربحية مقرها في هولندا",
    "category:non-profit organisations based in new south wales": "تصنيف:منظمات غير ربحية مقرها في نيوساوث ويلز",
    "category:non-profit organisations based in new zealand": "تصنيف:منظمات غير ربحية مقرها في نيوزيلندا",
    "category:non-profit organisations based in north rhine-westphalia": "تصنيف:منظمات غير ربحية مقرها في شمال الراين-وستفاليا",
    "category:non-profit organisations based in northern ireland": "تصنيف:منظمات غير ربحية مقرها في أيرلندا الشمالية",
    "category:non-profit organisations based in northern territory": "تصنيف:منظمات غير ربحية مقرها في الإقليم الشمالي",
    "category:non-profit organisations based in norway": "تصنيف:منظمات غير ربحية مقرها في النرويج",
    "category:non-profit organisations based in pakistan": "تصنيف:منظمات غير ربحية مقرها في باكستان",
    "category:non-profit organisations based in peru": "تصنيف:منظمات غير ربحية مقرها في بيرو",
    "category:non-profit organisations based in poland": "تصنيف:منظمات غير ربحية مقرها في بولندا",
    "category:non-profit organisations based in portugal": "تصنيف:منظمات غير ربحية مقرها في البرتغال",
    "category:non-profit organisations based in puntland": "تصنيف:منظمات غير ربحية مقرها في أرض البنط",
    "category:non-profit organisations based in qatar": "تصنيف:منظمات غير ربحية مقرها في قطر",
    "category:non-profit organisations based in queensland": "تصنيف:منظمات غير ربحية مقرها في كوينزلاند",
    "category:non-profit organisations based in republic of ireland": "تصنيف:منظمات غير ربحية مقرها في جمهورية أيرلندا",
    "category:non-profit organisations based in rhineland-palatinate": "تصنيف:منظمات غير ربحية مقرها في راينلند بالاتينات",
    "category:non-profit organisations based in saudi arabia": "تصنيف:منظمات غير ربحية مقرها في السعودية",
    "category:non-profit organisations based in saxony": "تصنيف:منظمات غير ربحية مقرها في ساكسونيا",
    "category:non-profit organisations based in saxony-anhalt": "تصنيف:منظمات غير ربحية مقرها في ساكسونيا أنهالت",
    "category:non-profit organisations based in schleswig-holstein": "تصنيف:منظمات غير ربحية مقرها في شليسفيغ هولشتاين",
    "category:non-profit organisations based in scotland": "تصنيف:منظمات غير ربحية مقرها في إسكتلندا",
    "category:non-profit organisations based in singapore": "تصنيف:منظمات غير ربحية مقرها في سنغافورة",
    "category:non-profit organisations based in slovakia": "تصنيف:منظمات غير ربحية مقرها في سلوفاكيا",
    "category:non-profit organisations based in solomon islands": "تصنيف:منظمات غير ربحية مقرها في جزر سليمان",
    "category:non-profit organisations based in somalia": "تصنيف:منظمات غير ربحية مقرها في الصومال",
    "category:non-profit organisations based in south africa": "تصنيف:منظمات غير ربحية مقرها في جنوب إفريقيا",
    "category:non-profit organisations based in south australia": "تصنيف:منظمات غير ربحية مقرها في جنوب أستراليا",
    "category:non-profit organisations based in spain": "تصنيف:منظمات غير ربحية مقرها في إسبانيا",
    "category:non-profit organisations based in sri lanka": "تصنيف:منظمات غير ربحية مقرها في سريلانكا",
    "category:non-profit organisations based in sudan": "تصنيف:منظمات غير ربحية مقرها في السودان",
    "category:non-profit organisations based in sweden": "تصنيف:منظمات غير ربحية مقرها في السويد",
    "category:non-profit organisations based in switzerland": "تصنيف:منظمات غير ربحية مقرها في سويسرا",
    "category:non-profit organisations based in syria": "تصنيف:منظمات غير ربحية مقرها في سوريا",
    "category:non-profit organisations based in tasmania": "تصنيف:منظمات غير ربحية مقرها في تسمانيا",
    "category:non-profit organisations based in togo": "تصنيف:منظمات غير ربحية مقرها في توغو",
    "category:non-profit organisations based in trinidad and tobago": "تصنيف:منظمات غير ربحية مقرها في ترينيداد وتوباغو",
    "category:non-profit organisations based in uganda": "تصنيف:منظمات غير ربحية مقرها في أوغندا",
    "category:non-profit organisations based in united arab emirates": "تصنيف:منظمات غير ربحية مقرها في الإمارات العربية المتحدة",
    "category:non-profit organisations based in united kingdom": "تصنيف:منظمات غير ربحية مقرها في المملكة المتحدة",
    "category:non-profit organisations based in wales": "تصنيف:منظمات غير ربحية مقرها في ويلز",
    "category:non-profit organisations based in western australia": "تصنيف:منظمات غير ربحية مقرها في أستراليا الغربية",
    "category:non-profit organisations based in zambia": "تصنيف:منظمات غير ربحية مقرها في زامبيا",
    "category:non-profit organizations based in africa by country": "تصنيف:منظمات غير ربحية مقرها في إفريقيا حسب البلد",
    "category:non-profit organizations based in africa": "تصنيف:منظمات غير ربحية مقرها في إفريقيا",
    "category:non-profit organizations based in alabama": "تصنيف:منظمات غير ربحية مقرها في ألاباما",
    "category:non-profit organizations based in alaska": "تصنيف:منظمات غير ربحية مقرها في ألاسكا",
    "category:non-profit organizations based in alberta": "تصنيف:منظمات غير ربحية مقرها في ألبرتا",
    "category:non-profit organizations based in arizona": "تصنيف:منظمات غير ربحية مقرها في أريزونا",
    "category:non-profit organizations based in arkansas": "تصنيف:منظمات غير ربحية مقرها في أركنساس",
    "category:non-profit organizations based in asia by country": "تصنيف:منظمات غير ربحية مقرها في آسيا حسب البلد",
    "category:non-profit organizations based in asia": "تصنيف:منظمات غير ربحية مقرها في آسيا",
    "category:non-profit organizations based in azerbaijan": "تصنيف:منظمات غير ربحية مقرها في أذربيجان",
    "category:non-profit organizations based in barrie": "تصنيف:منظمات غير ربحية مقرها في باري (أونتاريو)",
    "category:non-profit organizations based in belarus": "تصنيف:منظمات غير ربحية مقرها في روسيا البيضاء",
    "category:non-profit organizations based in bosnia and herzegovina": "تصنيف:منظمات غير ربحية مقرها في البوسنة والهرسك",
    "category:non-profit organizations based in boston": "تصنيف:منظمات غير ربحية مقرها في بوسطن",
    "category:non-profit organizations based in british columbia": "تصنيف:منظمات غير ربحية مقرها في كولومبيا البريطانية",
    "category:non-profit organizations based in bronx": "تصنيف:منظمات غير ربحية مقرها في ذا برونكس",
    "category:non-profit organizations based in brooklyn": "تصنيف:منظمات غير ربحية مقرها في بروكلين",
    "category:non-profit organizations based in bulgaria": "تصنيف:منظمات غير ربحية مقرها في بلغاريا",
    "category:non-profit organizations based in california": "تصنيف:منظمات غير ربحية مقرها في كاليفورنيا",
    "category:non-profit organizations based in canada by province or territory": "تصنيف:منظمات غير ربحية مقرها في كندا حسب المقاطعة أو الإقليم",
    "category:non-profit organizations based in canada": "تصنيف:منظمات غير ربحية مقرها في كندا",
    "category:non-profit organizations based in chicago": "تصنيف:منظمات غير ربحية مقرها في شيكاغو",
    "category:non-profit organizations based in china": "تصنيف:منظمات غير ربحية مقرها في الصين",
    "category:non-profit organizations based in cincinnati": "تصنيف:منظمات غير ربحية مقرها في سينسيناتي",
    "category:non-profit organizations based in colorado": "تصنيف:منظمات غير ربحية مقرها في كولورادو",
    "category:non-profit organizations based in connecticut": "تصنيف:منظمات غير ربحية مقرها في كونيتيكت",
    "category:non-profit organizations based in costa rica": "تصنيف:منظمات غير ربحية مقرها في كوستاريكا",
    "category:non-profit organizations based in croatia": "تصنيف:منظمات غير ربحية مقرها في كرواتيا",
    "category:non-profit organizations based in czech republic": "تصنيف:منظمات غير ربحية مقرها في التشيك",
    "category:non-profit organizations based in delaware": "تصنيف:منظمات غير ربحية مقرها في ديلاوير",
    "category:non-profit organizations based in el salvador": "تصنيف:منظمات غير ربحية مقرها في السلفادور",
    "category:non-profit organizations based in estonia": "تصنيف:منظمات غير ربحية مقرها في إستونيا",
    "category:non-profit organizations based in europe by country": "تصنيف:منظمات غير ربحية مقرها في أوروبا حسب البلد",
    "category:non-profit organizations based in europe": "تصنيف:منظمات غير ربحية مقرها في أوروبا",
    "category:non-profit organizations based in florida": "تصنيف:منظمات غير ربحية مقرها في فلوريدا",
    "category:non-profit organizations based in georgia (u.s. state)": "تصنيف:منظمات غير ربحية مقرها في ولاية جورجيا",
    "category:non-profit organizations based in greece": "تصنيف:منظمات غير ربحية مقرها في اليونان",
    "category:non-profit organizations based in guatemala": "تصنيف:منظمات غير ربحية مقرها في غواتيمالا",
    "category:non-profit organizations based in haiti": "تصنيف:منظمات غير ربحية مقرها في هايتي",
    "category:non-profit organizations based in hawaii": "تصنيف:منظمات غير ربحية مقرها في هاواي",
    "category:non-profit organizations based in houston": "تصنيف:منظمات غير ربحية مقرها في هيوستن",
    "category:non-profit organizations based in idaho": "تصنيف:منظمات غير ربحية مقرها في أيداهو",
    "category:non-profit organizations based in illinois": "تصنيف:منظمات غير ربحية مقرها في إلينوي",
    "category:non-profit organizations based in indiana": "تصنيف:منظمات غير ربحية مقرها في إنديانا",
    "category:non-profit organizations based in indianapolis": "تصنيف:منظمات غير ربحية مقرها في إنديانابوليس",
    "category:non-profit organizations based in indonesia": "تصنيف:منظمات غير ربحية مقرها في إندونيسيا",
    "category:non-profit organizations based in insular areas of united states": "تصنيف:منظمات غير ربحية مقرها في المناطق المعزولة في الولايات المتحدة",
    "category:non-profit organizations based in iowa": "تصنيف:منظمات غير ربحية مقرها في آيوا",
    "category:non-profit organizations based in iraq": "تصنيف:منظمات غير ربحية مقرها في العراق",
    "category:non-profit organizations based in israel": "تصنيف:منظمات غير ربحية مقرها في إسرائيل",
    "category:non-profit organizations based in japan": "تصنيف:منظمات غير ربحية مقرها في اليابان",
    "category:non-profit organizations based in kaduna": "تصنيف:منظمات غير ربحية مقرها في كادونا",
    "category:non-profit organizations based in kansas": "تصنيف:منظمات غير ربحية مقرها في كانساس",
    "category:non-profit organizations based in kazakhstan": "تصنيف:منظمات غير ربحية مقرها في كازاخستان",
    "category:non-profit organizations based in kentucky": "تصنيف:منظمات غير ربحية مقرها في كنتاكي",
    "category:non-profit organizations based in kuwait": "تصنيف:منظمات غير ربحية مقرها في الكويت",
    "category:non-profit organizations based in lagos": "تصنيف:منظمات غير ربحية مقرها في ولاية لاغوس",
    "category:non-profit organizations based in lithuania": "تصنيف:منظمات غير ربحية مقرها في ليتوانيا",
    "category:non-profit organizations based in los angeles": "تصنيف:منظمات غير ربحية مقرها في لوس أنجلوس",
    "category:non-profit organizations based in louisiana": "تصنيف:منظمات غير ربحية مقرها في لويزيانا",
    "category:non-profit organizations based in macau": "تصنيف:منظمات غير ربحية مقرها في ماكاو",
    "category:non-profit organizations based in maine": "تصنيف:منظمات غير ربحية مقرها في مين",
    "category:non-profit organizations based in manitoba": "تصنيف:منظمات غير ربحية مقرها في مانيتوبا",
    "category:non-profit organizations based in maryland": "تصنيف:منظمات غير ربحية مقرها في ماريلند",
    "category:non-profit organizations based in massachusetts": "تصنيف:منظمات غير ربحية مقرها في ماساتشوستس",
    "category:non-profit organizations based in mexico": "تصنيف:منظمات غير ربحية مقرها في المكسيك",
    "category:non-profit organizations based in michigan": "تصنيف:منظمات غير ربحية مقرها في ميشيغان",
    "category:non-profit organizations based in minnesota": "تصنيف:منظمات غير ربحية مقرها في منيسوتا",
    "category:non-profit organizations based in mississippi": "تصنيف:منظمات غير ربحية مقرها في مسيسيبي",
    "category:non-profit organizations based in missouri": "تصنيف:منظمات غير ربحية مقرها في ميزوري",
    "category:non-profit organizations based in mongolia": "تصنيف:منظمات غير ربحية مقرها في منغوليا",
    "category:non-profit organizations based in montana": "تصنيف:منظمات غير ربحية مقرها في مونتانا",
    "category:non-profit organizations based in montreal": "تصنيف:منظمات غير ربحية مقرها في مونتريال",
    "category:non-profit organizations based in morocco": "تصنيف:منظمات غير ربحية مقرها في المغرب",
    "category:non-profit organizations based in nebraska": "تصنيف:منظمات غير ربحية مقرها في نبراسكا",
    "category:non-profit organizations based in nevada": "تصنيف:منظمات غير ربحية مقرها في نيفادا",
    "category:non-profit organizations based in new brunswick": "تصنيف:منظمات غير ربحية مقرها في نيو برونزويك",
    "category:non-profit organizations based in new hampshire": "تصنيف:منظمات غير ربحية مقرها في نيوهامشير",
    "category:non-profit organizations based in new jersey": "تصنيف:منظمات غير ربحية مقرها في نيوجيرسي",
    "category:non-profit organizations based in new mexico": "تصنيف:منظمات غير ربحية مقرها في نيومكسيكو",
    "category:non-profit organizations based in new orleans": "تصنيف:منظمات غير ربحية مقرها في نيو أورلينز",
    "category:non-profit organizations based in new york (state)": "تصنيف:منظمات غير ربحية مقرها في ولاية نيويورك",
    "category:non-profit organizations based in new york city": "تصنيف:منظمات غير ربحية مقرها في مدينة نيويورك",
    "category:non-profit organizations based in newfoundland and labrador": "تصنيف:منظمات غير ربحية مقرها في نيوفاوندلاند واللابرادور",
    "category:non-profit organizations based in nigeria": "تصنيف:منظمات غير ربحية مقرها في نيجيريا",
    "category:non-profit organizations based in north america by country": "تصنيف:منظمات غير ربحية مقرها في أمريكا الشمالية حسب البلد",
    "category:non-profit organizations based in north america": "تصنيف:منظمات غير ربحية مقرها في أمريكا الشمالية",
    "category:non-profit organizations based in north carolina": "تصنيف:منظمات غير ربحية مقرها في كارولاينا الشمالية",
    "category:non-profit organizations based in north dakota": "تصنيف:منظمات غير ربحية مقرها في داكوتا الشمالية",
    "category:non-profit organizations based in north macedonia": "تصنيف:منظمات غير ربحية مقرها في مقدونيا الشمالية",
    "category:non-profit organizations based in nova scotia": "تصنيف:منظمات غير ربحية مقرها في نوفا سكوشا",
    "category:non-profit organizations based in oceania": "تصنيف:منظمات غير ربحية مقرها في أوقيانوسيا",
    "category:non-profit organizations based in ohio": "تصنيف:منظمات غير ربحية مقرها في أوهايو",
    "category:non-profit organizations based in oklahoma": "تصنيف:منظمات غير ربحية مقرها في أوكلاهوما",
    "category:non-profit organizations based in ontario": "تصنيف:منظمات غير ربحية مقرها في أونتاريو",
    "category:non-profit organizations based in oregon": "تصنيف:منظمات غير ربحية مقرها في أوريغن",
    "category:non-profit organizations based in ottawa": "تصنيف:منظمات غير ربحية مقرها في أوتاوا",
    "category:non-profit organizations based in palestine": "تصنيف:منظمات غير ربحية مقرها في فلسطين",
    "category:non-profit organizations based in panama": "تصنيف:منظمات غير ربحية مقرها في بنما",
    "category:non-profit organizations based in pennsylvania": "تصنيف:منظمات غير ربحية مقرها في بنسلفانيا",
    "category:non-profit organizations based in philadelphia": "تصنيف:منظمات غير ربحية مقرها في فيلادلفيا",
    "category:non-profit organizations based in philippines": "تصنيف:منظمات غير ربحية مقرها في الفلبين",
    "category:non-profit organizations based in pittsburgh": "تصنيف:منظمات غير ربحية مقرها في بيتسبرغ",
    "category:non-profit organizations based in prince edward island": "تصنيف:منظمات غير ربحية مقرها في جزيرة الأمير إدوارد",
    "category:non-profit organizations based in puerto rico": "تصنيف:منظمات غير ربحية مقرها في بورتوريكو",
    "category:non-profit organizations based in quebec": "تصنيف:منظمات غير ربحية مقرها في كيبك",
    "category:non-profit organizations based in rhode island": "تصنيف:منظمات غير ربحية مقرها في رود آيلاند",
    "category:non-profit organizations based in romania": "تصنيف:منظمات غير ربحية مقرها في رومانيا",
    "category:non-profit organizations based in russia": "تصنيف:منظمات غير ربحية مقرها في روسيا",
    "category:non-profit organizations based in san diego": "تصنيف:منظمات غير ربحية مقرها في سان دييغو",
    "category:non-profit organizations based in san francisco bay area": "تصنيف:منظمات غير ربحية مقرها في منطقة خليج سان فرانسيسكو",
    "category:non-profit organizations based in san francisco": "تصنيف:منظمات غير ربحية مقرها في سان فرانسيسكو",
    "category:non-profit organizations based in saskatchewan": "تصنيف:منظمات غير ربحية مقرها في ساسكاتشوان",
    "category:non-profit organizations based in seattle": "تصنيف:منظمات غير ربحية مقرها في سياتل",
    "category:non-profit organizations based in serbia": "تصنيف:منظمات غير ربحية مقرها في صربيا",
    "category:non-profit organizations based in slovenia": "تصنيف:منظمات غير ربحية مقرها في سلوفينيا",
    "category:non-profit organizations based in south america": "تصنيف:منظمات غير ربحية مقرها في أمريكا الجنوبية",
    "category:non-profit organizations based in south carolina": "تصنيف:منظمات غير ربحية مقرها في كارولاينا الجنوبية",
    "category:non-profit organizations based in south dakota": "تصنيف:منظمات غير ربحية مقرها في داكوتا الجنوبية",
    "category:non-profit organizations based in south korea": "تصنيف:منظمات غير ربحية مقرها في كوريا الجنوبية",
    "category:non-profit organizations based in soviet union": "تصنيف:منظمات غير ربحية مقرها في الاتحاد السوفيتي",
    "category:non-profit organizations based in st. louis": "تصنيف:منظمات غير ربحية مقرها في سينت لويس",
    "category:non-profit organizations based in taiwan": "تصنيف:منظمات غير ربحية مقرها في تايوان",
    "category:non-profit organizations based in tennessee": "تصنيف:منظمات غير ربحية مقرها في تينيسي",
    "category:non-profit organizations based in texas": "تصنيف:منظمات غير ربحية مقرها في تكساس",
    "category:non-profit organizations based in thailand": "تصنيف:منظمات غير ربحية مقرها في تايلاند",
    "category:non-profit organizations based in toronto": "تصنيف:منظمات غير ربحية مقرها في تورونتو",
    "category:non-profit organizations based in turkey": "تصنيف:منظمات غير ربحية مقرها في تركيا",
    "category:non-profit organizations based in ukraine": "تصنيف:منظمات غير ربحية مقرها في أوكرانيا",
    "category:non-profit organizations based in united states by city": "تصنيف:منظمات غير ربحية مقرها في الولايات المتحدة حسب المدينة",
    "category:non-profit organizations based in united states by state or territory": "تصنيف:منظمات غير ربحية مقرها في الولايات المتحدة حسب الولاية أو الإقليم",
    "category:non-profit organizations based in united states": "تصنيف:منظمات غير ربحية مقرها في الولايات المتحدة",
    "category:non-profit organizations based in uruguay": "تصنيف:منظمات غير ربحية مقرها في أوروغواي",
    "category:non-profit organizations based in utah": "تصنيف:منظمات غير ربحية مقرها في يوتا",
    "category:non-profit organizations based in vancouver": "تصنيف:منظمات غير ربحية مقرها في فانكوفر",
    "category:non-profit organizations based in venezuela": "تصنيف:منظمات غير ربحية مقرها في فنزويلا",
    "category:non-profit organizations based in vermont": "تصنيف:منظمات غير ربحية مقرها في فيرمونت",
    "category:non-profit organizations based in vietnam": "تصنيف:منظمات غير ربحية مقرها في فيتنام",
    "category:non-profit organizations based in virginia": "تصنيف:منظمات غير ربحية مقرها في فرجينيا",
    "category:non-profit organizations based in washington (state)": "تصنيف:منظمات غير ربحية مقرها في ولاية واشنطن",
    "category:non-profit organizations based in west virginia": "تصنيف:منظمات غير ربحية مقرها في فرجينيا الغربية",
    "category:non-profit organizations based in wisconsin": "تصنيف:منظمات غير ربحية مقرها في ويسكونسن",
    "category:non-profit organizations based in wyoming": "تصنيف:منظمات غير ربحية مقرها في وايومنغ",
    "category:non-profit organizations": "تصنيف:منظمات غير ربحية",
    "category:non-profit publishers": "تصنيف:ناشرون غير ربحيون",
    "category:non-profit technology": "تصنيف:تقانة العمل الخيري",
    "category:non-renewable energy companies": "تصنيف:شركات طاقة غير متجددة",
    "category:non-renewable resource companies by century of disestablishment": "تصنيف:شركات موارد غير متجددة حسب قرن الانحلال",
    "category:non-renewable resource companies by century of establishment": "تصنيف:شركات موارد غير متجددة حسب قرن التأسيس",
    "category:non-renewable resource companies by year of disestablishment": "تصنيف:شركات موارد غير متجددة حسب سنة الانحلال",
    "category:non-renewable resource companies by year of establishment": "تصنيف:شركات موارد غير متجددة حسب سنة التأسيس",
    "category:non-renewable resource companies disestablished in 1550": "تصنيف:شركات موارد غير متجددة انحلت في 1550",
    "category:non-renewable resource companies disestablished in 20th century": "تصنيف:شركات موارد غير متجددة انحلت في القرن 20",
    "category:non-renewable resource companies established in 1550": "تصنيف:شركات موارد غير متجددة أسست في 1550",
    "category:non-renewable resource companies established in 20th century": "تصنيف:شركات موارد غير متجددة أسست في القرن 20",
    "category:non-renewable resource companies": "تصنيف:شركات موارد غير متجددة",
    "category:non-sufficient funds": "تصنيف:شيك مردود",
    "category:non-volatile memory": "تصنيف:الذاكرة المستاديمة",
    "category:non-volatile random-access memory": "تصنيف:ذاكرة الوصول العشوائي غير المتطايرة",
    "category:norwegian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور نرويجيون",
    "category:norwegian non-fiction books": "تصنيف:كتب نرويجية غير خيالية",
    "category:norwegian non-fiction writers by century": "تصنيف:كتاب غير روائيين نرويجيون حسب القرن",
    "category:norwegian non-fiction writers": "تصنيف:كتاب غير روائيين نرويجيون",
    "category:norwegian women non-fiction writers": "تصنيف:كاتبات غير روائيات نرويجيات",
    "category:pakistani male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور باكستانيون",
    "category:pakistani non-fiction books": "تصنيف:كتب باكستانية غير خيالية",
    "category:pakistani non-fiction writers": "تصنيف:كتاب غير روائيين باكستانيون",
    "category:pakistani women non-fiction writers": "تصنيف:كاتبات غير روائيات باكستانيات",
    "category:palestinian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور فلسطينيون",
    "category:palestinian non-fiction writers": "تصنيف:كتاب غير روائيين فلسطينيون",
    "category:palestinian women non-fiction writers": "تصنيف:كاتبات غير روائيات فلسطينيات",
    "category:panamanian non-fiction writers": "تصنيف:كتاب غير روائيين بنميون",
    "category:paraguayan non-fiction writers": "تصنيف:كتاب غير روائيين بارغوايانيون",
    "category:peruvian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بيرويون",
    "category:peruvian non-fiction books": "تصنيف:كتب بيروية غير خيالية",
    "category:peruvian non-fiction writers": "تصنيف:كتاب غير روائيين بيرويون",
    "category:polish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بولنديون",
    "category:polish non-fiction books": "تصنيف:كتب بولندية غير خيالية",
    "category:polish non-fiction writers": "تصنيف:كتاب غير روائيين بولنديون",
    "category:polish women non-fiction writers": "تصنيف:كاتبات غير روائيات بولنديات",
    "category:portuguese male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور برتغاليون",
    "category:portuguese non-fiction books": "تصنيف:كتب برتغالية غير خيالية",
    "category:portuguese non-fiction writers by century": "تصنيف:كتاب غير روائيين برتغاليون حسب القرن",
    "category:portuguese non-fiction writers": "تصنيف:كتاب غير روائيين برتغاليون",
    "category:portuguese women non-fiction writers": "تصنيف:كاتبات غير روائيات برتغاليات",
    "category:puerto rican male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور بورتوريكيون",
    "category:puerto rican non-fiction writers by century": "تصنيف:كتاب غير روائيين بورتوريكيون حسب القرن",
    "category:puerto rican non-fiction writers": "تصنيف:كتاب غير روائيين بورتوريكيون",
    "category:puerto rican women non-fiction writers": "تصنيف:كاتبات غير روائيات بورتوريكيات",
    "category:qatari non-fiction writers": "تصنيف:كتاب غير روائيين قطريون",
    "category:romanian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور رومان",
    "category:romanian non-fiction writers": "تصنيف:كتاب غير روائيين رومان",
    "category:romanian women non-fiction writers": "تصنيف:كاتبات غير روائيات رومانيات",
    "category:russian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور روس",
    "category:russian non-fiction books": "تصنيف:كتب روسية غير خيالية",
    "category:russian non-fiction writers by century": "تصنيف:كتاب غير روائيين روس حسب القرن",
    "category:russian non-fiction writers": "تصنيف:كتاب غير روائيين روس",
    "category:russian women non-fiction writers": "تصنيف:كاتبات غير روائيات روسيات",
    "category:rwandan non-fiction writers": "تصنيف:كتاب غير روائيين روانديون",
    "category:sahrawi non-fiction writers": "تصنيف:كتاب غير روائيين صحراويون",
    "category:salvadoran non-fiction writers": "تصنيف:كتاب غير روائيين سلفادوريون",
    "category:samoan non-fiction writers": "تصنيف:كتاب غير روائيين سامويون",
    "category:saudi arabian non-fiction writers": "تصنيف:كتاب غير روائيين سعوديون",
    "category:scottish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إسكتلنديون",
    "category:scottish non-fiction books": "تصنيف:كتب إسكتلندية غير خيالية",
    "category:scottish non-fiction writers by century": "تصنيف:كتاب غير روائيين إسكتلنديون حسب القرن",
    "category:scottish non-fiction writers": "تصنيف:كتاب غير روائيين إسكتلنديون",
    "category:scottish women non-fiction writers": "تصنيف:كاتبات غير روائيات إسكتلنديات",
    "category:senegalese non-fiction writers": "تصنيف:كتاب غير روائيين سنغاليون",
    "category:serbian male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور صرب",
    "category:serbian non-fiction writers": "تصنيف:كتاب غير روائيين صرب",
    "category:serbian women non-fiction writers": "تصنيف:كاتبات غير روائيات صربيات",
    "category:series of non-fiction books": "تصنيف:سلسلات كتب غير خيالية",
    "category:sierra leonean non-fiction writers": "تصنيف:كتاب غير روائيين سيراليونيون",
    "category:singaporean non-fiction writers": "تصنيف:كتاب غير روائيين سنغافوريون",
    "category:slovak non-fiction writers": "تصنيف:كتاب غير روائيين سلوفاكيون",
    "category:slovenian non-fiction books": "تصنيف:كتب سلوفينية غير خيالية",
    "category:slovenian non-fiction writers": "تصنيف:كتاب غير روائيين سلوفينيون",
    "category:somalian non-fiction writers": "تصنيف:كتاب غير روائيين صوماليون",
    "category:south korean non-fiction writers": "تصنيف:كتاب غير روائيين كوريون جنوبيون",
    "category:south korean women non-fiction writers": "تصنيف:كاتبات غير روائيات كوريات جنوبيات",
    "category:soviet male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور سوفيت",
    "category:soviet non-fiction writers": "تصنيف:كتاب غير روائيين سوفيت",
    "category:spanish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور إسبان",
    "category:spanish non-fiction books": "تصنيف:كتب إسبانية غير خيالية",
    "category:spanish non-fiction writers by century": "تصنيف:كتاب غير روائيين إسبان حسب القرن",
    "category:spanish non-fiction writers": "تصنيف:كتاب غير روائيين إسبان",
    "category:spanish women non-fiction writers": "تصنيف:كاتبات غير روائيات إسبانيات",
    "category:sports non-profit organizations": "تصنيف:منظمات غير ربحية رياضية",
    "category:sri lankan non-fiction writers": "تصنيف:كتاب غير روائيين سريلانكيون",
    "category:sudanese non-fiction writers": "تصنيف:كتاب غير روائيين سودانيون",
    "category:swedish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور سويديون",
    "category:swedish non-fiction books": "تصنيف:كتب سويدية غير خيالية",
    "category:swedish non-fiction writers by century": "تصنيف:كتاب غير روائيين سويديون حسب القرن",
    "category:swedish non-fiction writers": "تصنيف:كتاب غير روائيين سويديون",
    "category:swedish women non-fiction writers": "تصنيف:كاتبات غير روائيات سويديات",
    "category:swiss male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور سويسريون",
    "category:swiss non-fiction books": "تصنيف:كتب سويسرية غير خيالية",
    "category:swiss non-fiction writers by century": "تصنيف:كتاب غير روائيين سويسريون حسب القرن",
    "category:swiss non-fiction writers": "تصنيف:كتاب غير روائيين سويسريون",
    "category:swiss women non-fiction writers": "تصنيف:كاتبات غير روائيات سويسريات",
    "category:syrian non-fiction books": "تصنيف:كتب سورية غير خيالية",
    "category:syrian non-fiction writers": "تصنيف:كتاب غير روائيين سوريون",
    "category:taiwanese non-fiction writers": "تصنيف:كتاب غير روائيين تايوانيون",
    "category:tajikistani non-fiction writers": "تصنيف:كتاب غير روائيين طاجيك",
    "category:tanzanian non-fiction writers": "تصنيف:كتاب غير روائيين تنزانيون",
    "category:television shows based on non-fiction books": "تصنيف:عروض تلفزيونية مبنية على كتب غير خيالية",
    "category:thai male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور تايلنديون",
    "category:thai non-fiction books": "تصنيف:كتب تايلندية غير خيالية",
    "category:thai non-fiction writers": "تصنيف:كتاب غير روائيين تايلنديون",
    "category:togolese non-fiction writers": "تصنيف:كتاب غير روائيين توغويون",
    "category:trinidad and tobago male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور ترنيداديون",
    "category:trinidad and tobago non-fiction writers": "تصنيف:كتاب غير روائيين ترنيداديون",
    "category:tunisian non-fiction writers": "تصنيف:كتاب غير روائيين تونسيون",
    "category:turkish cypriot non-fiction writers": "تصنيف:كتاب غير روائيين قبرصيون شماليون",
    "category:turkish male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور أتراك",
    "category:turkish non-fiction books": "تصنيف:كتب تركية غير خيالية",
    "category:turkish non-fiction writers by century": "تصنيف:كتاب غير روائيين أتراك حسب القرن",
    "category:turkish non-fiction writers": "تصنيف:كتاب غير روائيين أتراك",
    "category:turkish women non-fiction writers": "تصنيف:كاتبات غير روائيات تركيات",
    "category:ugandan non-fiction books": "تصنيف:كتب أوغندية غير خيالية",
    "category:ugandan non-fiction writers": "تصنيف:كتاب غير روائيين أوغنديون",
    "category:ukrainian non-fiction books": "تصنيف:كتب أوكرانية غير خيالية",
    "category:ukrainian non-fiction writers": "تصنيف:كتاب غير روائيين أوكرانيون",
    "category:ukrainian women non-fiction writers": "تصنيف:كاتبات غير روائيات أوكرانيات",
    "category:uruguayan non-fiction books": "تصنيف:كتب أوروغويانية غير خيالية",
    "category:uruguayan non-fiction writers": "تصنيف:كتاب غير روائيين أوروغويانيون",
    "category:venezuelan non-fiction writers": "تصنيف:كتاب غير روائيين فنزويليون",
    "category:vietnamese non-fiction writers": "تصنيف:كتاب غير روائيين فيتناميون",
    "category:welsh male non-fiction writers": "تصنيف:كتاب غير روائيين ذكور ويلزيون",
    "category:welsh non-fiction books": "تصنيف:كتب ويلزية غير خيالية",
    "category:welsh non-fiction writers by century": "تصنيف:كتاب غير روائيين ويلزيون حسب القرن",
    "category:welsh non-fiction writers": "تصنيف:كتاب غير روائيين ويلزيون",
    "category:welsh women non-fiction writers": "تصنيف:كاتبات غير روائيات ويلزيات",
    "category:women non-fiction writers by nationality": "تصنيف:كاتبات غير روائيات حسب الجنسية",
    "category:women non-fiction writers from northern ireland": "تصنيف:كاتبات غير روائيات من أيرلندا الشمالية",
    "category:women non-fiction writers": "تصنيف:كاتبات غير روائيات",
    "category:works based on non-fiction books": "تصنيف:أعمال مبنية على كتب غير خيالية",
    "category:yemeni non-fiction writers": "تصنيف:كتاب غير روائيين يمنيون",
    "category:yugoslav non-fiction writers": "تصنيف:كتاب غير روائيين يوغسلافيون",
    "category:zambian non-fiction writers": "تصنيف:كتاب غير روائيين زامبيون",
    "category:zimbabwean non-fiction writers": "تصنيف:كتاب غير روائيين زيمبابويون",
}

non_fiction = {
    "category:lists of non-fiction works": "تصنيف:قوائم أعمال غير خيالية",
    "category:non-fiction television shows": "تصنيف:عروض تلفزيونية غير خيالية",
    "category:non-fiction works about crime in canada": "تصنيف:أعمال غير خيالية عن جريمة في كندا",
    "category:non-fiction works about espionage": "تصنيف:أعمال غير خيالية عن التجسس",
    "category:non-fiction works about law in canada": "تصنيف:أعمال غير خيالية عن قانون في كندا",
    "category:non-fiction works about serial killers": "تصنيف:أعمال غير خيالية عن قتلة متسلسلون",
    "category:non-fiction works about united states air force": "تصنيف:أعمال غير خيالية عن القوات الجوية الأمريكية",
    "category:non-fiction works about united states navy": "تصنيف:أعمال غير خيالية عن البحرية الأمريكية",
    "category:non-fiction works": "تصنيف:أعمال غير خيالية",
}

data_series = {
    "category:american non-fiction television series": "تصنيف:مسلسلات تلفزيونية غير خيالية أمريكية",
    "category:american non-fiction web series": "تصنيف:مسلسلات ويب غير خيالية أمريكية",
    "category:australian non-fiction television series": "تصنيف:مسلسلات تلفزيونية غير خيالية أسترالية",
    "category:australian non-fiction web series": "تصنيف:مسلسلات ويب غير خيالية أسترالية",
    "category:british non-fiction television series": "تصنيف:مسلسلات تلفزيونية غير خيالية بريطانية",
    "category:british non-fiction web series": "تصنيف:مسلسلات ويب غير خيالية بريطانية",
    "category:bulgarian non-fiction television series": "تصنيف:مسلسلات تلفزيونية غير خيالية بلغارية",
    "category:canadian non-fiction web series": "تصنيف:مسلسلات ويب غير خيالية كندية",
    "category:finnish non-fiction television series": "تصنيف:مسلسلات تلفزيونية غير خيالية فنلندية",
    "category:non-fiction television series by country": "تصنيف:مسلسلات تلفزيونية غير خيالية حسب البلد",
    "category:non-fiction television series": "تصنيف:مسلسلات تلفزيونية غير خيالية",
    "category:non-fiction web series": "تصنيف:مسلسلات ويب غير خيالية",
    "category:taiwanese non-fiction television series": "تصنيف:مسلسلات تلفزيونية غير خيالية تايوانية",
}

to_test = [
    ("test_non", data1),
    ("test_non_fiction", non_fiction),
    ("test_data_series", data_series),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
@pytest.mark.slow
def test_non(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data_series.items(), ids=data_series.keys())
@pytest.mark.slow
def test_data_series(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_non_dump(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
