from __future__ import annotations

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.new_resolvers.relations_resolver import new_relations_resolvers

ireland_test_data = {
    "russia–south sudan relations": "العلاقات الروسية السودانية الجنوبية",
    "saudi arabia–south sudan relations": "العلاقات السعودية السودانية الجنوبية",
    "slovenia–south sudan relations": "العلاقات السلوفينية السودانية الجنوبية",
    "south sudan–sudan border": "الحدود السودانية السودانية الجنوبية",
    "south sudan–sudan relations": "العلاقات السودانية السودانية الجنوبية",
    "cameroon–north macedonia relations": "العلاقات الكاميرونية المقدونية الشمالية",
    "canada–north macedonia relations": "العلاقات الكندية المقدونية الشمالية",
    "canada–north yemen relations": "العلاقات الكندية اليمنية الشمالية",
    "canada–south yemen relations": "العلاقات الكندية اليمنية الجنوبية",
    "china–north macedonia relations": "العلاقات الصينية المقدونية الشمالية",
    "china–south yemen relations": "العلاقات الصينية اليمنية الجنوبية",
    "colombia–north macedonia relations": "العلاقات الكولومبية المقدونية الشمالية",
    "croatia–north macedonia relations": "العلاقات الكرواتية المقدونية الشمالية",
    "cuba–south yemen relations": "العلاقات الكوبية اليمنية الجنوبية",
    "cyprus–north macedonia relations": "العلاقات القبرصية المقدونية الشمالية",
    "democratic-republic-of-congo–north macedonia relations": "العلاقات الكونغوية الديمقراطية المقدونية الشمالية",
    "denmark–south sudan relations": "العلاقات الدنماركية السودانية الجنوبية",
    "egypt–north macedonia relations": "العلاقات المصرية المقدونية الشمالية",
    "equatorial guinea–north macedonia relations": "العلاقات الغينية الاستوائية المقدونية الشمالية",
    "finland–north macedonia relations": "العلاقات الفنلندية المقدونية الشمالية",
    "france–north macedonia relations": "العلاقات الفرنسية المقدونية الشمالية",
    "ghana–north macedonia relations": "العلاقات الغانية المقدونية الشمالية",
    "guinea–north macedonia relations": "العلاقات الغينية المقدونية الشمالية",
    "hungary–north macedonia relations": "العلاقات المجرية المقدونية الشمالية",
    "kazakhstan–north macedonia relations": "العلاقات الكازاخستانية المقدونية الشمالية",
    "kosovo–north macedonia border crossings": "معابر الحدود الكوسوفية المقدونية الشمالية",
    "kosovo–north macedonia border": "الحدود الكوسوفية المقدونية الشمالية",
    "kosovo–north macedonia relations": "العلاقات الكوسوفية المقدونية الشمالية",
    "latvia–north macedonia relations": "العلاقات اللاتفية المقدونية الشمالية",
    "liechtenstein–north macedonia relations": "العلاقات الليختنشتانية المقدونية الشمالية",
    "lithuania–north macedonia relations": "العلاقات الليتوانية المقدونية الشمالية",
    "luxembourg–north macedonia relations": "العلاقات اللوكسمبورغية المقدونية الشمالية",
    "malaysia–north macedonia relations": "العلاقات الماليزية المقدونية الشمالية",
    "maldives–north macedonia relations": "العلاقات المالديفية المقدونية الشمالية",
    "morocco–north macedonia relations": "العلاقات المغربية المقدونية الشمالية",
    "south korea–yemen relations": "العلاقات الكورية الجنوبية اليمنية",
    "afghanistan–ireland relations": "العلاقات الأفغانية الأيرلندية",
    "afghanistan–ireland sports relations": "العلاقات الأفغانية الأيرلندية الرياضية",
    "albania–ireland relations": "العلاقات الألبانية الأيرلندية",
    "algeria–ireland relations": "العلاقات الأيرلندية الجزائرية",
    "andorra–ireland relations": "العلاقات الأندورية الأيرلندية",
    "angola–ireland relations": "العلاقات الأنغولية الأيرلندية",
    "antigua and barbuda–ireland relations": "العلاقات الأنتيغوية والبربودية الأيرلندية",
    "argentina–ireland relations": "العلاقات الأرجنتينية الأيرلندية",
    "argentina–ireland sports relations": "العلاقات الأرجنتينية الأيرلندية الرياضية",
    "armenia–ireland relations": "العلاقات الأرمينية الأيرلندية",
    "australia–ireland relations": "العلاقات الأسترالية الأيرلندية",
    "australia–ireland sports relations": "العلاقات الأسترالية الأيرلندية الرياضية",
    "austria–ireland relations": "العلاقات الأيرلندية النمساوية",
    "azerbaijan–ireland relations": "العلاقات الأذربيجانية الأيرلندية",
    "bahamas–ireland relations": "العلاقات الأيرلندية البهامية",
    "bahrain–ireland relations": "العلاقات الأيرلندية البحرينية",
    "bangladesh–ireland relations": "العلاقات الأيرلندية البنغلاديشية",
    "bangladesh–ireland sports relations": "العلاقات الأيرلندية البنغلاديشية الرياضية",
    "barbados–ireland relations": "العلاقات الأيرلندية البربادوسية",
    "belarus–ireland relations": "العلاقات الأيرلندية البيلاروسية",
    "belgium–ireland relations": "العلاقات الأيرلندية البلجيكية",
    "benin–ireland relations": "العلاقات الأيرلندية البنينية",
    "bolivia–ireland relations": "العلاقات الأيرلندية البوليفية",
    "bosnia and herzegovina–ireland relations": "العلاقات الأيرلندية البوسنية",
    "brazil–ireland relations": "العلاقات الأيرلندية البرازيلية",
    "brunei–ireland relations": "العلاقات الأيرلندية البرونية",
    "bulgaria–ireland relations": "العلاقات الأيرلندية البلغارية",
    "burkina faso–ireland relations": "العلاقات الأيرلندية البوركينابية",
    "burundi–ireland relations": "العلاقات الأيرلندية البوروندية",
    "cambodia–ireland relations": "العلاقات الأيرلندية الكمبودية",
    "cameroon–ireland relations": "العلاقات الأيرلندية الكاميرونية",
    "canada–ireland relations": "العلاقات الأيرلندية الكندية",
    "canada–ireland sports relations": "العلاقات الأيرلندية الكندية الرياضية",
    "cape verde–ireland relations": "العلاقات الأيرلندية الرأس الأخضرية",
    "central african republic–ireland relations": "العلاقات الأيرلندية الإفريقية الأوسطية",
    "chile–ireland relations": "العلاقات الأيرلندية التشيلية",
    "china–ireland relations": "العلاقات الأيرلندية الصينية",
    "colombia–ireland relations": "العلاقات الأيرلندية الكولومبية",
    "costa rica–ireland relations": "العلاقات الأيرلندية الكوستاريكية",
    "croatia–ireland relations": "العلاقات الأيرلندية الكرواتية",
    "cuba–ireland relations": "العلاقات الأيرلندية الكوبية",
    "cyprus–ireland relations": "العلاقات الأيرلندية القبرصية",
    "czech republic–ireland relations": "العلاقات الأيرلندية التشيكية",
    "czechoslovakia–ireland relations": "العلاقات الأيرلندية التشيكوسلوفاكية",
    "denmark–ireland relations": "العلاقات الأيرلندية الدنماركية",
    "dominican republic–ireland relations": "العلاقات الأيرلندية الدومينيكانية",
    "ecuador–ireland relations": "العلاقات الأيرلندية الإكوادورية",
    "egypt–ireland relations": "العلاقات الأيرلندية المصرية",
    "el salvador–ireland relations": "العلاقات الأيرلندية السلفادورية",
    "england–ireland relations": "العلاقات الأيرلندية الإنجليزية",
    "estonia–ireland relations": "العلاقات الأيرلندية الإستونية",
    "ethiopia–ireland relations": "العلاقات الأيرلندية الإثيوبية",
    "fiji–ireland relations": "العلاقات الأيرلندية الفيجية",
    "fiji–ireland sports relations": "العلاقات الأيرلندية الفيجية الرياضية",
    "finland–ireland relations": "العلاقات الأيرلندية الفنلندية",
    "france–ireland relations": "العلاقات الأيرلندية الفرنسية",
    "france–ireland sports relations": "العلاقات الأيرلندية الفرنسية الرياضية",
    "gambia–ireland relations": "العلاقات الأيرلندية الغامبية",
    "georgia (country)–ireland relations": "العلاقات الأيرلندية الجورجية",
    "germany–ireland relations": "العلاقات الألمانية الأيرلندية",
    "ghana–ireland relations": "العلاقات الأيرلندية الغانية",
    "greece–ireland relations": "العلاقات الأيرلندية اليونانية",
    "guatemala–ireland relations": "العلاقات الأيرلندية الغواتيمالية",
    "guinea-bissau–ireland relations": "العلاقات الأيرلندية الغينية البيساوية",
    "guyana–ireland relations": "العلاقات الأيرلندية الغيانية",
    "haiti–ireland relations": "العلاقات الأيرلندية الهايتية",
    "honduras–ireland relations": "العلاقات الأيرلندية الهندوراسية",
    "hong kong–ireland relations": "العلاقات الأيرلندية الهونغ الكونغية",
    "hungary–ireland relations": "العلاقات الأيرلندية المجرية",
    "iceland–ireland relations": "العلاقات الآيسلندية الأيرلندية",
    "india–ireland relations": "العلاقات الأيرلندية الهندية",
    "india–ireland sports relations": "العلاقات الأيرلندية الهندية الرياضية",
    "indonesia–ireland relations": "العلاقات الأيرلندية الإندونيسية",
    "iran–ireland relations": "العلاقات الأيرلندية الإيرانية",
    "iraq–ireland relations": "العلاقات الأيرلندية العراقية",
    "ireland–israel relations": "العلاقات الأيرلندية الإسرائيلية",
    "ireland–italy relations": "العلاقات الأيرلندية الإيطالية",
    "ireland–italy sports relations": "العلاقات الأيرلندية الإيطالية الرياضية",
    "ireland–ivory coast relations": "العلاقات الأيرلندية الإيفوارية",
    "ireland–jamaica relations": "العلاقات الأيرلندية الجامايكية",
    "ireland–japan relations": "العلاقات الأيرلندية اليابانية",
    "ireland–jordan relations": "العلاقات الأردنية الأيرلندية",
    "ireland–kazakhstan relations": "العلاقات الأيرلندية الكازاخستانية",
    "ireland–kenya relations": "العلاقات الأيرلندية الكينية",
    "ireland–kenya sports relations": "العلاقات الأيرلندية الكينية الرياضية",
    "ireland–kosovo relations": "العلاقات الأيرلندية الكوسوفية",
    "ireland–kyrgyzstan relations": "العلاقات الأيرلندية القيرغيزستانية",
    "ireland–latvia relations": "العلاقات الأيرلندية اللاتفية",
    "ireland–lesotho relations": "العلاقات الأيرلندية الليسوتية",
    "ireland–libya relations": "العلاقات الأيرلندية الليبية",
    "ireland–liechtenstein relations": "العلاقات الأيرلندية الليختنشتانية",
    "ireland–lithuania relations": "العلاقات الأيرلندية الليتوانية",
    "ireland–luxembourg relations": "العلاقات الأيرلندية اللوكسمبورغية",
    "ireland–malawi relations": "العلاقات الأيرلندية الملاوية",
    "ireland–malaysia relations": "العلاقات الأيرلندية الماليزية",
    "ireland–mali relations": "العلاقات الأيرلندية المالية",
    "ireland–malta relations": "العلاقات الأيرلندية المالطية",
    "ireland–mexico relations": "العلاقات الأيرلندية المكسيكية",
    "ireland–moldova relations": "العلاقات الأيرلندية المولدوفية",
    "ireland–mongolia relations": "العلاقات الأيرلندية المنغولية",
    "ireland–montenegro relations": "العلاقات الأيرلندية المونتينيغرية",
    "ireland–morocco relations": "العلاقات الأيرلندية المغربية",
    "ireland–myanmar relations": "العلاقات الأيرلندية الميانمارية",
    "ireland–namibia relations": "العلاقات الأيرلندية الناميبية",
    "ireland–namibia sports relations": "العلاقات الأيرلندية الناميبية الرياضية",
    "ireland–nepal relations": "العلاقات الأيرلندية النيبالية",
    "ireland–netherlands relations": "العلاقات الأيرلندية الهولندية",
    "ireland–netherlands sports relations": "العلاقات الأيرلندية الهولندية الرياضية",
    "ireland–new zealand relations": "العلاقات الأيرلندية النيوزيلندية",
    "ireland–new zealand sports relations": "العلاقات الأيرلندية النيوزيلندية الرياضية",
    "ireland–nicaragua relations": "العلاقات الأيرلندية النيكاراغوية",
    "ireland–nigeria relations": "العلاقات الأيرلندية النيجيرية",
    "ireland–norway relations": "العلاقات الأيرلندية النرويجية",
    "ireland–pakistan relations": "العلاقات الأيرلندية الباكستانية",
    "ireland–pakistan sports relations": "العلاقات الأيرلندية الباكستانية الرياضية",
    "ireland–palestine relations": "العلاقات الأيرلندية الفلسطينية",
    "ireland–panama relations": "العلاقات الأيرلندية البنمية",
    "ireland–paraguay relations": "العلاقات الأيرلندية البارغوايانية",
    "ireland–peru relations": "العلاقات الأيرلندية البيروية",
    "ireland–philippines relations": "العلاقات الأيرلندية الفلبينية",
    "ireland–poland relations": "العلاقات الأيرلندية البولندية",
    "ireland–portugal relations": "العلاقات الأيرلندية البرتغالية",
    "ireland–qatar relations": "العلاقات الأيرلندية القطرية",
    "ireland–romania relations": "العلاقات الأيرلندية الرومانية",
    "ireland–russia relations": "العلاقات الأيرلندية الروسية",
    "ireland–rwanda relations": "العلاقات الأيرلندية الرواندية",
    "ireland–samoa relations": "العلاقات الأيرلندية الساموية",
    "ireland–saudi arabia relations": "العلاقات الأيرلندية السعودية",
    "ireland–scotland relations": "العلاقات الأيرلندية الإسكتلندية",
    "ireland–senegal relations": "العلاقات الأيرلندية السنغالية",
    "ireland–serbia relations": "العلاقات الأيرلندية الصربية",
    "ireland–sierra leone relations": "العلاقات الأيرلندية السيراليونية",
    "ireland–singapore relations": "العلاقات الأيرلندية السنغافورية",
    "ireland–slovakia relations": "العلاقات الأيرلندية السلوفاكية",
    "ireland–slovenia relations": "العلاقات الأيرلندية السلوفينية",
    "ireland–somalia relations": "العلاقات الأيرلندية الصومالية",
    "ireland–south korea relations": "العلاقات الأيرلندية الكورية الجنوبية",
    "ireland–soviet union relations": "العلاقات الأيرلندية السوفيتية",
    "ireland–spain relations": "العلاقات الأيرلندية الإسبانية",
    "ireland–spain sports relations": "العلاقات الأيرلندية الإسبانية الرياضية",
    "ireland–sri lanka relations": "العلاقات الأيرلندية السريلانكية",
    "ireland–sri lanka sports relations": "العلاقات الأيرلندية السريلانكية الرياضية",
    "ireland–sudan relations": "العلاقات الأيرلندية السودانية",
    "ireland–sweden relations": "العلاقات الأيرلندية السويدية",
    "ireland–switzerland relations": "العلاقات الأيرلندية السويسرية",
    "ireland–taiwan relations": "العلاقات الأيرلندية التايوانية",
    "ireland–tajikistan relations": "العلاقات الأيرلندية الطاجيكستانية",
    "ireland–tanzania relations": "العلاقات الأيرلندية التنزانية",
    "ireland–thailand relations": "العلاقات الأيرلندية التايلندية",
    "ireland–tonga relations": "العلاقات الأيرلندية التونغانية",
    "ireland–trinidad and tobago relations": "العلاقات الأيرلندية الترنيدادية",
    "ireland–tunisia relations": "العلاقات الأيرلندية التونسية",
    "ireland–turkey relations": "العلاقات الأيرلندية التركية",
    "ireland–uganda relations": "العلاقات الأوغندية الأيرلندية",
    "ireland–ukraine relations": "العلاقات الأوكرانية الأيرلندية",
    "ireland–united arab emirates relations": "العلاقات الأيرلندية الإماراتية",
    "ireland–united arab emirates sports relations": "العلاقات الأيرلندية الإماراتية الرياضية",
    "ireland–united kingdom relations": "العلاقات الأيرلندية البريطانية",
    "ireland–united kingdom sports relations": "العلاقات الأيرلندية البريطانية الرياضية",
    "ireland–united states relations": "العلاقات الأمريكية الأيرلندية",
    "ireland–united states sports relations": "العلاقات الأمريكية الأيرلندية الرياضية",
    "ireland–uruguay relations": "العلاقات الأوروغويانية الأيرلندية",
    "ireland–uzbekistan relations": "العلاقات الأوزبكستانية الأيرلندية",
    "ireland–venezuela relations": "العلاقات الأيرلندية الفنزويلية",
    "ireland–vietnam relations": "العلاقات الأيرلندية الفيتنامية",
    "ireland–west germany relations": "العلاقات الألمانية الغربية الأيرلندية",
    "ireland–yugoslavia relations": "العلاقات الأيرلندية اليوغسلافية",
    "ireland–zambia relations": "العلاقات الأيرلندية الزامبية",
    "ireland–zimbabwe relations": "العلاقات الأيرلندية الزيمبابوية",
    "ireland–zimbabwe sports relations": "العلاقات الأيرلندية الزيمبابوية الرياضية",
}

test_data = {
    "Georgia (country)–Luxembourg relations": "العلاقات الجورجية اللوكسمبورغية",
    "France–Papua New Guinea relations": "العلاقات الغينية الفرنسية",
    "Angola–Guinea-Bissau relations": "العلاقات الأنغولية الغينية البيساوية",
    "Azerbaijan–Guinea-Bissau relations": "العلاقات الأذربيجانية الغينية البيساوية",
    "Belgium–Guinea-Bissau relations": "العلاقات البلجيكية الغينية البيساوية",
    "Brazil–Guinea-Bissau relations": "العلاقات البرازيلية الغينية البيساوية",
    "Bulgaria–Guinea-Bissau relations": "العلاقات البلغارية الغينية البيساوية",
    "Cape Verde–Guinea-Bissau relations": "العلاقات الرأس الأخضرية الغينية البيساوية",
    "China–Guinea-Bissau relations": "العلاقات الصينية الغينية البيساوية",
    "Cyprus–Guinea-Bissau relations": "العلاقات الغينية البيساوية القبرصية",
    "Democratic republic of congo–republic of congo border crossings": "معابر الحدود الكونغوية الكونغوية الديمقراطية",
    "Egypt–Guinea-Bissau relations": "العلاقات الغينية البيساوية المصرية",
    "Ethiopia–Guinea-Bissau relations": "العلاقات الإثيوبية الغينية البيساوية",
    "Finland–Guinea-Bissau relations": "العلاقات الغينية البيساوية الفنلندية",
    "France–Guinea-Bissau relations": "العلاقات الغينية البيساوية الفرنسية",
    "Georgia (country)–Guinea-Bissau relations": "العلاقات الجورجية الغينية البيساوية",
    "Greece–Guinea-Bissau relations": "العلاقات الغينية البيساوية اليونانية",
    "democratic-republic-of-congo–libya relations": "العلاقات الكونغوية الديمقراطية الليبية",
    "democratic-republic-of-congo–netherlands relations": "العلاقات الكونغوية الديمقراطية الهولندية",
    "ireland–sahrawi arab democratic republic relations": "علاقات أيرلندا والجمهورية العربية الصحراوية الديمقراطية",
    "abbasid caliphate–byzantine empire relations": "علاقات الإمبراطورية البيزنطية والدولة العباسية",
    "algeria–sahrawi arab democratic republic relations": "علاقات الجزائر والجمهورية العربية الصحراوية الديمقراطية",
    "angola–sahrawi arab democratic republic relations": "علاقات أنغولا والجمهورية العربية الصحراوية الديمقراطية",
    "australia–cook islands relations": "علاقات أستراليا وجزر كوك",
    "australia–sahrawi arab democratic republic relations": "علاقات أستراليا والجمهورية العربية الصحراوية الديمقراطية",
    "australia–solomon islands relations": "علاقات أستراليا وجزر سليمان",
    "australia–tibet relations": "علاقات أستراليا والتبت",
    "bangladesh–solomon islands relations": "علاقات بنغلاديش وجزر سليمان",
    "belize–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وبليز",
    "belize–solomon islands relations": "علاقات بليز وجزر سليمان",
    "bermuda–canada relations": "علاقات برمودا وكندا",
    "bermuda–united states relations": "علاقات الولايات المتحدة وبرمودا",
    "byzantine empire–fatimid caliphate relations": "علاقات الإمبراطورية البيزنطية والدولة الفاطمية",
    "byzantine empire–holy roman empire relations": "علاقات الإمبراطورية البيزنطية والإمبراطورية الرومانية المقدسة",
    "canada–marshall islands relations": "علاقات جزر مارشال وكندا",
    "canada–solomon islands relations": "علاقات جزر سليمان وكندا",
    "canada–tibet relations": "علاقات التبت وكندا",
    "cayman islands–jamaica relations": "علاقات جامايكا وجزر كايمان",
    "cayman islands–sierra leone relations": "علاقات جزر كايمان وسيراليون",
    "china–cook islands relations": "علاقات الصين وجزر كوك",
    "china–great britain relations": "علاقات الصين وبريطانيا العظمى",
    "china–solomon islands relations": "علاقات الصين وجزر سليمان",
    "china–tibet relations": "علاقات التبت والصين",
    "cook islands–czech republic relations": "علاقات التشيك وجزر كوك",
    "cook islands–european union relations": "علاقات الاتحاد الأوروبي وجزر كوك",
    "cook islands–fiji relations": "علاقات جزر كوك وفيجي",
    "cook islands–japan relations": "علاقات اليابان وجزر كوك",
    "cook islands–new zealand relations": "علاقات جزر كوك ونيوزيلندا",
    "cook islands–papua new guinea relations": "علاقات بابوا غينيا الجديدة وجزر كوك",
    "cook islands–sweden relations": "علاقات السويد وجزر كوك",
    "cook islands–united kingdom relations": "علاقات المملكة المتحدة وجزر كوك",
    "cook islands–united states relations": "علاقات الولايات المتحدة وجزر كوك",
    "costa rica–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وكوستاريكا",
    "cuba–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وكوبا",
    "cuba–solomon islands relations": "علاقات جزر سليمان وكوبا",
    "czech republic–solomon islands relations": "علاقات التشيك وجزر سليمان",
    "denmark–holy roman empire relations": "علاقات الإمبراطورية الرومانية المقدسة والدنمارك",
    "dutch republic–england relations": "علاقات إنجلترا وجمهورية هولندا",
    "dutch republic–france relations": "علاقات جمهورية هولندا وفرنسا",
    "dutch republic–habsburg monarchy relations": "علاقات جمهورية هولندا وملكية هابسبورغ",
    "dutch republic–holy roman empire relations": "علاقات الإمبراطورية الرومانية المقدسة وجمهورية هولندا",
    "dutch republic–portugal relations": "علاقات البرتغال وجمهورية هولندا",
    "dutch republic–spain relations": "علاقات إسبانيا وجمهورية هولندا",
    "dutch republic–sweden relations": "علاقات السويد وجمهورية هولندا",
    "england–holy roman empire relations": "علاقات إنجلترا والإمبراطورية الرومانية المقدسة",
    "equatorial guinea–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وغينيا الاستوائية",
    "ethiopia–sahrawi arab democratic republic relations": "علاقات إثيوبيا والجمهورية العربية الصحراوية الديمقراطية",
    "federated states-of micronesia–solomon islands relations": "علاقات جزر سليمان وولايات ميكرونيسيا المتحدة",
    "fiji–marshall islands relations": "علاقات جزر مارشال وفيجي",
    "fiji–solomon islands relations": "علاقات جزر سليمان وفيجي",
    "france–great britain relations": "علاقات بريطانيا العظمى وفرنسا",
    "france–habsburg monarchy relations": "علاقات فرنسا وملكية هابسبورغ",
    "france–holy roman empire relations": "علاقات الإمبراطورية الرومانية المقدسة وفرنسا",
    "france–marshall islands relations": "علاقات جزر مارشال وفرنسا",
    "france–solomon islands relations": "علاقات جزر سليمان وفرنسا",
    "germany–solomon islands relations": "علاقات ألمانيا وجزر سليمان",
    "germany–tibet relations": "علاقات ألمانيا والتبت",
    "ghana–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وغانا",
    "ghana–solomon islands relations": "علاقات جزر سليمان وغانا",
    "great britain–habsburg monarchy relations": "علاقات بريطانيا العظمى وملكية هابسبورغ",
    "great britain–united states relations": "علاقات الولايات المتحدة وبريطانيا العظمى",
    "guernsey–united kingdom relations": "علاقات المملكة المتحدة وغيرنزي",
    "habsburg monarchy–holy roman empire relations": "علاقات الإمبراطورية الرومانية المقدسة وملكية هابسبورغ",
    "habsburg monarchy–ottoman empire relations": "علاقات الدولة العثمانية وملكية هابسبورغ",
    "habsburg monarchy–polish–lithuanian commonwealth relations": "علاقات الكومنولث البولندي الليتواني وملكية هابسبورغ",
    "habsburg monarchy–prussia relations": "علاقات بروسيا وملكية هابسبورغ",
    "habsburg monarchy–russia relations": "علاقات روسيا وملكية هابسبورغ",
    "habsburg monarchy–spain relations": "علاقات إسبانيا وملكية هابسبورغ",
    "holy roman empire–hungary relations": "علاقات الإمبراطورية الرومانية المقدسة والمجر",
    "holy roman empire–ottoman empire relations": "علاقات الإمبراطورية الرومانية المقدسة والدولة العثمانية",
    "holy roman empire–portugal relations": "علاقات الإمبراطورية الرومانية المقدسة والبرتغال",
    "holy roman empire–russia relations": "علاقات الإمبراطورية الرومانية المقدسة وروسيا",
    "holy roman empire–sweden relations": "علاقات الإمبراطورية الرومانية المقدسة والسويد",
    "hungary–solomon islands relations": "علاقات المجر وجزر سليمان",
    "india–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية والهند",
    "india–solomon islands relations": "علاقات الهند وجزر سليمان",
    "india–tibet relations": "علاقات التبت والهند",
    "indonesia–marshall islands relations": "علاقات إندونيسيا وجزر مارشال",
    "iran–sahrawi arab democratic republic relations": "علاقات إيران والجمهورية العربية الصحراوية الديمقراطية",
    "japan–marshall islands relations": "علاقات اليابان وجزر مارشال",
    "japan–solomon islands relations": "علاقات اليابان وجزر سليمان",
    "japan–tibet relations": "علاقات التبت واليابان",
    "kazakhstan–solomon islands relations": "علاقات جزر سليمان وكازاخستان",
    "kiribati–solomon islands relations": "علاقات جزر سليمان وكيريباتي",
    "malaysia–solomon islands relations": "علاقات جزر سليمان وماليزيا",
    "marshall islands–federated states-of micronesia relations": "علاقات جزر مارشال وولايات ميكرونيسيا المتحدة",
    "marshall islands–new zealand relations": "علاقات جزر مارشال ونيوزيلندا",
    "marshall islands–spain relations": "علاقات إسبانيا وجزر مارشال",
    "marshall islands–sweden relations": "علاقات السويد وجزر مارشال",
    "marshall islands–taiwan relations": "علاقات تايوان وجزر مارشال",
    "marshall islands–united states relations": "علاقات الولايات المتحدة وجزر مارشال",
    "mexico–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية والمكسيك",
    "mongolia–tibet relations": "علاقات التبت ومنغوليا",
    "nepal–tibet relations": "علاقات التبت ونيبال",
    "new zealand–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية ونيوزيلندا",
    "new zealand–solomon islands relations": "علاقات جزر سليمان ونيوزيلندا",
    "nicaragua–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية ونيكاراغوا",
    "nigeria–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية ونيجيريا",
    "nigeria–solomon islands relations": "علاقات جزر سليمان ونيجيريا",
    "pakistan–solomon islands relations": "علاقات باكستان وجزر سليمان",
    "palestine–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وفلسطين",
    "panama–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وبنما",
    "papua new guinea–solomon islands relations": "علاقات بابوا غينيا الجديدة وجزر سليمان",
    "peru–sahrawi arab democratic republic relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وبيرو",
    "romania–solomon islands relations": "علاقات جزر سليمان ورومانيا",
    "sahrawi arab democratic republic–syria relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وسوريا",
    "sahrawi arab democratic republic–united kingdom relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية والمملكة المتحدة",
    "sahrawi arab democratic republic–united states relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية والولايات المتحدة",
    "sahrawi arab democratic republic–venezuela relations": "علاقات الجمهورية العربية الصحراوية الديمقراطية وفنزويلا",
    "samoa–solomon islands relations": "علاقات جزر سليمان وساموا",
    "sierra leone–solomon islands relations": "علاقات جزر سليمان وسيراليون",
    "solomon islands–spain relations": "علاقات إسبانيا وجزر سليمان",
    "solomon islands–sri lanka relations": "علاقات جزر سليمان وسريلانكا",
    "solomon islands–sweden relations": "علاقات السويد وجزر سليمان",
    "solomon islands–taiwan relations": "علاقات تايوان وجزر سليمان",
    "solomon islands–uganda relations": "علاقات أوغندا وجزر سليمان",
    "solomon islands–united kingdom relations": "علاقات المملكة المتحدة وجزر سليمان",
    "solomon islands–united states relations": "علاقات الولايات المتحدة وجزر سليمان",
    "solomon islands–vietnam relations": "علاقات جزر سليمان وفيتنام",
    "switzerland–tibet relations": "علاقات التبت وسويسرا",
    "taiwan–tibet relations": "علاقات التبت وتايوان",
    "tibet–united kingdom relations": "علاقات التبت والمملكة المتحدة",
    "tibet–united states relations": "علاقات التبت والولايات المتحدة",
    "Ukraine–NATO relations": "علاقات أوكرانيا والناتو",
    "Switzerland–NATO relations": "علاقات الناتو وسويسرا",
    "Sweden–NATO relations": "علاقات السويد والناتو",
    "Serbia–NATO relations": "علاقات الناتو وصربيا",
    "Russia–NATO relations": "علاقات الناتو وروسيا",
    "Poland–NATO relations": "علاقات الناتو وبولندا",
    "Pakistan–NATO relations": "علاقات الناتو وباكستان",
    "Malta–NATO relations": "علاقات الناتو ومالطا",
    "Georgia (country)–NATO relations": "علاقات الناتو وجورجيا",
    "Bosnia and Herzegovina–NATO relations": "علاقات البوسنة والهرسك والناتو",
    "Belarus–NATO relations": "علاقات الناتو وروسيا البيضاء",
    "Azerbaijan–NATO relations": "علاقات أذربيجان والناتو",
    "Austria–NATO relations": "علاقات الناتو والنمسا",
    "Armenia–NATO relations": "علاقات أرمينيا والناتو",
    "afghanistan–european union relations": "علاقات أفغانستان والاتحاد الأوروبي",
    "albania–european union relations": "علاقات ألبانيا والاتحاد الأوروبي",
    "andorra–european union relations": "علاقات أندورا والاتحاد الأوروبي",
    "angola–european union relations": "علاقات أنغولا والاتحاد الأوروبي",
    "argentina–european union relations": "علاقات الأرجنتين والاتحاد الأوروبي",
    "armenia–european union relations": "علاقات أرمينيا والاتحاد الأوروبي",
    "australia–european union relations": "علاقات أستراليا والاتحاد الأوروبي",
    "azerbaijan–european union relations": "علاقات أذربيجان والاتحاد الأوروبي",
    "bahamas–european union relations": "علاقات الاتحاد الأوروبي وباهاماس",
    "bahrain–european union relations": "علاقات الاتحاد الأوروبي والبحرين",
    "bangladesh–european union relations": "علاقات الاتحاد الأوروبي وبنغلاديش",
    "barbados–european union relations": "علاقات الاتحاد الأوروبي وبربادوس",
    "belarus–european union relations": "علاقات الاتحاد الأوروبي وروسيا البيضاء",
    "bolivia–european union relations": "علاقات الاتحاد الأوروبي وبوليفيا",
    "bosnia and herzegovina–european union relations": "علاقات الاتحاد الأوروبي والبوسنة والهرسك",
    "botswana–european union relations": "علاقات الاتحاد الأوروبي وبوتسوانا",
    "brazil–european union relations": "علاقات الاتحاد الأوروبي والبرازيل",
    "brunei–european union relations": "علاقات الاتحاد الأوروبي وبروناي",
    "burkina faso–european union relations": "علاقات الاتحاد الأوروبي وبوركينا فاسو",
    "cambodia–european union relations": "علاقات الاتحاد الأوروبي وكمبوديا",
    "cameroon–european union relations": "علاقات الاتحاد الأوروبي والكاميرون",
    "canada–european union relations": "علاقات الاتحاد الأوروبي وكندا",
    "cape verde–european union relations": "علاقات الاتحاد الأوروبي والرأس الأخضر",
    "central african republic–european union relations": "علاقات الاتحاد الأوروبي وجمهورية إفريقيا الوسطى",
    "chad–european union relations": "علاقات الاتحاد الأوروبي وتشاد",
    "chile–european union relations": "علاقات الاتحاد الأوروبي وتشيلي",
    "china–european union relations": "علاقات الاتحاد الأوروبي والصين",
    "colombia–european union relations": "علاقات الاتحاد الأوروبي وكولومبيا",
    "cuba–european union relations": "علاقات الاتحاد الأوروبي وكوبا",
    "djibouti–european union relations": "علاقات الاتحاد الأوروبي وجيبوتي",
    "dominican republic–european union relations": "علاقات الاتحاد الأوروبي وجمهورية الدومينيكان",
    "ecuador–european union relations": "علاقات الإكوادور والاتحاد الأوروبي",
    "egypt–european union relations": "علاقات الاتحاد الأوروبي ومصر",
    "eritrea–european union relations": "علاقات إرتريا والاتحاد الأوروبي",
    "european union–ghana relations": "علاقات الاتحاد الأوروبي وغانا",
    "european union–sudan relations": "علاقات الاتحاد الأوروبي والسودان",
    "fiji–european union relations": "علاقات الاتحاد الأوروبي وفيجي",
    "georgia (country)–european union relations": "علاقات الاتحاد الأوروبي وجورجيا",
    "greenland–european union relations": "علاقات الاتحاد الأوروبي وجرينلاند",
    "guatemala–european union relations": "علاقات الاتحاد الأوروبي وغواتيمالا",
    "guyana–european union relations": "علاقات الاتحاد الأوروبي وغيانا",
    "iceland–european union relations": "علاقات آيسلندا والاتحاد الأوروبي",
    "india–european union relations": "علاقات الاتحاد الأوروبي والهند",
    "indonesia–european union relations": "علاقات إندونيسيا والاتحاد الأوروبي",
    "iran–european union relations": "علاقات إيران والاتحاد الأوروبي",
    "iraq–european union relations": "علاقات الاتحاد الأوروبي والعراق",
    "israel–european union relations": "علاقات إسرائيل والاتحاد الأوروبي",
    "ivory coast–european union relations": "علاقات الاتحاد الأوروبي وساحل العاج",
    "jamaica–european union relations": "علاقات الاتحاد الأوروبي وجامايكا",
    "japan–european union relations": "علاقات الاتحاد الأوروبي واليابان",
    "jordan–european union relations": "علاقات الأردن والاتحاد الأوروبي",
    "kazakhstan–european union relations": "علاقات الاتحاد الأوروبي وكازاخستان",
    "kosovo–european union relations": "علاقات الاتحاد الأوروبي وكوسوفو",
    "kyrgyzstan–european union relations": "علاقات الاتحاد الأوروبي وقيرغيزستان",
    "lebanon–european union relations": "علاقات الاتحاد الأوروبي ولبنان",
    "libya–european union relations": "علاقات الاتحاد الأوروبي وليبيا",
    "liechtenstein–european union relations": "علاقات الاتحاد الأوروبي وليختنشتاين",
    "madagascar–european union relations": "علاقات الاتحاد الأوروبي ومدغشقر",
    "maldives–european union relations": "علاقات الاتحاد الأوروبي وجزر المالديف",
    "mauritania–european union relations": "علاقات الاتحاد الأوروبي وموريتانيا",
    "mauritius–european union relations": "علاقات الاتحاد الأوروبي وموريشيوس",
    "mexico–european union relations": "علاقات الاتحاد الأوروبي والمكسيك",
    "moldova–european union relations": "علاقات الاتحاد الأوروبي ومولدوفا",
    "mongolia–european union relations": "علاقات الاتحاد الأوروبي ومنغوليا",
    "montenegro–european union relations": "علاقات الاتحاد الأوروبي والجبل الأسود",
    "morocco–european union relations": "علاقات الاتحاد الأوروبي والمغرب",
    "namibia–european union relations": "علاقات الاتحاد الأوروبي وناميبيا",
    "nepal–european union relations": "علاقات الاتحاد الأوروبي ونيبال",
    "new zealand–european union relations": "علاقات الاتحاد الأوروبي ونيوزيلندا",
    "nicaragua–european union relations": "علاقات الاتحاد الأوروبي ونيكاراغوا",
    "north korea–european union relations": "علاقات الاتحاد الأوروبي وكوريا الشمالية",
    "north macedonia–european union relations": "علاقات الاتحاد الأوروبي ومقدونيا الشمالية",
    "norway–european union relations": "علاقات الاتحاد الأوروبي والنرويج",
    "pakistan–european union relations": "علاقات الاتحاد الأوروبي وباكستان",
    "palau–european union relations": "علاقات الاتحاد الأوروبي وبالاو",
    "palestine–european union relations": "علاقات الاتحاد الأوروبي وفلسطين",
    "papua new guinea–european union relations": "علاقات الاتحاد الأوروبي وبابوا غينيا الجديدة",
    "philippines–european union relations": "علاقات الاتحاد الأوروبي والفلبين",
    "qatar–european union relations": "علاقات الاتحاد الأوروبي وقطر",
    "russia–european union relations": "علاقات الاتحاد الأوروبي وروسيا",
    "samoa–european union relations": "علاقات الاتحاد الأوروبي وساموا",
    "san marino–european union relations": "علاقات الاتحاد الأوروبي وسان مارينو",
    "saudi arabia–european union relations": "علاقات الاتحاد الأوروبي والسعودية",
    "serbia–european union relations": "علاقات الاتحاد الأوروبي وصربيا",
    "sierra leone–european union relations": "علاقات الاتحاد الأوروبي وسيراليون",
    "singapore–european union relations": "علاقات الاتحاد الأوروبي وسنغافورة",
    "somalia–european union relations": "علاقات الاتحاد الأوروبي والصومال",
    "south africa–european union relations": "علاقات الاتحاد الأوروبي وجنوب إفريقيا",
    "south korea–european union relations": "علاقات الاتحاد الأوروبي وكوريا الجنوبية",
    "sri lanka–european union relations": "علاقات الاتحاد الأوروبي وسريلانكا",
    "switzerland–european union relations": "علاقات الاتحاد الأوروبي وسويسرا",
    "syria–european union relations": "علاقات الاتحاد الأوروبي وسوريا",
    "taiwan–european union relations": "علاقات الاتحاد الأوروبي وتايوان",
    "tanzania–european union relations": "علاقات الاتحاد الأوروبي وتنزانيا",
    " gambia–european union relations": "علاقات الاتحاد الأوروبي وغامبيا",
    "tonga–european union relations": "علاقات الاتحاد الأوروبي وتونغا",
    "tunisia–european union relations": "علاقات الاتحاد الأوروبي وتونس",
    "turkey–european union relations": "علاقات الاتحاد الأوروبي وتركيا",
    "turkmenistan–european union relations": "علاقات الاتحاد الأوروبي وتركمانستان",
    "uganda–european union relations": "علاقات أوغندا والاتحاد الأوروبي",
    "ukraine–european union relations": "علاقات أوكرانيا والاتحاد الأوروبي",
    "united kingdom–european union relations": "علاقات الاتحاد الأوروبي والمملكة المتحدة",
    "united states–european union relations": "علاقات الاتحاد الأوروبي والولايات المتحدة",
    "uzbekistan–european union relations": "علاقات أوزبكستان والاتحاد الأوروبي",
    "venezuela–european union relations": "علاقات الاتحاد الأوروبي وفنزويلا",
    "yemen–european union relations": "علاقات الاتحاد الأوروبي واليمن",
    "zambia–european union relations": "علاقات الاتحاد الأوروبي وزامبيا",
    "zimbabwe–european union relations": "علاقات الاتحاد الأوروبي وزيمبابوي",
}


@pytest.mark.parametrize("category, expected", ireland_test_data.items(), ids=ireland_test_data.keys())
@pytest.mark.fast
def test_ireland_test_data(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data.items(), ids=test_data.keys())
@pytest.mark.fast
def test_work_relations_new(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


TEMPORAL_CASES = [
    ("test_work_relations_new", test_data, new_relations_resolvers),
    ("test_work_relations_ireland", ireland_test_data, new_relations_resolvers),
]


@pytest.mark.parametrize("name,data,callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_dump_all(name: str, data: str, callback: str) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, f"test_new_relations_resolvers_big_data_{name}")

    # dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
