#!/usr/bin/python3
""" """

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.raw_sports import find_jobs_bot, wrap_team_xo_normal_2025_with_ends

test_find_jobs_bot_data_with_additional = {
    "women's national youth association football teams": "منتخبات كرة قدم وطنية للشابات",
    "women's national ice hockey teams": "منتخبات هوكي جليد وطنية للسيدات",
    "national under-18 ice hockey teams": "منتخبات هوكي جليد وطنية تحت 18 سنة",
    "women's national under-18 ice hockey teams": "منتخبات هوكي جليد وطنية تحت 18 سنة للسيدات",
    "national youth women's football teams": "منتخبات كرة قدم وطنية للشابات",
    "american football leagues templates": "قوالب دوريات كرة قدم أمريكية",
    "national softball teams coaches": "مدربو منتخبات كرة لينة وطنية",
    "national under-15 football teams": "منتخبات كرة قدم وطنية تحت 15 سنة",
    "national under-18 football teams": "منتخبات كرة قدم وطنية تحت 18 سنة",
    "national under-19 basketball teams": "منتخبات كرة سلة وطنية تحت 19 سنة",
    "national under-20 basketball teams": "منتخبات كرة سلة وطنية تحت 20 سنة",
    "national under-21 field hockey teams": "منتخبات هوكي ميدان وطنية تحت 21 سنة",
    "national women's under-19 basketball teams": "منتخبات كرة سلة وطنية تحت 19 سنة للسيدات",
    "national women's under-20 football teams": "منتخبات كرة قدم وطنية تحت 20 سنة للسيدات",
    "national women's under-23 football teams": "منتخبات كرة قدم وطنية تحت 23 سنة للسيدات",
    "national youth women's under-14 softball leagues scouts": "كشافة دوريات كرة لينة وطنية تحت 14 سنة للشابات",
    "national youth women's under-14 softball leagues trainers": "مدربو دوريات كرة لينة وطنية تحت 14 سنة للشابات",
    "national youth women's under-14 softball leagues umpires": "حكام دوريات كرة لينة وطنية تحت 14 سنة للشابات",
    "national youth women's under-14 softball teams coaches": "مدربو منتخبات كرة لينة وطنية تحت 14 سنة للشابات",
    "national youth women's under-14 softball teams scouts": "كشافة منتخبات كرة لينة وطنية تحت 14 سنة للشابات",
    "national youth women's under-14 softball teams trainers": "مدربو منتخبات كرة لينة وطنية تحت 14 سنة للشابات",
    "rugby league teams": "فرق دوري رجبي",
    "rugby teams": "فرق رجبي",
    "under-13 baseball leagues films": "أفلام دوريات كرة قاعدة تحت 13 سنة",
    "under-13 baseball leagues finals": "نهائيات دوريات كرة قاعدة تحت 13 سنة",
    "under-13 baseball leagues positions": "مراكز دوريات كرة قاعدة تحت 13 سنة",
    "under-13 baseball leagues tournaments": "بطولات دوريات كرة قاعدة تحت 13 سنة",
    "under-13 baseball teams films": "أفلام فرق كرة قاعدة تحت 13 سنة",
    "under-13 baseball teams positions": "مراكز فرق كرة قاعدة تحت 13 سنة",
    "under-13 baseball teams tournaments": "بطولات فرق كرة قاعدة تحت 13 سنة",
    "wheelchair rugby league teams": "فرق دوري رجبي على كراسي متحركة",
    "wheelchair rugby teams": "فرق رجبي على كراسي متحركة",
}

test_find_jobs_bot_data_0 = {
    # "college football": "كرة قدم الكليات",
    "baseball competitions": "منافسات كرة قاعدة",
    "national football manager history": "تاريخ مدربو منتخبات كرة قدم وطنية",
    "national under-20 football manager history": "تاريخ مدربو منتخبات كرة قدم تحت 20 سنة",
    "swimming competitions": "منافسات سباحة",
}

test_find_jobs_bot_data = {
    "amateur wrestling": "مصارعة للهواة",
    "international women's wrestling competitions": "منافسات مصارعة دولية للسيدات",
    "international women's basketball competitions": "منافسات كرة سلة دولية للسيدات",
    "international women's cricket competitions": "منافسات كريكت دولية للسيدات",
    "international women's field hockey competitions": "منافسات هوكي ميدان دولية للسيدات",
    "international women's football competitions": "منافسات كرة قدم دولية للسيدات",
    "international men's wrestling competitions": "منافسات مصارعة دولية للرجال",
    "international men's football competitions": "منافسات كرة قدم دولية للرجال",
    "women's international basketball": "كرة سلة دولية للسيدات",
    "women's international football": "كرة قدم دولية للسيدات",
    "national women's equestrian manager history": "تاريخ مدربو منتخبات فروسية وطنية للسيدات",
    "domestic women's football leagues": "دوريات كرة قدم محلية للسيدات",
    "domestic women's handball leagues": "دوريات كرة يد محلية للسيدات",
    "women's international wrestling": "مصارعة دولية للسيدات",
    "national women's wrestling manager history": "تاريخ مدربو منتخبات مصارعة وطنية للسيدات",
    "international women's wrestling": "مصارعة دولية للسيدات",
    "domestic women's wrestling clubs": "أندية مصارعة محلية للسيدات",
    "domestic women's wrestling coaches": "مدربو مصارعة محلية للسيدات",
    "domestic women's wrestling competitions": "منافسات مصارعة محلية للسيدات",
    "domestic women's wrestling leagues": "دوريات مصارعة محلية للسيدات",
    "domestic women's wrestling cups": "كؤوس مصارعة محلية للسيدات",
    "national women's field hockey teams": "منتخبات هوكي ميدان وطنية نسائية",
    "national women's floorball teams": "منتخبات كرة أرض وطنية نسائية",
    "national women's rugby sevens teams": "منتخبات سباعيات رجبي وطنية نسائية",
    "national women's softball teams": "منتخبات كرة لينة وطنية نسائية",
    "national women's wheelchair basketball teams": "منتخبات كرة سلة على كراسي متحركة وطنية نسائية",
    "women's wrestling": "مصارعة نسائية",
    "women's wrestling teams": "فرق مصارعة نسائية",
    "national women's wrestling teams": "منتخبات مصارعة وطنية نسائية",
    "under-13 wrestling manager history": "تاريخ مدربو مصارعة تحت 13 سنة",
    "under-14 wrestling manager history": "تاريخ مدربو مصارعة تحت 14 سنة",
    "under-15 wrestling manager history": "تاريخ مدربو مصارعة تحت 15 سنة",
    "under-16 wrestling manager history": "تاريخ مدربو مصارعة تحت 16 سنة",
    "under-17 wrestling manager history": "تاريخ مدربو مصارعة تحت 17 سنة",
    "under-18 wrestling manager history": "تاريخ مدربو مصارعة تحت 18 سنة",
    "under-19 wrestling manager history": "تاريخ مدربو مصارعة تحت 19 سنة",
    "under-20 wrestling manager history": "تاريخ مدربو مصارعة تحت 20 سنة",
    "under-21 wrestling manager history": "تاريخ مدربو مصارعة تحت 21 سنة",
    "under-23 wrestling manager history": "تاريخ مدربو مصارعة تحت 23 سنة",
    "under-24 wrestling manager history": "تاريخ مدربو مصارعة تحت 24 سنة",
    "under-13 equestrian manager history": "تاريخ مدربو فروسية تحت 13 سنة",
    "under-14 equestrian manager history": "تاريخ مدربو فروسية تحت 14 سنة",
    "grand slam (wrestling) tournaments": "بطولات مصارعة كبرى",
    "professional wrestling cups": "كؤوس مصارعة محترفين",
    "professional wrestling competitions": "منافسات مصارعة محترفين",
    "professional wrestling leagues": "دوريات مصارعة محترفين",
    "defunct indoor wrestling cups": "كؤوس مصارعة داخل الصالات سابقة",
    "defunct outdoor wrestling cups": "كؤوس مصارعة في الهواء الطلق سابقة",
    "defunct wrestling cup competitions": "منافسات كؤوس مصارعة سابقة",
    "defunct wrestling cups": "كؤوس مصارعة سابقة",
    "domestic wrestling cup": "كؤوس مصارعة محلية",
    "domestic wrestling cups": "كؤوس مصارعة محلية",
    "wrestling cup competitions": "منافسات كؤوس مصارعة",
    "wrestling cups": "كؤوس مصارعة",
    "outdoor wrestling cups": "كؤوس مصارعة في الهواء الطلق",
    "indoor wrestling cups": "كؤوس مصارعة داخل الصالات",
    "amateur wrestling championships": "بطولات مصارعة للهواة",
    "current wrestling seasons": "مواسم مصارعة حالية",
    "defunct indoor wrestling clubs": "أندية مصارعة داخل الصالات سابقة",
    "defunct indoor wrestling coaches": "مدربو مصارعة داخل الصالات سابقة",
    "defunct indoor wrestling competitions": "منافسات مصارعة داخل الصالات سابقة",
    "defunct indoor wrestling leagues": "دوريات مصارعة داخل الصالات سابقة",
    "defunct outdoor wrestling clubs": "أندية مصارعة في الهواء الطلق سابقة",
    "defunct outdoor wrestling coaches": "مدربو مصارعة في الهواء الطلق سابقة",
    "defunct outdoor wrestling competitions": "منافسات مصارعة في الهواء الطلق سابقة",
    "defunct outdoor wrestling leagues": "دوريات مصارعة في الهواء الطلق سابقة",
    "defunct wrestling clubs": "أندية مصارعة سابقة",
    "defunct wrestling coaches": "مدربو مصارعة سابقة",
    "defunct wrestling competitions": "منافسات مصارعة سابقة",
    "defunct wrestling leagues": "دوريات مصارعة سابقة",
    "defunct wrestling teams": "فرق مصارعة سابقة",
    "domestic wrestling": "مصارعة محلية",
    "domestic wrestling clubs": "أندية مصارعة محلية",
    "domestic wrestling coaches": "مدربو مصارعة محلية",
    "domestic wrestling competitions": "منافسات مصارعة محلية",
    "domestic wrestling leagues": "دوريات مصارعة محلية",
    "fictional wrestling": "مصارعة خيالية",
    "fifth level wrestling league": "دوريات مصارعة من الدرجة الخامسة",
    "fifth level wrestling leagues": "دوريات مصارعة من الدرجة الخامسة",
    "fifth tier wrestling league": "دوريات مصارعة من الدرجة الخامسة",
    "fifth tier wrestling leagues": "دوريات مصارعة من الدرجة الخامسة",
    "first level wrestling league": "دوريات مصارعة من الدرجة الأولى",
    "first level wrestling leagues": "دوريات مصارعة من الدرجة الأولى",
    "first tier wrestling league": "دوريات مصارعة من الدرجة الأولى",
    "first tier wrestling leagues": "دوريات مصارعة من الدرجة الأولى",
    "first-class wrestling": "مصارعة من الدرجة الأولى",
    "first-class wrestling competitions": "منافسات مصارعة من الدرجة الأولى",
    "first-class wrestling matches": "مباريات مصارعة من الدرجة الأولى",
    "first-class wrestling teams": "فرق مصارعة من الدرجة الأولى",
    "fourth level wrestling league": "دوريات مصارعة من الدرجة الرابعة",
    "fourth level wrestling leagues": "دوريات مصارعة من الدرجة الرابعة",
    "fourth tier wrestling league": "دوريات مصارعة من الدرجة الرابعة",
    "fourth tier wrestling leagues": "دوريات مصارعة من الدرجة الرابعة",
    "grand slam (wrestling)": "بطولات مصارعة كبرى",
    "grand slam (wrestling) tournament champions": "أبطال بطولات مصارعة كبرى",
    "indoor wrestling": "مصارعة داخل الصالات",
    "indoor wrestling clubs": "أندية مصارعة داخل الصالات",
    "indoor wrestling coaches": "مدربو مصارعة داخل الصالات",
    "indoor wrestling competitions": "منافسات مصارعة داخل الصالات",
    "indoor wrestling leagues": "دوريات مصارعة داخل الصالات",
    "international men's wrestling": "مصارعة دولية للرجال",
    "international men's wrestling players": "لاعبو مصارعة دوليون",
    "international men's wrestling playerss": "لاعبو مصارعة دوليون",
    "international women's wrestling players": "لاعبات مصارعة دوليات",
    "international women's wrestling playerss": "لاعبات مصارعة دوليات",
    "international wrestling": "مصارعة دولية",
    "International wrestling competition tournaments": "بطولات منافسات مصارعة دولية",
    "International wrestling competitions": "منافسات مصارعة دولية",
    "international wrestling managers": "مدربو مصارعة دوليون",
    "international wrestling players": "لاعبو مصارعة دوليون",
    "international wrestling playerss": "لاعبو مصارعة دوليون",
    "International wrestling races": "سباقات مصارعة دولية",
    "International wrestling tournaments": "بطولات مصارعة دولية",
    "international youth wrestling competitions": "منافسات مصارعة شبابية دولية",
    "men's international wrestling": "مصارعة دولية للرجال",
    "men's international wrestling players": "لاعبو مصارعة دوليون",
    "men's international wrestling playerss": "لاعبو مصارعة دوليون",
    "men's wrestling": "مصارعة رجالية",
    "men's wrestling teams": "فرق مصارعة رجالية",
    "military wrestling": "مصارعة عسكرية",
    "military wrestling competitions": "منافسات مصارعة عسكرية",
    "multi-national wrestling championships": "بطولات مصارعة متعددة الجنسيات",
    "multi-national wrestling league": "دوريات مصارعة متعددة الجنسيات",
    "multi-national wrestling leagues": "دوريات مصارعة متعددة الجنسيات",
    "national a' wrestling teams": "منتخبات مصارعة للمحليين",
    "national a. wrestling teams": "منتخبات مصارعة للمحليين",
    "national b wrestling teams": "منتخبات مصارعة رديفة",
    "national b. wrestling teams": "منتخبات مصارعة رديفة",
    "national junior men's wrestling teams": "منتخبات مصارعة وطنية للناشئين",
    "national junior wrestling teams": "منتخبات مصارعة وطنية للناشئين",
    "national men's wrestling manager history": "تاريخ مدربو منتخبات مصارعة وطنية للرجال",
    "national men's wrestling teams": "منتخبات مصارعة وطنية رجالية",
    "national reserve wrestling teams": "منتخبات مصارعة وطنية احتياطية",
    "national under-13 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 13 سنة",
    "national under-14 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 14 سنة",
    "national under-15 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 15 سنة",
    "national under-16 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 16 سنة",
    "national under-17 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 17 سنة",
    "national under-18 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 18 سنة",
    "national under-19 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 19 سنة",
    "national under-20 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 20 سنة",
    "national under-21 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 21 سنة",
    "national under-23 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 23 سنة",
    "national under-24 wrestling manager history": "تاريخ مدربو منتخبات مصارعة تحت 24 سنة",
    "national wrestling champions": "أبطال بطولات مصارعة وطنية",
    "national wrestling championships": "بطولات مصارعة وطنية",
    "national wrestling league": "دوريات مصارعة وطنية",
    "national wrestling leagues": "دوريات مصارعة وطنية",
    "national wrestling manager history": "تاريخ مدربو منتخبات مصارعة وطنية",
    "national wrestling team results": "نتائج منتخبات مصارعة وطنية",
    "national wrestling teams": "منتخبات مصارعة وطنية",
    "national youth wrestling teams": "منتخبات مصارعة وطنية شبابية",
    "outdoor wrestling": "مصارعة في الهواء الطلق",
    "outdoor wrestling clubs": "أندية مصارعة في الهواء الطلق",
    "outdoor wrestling coaches": "مدربو مصارعة في الهواء الطلق",
    "outdoor wrestling competitions": "منافسات مصارعة في الهواء الطلق",
    "outdoor wrestling leagues": "دوريات مصارعة في الهواء الطلق",
    "premier wrestling league": "دوريات مصارعة من الدرجة الممتازة",
    "premier wrestling leagues": "دوريات مصارعة من الدرجة الممتازة",
    "reserve wrestling teams": "فرق مصارعة احتياطية",
    "second level wrestling league": "دوريات مصارعة من الدرجة الثانية",
    "second level wrestling leagues": "دوريات مصارعة من الدرجة الثانية",
    "second tier wrestling league": "دوريات مصارعة من الدرجة الثانية",
    "second tier wrestling leagues": "دوريات مصارعة من الدرجة الثانية",
    "seventh level wrestling league": "دوريات مصارعة من الدرجة السابعة",
    "seventh level wrestling leagues": "دوريات مصارعة من الدرجة السابعة",
    "seventh tier wrestling league": "دوريات مصارعة من الدرجة السابعة",
    "seventh tier wrestling leagues": "دوريات مصارعة من الدرجة السابعة",
    "sixth level wrestling league": "دوريات مصارعة من الدرجة السادسة",
    "sixth level wrestling leagues": "دوريات مصارعة من الدرجة السادسة",
    "sixth tier wrestling league": "دوريات مصارعة من الدرجة السادسة",
    "sixth tier wrestling leagues": "دوريات مصارعة من الدرجة السادسة",
    "third level wrestling league": "دوريات مصارعة من الدرجة الثالثة",
    "third level wrestling leagues": "دوريات مصارعة من الدرجة الثالثة",
    "third tier wrestling league": "دوريات مصارعة من الدرجة الثالثة",
    "third tier wrestling leagues": "دوريات مصارعة من الدرجة الثالثة",
    "top level wrestling league": "دوريات مصارعة من الدرجة الأولى",
    "top level wrestling leagues": "دوريات مصارعة من الدرجة الأولى",
    "under-13 wrestling": "مصارعة تحت 13 سنة",
    "under-14 wrestling": "مصارعة تحت 14 سنة",
    "under-15 wrestling": "مصارعة تحت 15 سنة",
    "under-16 wrestling": "مصارعة تحت 16 سنة",
    "under-17 wrestling": "مصارعة تحت 17 سنة",
    "under-18 wrestling": "مصارعة تحت 18 سنة",
    "under-19 wrestling": "مصارعة تحت 19 سنة",
    "under-20 wrestling": "مصارعة تحت 20 سنة",
    "under-21 wrestling": "مصارعة تحت 21 سنة",
    "under-23 wrestling": "مصارعة تحت 23 سنة",
    "under-24 wrestling": "مصارعة تحت 24 سنة",
    "women's international wrestling players": "لاعبات مصارعة دوليات",
    "women's international wrestling playerss": "لاعبات مصارعة دوليات",
    "wrestling chairmen and investors": "رؤساء ومسيرو مصارعة",
    "wrestling competitions": "منافسات مصارعة",
    "wrestling league competitions": "منافسات دوري مصارعة",
    "wrestling league teams": "فرق دوري مصارعة",
    "wrestling leagues": "دوريات مصارعة",
    "wrestling olympic bronze medalists": "ميداليات مصارعة برونزية أولمبية",
    "wrestling olympic gold medalists": "ميداليات مصارعة ذهبية أولمبية",
    "wrestling olympic silver medalists": "ميداليات مصارعة فضية أولمبية",
    "wrestling races": "سباقات مصارعة",
    "wrestling super leagues": "دوريات سوبر مصارعة",
    "youth international wrestling": "مصارعة دولية شبابية",
    "youth wrestling": "مصارعة شبابية",
    "youth wrestling competitions": "منافسات مصارعة شبابية",
    "national men's beach volleyball teams": "منتخبات كرة طائرة شاطئية وطنية رجالية",
    "national men's volleyball teams": "منتخبات كرة طائرة وطنية رجالية",
    "national men's wheelchair basketball teams": "منتخبات كرة سلة على كراسي متحركة وطنية رجالية",
    "basketball olympic bronze medalists": "ميداليات كرة سلة برونزية أولمبية",
    "current badminton seasons": "مواسم تنس ريشة حالية",
    "current cricket seasons": "مواسم كريكت حالية",
    "current football seasons": "مواسم كرة قدم حالية",
    "current hurling seasons": "مواسم قذف حالية",
    "cycling races": "سباقات سباق دراجات هوائية",
    "defunct american football teams": "فرق كرة قدم أمريكية سابقة",
    "defunct athletics clubs": "أندية ألعاب قوى سابقة",
    "defunct australian rules football clubs": "أندية كرة قدم أسترالية سابقة",
    "defunct baseball teams": "فرق كرة قاعدة سابقة",
    "defunct basketball leagues": "دوريات كرة سلة سابقة",
    "defunct basketball teams": "فرق كرة سلة سابقة",
    "defunct canadian football teams": "فرق كرة قدم كندية سابقة",
    "defunct cycling teams": "فرق سباق دراجات هوائية سابقة",
    "defunct football clubs": "أندية كرة قدم سابقة",
    "defunct football competitions": "منافسات كرة قدم سابقة",
    "defunct football leagues": "دوريات كرة قدم سابقة",
    "defunct handball clubs": "أندية كرة يد سابقة",
    "defunct handball competitions": "منافسات كرة يد سابقة",
    "defunct ice hockey leagues": "دوريات هوكي جليد سابقة",
    "defunct ice hockey teams": "فرق هوكي جليد سابقة",
    "defunct indoor american football leagues": "دوريات كرة قدم أمريكية داخل الصالات سابقة",
    "defunct lacrosse teams": "فرق لاكروس سابقة",
    "defunct rugby league teams": "فرق دوري رجبي سابقة",
    "defunct rugby union competitions": "منافسات اتحاد رجبي سابقة",
    "defunct soccer clubs": "أندية كرة قدم سابقة",
    "defunct speed skating clubs": "أندية تزلج سريع سابقة",
    "defunct sports clubs": "أندية رياضية سابقة",
    "defunct sports competitions": "منافسات رياضية سابقة",
    "defunct sports leagues": "دوريات رياضية سابقة",
    "defunct volleyball clubs": "أندية كرة طائرة سابقة",
    "domestic cricket competitions": "منافسات كريكت محلية",
    "domestic football leagues": "دوريات كرة قدم محلية",
    "domestic football": "كرة قدم محلية",
    "domestic handball leagues": "دوريات كرة يد محلية",
    "fictional motorsports": "رياضة محركات خيالية",
    "first-class cricket teams": "فرق كريكت من الدرجة الأولى",
    "first-class cricket": "كريكت من الدرجة الأولى",
    "football chairmen and investors": "رؤساء ومسيرو كرة قدم",
    "football league competitions": "منافسات دوري كرة قدم",
    "fourth level football leagues": "دوريات كرة قدم من الدرجة الرابعة",
    "indoor football": "كرة قدم داخل الصالات",
    "indoor hockey clubs": "أندية هوكي داخل الصالات",
    "indoor hockey": "هوكي داخل الصالات",
    "indoor soccer clubs": "أندية كرة قدم داخل الصالات",
    "indoor soccer coaches": "مدربو كرة قدم داخل الصالات",
    "indoor soccer": "كرة قدم داخل الصالات",
    "indoor track and field": "سباقات مضمار وميدان داخل الصالات",
    "international aquatics competitions": "منافسات رياضات مائية دولية",
    "international archery competitions": "منافسات نبالة دولية",
    "international athletics competitions": "منافسات ألعاب قوى دولية",
    "international bandy competitions": "منافسات باندي دولية",
    "international baseball competitions": "منافسات كرة قاعدة دولية",
    "international basketball competitions": "منافسات كرة سلة دولية",
    "international boxing competitions": "منافسات بوكسينغ دولية",
    "international chess competitions": "منافسات شطرنج دولية",
    "international cricket": "كريكت دولية",
    "international cricket competitions": "منافسات كريكت دولية",
    "international curling competitions": "منافسات كيرلنغ دولية",
    "international cycle races": "سباقات دراجات دولية",
    "international fencing competitions": "منافسات مبارزة سيف شيش دولية",
    "international field hockey competitions": "منافسات هوكي ميدان دولية",
    "international figure skating competitions": "منافسات تزلج فني دولية",
    "international football": "كرة قدم دولية",
    "international football competitions": "منافسات كرة قدم دولية",
    "international futsal competitions": "منافسات كرة صالات دولية",
    "international gymnastics competitions": "منافسات جمباز دولية",
    "international handball competitions": "منافسات كرة يد دولية",
    "international ice hockey competitions": "منافسات هوكي جليد دولية",
    "international kabaddi competitions": "منافسات كابادي دولية",
    "international netball competitions": "منافسات كرة شبكة دولية",
    "international roller hockey competitions": "منافسات هوكي دحرجة دولية",
    "international rugby league competitions": "منافسات دوري رجبي دولية",
    "international rugby sevens players": "لاعبو سباعيات رجبي دوليون",
    "international rugby union competitions": "منافسات اتحاد رجبي دولية",
    "international softball competitions": "منافسات كرة لينة دولية",
    "international taekwondo competitions": "منافسات تايكوندو دولية",
    "international track and field competitions": "منافسات سباقات مضمار وميدان دولية",
    "international volleyball competitions": "منافسات كرة طائرة دولية",
    "international water polo competitions": "منافسات كرة ماء دولية",
    "international weightlifting competitions": "منافسات رفع أثقال دولية",
    "international wrestling competitions": "منافسات مصارعة دولية",
    "international youth basketball competitions": "منافسات كرة سلة شبابية دولية",
    "international youth football competitions": "منافسات كرة قدم شبابية دولية",
    "men's international basketball": "كرة سلة دولية للرجال",
    "men's international football": "كرة قدم دولية للرجال",
    "military diving": "غطس عسكرية",
    "military football": "كرة قدم عسكرية",
    "national b football teams": "منتخبات كرة قدم رديفة",
    "national badminton teams": "منتخبات تنس ريشة وطنية",
    "national bobsleigh teams": "منتخبات زلاجة جماعية وطنية",
    "national equestrian manager history": "تاريخ مدربو منتخبات فروسية وطنية",
    "national football team results": "نتائج منتخبات كرة قدم وطنية",
    "national ice hockey teams": "منتخبات هوكي جليد وطنية",
    "national junior men's handball teams": "منتخبات كرة يد وطنية للناشئين",
    "national men's equestrian manager history": "تاريخ مدربو منتخبات فروسية وطنية للرجال",
    "national rowing championships": "بطولات تجديف وطنية",
    "national rugby sevens teams": "منتخبات سباعيات رجبي وطنية",
    "national softball teams": "منتخبات كرة لينة وطنية",
    "national speed skating championships": "بطولات تزلج سريع وطنية",
    "national tennis league": "دوريات كرة مضرب وطنية",
    "national under-13 equestrian manager history": "تاريخ مدربو منتخبات فروسية تحت 13 سنة",
    "national under-14 equestrian manager history": "تاريخ مدربو منتخبات فروسية تحت 14 سنة",
    "national wheelchair basketball teams": "منتخبات كرة سلة على كراسي متحركة وطنية",
    "national wheelchair handball teams": "منتخبات كرة يد على كراسي متحركة وطنية",
    "national wheelchair rugby teams": "منتخبات رجبي على كراسي متحركة وطنية",
    "outdoor equestrian": "فروسية في الهواء الطلق",
    "premier badminton league": "دوريات تنس ريشة من الدرجة الممتازة",
    "premier volleyball league": "دوريات كرة طائرة من الدرجة الممتازة",
    "professional ice hockey leagues": "دوريات هوكي جليد للمحترفين",
    "professional soccer leagues": "دوريات كرة قدم للمحترفين",
    "professional sports leagues": "دوريات رياضية للمحترفين",
    "rugby competitions": "منافسات رجبي",
    "rugby league competitions": "منافسات دوري رجبي",
    "softball competitions": "منافسات كرة لينة",
    "under-13 equestrian": "فروسية تحت 13 سنة",
    "under-14 equestrian": "فروسية تحت 14 سنة",
    "under-17 football": "كرة قدم تحت 17 سنة",
    "under-18 ice hockey": "هوكي جليد تحت 18 سنة",
    "under-18 rugby union": "اتحاد رجبي تحت 18 سنة",
    "under-20 basketball": "كرة سلة تحت 20 سنة",
    "wheelchair rugby competitions": "منافسات رجبي على كراسي متحركة",
    "wheelchair rugby league competitions": "منافسات دوري رجبي على كراسي متحركة",
    "youth international football": "كرة قدم دولية شبابية",
}


def wrap_callback(category: str) -> str:
    return wrap_team_xo_normal_2025_with_ends(category, callback=find_jobs_bot)


@pytest.mark.parametrize("category, expected", test_find_jobs_bot_data.items(), ids=test_find_jobs_bot_data.keys())
@pytest.mark.fast
def test_Get_New_team_xo_data(category: str, expected: str) -> None:
    label1 = wrap_callback(category)
    assert isinstance(label1, str)
    assert label1 == expected


@pytest.mark.parametrize("category, expected", test_find_jobs_bot_data_0.items(), ids=test_find_jobs_bot_data_0.keys())
@pytest.mark.fast
def test_test_find_jobs_bot_data_0(category: str, expected: str) -> None:
    label1 = wrap_callback(category)
    assert isinstance(label1, str)
    assert label1 == expected


TEMPORAL_CASES = [
    ("test_find_jobs_bot", test_find_jobs_bot_data, wrap_callback),
    # ("test_find_jobs_bot_with_additional", test_find_jobs_bot_data_with_additional, wrap_callback),
]


@pytest.mark.parametrize("name,data,callback", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
