#!/usr/bin/python3


""" """

# from .numbers1 import change_numb_to_word, change_numb
# ---
change_numb_to_word = {
    "100": "المئة",
    "200": "المائتين",
    "300": "الثلاثمائة",
}
# ---
change_numb = {
    "1": "الأول",
    "2": "الثاني",
    "3": "الثالث",
    "4": "الرابع",
    "5": "الخامس",
    "6": "السادس",
    "7": "السابع",
    "8": "الثامن",
    "9": "التاسع",
    "10": "العاشر",
    "11": "الحادي عشر",
    "12": "الثاني عشر",
    "13": "الثالث عشر",
    "14": "الرابع عشر",
    "15": "الخامس عشر",
    "16": "السادس عشر",
    "17": "السابع عشر",
    "18": "الثامن عشر",
    "19": "التاسع عشر",
    "20": "العشرون",
    "21": "الحادي والعشرون",
    "22": "الثاني والعشرون",
    "23": "الثالث والعشرون",
    "24": "الرابع والعشرون",
    "25": "الخامس والعشرون",
    "26": "السادس والعشرون",
    "27": "السابع والعشرون",
    "28": "الثامن والعشرون",
    "29": "التاسع والعشرون",
    "30": "الثلاثون",
    "31": "الحادي والثلاثون",
    "32": "الثاني والثلاثون",
    "33": "الثالث والثلاثون",
    "34": "الرابع والثلاثون",
    "35": "الخامس والثلاثون",
    "36": "السادس والثلاثون",
    "37": "السابع والثلاثون",
    "38": "الثامن والثلاثون",
    "39": "التاسع والثلاثون",
    "40": "الأربعون",
    "41": "الحادي والأربعون",
    "42": "الثاني والأربعون",
    "43": "الثالث والأربعون",
    "44": "الرابع والأربعون",
    "45": "الخامس والأربعون",
    "46": "السادس والأربعون",
    "47": "السابع والأربعون",
    "48": "الثامن والأربعون",
    "49": "التاسع والأربعون",
    "50": "الخمسون",
    "51": "الحادي والخمسون",
    "52": "الثاني والخمسون",
    "53": "الثالث والخمسون",
    "54": "الرابع والخمسون",
    "55": "الخامس والخمسون",
    "56": "السادس والخمسون",
    "57": "السابع والخمسون",
    "58": "الثامن والخمسون",
    "59": "التاسع والخمسون",
    "60": "الستون",
    "61": "الحادي والستون",
    "62": "الثاني والستون",
    "63": "الثالث والستون",
    "64": "الرابع والستون",
    "65": "الخامس والستون",
    "66": "السادس والستون",
    "67": "السابع والستون",
    "68": "الثامن والستون",
    "69": "التاسع والستون",
    "70": "السبعون",
    "71": "الحادي والسبعون",
    "72": "الثاني والسبعون",
    "73": "الثالث والسبعون",
    "74": "الرابع والسبعون",
    "75": "الخامس والسبعون",
    "76": "السادس والسبعون",
    "77": "السابع والسبعون",
    "78": "الثامن والسبعون",
    "79": "التاسع والسبعون",
    "80": "الثمانون",
    "81": "الحادي والثمانون",
    "82": "الثاني والثمانون",
    "83": "الثالث والثمانون",
    "84": "الرابع والثمانون",
    "85": "الخامس والثمانون",
    "86": "السادس والثمانون",
    "87": "السابع والثمانون",
    "88": "الثامن والثمانون",
    "89": "التاسع والثمانون",
    "90": "التسعون",
    "91": "الحادي والتسعون",
    "92": "الثاني والتسعون",
    "93": "الثالث والتسعون",
    "94": "الرابع والتسعون",
    "95": "الخامس والتسعون",
    "96": "السادس والتسعون",
    "97": "السابع والتسعون",
    "98": "الثامن والتسعون",
    "99": "التاسع والتسعون",
}
# ---
for number_key, arabic_label in change_numb.items():
    change_numb_to_word[number_key] = arabic_label
    extended_hundreds_key = number_key
    if len(number_key) == 1:
        extended_hundreds_key = f"10{number_key}"
    if len(number_key) == 2:
        extended_hundreds_key = f"1{number_key}"
    change_numb_to_word[extended_hundreds_key] = f"{arabic_label} بعد المئة"
    # print('dt1:%s' % dt1 )
    extended_two_hundred_key = number_key
    if len(number_key) == 1:
        extended_two_hundred_key = f"20{number_key}"
    if len(number_key) == 2:
        extended_two_hundred_key = f"2{number_key}"
    change_numb_to_word[extended_two_hundred_key] = f"{arabic_label} بعد المائتين"
    extended_three_hundred_key = number_key
    if len(number_key) == 1:
        extended_three_hundred_key = f"30{number_key}"
    if len(number_key) == 2:
        extended_three_hundred_key = f"3{number_key}"
    change_numb_to_word[extended_three_hundred_key] = f"{arabic_label} بعد الثلاثمائة"
