country_names_and_nats_data = {
    # "{en} army": "الجيش {the_male}",
    "{en} invasion": "الغزو {the_male}",
    "{en} military": "الجيش {the_male}",
    "{en} solidarity movement": "حركة التضامن {the_male}",
    # en_is_P17_ar_is_al_women
    # the_female - en_is_nat_ar_is_al_women
    "{en} royal air force": "القوات الجوية الملكية {the_female}",
    "{en} civil war": "الحرب الأهلية {the_female}",
    "{en} air force": "القوات الجوية {the_female}",
    "{en} air force personnel": "أفراد القوات الجوية {the_female}",
    "{en} air force generals": "جنرالات القوات الجوية {the_female}",
    "{en} royal defence force": "قوات الدفاع الملكية {the_female}",
    "{en} navy": "البحرية {the_female}",
    "{en} royal navy": "البحرية الملكية {the_female}",
    "{en} naval force": "البحرية {the_female}",
    "{en} naval forces": "البحرية {the_female}",
    # female - military_format_women
    "{en} airlines": "الخطوط الجوية {the_female}",
    "{en} armed forces": "القوات المسلحة {the_female}",
    "{en} army aviation": "طيران القوات المسلحة {the_female}",
    "{en} army": "القوات المسلحة {the_female}",
    "{en} case law": "السوابق القضائية {the_female}",
    "{en} communications": "الاتصالات {the_female}",
    "{en} diplomacy": "الدبلوماسية {the_female}",
    "{en} federal election candidates": "مرشحي الانتخابات الفيدرالية {the_female}",
    "{en} federal election": "الانتخابات الفيدرالية {the_female}",
    "{en} federal elections": "الانتخابات الفيدرالية {the_female}",
    "{en} football club": "أندية كرة القدم {the_female}",
    "{en} football manager history": "تاريخ مدربي كرة القدم {the_female}",
    "{en} football manager": "مدربي كرة القدم {the_female}",
    "{en} football": "كرة القدم {the_female}",
    "{en} general election candidates": "مرشحي الانتخابات العامة {the_female}",
    "{en} general election": "الانتخابات العامة {the_female}",
    "{en} general elections": "الانتخابات العامة {the_female}",
    "{en} legislature election": "الانتخابات التشريعية {the_female}",
    "{en} legislature elections": "الانتخابات التشريعية {the_female}",
    "{en} local election": "الانتخابات المحلية {the_female}",
    "{en} local elections": "الانتخابات المحلية {the_female}",
    "{en} national navy": "القوات البحرية الوطنية {the_female}",
    "political positions of {en} presidential candidates": "مواقف سياسية لمرشحي الرئاسة {the_female}",
    "{en} presidential candidates": "مرشحي الرئاسة {the_female}",
    "{en} presidential election": "انتخابات الرئاسة {the_female}",
    "{en} presidential elections": "انتخابات الرئاسة {the_female}",
    "{en} presidential electors": "ناخبو الرئاسة {the_female}",
    "{en} presidential primaries": "الانتخابات الرئاسية التمهيدية {the_female}",
    "{en} presidential-elections": "انتخابات الرئاسة {the_female}",
    "{en} presidential-primaries": "الانتخابات الرئاسية التمهيدية {the_female}",
    "{en} state legislative": "المجالس التشريعية للولايات {the_female}",
    "{en} state lower house": "المجالس الدنيا للولايات {the_female}",
    "{en} state upper house": "المجالس العليا للولايات {the_female}",
    "{en} supreme court": "المحكمة العليا {the_female}",
    # the_male
    "{en} premier division": "الدوري {the_male} الممتاز",
    # the_male
    # military_format_men
    "{en} congressional delegation": "وفود الكونغرس {the_male}",
    "{en} congressional delegations": "وفود الكونغرس {the_male}",
    "{en} parliament": "البرلمان {the_male}",
    "{en} congress": "الكونغرس {the_male}",
    "{en} house of commons": "مجلس العموم {the_male}",
    "{en} house-of-commons": "مجلس العموم {the_male}",
    "{en} senate election": "انتخابات مجلس الشيوخ {the_male}",
    "{en} senate elections": "انتخابات مجلس الشيوخ {the_male}",
    "{en} fa cup": "كأس الاتحاد {the_male}",  # Category:Iraq FA Cup
    "{en} federation cup": "كأس الاتحاد {the_male}",  # Category:Bangladesh Federation Cup
    "{en} marine corps personnel": "أفراد سلاح مشاة البحرية {the_male}",
    "{en} army personnel": "أفراد الجيش {the_male}",
    "{en} army generals": "جنرالات الجيش {the_male}",
    "{en} coast guard": "خفر السواحل {the_male}",
    "{en} coast guard aviation": "طيران خفر السواحل {the_male}",
    "{en} abortion law": "قانون الإجهاض {the_male}",
    "{en} labour law": "قانون العمل {the_male}",  # Category:French_labour_law
    "{en} professional league": "دوري المحترفين {the_male}",
    "{en} first division league": "الدوري {the_male} الدرجة الأولى",
    "{en} second division": "الدوري {the_male} الدرجة الثانية",
    "{en} second division league": "الدوري {the_male} الدرجة الثانية",
    "{en} third division league": "الدوري {the_male} الدرجة الثالثة",
    "{en} forth division league": "الدوري {the_male} الدرجة الرابعة",
}


sports_formatted_data_for_jobs = {
    # Category:American players of Canadian football
    "{en} players of {en_sport}": "لاعبو {sport_jobs} {males}",
    "{en}-american coaches of canadian-football": "مدربو كرة قدم كندية أمريكيون {males}",
    # american coaches of basketball
    "{en} coaches of {en_sport}": "مدربو {sport_jobs} {males}",
    "{en}-american coaches of {en_sport}": "مدربو {sport_jobs} أمريكيون {males}",
    # coaches of basketball
    "coaches of {en_sport}": "مدربو {sport_jobs}",
    "players of {en_sport}": "لاعبو {sport_jobs}",
    # lithuanian expatriate basketball people "أعلام كرة سلة ليتوانيون مغتربون"
    "{en} expatriate {en_sport} peoplee": "أعلام {sport_jobs} {males} مغتربون",
    "{en} expatriate {en_sport} people": "أعلام {sport_jobs} {males} مغتربون",
    # expatriate basketball people
    "expatriate {en_sport} peoplee": "أعلام {sport_jobs} مغتربون",
    "expatriate {en_sport} people": "أعلام {sport_jobs} مغتربون",
    "{en} women's {en_sport} players": "لاعبات {sport_jobs} {females}",
    "women's {en_sport} players": "لاعبات {sport_jobs}",
    "{en} women's {en_sport} playerss": "لاعبات {sport_jobs} {females}",
    "women's {en_sport} playerss": "لاعبات {sport_jobs}",
    "{en} women's national {en_sport} team players": "لاعبات منتخب {ar} {sport_team} للسيدات",
    "{en} national {en_sport} team players": "لاعبو منتخب {ar} {sport_team}",
    "{en} women's international footballers": "لاعبات منتخب {ar} لكرة القدم للسيدات",
    "{en} women's youth international footballers": "لاعبات منتخب {ar} لكرة القدم للشابات",
    "{en} women's international {en_sport} players": "لاعبات {sport_jobs} دوليات من {ar}",
    "{en} international footballers": "لاعبو منتخب {ar} لكرة القدم",
    "{en} international {en_sport} players": "لاعبو {sport_jobs} دوليون من {ar}",
}

for_jobs = {
    # american coaches of basketball
    # "{en} coaches of {en_sport}": "مدربو {sport_jobs} {males}",
    # "{en}-american coaches of {en_sport}": "مدربو {sport_jobs} أمريكيون {males}",
    # coaches of basketball
    "coaches of {en_sport}": "مدربو {sport_jobs}",
    "players of {en_sport}": "لاعبو {sport_jobs}",
}

sports_formatted_data_for_jobs.update(for_jobs)

for x, v in for_jobs.items():
    # american coaches of basketball
    # "{en} coaches of {en_sport}": "مدربو {sport_jobs} {males}",
    sports_formatted_data_for_jobs[f"{{en}} {x}"] = f"{v} {{males}}"
