#!/usr/bin/python3
"""

"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.sports_resolvers.nationalities_and_sports import resolve_nats_sport_multi_v2

en_is_nat_ar_is_P17_data = {
    "yemeni acrobatic gymnastics cup": "كأس اليمن للجمباز الاكروباتيكي",
    "yemeni acrobatic gymnastics racing cup": "كأس اليمن لسباق الجمباز الاكروباتيكي",
    "yemeni aerobics cup": "كأس اليمن لجمباز أيروبيكس",
    "yemeni aerobics racing cup": "كأس اليمن لسباق جمباز أيروبيكس",
    "yemeni alpine skiing cup": "كأس اليمن للتزلج على المنحدرات الثلجية",
    "yemeni alpine skiing racing cup": "كأس اليمن لسباق التزلج على المنحدرات الثلجية",
    "yemeni women's australian rules football cup": "كأس اليمن لكرة القدم الأسترالية للسيدات",
    "yemeni women's australian rules football racing cup": "كأس اليمن لسباق كرة القدم الأسترالية للسيدات",
    "yemeni women's auto racing cup": "كأس اليمن لسباق السيارات للسيدات",
    "yemeni women's automobile racing cup": "كأس اليمن لسباق السيارات للسيدات",
    "yemeni women's badminton cup": "كأس اليمن لتنس الريشة للسيدات",
    "yemeni women's badminton racing cup": "كأس اليمن لسباق تنس الريشة للسيدات",
    "yemeni women's ball hockey cup": "كأس اليمن لهوكي الكرة للسيدات",
    "yemeni women's ball hockey racing cup": "كأس اليمن لسباق هوكي الكرة للسيدات",
    "yemeni women's bandy cup": "كأس اليمن للباندي للسيدات",
    "yemeni women's bandy racing cup": "كأس اليمن لسباق باندي للسيدات",
    "yemeni women's baseball cup": "كأس اليمن لكرة القاعدة للسيدات",
    "yemeni women's baseball racing cup": "كأس اليمن لسباق كرة القاعدة للسيدات",
    "yemeni women's basketball cup": "كأس اليمن لكرة السلة للسيدات",
    "yemeni women's basketball racing cup": "كأس اليمن لسباق كرة السلة للسيدات",
    "yemeni women's basque pelota cup": "كأس اليمن لكرة الباسك للسيدات",
    "yemeni women's basque pelota racing cup": "كأس اليمن لسباق كرة الباسك للسيدات",
    "yemeni women's beach handball cup": "كأس اليمن لكرة اليد الشاطئية للسيدات",
    "yemeni women's beach handball racing cup": "كأس اليمن لسباق كرة اليد الشاطئية للسيدات",
    "yemeni women's beach soccer cup": "كأس اليمن لكرة القدم الشاطئية للسيدات",
    "yemeni women's beach soccer racing cup": "كأس اليمن لسباق كرة القدم الشاطئية للسيدات",
    "yemeni women's beach volleyball cup": "كأس اليمن لكرة الطائرة الشاطئية للسيدات",
    "yemeni women's beach volleyball racing cup": "كأس اليمن لسباق كرة الطائرة الشاطئية للسيدات",
    "yemeni women's biathlon cup": "كأس اليمن للبياثلون للسيدات",
    "yemeni women's biathlon racing cup": "كأس اليمن لسباق البياثلون للسيدات",
    "yemeni women's bicycle motocross cup": "كأس اليمن للبي ام اكس للسيدات",
    "yemeni women's bicycle motocross racing cup": "كأس اليمن لسباق بي ام اكس للسيدات",
    "yemeni women's bmx cup": "كأس اليمن لسباق البي إم إكس للسيدات",
    "yemeni women's bmx racing cup": "كأس اليمن لسباق البي إم إكس للسيدات",
    "yemeni women's board games cup": "كأس اليمن لألعاب الطاولة للسيدات",
    "yemeni women's board games racing cup": "كأس اليمن لسباق ألعاب الطاولة للسيدات",
    "yemeni women's boat racing cup": "كأس اليمن لسباق الزوارق للسيدات",
    "yemeni women's bobsleigh cup": "كأس اليمن للزلاجة الجماعية للسيدات",
    "yemeni women's bobsleigh racing cup": "كأس اليمن لسباق الزلاجة الجماعية للسيدات",
    "yemeni women's boccia cup": "كأس اليمن للبوتشيا للسيدات",
    "yemeni women's boccia racing cup": "كأس اليمن لسباق البوتشيا للسيدات",
    "yemeni women's bodybuilding cup": "كأس اليمن لكمال الأجسام للسيدات",
    "yemeni women's bodybuilding racing cup": "كأس اليمن لسباق كمال الأجسام للسيدات",
    "yemeni women's bouldering cup": "كأس اليمن للبولدرنق للسيدات",
    "yemeni women's bouldering racing cup": "كأس اليمن لسباق بولدرنق للسيدات",
    "yemeni women's boules cup": "كأس اليمن للبوتشي للسيدات",
    "yemeni women's boules racing cup": "كأس اليمن لسباق بوتشي للسيدات",
    "yemeni women's bowling cup": "كأس اليمن للبولينج للسيدات",
    "yemeni women's bowling racing cup": "كأس اليمن لسباق بولينج للسيدات",
    "yemeni women's bowls cup": "كأس اليمن للبولينج للسيدات",
    "yemeni women's bowls racing cup": "كأس اليمن لسباق البولينج للسيدات",
    "yemeni women's boxing cup": "كأس اليمن للبوكسينغ للسيدات",
    "yemeni women's boxing racing cup": "كأس اليمن لسباق البوكسينغ للسيدات",
    "yemeni women's bullfighting cup": "كأس اليمن لمصارعة الثيران للسيدات",
    "yemeni women's bullfighting racing cup": "كأس اليمن لسباق مصارعة الثيران للسيدات",
    "yemeni women's canadian football cup": "كأس اليمن لكرة القدم الكندية للسيدات",
    "yemeni women's canadian football racing cup": "كأس اليمن لسباق كرة القدم الكندية للسيدات",
    "yemeni women's canadian-football cup": "كأس اليمن لكرة القدم الكندية للسيدات",
    "yemeni women's canadian-football racing cup": "كأس اليمن لسباق كرة القدم الكندية للسيدات",
    "yemeni women's canoe sprint cup": "كأس اليمن لسباق القوارب للسيدات",
    "yemeni women's canoeing and kayaking cup": "كأس اليمن للكانو كاياك للسيدات",
    "yemeni women's canoeing and kayaking racing cup": "كأس اليمن لسباق كانو-كاياك للسيدات",
    "yemeni women's canoeing cup": "كأس اليمن لركوب الكنو للسيدات",
    "yemeni women's canoeing racing cup": "كأس اليمن لسباق ركوب الكنو للسيدات",
    "yemeni women's chess cup": "كأس اليمن للشطرنج للسيدات",
    "yemeni women's chess racing cup": "كأس اليمن لسباق الشطرنج للسيدات",
    "yemeni women's chinese martial arts cup": "كأس اليمن للفنون القتالية الصينية للسيدات",
    "yemeni women's chinese martial arts racing cup": "كأس اليمن لسباق الفنون القتالية الصينية للسيدات",
    "yemeni women's climbing cup": "كأس اليمن للتسلق للسيدات",
    "yemeni women's climbing racing cup": "كأس اليمن لسباق التسلق للسيدات",
    "yemeni women's college cup": "كأس اليمن للكليات للسيدات",
    "yemeni women's college racing cup": "كأس اليمن لسباق الكليات للسيدات",
    "yemeni women's cricket cup": "كأس اليمن للكريكت للسيدات",
    "yemeni women's cricket racing cup": "كأس اليمن لسباق الكريكت للسيدات",
    "yemeni women's croquet cup": "كأس اليمن للكروكيت للسيدات",
    "yemeni women's croquet racing cup": "كأس اليمن لسباق الكروكيت للسيدات",
    "yemeni women's cross country cup": "كأس اليمن للعدو الريفي للسيدات",
    "yemeni women's cross country racing cup": "كأس اليمن لسباق العدو الريفي للسيدات",
    "yemeni women's cross country running cup": "كأس اليمن للعدو الريفي للسيدات",
    "yemeni women's cross country running racing cup": "كأس اليمن لسباق العدو الريفي للسيدات",
    "yemeni women's cross-country skiing cup": "كأس اليمن للتزلج الريفي للسيدات",
    "yemeni women's cross-country skiing racing cup": "كأس اليمن لسباق التزلج الريفي للسيدات",
    "yemeni women's cue sports cup": "كأس اليمن للبلياردو للسيدات",
    "yemeni women's cue sports racing cup": "كأس اليمن لسباق بلياردو للسيدات",
    "yemeni women's curling cup": "كأس اليمن للكيرلنغ للسيدات",
    "yemeni women's curling racing cup": "كأس اليمن لسباق الكيرلنغ للسيدات",
    "yemeni women's cycle cup": "كأس اليمن للدراجات للسيدات",
    "yemeni women's cycle race cup": "كأس اليمن لسباق الدراجات للسيدات",
    "yemeni women's cycle racing cup": "كأس اليمن لسباق الدراجات للسيدات",
    "yemeni women's cycle speedway cup": "كأس اليمن لسباق الدراجات النارية على المنعطفات للسيدات",
    "yemeni women's cycling cup": "كأس اليمن لسباق الدراجات الهوائية للسيدات",
    "yemeni women's cycling road race cup": "كأس اليمن لسباق الدراجات على الطريق للسيدات",
    "yemeni women's cyclo-cross cup": "كأس اليمن للسيكلو كروس للسيدات",
    "yemeni women's cyclo-cross racing cup": "كأس اليمن لسباق سيكلو كروس للسيدات",
    "yemeni women's darts cup": "كأس اليمن للسهام المريشة للسيدات",
    "yemeni women's darts racing cup": "كأس اليمن لسباق السهام المريشة للسيدات",
    "yemeni women's davis cup cup": "كأس اليمن لكأس ديفيز للسيدات",
    "yemeni women's davis cup racing cup": "كأس اليمن لسباق كأس ديفيز للسيدات",
    "yemeni women's discus throw cup": "كأس اليمن لرمي القرص للسيدات",
    "yemeni women's discus throw racing cup": "كأس اليمن لسباق رمي القرص للسيدات",
    "yemeni women's diving cup": "كأس اليمن للغطس للسيدات",
    "yemeni women's diving racing cup": "كأس اليمن لسباق الغطس للسيدات",
    "yemeni women's dragon boat cup": "كأس اليمن لسباق قوارب التنين للسيدات",
    "yemeni women's dragon boat racing cup": "كأس اليمن لسباق قوارب التنين للسيدات",
    "yemeni women's draughts cup": "كأس اليمن للضامة للسيدات",
    "yemeni women's draughts racing cup": "كأس اليمن لسباق ضامة للسيدات",
    "yemeni women's dressage cup": "كأس اليمن لترويض الخيول للسيدات",
    "yemeni women's dressage racing cup": "كأس اليمن لسباق ترويض الخيول للسيدات",
    "yemeni women's equestrian cup": "كأس اليمن للفروسية للسيدات",
    "yemeni women's equestrian racing cup": "كأس اليمن لسباق الفروسية للسيدات",
    "yemeni women's equestrianism cup": "كأس اليمن للفروسية للسيدات",
    "yemeni women's equestrianism racing cup": "كأس اليمن لسباق الفروسية للسيدات",
    "yemeni women's esports cup": "كأس اليمن للرياضة الإلكترونية للسيدات",
    "yemeni women's esports racing cup": "كأس اليمن لسباق رياضة إلكترونية للسيدات",
    "yemeni women's eventing cup": "كأس اليمن لمحاكمة الخيول للسيدات",
    "yemeni women's eventing racing cup": "كأس اليمن لسباق محاكمة الخيول للسيدات",
    "yemeni women's fencing cup": "كأس اليمن لمبارزة سيف الشيش للسيدات",
    "yemeni women's fencing racing cup": "كأس اليمن لسباق مبارزة سيف الشيش للسيدات",
    "yemeni women's field hockey cup": "كأس اليمن لهوكي الميدان للسيدات",
    "yemeni women's field hockey racing cup": "كأس اليمن لسباق هوكي الميدان للسيدات",
    "yemeni women's fifa futsal world cup cup": "كأس اليمن لكأس العالم لكرة الصالات للسيدات",
    "yemeni women's fifa futsal world cup racing cup": "كأس اليمن لسباق كأس العالم لكرة الصالات للسيدات",
    "yemeni women's fifa world cup cup": "كأس اليمن لكأس العالم لكرة القدم للسيدات",
    "yemeni women's fifa world cup racing cup": "كأس اليمن لسباق كأس العالم لكرة القدم للسيدات",
    "yemeni women's figure skating cup": "كأس اليمن للتزلج الفني للسيدات",
    "yemeni women's figure skating racing cup": "كأس اليمن لسباق التزلج الفني للسيدات",
    "yemeni women's floorball cup": "كأس اليمن لكرة الأرض للسيدات",
    "yemeni women's floorball racing cup": "كأس اليمن لسباق كرة الأرض للسيدات",
    "yemeni women's football cup": "كأس اليمن لكرة القدم للسيدات",
    "yemeni women's football racing cup": "كأس اليمن لسباق كرة القدم للسيدات",
    "yemeni women's formula e cup": "كأس اليمن للفورمولا إي للسيدات",
    "yemeni women's formula e racing cup": "كأس اليمن لسباق فورمولا إي للسيدات",
    "yemeni women's formula one cup": "كأس اليمن للفورمولا ون للسيدات",
    "yemeni women's formula one racing cup": "كأس اليمن لسباق فورمولا ون للسيدات",
    "yemeni women's formula racing cup": "كأس اليمن لسباقات الفورمولا للسيدات",
    "yemeni women's freestyle skiing cup": "كأس اليمن للتزلج الحر للسيدات",
    "yemeni women's freestyle skiing racing cup": "كأس اليمن لسباق التزلج الحر للسيدات",
    "yemeni women's freestyle wrestling cup": "كأس اليمن للمصارعة الحرة للسيدات",
    "yemeni women's freestyle wrestling racing cup": "كأس اليمن لسباق المصارعة الحرة للسيدات",
    "yemeni women's futsal cup": "كأس اليمن لكرة الصالات للسيدات",
    "yemeni women's futsal racing cup": "كأس اليمن لسباق كرة صالات للسيدات",
    "yemeni women's gaelic football cup": "كأس اليمن لكرة القدم الغالية للسيدات",
    "yemeni women's gaelic football racing cup": "كأس اليمن لسباق كرة القدم الغالية للسيدات",
    "yemeni women's go cup": "كأس اليمن للغو للسيدات",
    "yemeni women's go racing cup": "كأس اليمن لسباق غو للسيدات",
    "yemeni women's goalball cup": "كأس اليمن لكرة الهدف للسيدات",
    "yemeni women's goalball racing cup": "كأس اليمن لسباق كرة الهدف للسيدات",
    "yemeni women's golf cup": "كأس اليمن للغولف للسيدات",
    "yemeni women's golf racing cup": "كأس اليمن لسباق الغولف للسيدات",
    "yemeni women's greco-roman wrestling cup": "كأس اليمن للمصارعة اليونانية الرومانية للسيدات",
    "yemeni women's greco-roman wrestling racing cup": "كأس اليمن لسباق المصارعة اليونانية الرومانية للسيدات",
    "yemeni women's gridiron football cup": "كأس اليمن لكرة القدم الأمريكية الشمالية للسيدات",
    "yemeni women's gridiron football racing cup": "كأس اليمن لسباق كرة القدم الأمريكية الشمالية للسيدات",
    "yemeni women's gymnastics cup": "كأس اليمن للجمباز للسيدات",
    "yemeni women's gymnastics racing cup": "كأس اليمن لسباق الجمباز للسيدات",
    "yemeni women's hammer throw cup": "كأس اليمن لرمي المطرقة للسيدات",
    "yemeni women's hammer throw racing cup": "كأس اليمن لسباق رمي المطرقة للسيدات",
    "yemeni women's handball cup": "كأس اليمن لكرة اليد للسيدات",
    "yemeni women's handball racing cup": "كأس اليمن لسباق كرة اليد للسيدات",
    "yemeni women's high jump cup": "كأس اليمن للقفز العالي للسيدات",
    "yemeni women's high jump racing cup": "كأس اليمن لسباق القفز العالي للسيدات",
    "yemeni women's high school cup": "كأس اليمن للمدارس الثانوية للسيدات",
    "yemeni women's high school racing cup": "كأس اليمن لسباق المدارس الثانوية للسيدات",
    "yemeni women's hockey cup": "كأس اليمن للهوكي للسيدات",
    "yemeni women's hockey racing cup": "كأس اليمن لسباق هوكي للسيدات",
    "yemeni women's hurling cup": "كأس اليمن للقذف للسيدات",
    "yemeni women's hurling racing cup": "كأس اليمن لسباق القذف للسيدات",
    "yemeni women's ice dancing cup": "كأس اليمن للرقص على الجليد للسيدات",
    "yemeni women's ice dancing racing cup": "كأس اليمن لسباق الرقص على الجليد للسيدات",
    "yemeni women's ice hockey cup": "كأس اليمن لهوكي الجليد للسيدات",
    "yemeni women's ice hockey racing cup": "كأس اليمن لسباق هوكي الجليد للسيدات",
    "yemeni women's ice skating cup": "كأس اليمن للتزلج على الجليد للسيدات",
    "yemeni women's ice skating racing cup": "كأس اليمن لسباق تزلج على الجليد للسيدات",
    "yemeni women's ice sledge hockey cup": "كأس اليمن لهوكي المزلجة على الجليد للسيدات",
    "yemeni women's ice sledge hockey racing cup": "كأس اليمن لسباق هوكي المزلجة على الجليد للسيدات",
    "yemeni women's inline hockey cup": "كأس اليمن للهوكي المضمن للسيدات",
    "yemeni women's inline hockey racing cup": "كأس اليمن لسباق هوكي مضمن للسيدات",
    "yemeni women's javelin throw cup": "كأس اليمن لرمي الرمح للسيدات",
    "yemeni women's javelin throw racing cup": "كأس اليمن لسباق رمي الرمح للسيدات",
    "yemeni women's ju-jitsu cup": "كأس اليمن للجوجوتسو للسيدات",
    "yemeni women's ju-jitsu racing cup": "كأس اليمن لسباق جوجوتسو للسيدات",
    "yemeni women's judo cup": "كأس اليمن للجودو للسيدات",
    "yemeni women's judo racing cup": "كأس اليمن لسباق الجودو للسيدات",
    "yemeni women's jujutsu cup": "كأس اليمن للجوجوتسو للسيدات",
    "yemeni women's jujutsu racing cup": "كأس اليمن لسباق جوجوتسو للسيدات",
    "yemeni women's kabaddi cup": "كأس اليمن للكابادي للسيدات",
    "yemeni women's kabaddi racing cup": "كأس اليمن لسباق الكابادي للسيدات",
    "yemeni women's karate cup": "كأس اليمن للكاراتيه للسيدات",
    "yemeni women's karate racing cup": "كأس اليمن لسباق الكاراتيه للسيدات",
    "yemeni women's kick boxing cup": "كأس اليمن للكيك بوكسينغ للسيدات",
    "yemeni women's kick boxing racing cup": "كأس اليمن لسباق الكيك بوكسينغ للسيدات",
    "yemeni women's kickboxing cup": "كأس اليمن للكيك بوكسينغ للسيدات",
    "yemeni women's kickboxing racing cup": "كأس اليمن لسباق الكيك بوكسينغ للسيدات",
    "yemeni women's korfball cup": "كأس اليمن للكورفبال للسيدات",
    "yemeni women's korfball racing cup": "كأس اليمن لسباق كورفبال للسيدات",
    "yemeni women's kurash cup": "كأس اليمن للكوراش للسيدات",
    "yemeni women's kurash racing cup": "كأس اليمن لسباق كوراش للسيدات",
    "yemeni women's lacrosse racing cup": "كأس اليمن لسباق لاكروس للسيدات",
    "yemeni women's lawn bowls cup": "كأس اليمن للبولينغ العشبي للسيدات",
    "yemeni women's lawn bowls racing cup": "كأس اليمن لسباق البولينغ العشبي للسيدات",
    "yemeni women's long jump cup": "كأس اليمن للقفز الطويل للسيدات",
    "yemeni women's long jump racing cup": "كأس اليمن لسباق القفز الطويل للسيدات",
    "yemeni women's long-distance running cup": "كأس اليمن لركض المسافات الطويلة للسيدات",
    "yemeni women's long-distance running racing cup": "كأس اليمن لسباق ركض المسافات الطويلة للسيدات",
    "yemeni women's luge cup": "كأس اليمن للزحف الثلجي للسيدات",
    "yemeni women's luge racing cup": "كأس اليمن لسباق الزحف الثلجي للسيدات",
    "yemeni women's marathon running cup": "كأس اليمن لسباق الماراثون للسيدات",
    "yemeni women's martial arts cup": "كأس اليمن للفنون القتالية للسيدات",
    "yemeni women's martial arts racing cup": "كأس اليمن لسباق الفنون القتالية للسيدات",
    "yemeni women's middle-distance running cup": "كأس اليمن لركض المسافات المتوسطة للسيدات",
    "yemeni women's middle-distance running racing cup": "كأس اليمن لسباق ركض المسافات المتوسطة للسيدات",
    "yemeni women's mixed martial arts cup": "كأس اليمن لفنون القتال المختلطة للسيدات",
    "yemeni women's mixed martial arts racing cup": "كأس اليمن لسباق فنون القتال المختلطة للسيدات",
    "yemeni women's modern pentathlon cup": "كأس اليمن للخماسي الحديث للسيدات",
    "yemeni women's modern pentathlon racing cup": "كأس اليمن لسباق الخماسي الحديث للسيدات",
    "yemeni women's motocross cup": "كأس اليمن للموتو كروس للسيدات",
    "yemeni women's motocross racing cup": "كأس اليمن لسباق موتو كروس للسيدات",
    "yemeni women's motor cup": "كأس اليمن للمحركات للسيدات",
    "yemeni women's motor racing cup": "كأس اليمن لسباق المحركات للسيدات",
    "yemeni women's motorboat cup": "كأس اليمن للزوارق النارية للسيدات",
    "yemeni women's motorboat racing cup": "كأس اليمن لسباق الزوارق النارية للسيدات",
    "yemeni women's motorcycle cup": "كأس اليمن للدراجات النارية للسيدات",
    "yemeni women's motorcycle racing cup": "كأس اليمن لسباق الدراجات النارية للسيدات",
    "yemeni women's motorsport cup": "كأس اليمن لرياضة المحركات للسيدات",
    "yemeni women's motorsport racing cup": "كأس اليمن لسباق رياضة المحركات للسيدات",
    "yemeni women's motorsports cup": "كأس اليمن لرياضة المحركات للسيدات",
    "yemeni women's motorsports racing cup": "كأس اليمن لسباق رياضة المحركات للسيدات",
    "yemeni women's mountain bike cup": "كأس اليمن لسباق الدراجات الجبلية للسيدات",
    "yemeni women's mountain bike racing cup": "كأس اليمن لسباق الدراجات الجبلية للسيدات",
    "yemeni women's muay thai cup": "كأس اليمن للموياي تاي للسيدات",
    "yemeni women's muay thai racing cup": "كأس اليمن لسباق موياي تاي للسيدات",
    "yemeni women's netball cup": "كأس اليمن لكرة الشبكة للسيدات",
    "yemeni women's netball racing cup": "كأس اليمن لسباق كرة الشبكة للسيدات",
    "yemeni women's nordic combined cup": "كأس اليمن للتزلج النوردي المزدوج للسيدات",
    "yemeni women's nordic combined racing cup": "كأس اليمن لسباق التزلج النوردي المزدوج للسيدات",
    "yemeni women's orienteering cup": "كأس اليمن لسباق الموجه للسيدات",
    "yemeni women's pair skating cup": "كأس اليمن للتزلج الفني على الجليد للسيدات",
    "yemeni women's pair skating racing cup": "كأس اليمن لسباق التزلج الفني على الجليد للسيدات",
    "yemeni women's pencak silat cup": "كأس اليمن للبنكات سيلات للسيدات",
    "yemeni women's pencak silat racing cup": "كأس اليمن لسباق بنكات سيلات للسيدات",
    "yemeni women's pentathlon cup": "كأس اليمن للخماسي للسيدات",
    "yemeni women's pentathlon racing cup": "كأس اليمن لسباق الخماسي للسيدات",
    "yemeni women's pesäpallo cup": "كأس اليمن للبيسبالو للسيدات",
    "yemeni women's pesäpallo racing cup": "كأس اليمن لسباق بيسبالو للسيدات",
    "yemeni women's poker cup": "كأس اليمن للبوكر للسيدات",
    "yemeni women's poker racing cup": "كأس اليمن لسباق البوكر للسيدات",
    "yemeni women's pole vault cup": "كأس اليمن للقفز بالزانة للسيدات",
    "yemeni women's pole vault racing cup": "كأس اليمن لسباق القفز بالزانة للسيدات",
    "yemeni women's polo cup": "كأس اليمن للبولو للسيدات",
    "yemeni women's polo racing cup": "كأس اليمن لسباق البولو للسيدات",
    "yemeni women's powerlifting cup": "كأس اليمن لرياضة القوة للسيدات",
    "yemeni women's powerlifting racing cup": "كأس اليمن لسباق رياضة القوة للسيدات",
    "yemeni women's professional wrestling cup": "كأس اليمن لمصارعة المحترفين للسيدات",
    "yemeni women's professional wrestling racing cup": "كأس اليمن لسباق مصارعة المحترفين للسيدات",
    "yemeni women's racewalking cup": "كأس اليمن لسباق الجري للسيدات",
    "yemeni women's racingxx cup": "كأس اليمن لسباق السيارات للسيدات",
    "yemeni women's racquetball cup": "كأس اليمن لكرة الراح للسيدات",
    "yemeni women's racquetball racing cup": "كأس اليمن لسباق كرة الراح للسيدات",
    "yemeni women's racquets cup": "كأس اليمن للعبة الراح للسيدات",
    "yemeni women's racquets racing cup": "كأس اليمن لسباق لعبة الراح للسيدات",
    "yemeni women's rally cup": "كأس اليمن للرالي للسيدات",
    "yemeni women's rally racing cup": "كأس اليمن لسباق الرالي للسيدات",
    "yemeni women's rally raid cup": "كأس اليمن للرالي رايد للسيدات",
    "yemeni women's rally raid racing cup": "كأس اليمن لسباق الرالي رايد للسيدات",
    "yemeni women's rallying cup": "كأس اليمن للراليات للسيدات",
    "yemeni women's rallying racing cup": "كأس اليمن لسباق الراليات للسيدات",
    "yemeni women's relay race cup": "كأس اليمن لسباق التتابع للسيدات",
    "yemeni women's rhythmic gymnastics cup": "كأس اليمن للجمباز الإيقاعي للسيدات",
    "yemeni women's rhythmic gymnastics racing cup": "كأس اليمن لسباق الجمباز الإيقاعي للسيدات",
    "yemeni women's rifle shooting cup": "كأس اليمن لرماية البندقية للسيدات",
    "yemeni women's rifle shooting racing cup": "كأس اليمن لسباق رماية البندقية للسيدات",
    "yemeni women's road bicycle racing cup": "كأس اليمن لسباق الدراجات على الطريق للسيدات",
    "yemeni women's road cycling cup": "كأس اليمن لسباق الدراجات على الطريق للسيدات",
    "yemeni women's road race cup": "كأس اليمن لسباق الدراجات على الطريق للسيدات",
    "yemeni women's roller hockey (quad) cup": "كأس اليمن لهوكي الدحرجة للسيدات",
    "yemeni women's roller hockey (quad) racing cup": "كأس اليمن لسباق هوكي الدحرجة للسيدات",
    "yemeni women's roller hockey cup": "كأس اليمن لهوكي الدحرجة للسيدات",
    "yemeni women's roller hockey racing cup": "كأس اليمن لسباق هوكي الدحرجة للسيدات",
    "yemeni women's roller skating cup": "كأس اليمن للتزلج بالعجلات للسيدات",
    "yemeni women's roller skating racing cup": "كأس اليمن لسباق التزلج بالعجلات للسيدات",
    "yemeni women's rowing cup": "كأس اليمن للتجديف للسيدات",
    "yemeni women's rowing racing cup": "كأس اليمن لسباق التجديف للسيدات",
    "yemeni women's rugby cup": "كأس اليمن للرجبي للسيدات",
    "yemeni women's rugby football cup": "كأس اليمن لكرة قدم الرجبي للسيدات",
    "yemeni women's rugby football racing cup": "كأس اليمن لسباق كرة قدم الرجبي للسيدات",
    "yemeni women's rugby league cup": "كأس اليمن لدوري الرجبي للسيدات",
    "yemeni women's rugby league racing cup": "كأس اليمن لسباق دوري الرجبي للسيدات",
    "yemeni women's rugby racing cup": "كأس اليمن لسباق الرجبي للسيدات",
    "yemeni women's rugby sevens cup": "كأس اليمن لسباعيات الرجبي للسيدات",
    "yemeni women's rugby sevens racing cup": "كأس اليمن لسباق سباعيات الرجبي للسيدات",
    "yemeni women's rugby union cup": "كأس اليمن لاتحاد الرجبي للسيدات",
    "yemeni women's rugby union racing cup": "كأس اليمن لسباق اتحاد الرجبي للسيدات",
    "yemeni women's rugbyunion cup": "كأس اليمن لاتحاد الرجبي للسيدات",
    "yemeni women's rugbyunion racing cup": "كأس اليمن لسباق اتحاد الرجبي للسيدات",
    "yemeni women's running cup": "كأس اليمن للركض للسيدات",
    "yemeni women's running racing cup": "كأس اليمن لسباق الركض للسيدات",
    "yemeni women's sailing (sport) cup": "كأس اليمن لرياضة الإبحار للسيدات",
    "yemeni women's sailing (sport) racing cup": "كأس اليمن لسباق رياضة الإبحار للسيدات",
    "yemeni women's sailing cup": "كأس اليمن للإبحار للسيدات",
    "yemeni women's sailing racing cup": "كأس اليمن لسباق الإبحار للسيدات",
    "yemeni women's sambo cup": "كأس اليمن للسامبو للسيدات",
    "yemeni women's sambo racing cup": "كأس اليمن لسباق سامبو للسيدات",
    "yemeni women's sepak takraw cup": "كأس اليمن للسيباك تاكرو للسيدات",
    "yemeni women's sepak takraw racing cup": "كأس اليمن لسباق سيباك تاكرو للسيدات",
    "yemeni women's shooting cup": "كأس اليمن للرماية للسيدات",
    "yemeni women's shooting racing cup": "كأس اليمن لسباق الرماية للسيدات",
    "yemeni women's shooting sport cup": "كأس اليمن للرماية للسيدات",
    "yemeni women's shooting sport racing cup": "كأس اليمن لسباق الرماية للسيدات",
    "yemeni women's shooting sports cup": "كأس اليمن للرماية للسيدات",
    "yemeni women's shooting sports racing cup": "كأس اليمن لسباق الرماية للسيدات",
    "yemeni women's short track speed skating cup": "كأس اليمن للتزلج على مسار قصير للسيدات",
    "yemeni women's short track speed skating racing cup": "كأس اليمن لسباق التزلج على مسار قصير للسيدات",
    "yemeni women's shot put cup": "كأس اليمن لدفع الثقل للسيدات",
    "yemeni women's shot put racing cup": "كأس اليمن لسباق دفع الثقل للسيدات",
    "yemeni women's show jumping cup": "كأس اليمن لقفز الحواجز للسيدات",
    "yemeni women's show jumping racing cup": "كأس اليمن لسباق قفز الحواجز للسيدات",
    "yemeni women's silat cup": "كأس اليمن للسيلات للسيدات",
    "yemeni women's silat racing cup": "كأس اليمن لسباق سيلات للسيدات",
    "yemeni women's single skating cup": "كأس اليمن للتزلج الفردي على الجليد للسيدات",
    "yemeni women's single skating racing cup": "كأس اليمن لسباق التزلج الفردي على الجليد للسيدات",
    "yemeni women's skateboarding cup": "كأس اليمن للتزلج على اللوح للسيدات",
    "yemeni women's skateboarding racing cup": "كأس اليمن لسباق التزلج على اللوح للسيدات",
    "yemeni women's skating cup": "كأس اليمن للتزلج للسيدات",
    "yemeni women's skating racing cup": "كأس اليمن لسباق التزلج للسيدات",
    "yemeni women's skeleton cup": "كأس اليمن للزلاجات الصدرية للسيدات",
    "yemeni women's skeleton racing cup": "كأس اليمن لسباق الزلاجات الصدرية للسيدات",
    "yemeni women's ski flying cup": "كأس اليمن لتزلج طائر للسيدات",
    "yemeni women's ski flying racing cup": "كأس اليمن لسباق التزلج الطائر للسيدات",
    "yemeni women's ski jumping cup": "كأس اليمن للقفز التزلجي للسيدات",
    "yemeni women's ski jumping racing cup": "كأس اليمن لسباق القفز التزلجي للسيدات",
    "yemeni women's ski-orienteering cup": "كأس اليمن لسباق التزلج الموجه للسيدات",
    "yemeni women's skiing cup": "كأس اليمن للتزلج للسيدات",
    "yemeni women's skiing racing cup": "كأس اليمن لسباق التزلج للسيدات",
    "yemeni women's sledge hockey cup": "كأس اليمن لهوكي المزلجة للسيدات",
    "yemeni women's sledge hockey racing cup": "كأس اليمن لسباق هوكي المزلجة للسيدات",
    "yemeni women's snooker cup": "كأس اليمن للسنوكر للسيدات",
    "yemeni women's snooker racing cup": "كأس اليمن لسباق السنوكر للسيدات",
    "yemeni women's snowboarding cup": "كأس اليمن للتزلج على الثلوج للسيدات",
    "yemeni women's snowboarding racing cup": "كأس اليمن لسباق التزلج على الثلوج للسيدات",
    "yemeni women's soccer cup": "كأس اليمن لكرة القدم للسيدات",
    "yemeni women's soccer racing cup": "كأس اليمن لسباق كرة القدم للسيدات",
    "yemeni women's soft tennis cup": "كأس اليمن لكرة المضرب اللينة للسيدات",
    "yemeni women's soft tennis racing cup": "كأس اليمن لسباق كرة المضرب اللينة للسيدات",
    "yemeni women's softball cup": "كأس اليمن للكرة اللينة للسيدات",
    "yemeni women's softball racing cup": "كأس اليمن لسباق الكرة اللينة للسيدات",
    "yemeni women's speed skating cup": "كأس اليمن لتزلج السريع للسيدات",
    "yemeni women's speed skating racing cup": "كأس اليمن لسباق التزلج السريع للسيدات",
    "yemeni women's speed skiing cup": "كأس اليمن للتزلج السريع للسيدات",
    "yemeni women's speed skiing racing cup": "كأس اليمن لسباق التزلج السريع للسيدات",
    "yemeni women's sport climbing cup": "كأس اليمن للتسلق للسيدات",
    "yemeni women's sport climbing racing cup": "كأس اليمن لسباق التسلق للسيدات",
    "yemeni women's sprinting cup": "كأس اليمن للجري السريع للسيدات",
    "yemeni women's sprinting racing cup": "كأس اليمن لسباق الجري السريع للسيدات",
    "yemeni women's squash cup": "كأس اليمن للاسكواش للسيدات",
    "yemeni women's squash racing cup": "كأس اليمن لسباق اسكواش للسيدات",
    "yemeni women's submission wrestling cup": "كأس اليمن لمصارعة الخضوع للسيدات",
    "yemeni women's submission wrestling racing cup": "كأس اليمن لسباق مصارعة الخضوع للسيدات",
    "yemeni women's sumo cup": "كأس اليمن للسومو للسيدات",
    "yemeni women's sumo racing cup": "كأس اليمن لسباق السومو للسيدات",
    "yemeni women's surfing cup": "كأس اليمن للركمجة للسيدات",
    "yemeni women's surfing racing cup": "كأس اليمن لسباق الركمجة للسيدات",
    "yemeni women's swimming cup": "كأس اليمن للسباحة للسيدات",
    "yemeni women's swimming racing cup": "كأس اليمن لسباق السباحة للسيدات",
    "yemeni women's synchronised swimming cup": "كأس اليمن للسباحة المتزامنة للسيدات",
    "yemeni women's synchronised swimming racing cup": "كأس اليمن لسباق السباحة المتزامنة للسيدات",
    "yemeni women's synchronized swimming cup": "كأس اليمن للسباحة المتزامنة للسيدات",
    "yemeni women's synchronized swimming racing cup": "كأس اليمن لسباق السباحة المتزامنة للسيدات",
    "yemeni women's table tennis cup": "كأس اليمن لكرة الطاولة للسيدات",
    "yemeni women's table tennis racing cup": "كأس اليمن لسباق كرة الطاولة للسيدات",
    "yemeni women's taekwondo cup": "كأس اليمن للتايكوندو للسيدات",
    "yemeni women's taekwondo racing cup": "كأس اليمن لسباق التايكوندو للسيدات",
    "yemeni women's tennis cup": "كأس اليمن لكرة المضرب للسيدات",
    "yemeni women's tennis racing cup": "كأس اليمن لسباق كرة المضرب للسيدات",
    "yemeni women's time trial cup": "كأس اليمن لسباق الدراجات ضد الساعة للسيدات",
    "yemeni women's track and field cup": "كأس اليمن لسباقات المضمار والميدان للسيدات",
    "yemeni women's track cycling cup": "كأس اليمن لسباق الدراجات على المضمار للسيدات",
    "yemeni women's track-and-field athletics cup": "كأس اليمن لألعاب قوى المضمار والميدان للسيدات",
    "yemeni women's track-and-field athletics racing cup": "كأس اليمن لسباق ألعاب قوى المضمار والميدان للسيدات",
    "yemeni women's trampolining cup": "كأس اليمن لجمباز القفز للسيدات",
    "yemeni women's trampolining racing cup": "كأس اليمن لسباق جمباز القفز للسيدات",
    "yemeni women's triathlon cup": "كأس اليمن للسباق الثلاثي للسيدات",
    "yemeni women's triple jump cup": "كأس اليمن للقفز الثلاثي للسيدات",
    "yemeni women's triple jump racing cup": "كأس اليمن لسباق القفز الثلاثي للسيدات",
    "yemeni women's uiiu 22 formula e season racing cup": "كأس اليمن لسباق موسم فورمولا إي للسيدات",
    "yemeni women's underwater hockey cup": "كأس اليمن للهوكي تحت الماء للسيدات",
    "yemeni women's underwater hockey racing cup": "كأس اليمن لسباق هوكي تحت الماء للسيدات",
    "yemeni women's volleyball cup": "كأس اليمن لكرة الطائرة للسيدات",
    "yemeni women's volleyball racing cup": "كأس اليمن لسباق كرة الطائرة للسيدات",
    "yemeni women's water polo cup": "كأس اليمن لكرة الماء للسيدات",
    "yemeni women's water polo racing cup": "كأس اليمن لسباق كرة الماء للسيدات",
    "yemeni women's water skiing cup": "كأس اليمن لتزلج على الماء للسيدات",
    "yemeni women's water skiing racing cup": "كأس اليمن لسباق التزلج على الماء للسيدات",
    "yemeni women's waterskiing cup": "كأس اليمن للتزلج على الماء للسيدات",
    "yemeni women's waterskiing racing cup": "كأس اليمن لسباق التزلج على الماء للسيدات",
    "yemeni women's weightlifting cup": "كأس اليمن لرفع الأثقال للسيدات",
    "yemeni women's weightlifting racing cup": "كأس اليمن لسباق رفع الأثقال للسيدات",
    "yemeni women's wheelchair basketball cup": "كأس اليمن لكرة السلة على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair beach handball cup": "كأس اليمن لكرة اليد الشاطئية على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair curling cup": "كأس اليمن للكيرلنغ على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair fencing cup": "كأس اليمن لمبارزة سيف الشيش على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair handball cup": "كأس اليمن لكرة اليد على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair rugby cup": "كأس اليمن للرجبي على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair rugby league cup": "كأس اليمن لدوري الرجبي على الكراسي المتحركة للسيدات",
    "yemeni women's wheelchair tennis cup": "كأس اليمن لكرة المضرب على الكراسي المتحركة للسيدات",
    "yemeni women's windsurfing cup": "كأس اليمن لركوب القوارب الشراعية للسيدات",
    "yemeni women's windsurfing racing cup": "كأس اليمن لسباق ركوب القوارب الشراعية للسيدات",
    "yemeni women's wrestling cup": "كأس اليمن للمصارعة للسيدات",
    "yemeni women's wrestling racing cup": "كأس اليمن لسباق المصارعة للسيدات",
    "yemeni women's wushu cup": "كأس اليمن للووشو للسيدات",
    "yemeni women's wushu racing cup": "كأس اليمن لسباق ووشو للسيدات",
    "yemeni women's xiangqi cup": "كأس اليمن للشطرنج الصيني للسيدات",
    "yemeni women's xiangqi racing cup": "كأس اليمن لسباق الشطرنج الصيني للسيدات",
    "yemeni women's yacht racing cup": "كأس اليمن لسباقات اليخوت للسيدات",
    "yemeni wrestling cup": "كأس اليمن للمصارعة",
    "yemeni wrestling racing cup": "كأس اليمن لسباق المصارعة",
    "yemeni wushu cup": "كأس اليمن للووشو",
    "yemeni wushu racing cup": "كأس اليمن لسباق ووشو",
    "yemeni xiangqi cup": "كأس اليمن للشطرنج الصيني",
    "yemeni xiangqi racing cup": "كأس اليمن لسباق الشطرنج الصيني",
    "yemeni yacht racing cup": "كأس اليمن لسباقات اليخوت",
}


wheelchair_data_0 = {
    "american men wheelchair racers": "متسابقو كراسي متحركة أمريكيون",
    "australian men wheelchair racers": "متسابقو كراسي متحركة أستراليون",
    "austrian men wheelchair racers": "متسابقو كراسي متحركة نمساويون",
    "belgian men wheelchair racers": "متسابقو كراسي متحركة بلجيكيون",
    "british men wheelchair racers": "متسابقو كراسي متحركة بريطانيون",
    "brazilian men wheelchair racers": "متسابقو كراسي متحركة برازيليون",
    "canadian men wheelchair racers": "متسابقو كراسي متحركة كنديون",
    "english men wheelchair racers": "متسابقو كراسي متحركة إنجليز",
    "finnish men wheelchair racers": "متسابقو كراسي متحركة فنلنديون",
    "dutch men wheelchair racers": "متسابقو كراسي متحركة هولنديون",
    "chinese men wheelchair racers": "متسابقو كراسي متحركة صينيون",
    "french men wheelchair racers": "متسابقو كراسي متحركة فرنسيون",
    "gabonese men wheelchair racers": "متسابقو كراسي متحركة غابونيون",
    "german men wheelchair racers": "متسابقو كراسي متحركة ألمان",
    "irish men wheelchair racers": "متسابقو كراسي متحركة أيرلنديون",
    "israeli men wheelchair racers": "متسابقو كراسي متحركة إسرائيليون",
    "japanese men wheelchair racers": "متسابقو كراسي متحركة يابانيون",
    "mexican men wheelchair racers": "متسابقو كراسي متحركة مكسيكيون",
    "swiss men wheelchair racers": "متسابقو كراسي متحركة سويسريون",
    "welsh men wheelchair racers": "متسابقو كراسي متحركة ويلزيون",
}

data_1 = {
    "american men wheelchair racers": "متسابقو كراسي متحركة أمريكيون",
    "yemeni men basketball players": "لاعبو كرة سلة يمنيون",
    "yemeni men's basketball players": "لاعبو كرة سلة يمنيون",
    "chinese outdoor boxing clubs": "أندية بوكسينغ صينية في الهواء الطلق",
    "chinese outdoor boxing": "بوكسينغ صينية في الهواء الطلق",
    "chinese women's boxing": "بوكسينغ صينية للسيدات",
    "chinese indoor boxing": "بوكسينغ صينية داخل الصالات",
}

data_3 = {
    "chinese men's boxing championship": "بطولة الصين للبوكسينغ للرجال",
    "chinese amateur boxing championship": "بطولة الصين للبوكسينغ للهواة",
    "chinese amateur boxing championships": "بطولة الصين للبوكسينغ للهواة",
    "chinese championships boxing": "بطولة الصين للبوكسينغ",
    "chinese men's boxing championships": "بطولة الصين للبوكسينغ للرجال",
    "chinese men's boxing national team": "منتخب الصين للبوكسينغ للرجال",
    "chinese men's u23 national boxing team": "منتخب الصين للبوكسينغ تحت 23 سنة للرجال",
    "chinese boxing championship": "بطولة الصين للبوكسينغ",
    "chinese boxing championships": "بطولة الصين للبوكسينغ",
    "chinese boxing indoor championship": "بطولة الصين للبوكسينغ داخل الصالات",
    "chinese boxing indoor championships": "بطولة الصين للبوكسينغ داخل الصالات",
    "chinese boxing junior championships": "بطولة الصين للبوكسينغ للناشئين",
    "chinese boxing national team": "منتخب الصين للبوكسينغ",
    "chinese boxing u-13 championships": "بطولة الصين للبوكسينغ تحت 13 سنة",
    "chinese boxing u-14 championships": "بطولة الصين للبوكسينغ تحت 14 سنة",
    "chinese boxing u-15 championships": "بطولة الصين للبوكسينغ تحت 15 سنة",
    "chinese boxing u-16 championships": "بطولة الصين للبوكسينغ تحت 16 سنة",
    "chinese boxing u-17 championships": "بطولة الصين للبوكسينغ تحت 17 سنة",
    "chinese boxing u-18 championships": "بطولة الصين للبوكسينغ تحت 18 سنة",
    "chinese boxing u-19 championships": "بطولة الصين للبوكسينغ تحت 19 سنة",
    "chinese boxing u-20 championships": "بطولة الصين للبوكسينغ تحت 20 سنة",
    "chinese boxing u-21 championships": "بطولة الصين للبوكسينغ تحت 21 سنة",
    "chinese boxing u-23 championships": "بطولة الصين للبوكسينغ تحت 23 سنة",
    "chinese boxing u-24 championships": "بطولة الصين للبوكسينغ تحت 24 سنة",
    "chinese boxing u13 championships": "بطولة الصين للبوكسينغ تحت 13 سنة",
    "chinese boxing u14 championships": "بطولة الصين للبوكسينغ تحت 14 سنة",
    "chinese boxing u15 championships": "بطولة الصين للبوكسينغ تحت 15 سنة",
    "chinese boxing u16 championships": "بطولة الصين للبوكسينغ تحت 16 سنة",
    "chinese boxing u17 championships": "بطولة الصين للبوكسينغ تحت 17 سنة",
    "chinese boxing u18 championships": "بطولة الصين للبوكسينغ تحت 18 سنة",
    "chinese boxing u19 championships": "بطولة الصين للبوكسينغ تحت 19 سنة",
    "chinese boxing u20 championships": "بطولة الصين للبوكسينغ تحت 20 سنة",
    "chinese boxing u21 championships": "بطولة الصين للبوكسينغ تحت 21 سنة",
    "chinese boxing u23 championships": "بطولة الصين للبوكسينغ تحت 23 سنة",
    "chinese boxing u24 championships": "بطولة الصين للبوكسينغ تحت 24 سنة",
    "chinese open boxing": "الصين المفتوحة للبوكسينغ",
    "chinese outdoor boxing championship": "بطولة الصين للبوكسينغ في الهواء الطلق",
    "chinese outdoor boxing championships": "بطولة الصين للبوكسينغ في الهواء الطلق",
    "chinese women's boxing championship": "بطولة الصين للبوكسينغ للسيدات",
    "chinese women's boxing championships": "بطولة الصين للبوكسينغ للسيدات",
    "chinese youth boxing championship": "بطولة الصين للبوكسينغ للشباب",
    "chinese youth boxing championships": "بطولة الصين للبوكسينغ للشباب",
}


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_sport_lab_oioioi_load_1(category: str, expected: str) -> None:
    label2 = resolve_nats_sport_multi_v2(category)
    assert label2 == expected


@pytest.mark.parametrize("category, expected", data_3.items(), ids=data_3.keys())
@pytest.mark.fast
def test_sport_lab_oioioi_load_3(category: str, expected: str) -> None:
    label2 = resolve_nats_sport_multi_v2(category)
    assert label2 == expected


to_test = [
    ("test_sport_lab_oioioi_load_1", data_1, resolve_nats_sport_multi_v2),
    ("test_sport_lab_oioioi_load_3", data_3, resolve_nats_sport_multi_v2),
    ("oioioi_wheelchair_data_0", wheelchair_data_0, resolve_nats_sport_multi_v2),
    ("test_en_is_nat_ar_is_P17", en_is_nat_ar_is_P17_data, resolve_nats_sport_multi_v2),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)

    # add_result = {x: v for x, v in data.items() if x in diff_result and "" == diff_result.get(x)}
    # dump_diff(add_result, f"{name}_add")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
