from ..helps import len_print

companies_data = {
    "aviation accidents": "حوادث طيران",
    "financial services": "خدمات مالية",
    "aviation accidents-and-incidents": "حوادث طيران",
    "railway accidents": "حوادث سكك حديدية",
    "aviation accidents or incidents": "حوادث طيران",
    "manufacturing companies of": "شركات تصنيع في",
    "railway services": "خدمات سكك حديدية",
    "financial services companies of": "شركات خدمات مالية في",
    "technology companies of": "شركات تقانة في",
    "drink companies of": "شركات مشروبات في",
    "energy companies of": "شركات طاقة في",
    "defunct airlines": "طيران سابقة",
    "publishing companies of": "شركات نشر في",
    "service companies of": "شركات خدمات في",
    "defunct mass media": "وسائل إعلام سابقة",
    "defunct airlines of": "طيران سابقة في",
    "railway accidents-and-incidents": "حوادث سكك حديدية",
    "transport companies of": "شركات نقل في",
    "gas companies of": "شركات غاز في",
    "engineering companies of": "شركات هندسية في",
    "media franchises": "امتيازات إعلامية",
    "food and drink companies of": "شركات أطعمة ومشروبات في",
    "media companies of": "شركات إعلامية في",
    "mass media companies of": "شركات وسائل إعلام في",
    "mass media franchises": "امتيازات وسائل إعلام",
    "electric power companies of": "شركات طاقة كهربائية في",
    "railway companies of": "شركات سكك حديدية في",
    "mining companies of": "شركات تعدين في",
    "architecture firms": "شركات هندسة معمارية",
    "retail companies of": "شركات تجارة التجزئة في",
    "hospitality industry": "صناعة ضيافة",
    "music organizations": "منظمات الموسيقى",
    "defunct manufacturing": "تصنيع سابقة",
    "defunct-manufacturing-companies": "شركات تصنيع سابقة",
    "insurance companies of": "شركات تأمين في",
    "shipping companies of": "شركات نقل بحري في",
    "transport organizations": "منظمات نقل",
    "video game companies of": "شركات ألعاب فيديو في",
    "airliner accidents": "حوادث طائرات",
    "airliner accidents-and-incidents": "حوادث طائرات",
    "defunct railway": "سكك حديدية سابقة",
    "software companies of": "شركات برمجيات في",
    "airlines accidents": "حوادث طيران",
    "airlines accidents-and-incidents": "حوادث طيران",
    "information technology companies of": "شركات تقانة المعلومات في",
    "railway museums": "متاحف سكك حديدية",
    "agriculture companies of": "شركات زراعة في",
    "defunct banks": "بنوك سابقة",
    "pharmaceutical companies of": "شركات أدوية في",
    "metal companies of": "شركات معادن في",
    "defunct department stores": "متاجر متعددة الأقسام سابقة",
    "shipbuilding companies of": "شركات سفن في",
    "holding companies of": "شركات قابضة في",
    "defunct banks of": "بنوك سابقة في",
    "transport museums": "متاحف نقل",
    "music industry": "صناعة الموسيقى",
    "construction and civil engineering companies of": "شركات بناء وهندسة مدنية في",
    "privately held companies of": "شركات خاصة في",
    "entertainment companies of": "شركات ترفيه في",
    "video game industry": "صناعة ألعاب فيديو",
    "video game franchises": "امتيازات ألعاب فيديو",
    "defence companies of": "شركات دفاعية في",
    "real estate companies of": "شركات عقارية في",
    "defunct transport": "نقل سابقة",
    "clothing companies of": "شركات ملابس في",
    "defunct hotels": "فنادق سابقة",
    "chemical companies of": "شركات كيميائية في",
    "automotive industry": "صناعة سيارات",
    "music museums": "متاحف الموسيقى",
    "gambling companies of": "شركات مقامرة في",
    "television companies of": "شركات تلفاز في",
    "hospitality companies of": "شركات ضيافة في",
    "electronics companies of": "شركات إلكترونيات في",
    "investment companies of": "شركات استثمارية في",
    "automotive companies of": "شركات سيارات في",
    "cement companies of": "شركات أسمنت في",
    "defunct television": "تلفاز سابقة",
    "logistics companies of": "شركات لوجستية في",
    "oil companies of": "شركات زيت الوقود في",
    "architecture firms of": "شركات هندسة معمارية في",
    "publishing company": "شركات نشر",
    "sugar industry": "صناعة السكر",
    "coal companies of": "شركات فحم في",
    "defunct-transport-companies": "شركات نقل سابقة",
    "defunct motor vehicle manufacturers": "مصانع سيارات سابقة",
    "mining museums": "متاحف تعدين",
    "railway company": "شركات سكك حديدية",
    "defunct motor vehicle manufacturers of": "مصانع سيارات سابقة في",
    "health care companies of": "شركات رعاية صحية في",
    "tobacco companies of": "شركات التبغ في",
    "travel and holiday companies of": "شركات السفر والعطلات في",
    "food industry": "صناعة أطعمة",
    "aluminium companies of": "شركات ألومنيوم في",
    "aviation organizations": "منظمات طيران",
    "biotechnology companies of": "شركات تقانة حيوية في",
    "computer companies of": "شركات حوسبة في",
    "online music": "الموسيقى عبر الإنترنت",
    "real estate industry": "صناعة عقارية",
    "defunct energy": "طاقة سابقة",
    "defunct-energy-companies": "شركات طاقة سابقة",
    "pulp and paper companies of": "شركات اللب والورق في",
    "entertainment company": "شركات ترفيه",
    "defunct video game": "ألعاب فيديو سابقة",
    "mass media company": "شركات وسائل إعلام",
    "media company": "شركات إعلامية",
    "jewellery companies of": "شركات مجوهرات في",
    "cosmetics companies of": "شركات مستحضرات التجميل في",
    "technology museums": "متاحف تقانة",
    "education companies of": "شركات تعليم في",
    "defunct-video game-companies": "شركات ألعاب فيديو سابقة",
    "agriculture museums": "متاحف زراعة",
    "natural gas companies of": "شركات غاز طبيعي في",
    "health care industry": "صناعة رعاية صحية",
    "defunct-railway-companies": "شركات سكك حديدية سابقة",
    "online gambling": "مقامرة عبر الإنترنت",
    "chemical industry": "صناعة كيميائية",
    "defunct food": "أطعمة سابقة",
    "agriculture organization": "منظمات زراعة",
    "water companies of": "شركات مياه في",
    "technology organizations": "منظمات تقانة",
    "design companies of": "شركات تصميم في",
    "security companies of": "شركات أمن في",
    "entertainment industry": "صناعة ترفيه",
    "television organizations": "منظمات تلفاز",
    "glassmaking companies of": "شركات الزجاج في",
    "television company": "شركات تلفاز",
    "defunct architecture": "هندسة معمارية سابقة",
    "defunct food and drink": "أطعمة ومشروبات سابقة",
    "eyewear companies of": "شركات نظارات في",
    "renewable energy companies of": "شركات طاقة متجددة في",
    "technology company": "شركات تقانة",
    "energy industry": "صناعة طاقة",
    "pharmaceutical industry": "صناعة أدوية",
    "defunct-food and drink-companies": "شركات أطعمة ومشروبات سابقة",
    "defunct computer": "حوسبة سابقة",
    "music companies of": "شركات الموسيقى في",
    "online financial": "مالية عبر الإنترنت",
    "online financial services": "خدمات مالية عبر الإنترنت",
    "oil industry": "صناعة زيت الوقود",
    "media organizations": "منظمات إعلامية",
    "construction industry": "صناعة بناء",
    "defunct technology": "تقانة سابقة",
    "defunct software": "برمجيات سابقة",
    "defunct-software-companies": "شركات برمجيات سابقة",
    "defunct-technology-companies": "شركات تقانة سابقة",
    "television franchises": "امتيازات تلفاز",
    "manufacturing company": "شركات تصنيع",
    "defence agencies": "وكالات دفاعية",
    "information technology organizations": "منظمات تقانة المعلومات",
    "waste management companies of": "شركات إدارة المخلفات في",
    "marketing companies of": "شركات تسويق في",
    "shipping company": "شركات نقل بحري",
    "defunct-computer-companies": "شركات حوسبة سابقة",
    "food museums": "متاحف أطعمة",
    "education organizations": "منظمات تعليم",
    "engineering organizations": "منظمات هندسية",
    "submarine accidents": "حوادث غواصات",
    "pulp and paper industry": "صناعة اللب والورق",
    "defunct financial": "مالية سابقة",
    "defunct retail": "تجارة التجزئة سابقة",
    "defunct-retail-companies": "شركات تجارة التجزئة سابقة",
    "media museums": "متاحف إعلامية",
    "sugar companies of": "شركات السكر في",
    "tobacco industry": "صناعة التبغ",
    "insurance industry": "صناعة تأمين",
    "defunct shipping": "نقل بحري سابقة",
    "defunct-shipping-companies": "شركات نقل بحري سابقة",
    "management consulting firms": "شركات استشارات إدارية",
    "drink industry": "صناعة مشروبات",
    "airline industry": "صناعة خطوط جوية",
    "electronics industry": "صناعة إلكترونيات",
    "gas industry": "صناعة غاز",
    "security software": "برمجيات أمن",
    "defunct financial services": "خدمات مالية سابقة",
    "defunct-financial services-companies": "شركات خدمات مالية سابقة",
    "defunct shipbuilding": "سفن سابقة",
    "defunct-shipbuilding-companies": "شركات سفن سابقة",
    "printing companies of": "شركات طباعة في",
    "engineering software": "برمجيات هندسية",
    "aviation organization": "منظمات طيران",
    "building materials companies of": "شركات مواد بناء في",
    "car rental companies of": "شركات تأجير السيارات في",
    "defunct oil": "زيت الوقود سابقة",
    "electrical engineering companies of": "شركات هندسة كهربائية في",
    "service organizations": "منظمات خدمات",
    "music publishing companies of": "شركات نشر موسيقى في",
    "nuclear bunkers": "مخابئ نووية",
    "postal services": "خدمات بريد",
    "media industry": "صناعة إعلامية",
    "natural gas industry": "صناعة غاز طبيعي",
    "defunct electric power": "طاقة كهربائية سابقة",
    "defunct-electric power-companies": "شركات طاقة كهربائية سابقة",
    "defunct-mass media-companies": "شركات وسائل إعلام سابقة",
    "defunct music": "الموسيقى سابقة",
    "distribution companies of": "شركات توزيع في",
    "food companies of": "شركات أطعمة في",
    "printing museums": "متاحف طباعة",
    "defence services": "خدمات دفاعية",
    "cosmetics industry": "صناعة مستحضرات التجميل",
    "retail company": "شركات تجارة التجزئة",
    "transport accidents": "حوادث نقل",
    "condiment companies of": "شركات توابل في",
    "design museums": "متاحف تصميم",
    "rail services": "خدمات سكك حديدية",
    "map companies of": "شركات خرائط في",
    "online clothing": "ملابس عبر الإنترنت",
    "online clothing retailers": "متاجر ملابس بالتجزئة عبر الإنترنت",
    "coal industry": "صناعة فحم",
    "computer industry": "صناعة حوسبة",
    "mass media industry": "صناعة وسائل إعلام",
    "manufacturing industry": "صناعة تصنيع",
    "architecture museums": "متاحف هندسة معمارية",
    "video game company": "شركات ألعاب فيديو",
    "transport accidents-and-incidents": "حوادث نقل",
    "energy organizations": "منظمات طاقة",
    "management consulting firms of": "شركات استشارات إدارية في",
    "design software": "برمجيات تصميم",
    "metal industry": "صناعة معادن",
    "financial company": "شركات مالية",
    "oil company": "شركات زيت الوقود",
    "music software": "برمجيات الموسيقى",
    "defunct department stores of": "متاجر متعددة الأقسام سابقة في",
    "rail industry": "صناعة سكك حديدية",
    "publishing software": "برمجيات نشر",
    "nuclear accidents": "حوادث نووية",
    "financial services company": "شركات خدمات مالية",
    "vehicle manufacturing companies of": "شركات تصنيع مركبات في",
    "online publishing": "نشر عبر الإنترنت",
    "property organization": "منظمات ممتلكات",
    "tobacco company": "شركات التبغ",
    "mass media offices": "مكاتب وسائل إعلام",
    "media offices": "مكاتب إعلامية",
    "entertainment software": "برمجيات ترفيه",
    "entertainment franchises": "امتيازات ترفيه",
    "music company": "شركات الموسيقى",
    "business services companies of": "شركات خدمات أعمال تجارية في",
    "drink company": "شركات مشروبات",
    "pharmaceutical company": "شركات أدوية",
    "health care software": "برمجيات رعاية صحية",
    "trucking industry": "صناعة نقل بالشاحنات",
    "architecture organizations": "منظمات هندسة معمارية",
    "automotive museums": "متاحف سيارات",
    "mining company": "شركات تعدين",
    "manufacturing software": "برمجيات تصنيع",
    "engineering company": "شركات هندسية",
    "defunct engineering": "هندسية سابقة",
    "defunct entertainment": "ترفيه سابقة",
    "defunct mining": "تعدين سابقة",
    "defunct-mining-companies": "شركات تعدين سابقة",
    "defunct publishing": "نشر سابقة",
    "defunct-publishing-companies": "شركات نشر سابقة",
    "energy company": "شركات طاقة",
    "property companies of": "شركات ممتلكات في",
    "shipbuilding company": "شركات سفن",
    "transport company": "شركات نقل",
    "academic organizations": "منظمات أكاديمية",
    "drink museums": "متاحف مشروبات",
    "drink organizations": "منظمات مشروبات",
    "food company": "شركات أطعمة",
    "internet company": "شركات إنترنت",
    "television services": "خدمات تلفاز",
    "nuclear organizations": "منظمات نووية",
    "cement industry": "صناعة أسمنت",
    "software industry": "صناعة برمجيات",
    "computer company": "شركات حوسبة",
    "clothing industry": "صناعة ملابس",
    "computer museums": "متاحف حوسبة",
    "construction company": "شركات بناء",
    "defunct aviation": "طيران سابقة",
    "defunct education": "تعليم سابقة",
    "defunct-engineering-companies": "شركات هندسية سابقة",
    "nuclear accidents-and-incidents": "حوادث نووية",
    "fraternal service organizations": "منظمات خدمات أخوية",
    "storage software": "برمجيات تخزين",
    "horticultural companies of": "شركات بستنة في",
    "horticultural organizations": "منظمات بستنة",
    "insurance company": "شركات تأمين",
    "internet software": "برمجيات إنترنت",
    "jewellery industry": "صناعة مجوهرات",
    "online mass media": "وسائل إعلام عبر الإنترنت",
    "paint and coatings companies of": "شركات رسم وطلاء في",
    "printing software": "برمجيات طباعة",
    "aviation incidents": "حوادث طيران",
    "real estate company": "شركات عقارية",
    "computer software": "برمجيات حوسبة",
    "automotive company": "شركات سيارات",
    "aviation companies of": "شركات طيران في",
    "aviation company": "شركات طيران",
    "holding company": "شركات قابضة",
    "security services": "خدمات أمن",
    "railway facilities": "مرافق سكك حديدية",
    "chemical company": "شركات كيميائية",
    "security organizations": "منظمات أمن",
    "food and drink company": "شركات أطعمة ومشروبات",
    "defence industry": "صناعة دفاعية",
    "defunct airline": "خطوط جوية سابقة",
    "defunct comics": "قصص مصورة سابقة",
    "defunct insurance": "تأمين سابقة",
    "defunct-insurance-companies": "شركات تأمين سابقة",
    "defunct marketing": "تسويق سابقة",
    "defunct-marketing-companies": "شركات تسويق سابقة",
    "defunct-oil-companies": "شركات زيت الوقود سابقة",
    "defunct pharmaceutical": "أدوية سابقة",
    "defunct-pharmaceutical-companies": "شركات أدوية سابقة",
    "defunct water": "مياه سابقة",
    "television software": "برمجيات تلفاز",
    "security organization": "منظمات أمن",
    "education software": "برمجيات تعليم",
    "energy accidents": "حوادث طاقة",
    "energy accidents-and-incidents": "حوادث طاقة",
    "online entertainment": "ترفيه عبر الإنترنت",
    "hotel and leisure companies of": "شركات فنادق وترفيه في",
    "design firms": "شركات تصميم",
    "information technology company": "شركات تقانة المعلومات",
    "information technology industry": "صناعة تقانة المعلومات",
    "technology industry": "صناعة تقانة",
    "renewable energy organizations": "منظمات طاقة متجددة",
    "rail company": "شركات سكك حديدية",
    "mass media museums": "متاحف وسائل إعلام",
    "aviation museums": "متاحف طيران",
    "video game services": "خدمات ألعاب فيديو",
    "nuclear facilities": "مرافق نووية",
    "security agencies": "وكالات أمن",
    "online automotive": "سيارات عبر الإنترنت",
    "transport industry": "صناعة نقل",
    "software company": "شركات برمجيات",
    "veterinary companies of": "شركات بيطرة في",
    "marketing organizations": "منظمات تسويق",
    "airline company": "شركات خطوط جوية",
    "alcohol agencies": "وكالات كحول",
    "alcohol industry": "صناعة كحول",
    "online media": "إعلامية عبر الإنترنت",
    "publishing industry": "صناعة نشر",
    "food and drink organizations": "منظمات أطعمة ومشروبات",
    "wine industry": "صناعة نبيذ",
    "design organizations": "منظمات تصميم",
    "aviation industry": "صناعة طيران",
    "investment company": "شركات استثمارية",
    "property services": "خدمات ممتلكات",
    "coal museums": "متاحف فحم",
    "construction accidents": "حوادث بناء",
    "construction and civil engineering company": "شركات بناء وهندسة مدنية",
    "comics organizations": "منظمات قصص مصورة",
    "defunct agriculture": "زراعة سابقة",
    "defunct-agriculture-companies": "شركات زراعة سابقة",
    "defunct biotechnology": "تقانة حيوية سابقة",
    "defunct-biotechnology-companies": "شركات تقانة حيوية سابقة",
    "defunct cargo airlines": "شحن جوي سابقة",
    "music services": "خدمات الموسيقى",
    "defunct-education-companies": "شركات تعليم سابقة",
    "defunct electronics": "إلكترونيات سابقة",
    "defunct-electronics-companies": "شركات إلكترونيات سابقة",
    "defunct internet": "إنترنت سابقة",
    "defunct natural gas": "غاز طبيعي سابقة",
    "defunct-natural gas-companies": "شركات غاز طبيعي سابقة",
    "defunct privately held": "خاصة سابقة",
    "defunct-privately held-companies": "شركات خاصة سابقة",
    "defunct rail": "سكك حديدية سابقة",
    "defunct real estate": "عقارية سابقة",
    "defunct-real estate-companies": "شركات عقارية سابقة",
    "education museums": "متاحف تعليم",
    "education organization": "منظمات تعليم",
    "technology software": "برمجيات تقانة",
    "marketing software": "برمجيات تسويق",
    "energy agencies": "وكالات طاقة",
    "energy museums": "متاحف طاقة",
    "financial software": "برمجيات مالية",
    "food and drink museums": "متاحف أطعمة ومشروبات",
    "software organizations": "منظمات برمجيات",
    "transport software": "برمجيات نقل",
    "health care company": "شركات رعاية صحية",
    "hotels company": "شركات فنادق",
    "internet services": "خدمات إنترنت",
    "logistics industry": "صناعة لوجستية",
    "software software": "برمجيات برمجيات",
    "transport agencies": "وكالات نقل",
    "mining industry": "صناعة تعدين",
    "education services": "خدمات تعليم",
    "nuclear industry": "صناعة نووية",
    "oil shale companies of": "شركات صخر زيتي في",
    "online food": "أطعمة عبر الإنترنت",
    "online jewellery": "مجوهرات عبر الإنترنت",
    "online real estate": "عقارية عبر الإنترنت",
    "travel agencies": "وكالات سفر",
    "online video game": "ألعاب فيديو عبر الإنترنت",
    "railway accidents or incidents": "حوادث سكك حديدية",
    "real estate services": "خدمات عقارية",
    "service company": "شركات خدمات",
    "submarine museums": "متاحف غواصات",
    "electric power company": "شركات طاقة كهربائية",
    "trucking companies of": "شركات نقل بالشاحنات في",
    "water organizations": "منظمات مياه",
    "airline companies of": "شركات خطوط جوية في",
    "academic disciplines": "تخصصات أكاديمية",
    "aluminium industry": "صناعة ألومنيوم",
    "manga franchises": "امتيازات مانغا",
    "manga museums": "متاحف مانغا",
    "architecture databases": "قواعد بيانات هندسة معمارية",
    "cement company": "شركات أسمنت",
    "automotive organization": "منظمات سيارات",
    "automotive services": "خدمات سيارات",
    "automotive software": "برمجيات سيارات",
    "biotechnology databases": "قواعد بيانات تقانة حيوية",
    "biotechnology organizations": "منظمات تقانة حيوية",
    "manufacturing facilities": "مرافق تصنيع",
    "business services company": "شركات خدمات أعمال تجارية",
    "wine organizations": "منظمات نبيذ",
    "service accidents": "حوادث خدمات",
    "service accidents-and-incidents": "حوادث خدمات",
    "chemical databases": "قواعد بيانات كيميائية",
    "coal company": "شركات فحم",
    "coal organizations": "منظمات فحم",
    "comics company": "شركات قصص مصورة",
    "comics industry": "صناعة قصص مصورة",
    "construction organizations": "منظمات بناء",
    "construction software": "برمجيات بناء",
    "design company": "شركات تصميم",
    "comics franchises": "امتيازات قصص مصورة",
    "technology agencies": "وكالات تقانة",
    "defunct academic": "أكاديمية سابقة",
    "defunct automotive": "سيارات سابقة",
    "defunct-automotive-companies": "شركات سيارات سابقة",
    "defunct cargo airlines of": "شحن جوي سابقة في",
    "defunct chemical": "كيميائية سابقة",
    "defunct-chemical-companies": "شركات كيميائية سابقة",
    "defunct clothing": "ملابس سابقة",
    "defunct clothing retailers": "متاجر ملابس بالتجزئة سابقة",
    "defunct clothing retailers of": "متاجر ملابس بالتجزئة سابقة في",
    "defunct coal": "فحم سابقة",
    "defunct construction": "بناء سابقة",
    "defunct construction and civil engineering": "بناء وهندسة مدنية سابقة",
    "defunct-construction and civil engineering-companies": "شركات بناء وهندسة مدنية سابقة",
    "defunct defence": "دفاعية سابقة",
    "defunct-defence-companies": "شركات دفاعية سابقة",
    "defunct design": "تصميم سابقة",
    "defunct drink": "مشروبات سابقة",
    "defunct-entertainment-companies": "شركات ترفيه سابقة",
    "defunct gambling": "مقامرة سابقة",
    "defunct-gambling-companies": "شركات مقامرة سابقة",
    "defunct glassmaking": "الزجاج سابقة",
    "defunct-glassmaking-companies": "شركات الزجاج سابقة",
    "defunct health care": "رعاية صحية سابقة",
    "defunct-health care-companies": "شركات رعاية صحية سابقة",
    "defunct horticultural": "بستنة سابقة",
    "defunct hotel chains": "سلاسل فندقية سابقة",
    "defunct internet service providers": "تزويد خدمة الإنترنت سابقة",
    "defunct investment": "استثمارية سابقة",
    "defunct-investment-companies": "شركات استثمارية سابقة",
    "defunct-music-companies": "شركات الموسيقى سابقة",
    "defunct nuclear": "نووية سابقة",
    "defunct pulp and paper": "اللب والورق سابقة",
    "defunct-pulp and paper-companies": "شركات اللب والورق سابقة",
    "defunct service": "خدمات سابقة",
    "defunct-service-companies": "شركات خدمات سابقة",
    "publishing franchises": "امتيازات نشر",
    "printing databases": "قواعد بيانات طباعة",
    "electrical engineering organizations": "منظمات هندسة كهربائية",
    "electric power industry": "صناعة طاقة كهربائية",
    "electric power industry organizations": "منظمات صناعة طاقة كهربائية",
    "electronics company": "شركات إلكترونيات",
    "energy industry organizations": "منظمات صناعة طاقة",
    "engineering disciplines": "تخصصات هندسية",
    "entertainment databases": "قواعد بيانات ترفيه",
    "entertainment organizations": "منظمات ترفيه",
    "food franchises": "امتيازات أطعمة",
    "financial companies of": "شركات مالية في",
    "financial industry": "صناعة مالية",
    "financial services organizations": "منظمات خدمات مالية",
    "food and drink industry": "صناعة أطعمة ومشروبات",
    "food databases": "قواعد بيانات أطعمة",
    "food industry organizations": "منظمات صناعة أطعمة",
    "water company": "شركات مياه",
    "gambling company": "شركات مقامرة",
    "online manga": "مانغا عبر الإنترنت",
    "gas museums": "متاحف غاز",
    "food industry organisations": "منظمات صناعة أطعمة",
    "shipping industry": "صناعة نقل بحري",
    "hospitality industry organizations": "منظمات صناعة ضيافة",
    "hospitality services": "خدمات ضيافة",
    "household and personal product companies of": "شركات المنتجات المنزلية والشخصية في",
    "engineering services": "خدمات هندسية",
    "insurance industry organizations": "منظمات صناعة تأمين",
    "insurance organizations": "منظمات تأمين",
    "property organizations": "منظمات ممتلكات",
    "education industry": "صناعة تعليم",
    "internet companies of": "شركات إنترنت في",
    "internet databases": "قواعد بيانات إنترنت",
    "jewellery museums": "متاحف مجوهرات",
    "jewellery organizations": "منظمات مجوهرات",
    "manga industry": "صناعة مانغا",
    "marketing company": "شركات تسويق",
    "marvel comics organizations": "منظمات مارفال كومكس",
    "mass media agencies": "وكالات وسائل إعلام",
    "media agencies": "وكالات إعلامية",
    "mass media facilities": "مرافق وسائل إعلام",
    "media facilities": "مرافق إعلامية",
    "investment firms": "شركات استثمارية",
    "veterinary services": "خدمات بيطرة",
    "mining organizations": "منظمات تعدين",
    "mining services": "خدمات تعدين",
    "shipbuilding industry": "صناعة سفن",
    "music databases": "قواعد بيانات الموسيقى",
    "music organization": "منظمات الموسيقى",
    "service museums": "متاحف خدمات",
    "natural gas organizations": "منظمات غاز طبيعي",
    "gas organizations": "منظمات غاز",
    "aviation services": "خدمات طيران",
    "software franchises": "امتيازات برمجيات",
    "nuclear companies of": "شركات نووية في",
    "nuclear industry organizations": "منظمات صناعة نووية",
    "nuclear organization": "منظمات نووية",
    "online banks": "بنوك عبر الإنترنت",
    "online computer": "حوسبة عبر الإنترنت",
    "online insurance": "تأمين عبر الإنترنت",
    "online magazine": "مجلات عبر الإنترنت",
    "real estate databases": "قواعد بيانات عقارية",
    "online retail": "تجارة التجزئة عبر الإنترنت",
    "online travel": "سفر عبر الإنترنت",
    "retail organizations": "منظمات تجارة التجزئة",
    "comics organization": "منظمات قصص مصورة",
    "online service": "خدمات عبر الإنترنت",
    "paint and coatings industry": "صناعة رسم وطلاء",
    "transport accidents or incidents": "حوادث نقل",
    "software services": "خدمات برمجيات",
    "postal museums": "متاحف بريد",
    "postal organizations": "منظمات بريد",
    "storage facilities": "مرافق تخزين",
    "energy organization": "منظمات طاقة",
    "security industry": "صناعة أمن",
    "gambling organizations": "منظمات مقامرة",
    "property agencies": "وكالات ممتلكات",
    "publishing organizations": "منظمات نشر",
    "rail accidents": "حوادث سكك حديدية",
    "rail companies of": "شركات سكك حديدية في",
    "construction companies of": "شركات بناء في",
    "railway franchises": "امتيازات سكك حديدية",
    "real estate services companies of": "شركات خدمات عقارية في",
    "road transport organizations": "منظمات نقل بري",
    "technology facilities": "مرافق تقانة",
    "security databases": "قواعد بيانات أمن",
    "service industry": "صناعة خدمات",
    "shipbuilding organizations": "منظمات سفن",
    "submarine organizations": "منظمات غواصات",
    "submarine services": "خدمات غواصات",
    "sugar museums": "متاحف السكر",
    "sugar organizations": "منظمات السكر",
    "gas company": "شركات غاز",
    "television industry": "صناعة تلفاز",
    "health care facilities": "مرافق رعاية صحية",
    "agriculture agencies": "وكالات زراعة",
    "agriculture facilities": "مرافق زراعة",
    "education agencies": "وكالات تعليم",
    "energy facilities": "مرافق طاقة",
    "veterinary organizations": "منظمات بيطرة",
    "video game museums": "متاحف ألعاب فيديو",
    "video game organizations": "منظمات ألعاب فيديو",
    "video game software": "برمجيات ألعاب فيديو",
    "water industry": "صناعة مياه",
    "water transport organizations": "منظمات نقل مائي",
    "map services": "خدمات خرائط",
    "engineering organization": "منظمات هندسية",
    "wine company": "شركات نبيذ",
    "wine industry organizations": "منظمات صناعة نبيذ",
    "wine museums": "متاحف نبيذ",
}

COMPANY_TYPE_TRANSLATIONS = {
    "privately held": "خاصة",
    "airliner": "طائرات",
    "condiment": "توابل",
    "academic": "أكاديمية",
    "magazine": "مجلات",
    "natural gas": "غاز طبيعي",
    "comics": "قصص مصورة",
    "marvel comics": "مارفال كومكس",
    "mass media": "وسائل إعلام",
    "television": "تلفاز",
    "manga": "مانغا",
    "coal": "فحم",
    "coal gas": "غاز الفحم",
    "oil shale": "صخر زيتي",
    "oil": "زيت الوقود",
    "gas": "غاز",
    "nuclear": "نووية",
    "renewable energy": "طاقة متجددة",
    "agriculture": "زراعة",
    "airlines": "طيران",
    "aluminium": "ألومنيوم",
    "architecture": "هندسة معمارية",
    "automotive": "سيارات",
    "banks": "بنوك",
    "holding": "قابضة",
    "biotechnology": "تقانة حيوية",
    "building materials": "مواد بناء",
    "cargo airlines": "شحن جوي",
    "aviation": "طيران",
    "airline": "خطوط جوية",
    "cement": "أسمنت",
    "chemical": "كيميائية",
    "clothing": "ملابس",
    "computer": "حوسبة",
    "construction": "بناء",
    "construction and civil engineering": "بناء وهندسة مدنية",
    "cosmetics": "مستحضرات التجميل",
    "defence": "دفاعية",
    "design": "تصميم",
    "distribution": "توزيع",
    "education": "تعليم",
    "electronics": "إلكترونيات",
    "energy": "طاقة",
    "photovoltaic": "خلايا كهروضوئية",
    "hydroelectric": "كهرمائية",
    "electric power": "طاقة كهربائية",
    "engineering": "هندسية",
    "electrical engineering": "هندسة كهربائية",
    # "entertainment":"ترفيهية",
    "entertainment": "ترفيه",
    "eyewear": "نظارات",
    "financial": "مالية",
    "financial services": "خدمات مالية",
    "business services": "خدمات أعمال تجارية",
    "food": "أطعمة",
    "food and drink": "أطعمة ومشروبات",
    "gambling": "مقامرة",
    "glassmaking": "الزجاج",
    "health care": "رعاية صحية",
    "health clubs": "نوادي صحية",
    "horticultural": "بستنة",
    "household and personal product": "المنتجات المنزلية والشخصية",
    "insurance": "تأمين",
    "internet": "إنترنت",
    "internet service providers": "تزويد خدمة الإنترنت",
    "investment": "استثمارية",
    "jewellery": "مجوهرات",
    # "law":"مؤسسات قانون",
    "management consulting": "استشارات إدارية",
    "manufacturing": "تصنيع",
    "map": "خرائط",
    "marketing": "تسويق",
    "media": "إعلامية",
    "metal": "معادن",
    "mining": "تعدين",
    "vehicle manufacturing": "تصنيع مركبات",
    # "motor vehicle manufacturers":"تصنيع السيارات",
    "motor vehicle manufacturers": "مصانع سيارات",
    "music": "الموسيقى",
    "paint and coatings": "رسم وطلاء",
    "pharmaceutical": "أدوية",
    "printing": "طباعة",
    "property": "ممتلكات",
    "public utilities": "مرافق عمومية",
    "cruise ships": "سفن سياحية",
    "music publishing": "نشر موسيقى",
    "publishing": "نشر",
    "pulp and paper": "اللب والورق",
    "submarine": "غواصات",
    "rail": "سكك حديدية",
    "railway": "سكك حديدية",
    "car rental": "تأجير السيارات",
    "real estate": "عقارية",
    "real estate services": "خدمات عقارية",
    "retail": "تجارة التجزئة",
    "security": "أمن",
    "fraternal service": "خدمات أخوية",
    "service": "خدمات",
    "shipbuilding": "سفن",
    "shipyards": "حوض بناء سفن",
    "software": "برمجيات",
    "sugar": "السكر",
    "technology": "تقانة",
    "information technology": "تقانة المعلومات",
    "tobacco": "التبغ",
    "transport": "نقل",
    "travel": "سفر",
    "travel insurance": "تأمين السفر",
    "travel and holiday": "السفر والعطلات",
    "urban regeneration": "تطوير حضري",
    "utilities": "مرافق عمومية",
    "veterinary": "بيطرة",
    "video game": "ألعاب فيديو",
    "waste management": "إدارة المخلفات",
    "hotel chains": "سلاسل فندقية",
    "hospitality": "ضيافة",
    "hotel and leisure": "فنادق وترفيه",
    "hotels": "فنادق",
    "road transport": "نقل بري",
    "water transport": "نقل مائي",
    "shipping": "نقل بحري",
    "wine": "نبيذ",
    "alcohol": "كحول",
    "drink": "مشروبات",
    "water": "مياه",
    "postal": "بريد",
    "storage": "تخزين",
    "trucking": "نقل بالشاحنات",
    "logistics": "لوجستية",
    "military logistics": "لوجستية عسكرية",
    "wholesalers": "بيع بالجملة",
    "department stores": "متاجر متعددة الأقسام",
    "clothing retailers": "متاجر ملابس بالتجزئة",
}

len_print.data_len(
    "companies.py",
    {
        "companies_data": companies_data,
        "COMPANY_TYPE_TRANSLATIONS": COMPANY_TYPE_TRANSLATIONS,
    },
)
