#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_label_ar

data_skip = {
    "south african anti–world-war-ii activists": "",
    "South African military memorials and cemeteries": "",
    "South African soccer biography stubs": "",
    "LGBTQ rights in South Africa": "",
}

data_0 = {
    "Deaths by firearm in South Africa": "وفيات بإطلاق النار في جنوب إفريقيا",
    "south african cricket": "الكريكت الجنوب الإفريقية",
    "south african netball": "كرة الشبكة الجنوب الإفريقية",
    "south african soccer leagues": "دوريات كرة القدم الجنوب الإفريقية",
    "south african jews": "جنوب إفريقيون يهود",
    "1550 in south african cricket": "الكريكت الجنوب الإفريقية في 1550",
    "LGBT rights in South Africa": "معاملة المثليين في جنوب إفريقيا",
    "Films by South African directors": "أفلام مخرجون جنوب إفريقيون",
    "Asian diaspora in South Africa": "شتات آسيوي في جنوب إفريقيا",
    "south african women non-fiction writers": "كاتبات غير روائيات جنوب إفريقيات",
    "Clothing retailers of South Africa": "متاجر ملابس بالتجزئة في جنوب إفريقيا",
    "Department stores of South Africa": "متاجر متعددة الأقسام في جنوب إفريقيا",
    "south africa national water polo team navigational boxes": "صناديق تصفح منتخب جنوب إفريقيا لكرة الماء",
    "south africa national soccer team results": "نتائج منتخب جنوب إفريقيا لكرة القدم",
    "south africa national women's cricket team templates": "قوالب منتخب جنوب إفريقيا للكريكت للسيدات",
    "ireland–south africa relations": "العلاقات الأيرلندية الجنوب الإفريقية",
    "ireland–south africa sports relations": "العلاقات الأيرلندية الجنوب الإفريقية الرياضية",
    "Unmanned aerial vehicles of South Africa": "طائرات بدون طيار جنوب إفريقية",
    "Unmanned military aircraft of South Africa": "طائرات عسكرية بدون طيار جنوب إفريقية",
    "15th century in South Africa": "جنوب إفريقيا في القرن 15",
    "1620s in South Africa": "جنوب إفريقيا في عقد 1620",
    "video gaming in south africa": "ألعاب الفيديو في جنوب إفريقيا",
    "South Africa international soccer players": "لاعبو منتخب جنوب إفريقيا لكرة القدم",
    "Deaths from the COVID-19 pandemic in South Africa": "وفيات من جائحة فيروس كورونا في جنوب إفريقيا",
    "Deaths by stabbing in South Africa": "وفيات بالطعن في جنوب إفريقيا",
    "Deaths from cancer in South Africa": "وفيات السرطان في جنوب إفريقيا",
    "Deaths from lung cancer in South Africa": "وفيات سرطان الرئة في جنوب إفريقيا",
    "Multi-sport events in South Africa": "أحداث رياضية متعددة في جنوب إفريقيا",
    "South Africa political leader navigational boxes": "صناديق تصفح قادة سياسيون جنوب إفريقيون",
    "Nuclear technology in South Africa": "تقانة نووية في جنوب إفريقيا",
    "Science and technology in South Africa": "العلوم والتقانة في جنوب إفريقيا",
    "Deaths by person in South Africa": "وفيات حسب الشخص في جنوب إفريقيا",
    "Deaths from brain cancer in South Africa": "وفيات سرطان الدماغ في جنوب إفريقيا",
    "Women members of the National Assembly of South Africa": "عضوات الجمعية الوطنية في جنوب إفريقيا",
    "Speakers of the National Assembly of South Africa": "رؤساء الجمعية الوطنية في جنوب إفريقيا",
    "Members of the National Assembly of South Africa 1994–1999": "أعضاء الجمعية الوطنية في جنوب إفريقيا 1994–1999",
    "Members of the National Assembly of South Africa 1999–2004": "أعضاء الجمعية الوطنية في جنوب إفريقيا 1999–2004",
    "Members of the National Assembly of South Africa 2004–2009": "أعضاء الجمعية الوطنية في جنوب إفريقيا 2004–2009",
    "Members of the National Assembly of South Africa 2009–2014": "أعضاء الجمعية الوطنية في جنوب إفريقيا 2009–2014",
    "Members of the National Assembly of South Africa 2014–2019": "أعضاء الجمعية الوطنية في جنوب إفريقيا 2014–2019",
    "Members of the National Assembly of South Africa 2019–2024": "أعضاء الجمعية الوطنية في جنوب إفريقيا 2019–2024",
    "Members of the National Assembly of South Africa 2024–2029": "أعضاء الجمعية الوطنية في جنوب إفريقيا 2024–2029",
    "Members of the National Assembly of South Africa": "أعضاء الجمعية الوطنية في جنوب إفريقيا",
    "South African Anglicans": "جنوب إفريقيون أنجليكيون",
    "South African Christians": "جنوب إفريقيون مسيحيون",
    "South African Hindus": "جنوب إفريقيون هندوس",
    "South African Sufis": "جنوب إفريقيون صوفيون",
    "South African Sunni Muslims": "جنوب إفريقيون مسلمون سنة",
    "South African Jews": "جنوب إفريقيون يهود",
    "20th-century South African Jews": "جنوب إفريقيون يهود في القرن 20",
    "South African Jews by century": "جنوب إفريقيون يهود حسب القرن",
    "South African Jews by occupation": "جنوب إفريقيون يهود حسب المهنة",
    "21st-century South African Jews": "جنوب إفريقيون يهود في القرن 21",
    "Anglican bishops in South Africa by diocese": "أساقفة أنجليكيون في جنوب إفريقيا حسب الأبرشية",
    "Anglican bishops in South Africa": "أساقفة أنجليكيون في جنوب إفريقيا",
    "Anglican missionaries in South Africa": "مبشرون أنجليكيون في جنوب إفريقيا",
    "Christian clergy in South Africa": "رجال دين مسيحيون في جنوب إفريقيا",
    "Christian denominations in South Africa": "طوائف مسيحية في جنوب إفريقيا",
    "Christian missionaries in South Africa": "مبشرون مسيحيون في جنوب إفريقيا",
    "Christian music albums by South African artists": "ألبومات موسيقى مسيحية بواسطة فنانون جنوب إفريقيون",
    "Christian rock albums by South African artists": "ألبومات روك مسيحي بواسطة فنانون جنوب إفريقيون",
    "Christian schools in South Africa": "مدارس مسيحية في جنوب إفريقيا",
    "Church of Jesus Christ of Latter-day Saints in South Africa": "كنيسة يسوع المسيح لقديسي الأيام الأخيرة في جنوب إفريقيا",
    "Hindu temples in South Africa": "معابد هندوسية في جنوب إفريقيا",
    "Islamic education in South Africa": "تعليم إسلامي في جنوب إفريقيا",
    "Islamic organisations based in South Africa": "منظمات إسلامية مقرها في جنوب إفريقيا",
    "Islamic political parties in South Africa": "أحزاب سياسية إسلامية في جنوب إفريقيا",
    "Islamic schools in South Africa": "مدارس إسلامية في جنوب إفريقيا",
    "Jewish emigrants from Nazi Germany to South Africa": "يهود مهاجرون من ألمانيا النازية إلى جنوب إفريقيا",
    "Jewish organisations based in South Africa": "منظمات يهودية مقرها في جنوب إفريقيا",
    "Jewish schools in South Africa": "مدارس يهودية في جنوب إفريقيا",
    "Jewish-South African families": "عائلات جنوب إفريقية يهودية",
    "Jews and Judaism in South Africa": "اليهود واليهودية في جنوب إفريقيا",
    "Methodist missionaries in South Africa": "مبشرون ميثوديون لاهوتيون في جنوب إفريقيا",
    "Protestant missionaries in South Africa": "مبشرون بروتستانتيون في جنوب إفريقيا",
    "South African Bahá'ís": "جنوب إفريقيون بهائيون",
    "South African Christian clergy": "رجال دين مسيحيون جنوب إفريقيون",
    "South African Christian missionaries": "مبشرون مسيحيون جنوب إفريقيون",
    "South African Christian religious leaders": "قادة دينيون مسيحيون جنوب إفريقيون",
    "South African leaders of Church of Jesus Christ of Latter-day Saints": "قادة جنوب إفريقيون في كنيسة يسوع المسيح لقديسي الأيام الأخيرة",
    "South African Methodist missionaries": "مبشرون ميثوديون لاهوتيون جنوب إفريقيون",
    "South African Muslim activists": "ناشطون مسلمون جنوب إفريقيون",
    "South African people of Greek-Jewish descent": "جنوب إفريقيون من أصل يهودي يوناني",
    "South African people of Jewish descent": "جنوب إفريقيون من أصل يهودي",
    "South African Protestant missionaries": "مبشرون بروتستانتيون جنوب إفريقيون",
    "South African Protestant religious leaders": "قادة دينيون بروتستانتيون جنوب إفريقيون",
    "South African Sunni Muslim scholars of Islam": "باحثون عن الإسلام مسلمون سنة جنوب إفريقيون",
    "south african political people": "ساسة جنوب إفريقيون",
    "south african lgbtq people": "أعلام إل جي بي تي كيو جنوب إفريقيون",
    "south african people": "جنوب إفريقيون",
    "south african snowboarding federation": "الاتحاد الجنوب الإفريقي للتزلج على الثلوج",
    "south african parliament": "البرلمان الجنوب الإفريقي",
    "1970s South African films": "أفلام جنوب إفريقية في عقد 1970",
    "South African comedy-drama films": "أفلام كوميدية درامية جنوب إفريقية",
    "south african provinces": "مقاطعات جنوب إفريقية",
    "south african wheelchair basketball players": "لاعبو كرة سلة على كراسي متحركة جنوب إفريقيون",
    "south african wheelchair racers": "متسابقو كراسي متحركة جنوب إفريقيون",
    "south african men wheelchair racers": "متسابقو كراسي متحركة جنوب إفريقيون",
    "south african sport": "رياضة جنوب إفريقية",
    "south african artists": "فنانون جنوب إفريقيون",
    "south african descent": "أصل جنوب إفريقي",
    "south african expatriate sports-people in peru": "رياضيون جنوب إفريقيون مغتربون في بيرو",
    "South Africa men's A' international soccer players": "لاعبو منتخب جنوب إفريقيا لكرة القدم للرجال للمحليين",
    "South African physicians": "أطباء جنوب إفريقيون",
    "Lists of South African politicians": "قوائم سياسيون جنوب إفريقيون",
    "Films by South African producers": "أفلام منتجون جنوب إفريقيون",
    "Asian people of South African descent": "آسيويون من أصل جنوب إفريقي",
    "Cultural depictions of South African people": "تصوير ثقافي عن جنوب إفريقيون",
    "21st-century South African non-fiction writers": "كتاب غير روائيين جنوب إفريقيون في القرن 21",
    "South African male non-fiction writers": "كتاب غير روائيين ذكور جنوب إفريقيون",
    "South African non-fiction writers": "كتاب غير روائيين جنوب إفريقيون",
    "South African non-fiction writers by century": "كتاب غير روائيين جنوب إفريقيون حسب القرن",
    "south african muslims": "جنوب إفريقيون مسلمون",
    "south african male non-fiction writers": "كتاب غير روائيين ذكور جنوب إفريقيون",
    "south african non-fiction books": "كتب جنوب إفريقية غير خيالية",
    "south african non-fiction writers": "كتاب غير روائيين جنوب إفريقيون",
    "20th-century south african non-fiction writers": "كتاب غير روائيين جنوب إفريقيون في القرن 20",
    "South African wheelchair racers": "متسابقو كراسي متحركة جنوب إفريقيون",
    "South African men wheelchair racers": "متسابقو كراسي متحركة جنوب إفريقيون",
    "South African wheelchair basketball players": "لاعبو كرة سلة على كراسي متحركة جنوب إفريقيون",
    "south african rugby union": "اتحاد الرجبي الجنوب الإفريقي",
    "south african premier division": "الدوري الجنوب الإفريقي الممتاز",
    "South African classical musicians by instrument": "موسيقيون كلاسيكيون جنوب إفريقيون حسب الآلة",
    "South African classical musicians": "موسيقيون كلاسيكيون جنوب إفريقيون",
    "South African classical composers": "ملحنون كلاسيكيون جنوب إفريقيون",
    "1990s South African novels": "روايات جنوب إفريقية في عقد 1990",
    "2000s South African novels": "روايات جنوب إفريقية في عقد 2000",
    "2010s South African novels": "روايات جنوب إفريقية في عقد 2010",
    "2020s South African novels": "روايات جنوب إفريقية في عقد 2020",
    "South African novels by decade": "روايات جنوب إفريقية حسب العقد",
    "Novels set during South African Border War": "روايات تجري أحداثها خلال حرب الحدود الجنوب الإفريقية",
    "1960s South African novels": "روايات جنوب إفريقية في عقد 1960",
    "1970s South African novels": "روايات جنوب إفريقية في عقد 1970",
    "1980s South African novels": "روايات جنوب إفريقية في عقد 1980",
    "1950s South African novels": "روايات جنوب إفريقية في عقد 1950",
    "South African expatriate swimmers in United States": "سباحون جنوب إفريقيون مغتربون في الولايات المتحدة",
    "1980s South African television series endings": "مسلسلات تلفزيونية جنوب إفريقية انتهت في عقد 1980",
    "South African film directors": "مخرجو أفلام جنوب إفريقيون",
    "2020 South African television series debuts": "مسلسلات تلفزيونية جنوب إفريقية بدأ عرضها في 2020",
    "1974 in South African law": "قانون جنوب إفريقي في 1974",
    "Indie rock albums by South African artists": "ألبومات إيندي روك بواسطة فنانون جنوب إفريقيون",
    "2015 South African television series endings": "مسلسلات تلفزيونية جنوب إفريقية انتهت في 2015",
    "South African artists": "فنانون جنوب إفريقيون",
    "South African companies established in 1985": "شركات جنوب إفريقية أسست في 1985",
    "South African directors": "مخرجون جنوب إفريقيون",
    "South African economists": "اقتصاديون جنوب إفريقيون",
    "South African male painters": "رسامون ذكور جنوب إفريقيون",
    "South African men by occupation": "رجال جنوب إفريقيون حسب المهنة",
    "South African people in sex industry": "جنوب إفريقيون في صناعة جنسية",
    "South African religious leaders": "قادة دينيون جنوب إفريقيون",
    "Works about South African Border War": "أعمال عن حرب الحدود الجنوب الإفريقية",
    "2027 in South African cricket": "الكريكت الجنوب الإفريقية في 2027",
    "2027 in South African sport": "رياضة جنوب إفريقية في 2027",
    "2026 in South Africa": "جنوب إفريقيا في 2026",
    "2026 in South African cricket": "الكريكت الجنوب الإفريقية في 2026",
    "2026 in South African rugby union": "اتحاد الرجبي الجنوب الإفريقي في 2026",
    "2026 in South African sport": "رياضة جنوب إفريقية في 2026",
}

data_1 = {
    "serbia-and-montenegro–south africa relations": "علاقات جنوب إفريقيا وصربيا والجبل الأسود",
    "saint kitts and nevis–south africa relations": "علاقات جنوب إفريقيا وسانت كيتس ونيفيس",
    "eswatini–south africa relations": "علاقات إسواتيني وجنوب إفريقيا",
    "Kenya–South Africa sports relations": "العلاقات الجنوب الإفريقية الكينية الرياضية",
    "Jamaica–South Africa sports relations": "العلاقات الجامايكية الجنوب الإفريقية الرياضية",
    "Grenada–South Africa sports relations": "العلاقات الجنوب الإفريقية الغرينادية الرياضية",
    "Guyana–South Africa sports relations": "العلاقات الجنوب الإفريقية الغيانية الرياضية",
    "Georgia (country)–South Africa sports relations": "العلاقات الجنوب الإفريقية الجورجية الرياضية",
    "Barbados–South Africa sports relations": "العلاقات البربادوسية الجنوب الإفريقية الرياضية",
    "Afghanistan–South Africa sports relations": "العلاقات الأفغانية الجنوب الإفريقية الرياضية",
    "south africa–saint kitts and nevis relations": "علاقات جنوب إفريقيا وسانت كيتس ونيفيس",
    "South Africa–Thailand sports relations": "العلاقات التايلندية الجنوب الإفريقية الرياضية",
    "South Africa–Tonga sports relations": "العلاقات التونغانية الجنوب الإفريقية الرياضية",
    "South Africa–Trinidad and Tobago sports relations": "العلاقات الترنيدادية الجنوب الإفريقية الرياضية",
    "South Africa–Uganda sports relations": "العلاقات الأوغندية الجنوب الإفريقية الرياضية",
    "South Africa–Uruguay sports relations": "العلاقات الأوروغويانية الجنوب الإفريقية الرياضية",
    "South Africa–Zimbabwe sports relations": "العلاقات الجنوب الإفريقية الزيمبابوية الرياضية",
    "Romania–South Africa sports relations": "العلاقات الجنوب الإفريقية الرومانية الرياضية",
    "Samoa–South Africa sports relations": "العلاقات الجنوب الإفريقية الساموية الرياضية",
    "Portugal–South Africa sports relations": "العلاقات البرتغالية الجنوب الإفريقية الرياضية",
    "Namibia–South Africa sports relations": "العلاقات الجنوب الإفريقية الناميبية الرياضية",
    "Nigeria–South Africa sports relations": "العلاقات الجنوب الإفريقية النيجيرية الرياضية",
    "Belgium–South Africa relations": "العلاقات البلجيكية الجنوب الإفريقية",
    "Benin–South Africa relations": "العلاقات البنينية الجنوب الإفريقية",
    "Botswana–South Africa border crossings": "معابر الحدود البوتسوانية الجنوب الإفريقية",
    "Botswana–South Africa border": "الحدود البوتسوانية الجنوب الإفريقية",
    "Botswana–South Africa relations": "العلاقات البوتسوانية الجنوب الإفريقية",
    "Brazil–South Africa relations": "العلاقات البرازيلية الجنوب الإفريقية",
    "Brunei–South Africa relations": "العلاقات البرونية الجنوب الإفريقية",
    "Bulgaria–South Africa relations": "العلاقات البلغارية الجنوب الإفريقية",
    "Burkina Faso–South Africa relations": "العلاقات البوركينابية الجنوب الإفريقية",
    "Burundi–South Africa relations": "العلاقات البوروندية الجنوب الإفريقية",
    "Cameroon–South Africa relations": "العلاقات الجنوب الإفريقية الكاميرونية",
    "Canada–South Africa relations": "العلاقات الجنوب الإفريقية الكندية",
    "Chad–South Africa relations": "العلاقات التشادية الجنوب الإفريقية",
    "Chile–South Africa relations": "العلاقات التشيلية الجنوب الإفريقية",
    "China–South Africa relations": "العلاقات الجنوب الإفريقية الصينية",
    "Colombia–South Africa relations": "العلاقات الجنوب الإفريقية الكولومبية",
    "Comoros–South Africa relations": "العلاقات الجنوب الإفريقية القمرية",
    "Costa Rica–South Africa relations": "العلاقات الجنوب الإفريقية الكوستاريكية",
    "Cuba–South Africa relations": "العلاقات الجنوب الإفريقية الكوبية",
    "Cyprus–South Africa relations": "العلاقات الجنوب الإفريقية القبرصية",
    "Czech Republic–South Africa relations": "العلاقات التشيكية الجنوب الإفريقية",
    "democratic-republic-of-congo–south africa relations": "العلاقات الجنوب الإفريقية الكونغوية الديمقراطية",
    "Denmark–South Africa relations": "العلاقات الجنوب الإفريقية الدنماركية",
    "Djibouti–South Africa relations": "العلاقات الجنوب الإفريقية الجيبوتية",
    "Egypt–South Africa relations": "العلاقات الجنوب الإفريقية المصرية",
    "El Salvador–South Africa relations": "العلاقات الجنوب الإفريقية السلفادورية",
    "Equatorial Guinea–South Africa relations": "العلاقات الجنوب الإفريقية الغينية الاستوائية",
    "Ethiopia–South Africa relations": "العلاقات الإثيوبية الجنوب الإفريقية",
    "Fiji–South Africa relations": "العلاقات الجنوب الإفريقية الفيجية",
    "Fiji–South Africa sports relations": "العلاقات الجنوب الإفريقية الفيجية الرياضية",
    "Finland–South Africa relations": "العلاقات الجنوب الإفريقية الفنلندية",
    "France–South Africa relations": "العلاقات الجنوب الإفريقية الفرنسية",
    "France–South Africa sports relations": "العلاقات الجنوب الإفريقية الفرنسية الرياضية",
    "Gabon–South Africa relations": "العلاقات الجنوب الإفريقية الغابونية",
    "Germany–South Africa relations": "العلاقات الألمانية الجنوب الإفريقية",
    "Ghana–South Africa relations": "العلاقات الجنوب الإفريقية الغانية",
    "Greece–South Africa relations": "العلاقات الجنوب الإفريقية اليونانية",
    "Grenada–South Africa relations": "العلاقات الجنوب الإفريقية الغرينادية",
    "Guatemala–South Africa relations": "العلاقات الجنوب الإفريقية الغواتيمالية",
    "Guinea-Bissau–South Africa relations": "العلاقات الجنوب الإفريقية الغينية البيساوية",
    "Guinea–South Africa relations": "العلاقات الجنوب الإفريقية الغينية",
    "Guyana–South Africa relations": "العلاقات الجنوب الإفريقية الغيانية",
    "Honduras–South Africa relations": "العلاقات الجنوب الإفريقية الهندوراسية",
    "Hungary–South Africa relations": "العلاقات الجنوب الإفريقية المجرية",
    "Iceland–South Africa relations": "العلاقات الآيسلندية الجنوب الإفريقية",
    "India–South Africa relations": "العلاقات الجنوب الإفريقية الهندية",
    "India–South Africa sports relations": "العلاقات الجنوب الإفريقية الهندية الرياضية",
    "Indonesia–South Africa relations": "العلاقات الإندونيسية الجنوب الإفريقية",
    "Iran–South Africa relations": "العلاقات الإيرانية الجنوب الإفريقية",
    "Iraq–South Africa relations": "العلاقات الجنوب الإفريقية العراقية",
    "Israel–South Africa relations": "العلاقات الإسرائيلية الجنوب الإفريقية",
    "Italy–South Africa relations": "العلاقات الإيطالية الجنوب الإفريقية",
    "Italy–South Africa sports relations": "العلاقات الإيطالية الجنوب الإفريقية الرياضية",
    "Ivory Coast–South Africa relations": "العلاقات الإيفوارية الجنوب الإفريقية",
    "Jamaica–South Africa relations": "العلاقات الجامايكية الجنوب الإفريقية",
    "Japan–South Africa relations": "العلاقات الجنوب الإفريقية اليابانية",
    "Jordan–South Africa relations": "العلاقات الأردنية الجنوب الإفريقية",
    "Kazakhstan–South Africa relations": "العلاقات الجنوب الإفريقية الكازاخستانية",
    "Kenya–South Africa relations": "العلاقات الجنوب الإفريقية الكينية",
    "Kuwait–South Africa relations": "العلاقات الجنوب الإفريقية الكويتية",
    "Lebanon–South Africa relations": "العلاقات الجنوب الإفريقية اللبنانية",
    "Lesotho–South Africa border crossings": "معابر الحدود الجنوب الإفريقية الليسوتية",
    "Lesotho–South Africa border": "الحدود الجنوب الإفريقية الليسوتية",
    "Lesotho–South Africa relations": "العلاقات الجنوب الإفريقية الليسوتية",
    "Liberia–South Africa relations": "العلاقات الجنوب الإفريقية الليبيرية",
    "Lithuania–South Africa relations": "العلاقات الجنوب الإفريقية الليتوانية",
    "Luxembourg–South Africa relations": "العلاقات الجنوب الإفريقية اللوكسمبورغية",
    "Madagascar–South Africa relations": "العلاقات الجنوب الإفريقية المدغشقرية",
    "Malawi–South Africa relations": "العلاقات الجنوب الإفريقية الملاوية",
    "Malaysia–South Africa relations": "العلاقات الجنوب الإفريقية الماليزية",
    "Mali–South Africa relations": "العلاقات الجنوب الإفريقية المالية",
    "Malta–South Africa relations": "العلاقات الجنوب الإفريقية المالطية",
    "Mauritius–South Africa relations": "العلاقات الجنوب الإفريقية الموريشيوسية",
    "Mexico–South Africa relations": "العلاقات الجنوب الإفريقية المكسيكية",
    "Morocco–South Africa relations": "العلاقات الجنوب الإفريقية المغربية",
    "Mozambique–South Africa border crossings": "معابر الحدود الجنوب الإفريقية الموزمبيقية",
    "Mozambique–South Africa border": "الحدود الجنوب الإفريقية الموزمبيقية",
    "Mozambique–South Africa relations": "العلاقات الجنوب الإفريقية الموزمبيقية",
    "Myanmar–South Africa relations": "العلاقات الجنوب الإفريقية الميانمارية",
    "Namibia–South Africa border crossings": "معابر الحدود الجنوب الإفريقية الناميبية",
    "Namibia–South Africa border": "الحدود الجنوب الإفريقية الناميبية",
    "Namibia–South Africa relations": "العلاقات الجنوب الإفريقية الناميبية",
    "Netherlands–South Africa relations": "العلاقات الجنوب الإفريقية الهولندية",
    "Netherlands–South Africa sports relations": "العلاقات الجنوب الإفريقية الهولندية الرياضية",
    "New Zealand–South Africa relations": "العلاقات الجنوب الإفريقية النيوزيلندية",
    "New Zealand–South Africa sports relations": "العلاقات الجنوب الإفريقية النيوزيلندية الرياضية",
    "Nicaragua–South Africa relations": "العلاقات الجنوب الإفريقية النيكاراغوية",
    "Nigeria–South Africa relations": "العلاقات الجنوب الإفريقية النيجيرية",
    "Norway–South Africa relations": "العلاقات الجنوب الإفريقية النرويجية",
    "Oman–South Africa relations": "العلاقات الجنوب الإفريقية العمانية",
    "Pakistan–South Africa relations": "العلاقات الباكستانية الجنوب الإفريقية",
    "Pakistan–South Africa sports relations": "العلاقات الباكستانية الجنوب الإفريقية الرياضية",
    "Palestine–South Africa relations": "العلاقات الجنوب الإفريقية الفلسطينية",
    "Panama–South Africa relations": "العلاقات البنمية الجنوب الإفريقية",
    "Papua New Guinea–South Africa relations": "العلاقات الجنوب الإفريقية الغينية",
    "Paraguay–South Africa relations": "العلاقات البارغوايانية الجنوب الإفريقية",
    "Peru–South Africa relations": "العلاقات البيروية الجنوب الإفريقية",
    "Philippines–South Africa relations": "العلاقات الجنوب الإفريقية الفلبينية",
    "Poland–South Africa relations": "العلاقات البولندية الجنوب الإفريقية",
    "Portugal–South Africa relations": "العلاقات البرتغالية الجنوب الإفريقية",
    "Qatar–South Africa relations": "العلاقات الجنوب الإفريقية القطرية",
    "republic-of-congo–south africa relations": "العلاقات الجنوب الإفريقية الكونغوية",
    "Rhodesia–South Africa military relations": "العلاقات الجنوب الإفريقية الرودوسية العسكرية",
    "Rhodesia–South Africa relations": "العلاقات الجنوب الإفريقية الرودوسية",
    "Romania–South Africa relations": "العلاقات الجنوب الإفريقية الرومانية",
    "Russia–South Africa relations": "العلاقات الجنوب الإفريقية الروسية",
    "Rwanda–South Africa relations": "العلاقات الجنوب الإفريقية الرواندية",
    "Samoa–South Africa relations": "العلاقات الجنوب الإفريقية الساموية",
    "Saudi Arabia–South Africa relations": "العلاقات الجنوب الإفريقية السعودية",
    "Senegal–South Africa relations": "العلاقات الجنوب الإفريقية السنغالية",
    "Serbia–South Africa relations": "العلاقات الجنوب الإفريقية الصربية",
    "Singapore–South Africa relations": "العلاقات الجنوب الإفريقية السنغافورية",
    "Slovakia–South Africa relations": "العلاقات الجنوب الإفريقية السلوفاكية",
    "Somalia–South Africa relations": "العلاقات الجنوب الإفريقية الصومالية",
    "South Africa–South Korea relations": "العلاقات الجنوب الإفريقية الكورية الجنوبية",
    "South Africa–South Sudan relations": "العلاقات الجنوب الإفريقية السودانية الجنوبية",
    "South Africa–Soviet Union relations": "العلاقات الجنوب الإفريقية السوفيتية",
    "South Africa–Spain military relations": "العلاقات الإسبانية الجنوب الإفريقية العسكرية",
    "South Africa–Spain relations": "العلاقات الإسبانية الجنوب الإفريقية",
    "South Africa–Sri Lanka relations": "العلاقات الجنوب الإفريقية السريلانكية",
    "South Africa–Sri Lanka sports relations": "العلاقات الجنوب الإفريقية السريلانكية الرياضية",
    "South Africa–Sweden relations": "العلاقات الجنوب الإفريقية السويدية",
    "South Africa–Switzerland relations": "العلاقات الجنوب الإفريقية السويسرية",
    "South Africa–Syria relations": "العلاقات الجنوب الإفريقية السورية",
    "South Africa–Taiwan relations": "العلاقات التايوانية الجنوب الإفريقية",
    "South Africa–Tanzania relations": "العلاقات التنزانية الجنوب الإفريقية",
    "South Africa–Thailand relations": "العلاقات التايلندية الجنوب الإفريقية",
    "South Africa–Togo relations": "العلاقات التوغوية الجنوب الإفريقية",
    "South Africa–Tonga relations": "العلاقات التونغانية الجنوب الإفريقية",
    "South Africa–Trinidad and Tobago relations": "العلاقات الترنيدادية الجنوب الإفريقية",
    "South Africa–Turkey relations": "العلاقات التركية الجنوب الإفريقية",
    "South Africa–Uganda relations": "العلاقات الأوغندية الجنوب الإفريقية",
    "South Africa–Ukraine relations": "العلاقات الأوكرانية الجنوب الإفريقية",
    "South Africa–United Arab Emirates relations": "العلاقات الإماراتية الجنوب الإفريقية",
    "South Africa–United Arab Emirates sports relations": "العلاقات الإماراتية الجنوب الإفريقية الرياضية",
    "South Africa–United Kingdom relations": "العلاقات البريطانية الجنوب الإفريقية",
    "South Africa–United Kingdom sports relations": "العلاقات البريطانية الجنوب الإفريقية الرياضية",
    "South Africa–United States relations": "العلاقات الأمريكية الجنوب الإفريقية",
    "South Africa–Uruguay relations": "العلاقات الأوروغويانية الجنوب الإفريقية",
    "South Africa–Venezuela relations": "العلاقات الجنوب الإفريقية الفنزويلية",
    "South Africa–Yugoslavia relations": "العلاقات الجنوب الإفريقية اليوغسلافية",
    "South Africa–Zambia relations": "العلاقات الجنوب الإفريقية الزامبية",
    "South Africa–Zimbabwe border crossings": "معابر الحدود الجنوب الإفريقية الزيمبابوية",
    "South Africa–Zimbabwe border": "الحدود الجنوب الإفريقية الزيمبابوية",
    "South Africa–Zimbabwe relations": "العلاقات الجنوب الإفريقية الزيمبابوية",
}

data_2 = {}

to_test = [
    ("test_south_african_0", data_0),
    ("test_south_african_1", data_1),
    ("test_south_african_2", data_2),
]


@pytest.mark.parametrize("category, expected", data_0.items(), ids=data_0.keys())
@pytest.mark.fast
def test_south_african_0(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_south_african_1(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)
    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"


@pytest.mark.parametrize("name,data", [("test_south_african_2", data_skip)])
@pytest.mark.skip2
def test_dump_it_skip2(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)
    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
