from __future__ import annotations

import pytest

from ArWikiCats.new_resolvers.relations_resolver import new_relations_resolvers

big_data = {
    "monaco–republic-of-congo relations": "العلاقات الكونغوية الموناكية",
    "georgia (country)–ireland sports relations": "العلاقات الأيرلندية الجورجية الرياضية",
    "ireland–japan sports relations": "العلاقات الأيرلندية اليابانية الرياضية",
    "ireland–romania sports relations": "العلاقات الأيرلندية الرومانية الرياضية",
    "ireland–russia sports relations": "العلاقات الأيرلندية الروسية الرياضية",
    "ireland–samoa sports relations": "العلاقات الأيرلندية الساموية الرياضية",
    "ireland–slovakia sports relations": "العلاقات الأيرلندية السلوفاكية الرياضية",
    "ireland–tanzania sports relations": "العلاقات الأيرلندية التنزانية الرياضية",
    "ireland–tonga sports relations": "العلاقات الأيرلندية التونغانية الرياضية",
    "ireland–uganda sports relations": "العلاقات الأوغندية الأيرلندية الرياضية",
    "ireland–uruguay sports relations": "العلاقات الأوروغويانية الأيرلندية الرياضية",
    "ireland–zambia sports relations": "العلاقات الأيرلندية الزامبية الرياضية",
    "federated states of micronesia–palau relations": "علاقات بالاو وولايات ميكرونيسيا المتحدة",
    "federated states of micronesia–papua new guinea relations": "علاقات بابوا غينيا الجديدة وولايات ميكرونيسيا المتحدة",
    "federated states of micronesia–sweden relations": "علاقات السويد وولايات ميكرونيسيا المتحدة",
    "federated states of micronesia–tonga relations": "علاقات تونغا وولايات ميكرونيسيا المتحدة",
    "marshall islands–samoa relations": "علاقات جزر مارشال وساموا",
    "marshall islands–tuvalu relations": "علاقات توفالو وجزر مارشال",
    "palau–solomon islands relations": "علاقات بالاو وجزر سليمان",
    "solomon islands–tonga relations": "علاقات تونغا وجزر سليمان",
    "solomon islands–tuvalu relations": "علاقات توفالو وجزر سليمان",
    "kiribati–vanuatu relations": "العلاقات الفانواتية الكيريباتية",
    "nauru–palau relations": "العلاقات البالاوية الناورونية",
    "nauru–samoa relations": "العلاقات الساموية الناورونية",
    "nauru–tonga relations": "العلاقات التونغانية الناورونية",
    "nauru–tuvalu relations": "العلاقات التوفالية الناورونية",
    "palau–vanuatu relations": "العلاقات البالاوية الفانواتية",
    "tuvalu–vanuatu relations": "العلاقات التوفالية الفانواتية",
    "afghanistan–european union relations": "علاقات أفغانستان والاتحاد الأوروبي",
    "andorra–european union relations": "علاقات أندورا والاتحاد الأوروبي",
    "armenia–european union relations": "علاقات أرمينيا والاتحاد الأوروبي",
    "bahamas–european union relations": "علاقات الاتحاد الأوروبي وباهاماس",
    "cambodia–european union relations": "علاقات الاتحاد الأوروبي وكمبوديا",
    "colombia–european union relations": "علاقات الاتحاد الأوروبي وكولومبيا",
    "georgia (country)–european union relations": "علاقات الاتحاد الأوروبي وجورجيا",
    "greenland–european union relations": "علاقات الاتحاد الأوروبي وجرينلاند",
    "guyana–european union relations": "علاقات الاتحاد الأوروبي وغيانا",
    "kosovo–european union relations": "علاقات الاتحاد الأوروبي وكوسوفو",
    "kyrgyzstan–european union relations": "علاقات الاتحاد الأوروبي وقيرغيزستان",
    "liechtenstein–european union relations": "علاقات الاتحاد الأوروبي وليختنشتاين",
    "mauritania–european union relations": "علاقات الاتحاد الأوروبي وموريتانيا",
    "moldova–european union relations": "علاقات الاتحاد الأوروبي ومولدوفا",
    "montenegro–european union relations": "علاقات الاتحاد الأوروبي والجبل الأسود",
    "namibia–european union relations": "علاقات الاتحاد الأوروبي وناميبيا",
    "north macedonia–european union relations": "علاقات الاتحاد الأوروبي ومقدونيا الشمالية",
    "qatar–european union relations": "علاقات الاتحاد الأوروبي وقطر",
    "saudi arabia–european union relations": "علاقات الاتحاد الأوروبي والسعودية",
    "syria–european union relations": "علاقات الاتحاد الأوروبي وسوريا",
    "tunisia–european union relations": "علاقات الاتحاد الأوروبي وتونس",
    "Afghanistan–Australia sports relations": "العلاقات الأسترالية الأفغانية الرياضية",
    "Afghanistan–Canada sports relations": "العلاقات الأفغانية الكندية الرياضية",
    "Afghanistan–India sports relations": "العلاقات الأفغانية الهندية الرياضية",
    "Afghanistan–Netherlands sports relations": "العلاقات الأفغانية الهولندية الرياضية",
    "Afghanistan–Pakistan sports relations": "العلاقات الأفغانية الباكستانية الرياضية",
    "Afghanistan–United Kingdom sports relations": "العلاقات الأفغانية البريطانية الرياضية",
    "Albania–Serbia sports relations": "العلاقات الألبانية الصربية الرياضية",
    "Algeria–Brunei relations": "العلاقات البرونية الجزائرية",
    "Algeria–France sports relations": "العلاقات الجزائرية الفرنسية الرياضية",
    "Argentina–Australia sports relations": "العلاقات الأرجنتينية الأسترالية الرياضية",
    "Argentina–Brazil sports relations": "العلاقات الأرجنتينية البرازيلية الرياضية",
    "Argentina–Canada sports relations": "العلاقات الأرجنتينية الكندية الرياضية",
    "Argentina–Chile sports relations": "العلاقات الأرجنتينية التشيلية الرياضية",
    "Argentina–China sports relations": "العلاقات الأرجنتينية الصينية الرياضية",
    "Argentina–Colombia sports relations": "العلاقات الأرجنتينية الكولومبية الرياضية",
    "Argentina–Costa Rica sports relations": "العلاقات الأرجنتينية الكوستاريكية الرياضية",
    "Argentina–Czech Republic sports relations": "العلاقات الأرجنتينية التشيكية الرياضية",
    "Argentina–Denmark sports relations": "العلاقات الأرجنتينية الدنماركية الرياضية",
    "Argentina–Ecuador sports relations": "العلاقات الأرجنتينية الإكوادورية الرياضية",
    "Argentina–France sports relations": "العلاقات الأرجنتينية الفرنسية الرياضية",
    "Argentina–Georgia (country) sports relations": "العلاقات الأرجنتينية الجورجية الرياضية",
    "Argentina–Germany sports relations": "العلاقات الأرجنتينية الألمانية الرياضية",
    "Argentina–Italy sports relations": "العلاقات الأرجنتينية الإيطالية الرياضية",
    "Argentina–Japan sports relations": "العلاقات الأرجنتينية اليابانية الرياضية",
    "Argentina–Mexico sports relations": "العلاقات الأرجنتينية المكسيكية الرياضية",
    "Argentina–Namibia sports relations": "العلاقات الأرجنتينية الناميبية الرياضية",
    "Argentina–Netherlands sports relations": "العلاقات الأرجنتينية الهولندية الرياضية",
    "Argentina–New Zealand sports relations": "العلاقات الأرجنتينية النيوزيلندية الرياضية",
    "Argentina–Panama sports relations": "العلاقات الأرجنتينية البنمية الرياضية",
    "Argentina–Paraguay sports relations": "العلاقات الأرجنتينية البارغوايانية الرياضية",
    "Argentina–Peru sports relations": "العلاقات الأرجنتينية البيروية الرياضية",
    "Argentina–Portugal sports relations": "العلاقات الأرجنتينية البرتغالية الرياضية",
    "Argentina–Romania sports relations": "العلاقات الأرجنتينية الرومانية الرياضية",
    "Argentina–Russia sports relations": "العلاقات الأرجنتينية الروسية الرياضية",
    "Argentina–Slovakia sports relations": "العلاقات الأرجنتينية السلوفاكية الرياضية",
    "Argentina–South Korea sports relations": "العلاقات الأرجنتينية الكورية الجنوبية الرياضية",
    "Argentina–Spain sports relations": "العلاقات الأرجنتينية الإسبانية الرياضية",
    "Argentina–Sweden sports relations": "العلاقات الأرجنتينية السويدية الرياضية",
    "Argentina–United Kingdom sports relations": "العلاقات الأرجنتينية البريطانية الرياضية",
    "Argentina–United States sports relations": "العلاقات الأرجنتينية الأمريكية الرياضية",
    "Argentina–Uruguay sports relations": "العلاقات الأرجنتينية الأوروغويانية الرياضية",
    "Argentina–Venezuela sports relations": "العلاقات الأرجنتينية الفنزويلية الرياضية",
    "Australia–Bangladesh sports relations": "العلاقات الأسترالية البنغلاديشية الرياضية",
    "Australia–Barbados sports relations": "العلاقات الأسترالية البربادوسية الرياضية",
    "Australia–Canada sports relations": "العلاقات الأسترالية الكندية الرياضية",
    "Australia–China sports relations": "العلاقات الأسترالية الصينية الرياضية",
    "Australia–France sports relations": "العلاقات الأسترالية الفرنسية الرياضية",
    "Australia–Grenada sports relations": "العلاقات الأسترالية الغرينادية الرياضية",
    "Australia–Guyana sports relations": "العلاقات الأسترالية الغيانية الرياضية",
    "Australia–Italy sports relations": "العلاقات الأسترالية الإيطالية الرياضية",
    "Australia–Jamaica sports relations": "العلاقات الأسترالية الجامايكية الرياضية",
    "Australia–Japan sports relations": "العلاقات الأسترالية اليابانية الرياضية",
    "Australia–Norway sports relations": "العلاقات الأسترالية النرويجية الرياضية",
    "Australia–Papua New Guinea sports relations": "العلاقات الأسترالية الغينية الرياضية",
    "Australia–Poland sports relations": "العلاقات الأسترالية البولندية الرياضية",
    "Australia–Samoa sports relations": "العلاقات الأسترالية الساموية الرياضية",
    "Australia–Spain sports relations": "العلاقات الأسترالية الإسبانية الرياضية",
    "Australia–Tonga sports relations": "العلاقات الأسترالية التونغانية الرياضية",
    "Australia–Trinidad and Tobago sports relations": "العلاقات الأسترالية الترنيدادية الرياضية",
    "Australia–Uganda sports relations": "العلاقات الأسترالية الأوغندية الرياضية",
    "Australia–Ukraine sports relations": "العلاقات الأسترالية الأوكرانية الرياضية",
    "Austria–Belgium sports relations": "العلاقات البلجيكية النمساوية الرياضية",
    "Austria–France sports relations": "العلاقات الفرنسية النمساوية الرياضية",
    "Austria–Germany sports relations": "العلاقات الألمانية النمساوية الرياضية",
    "Austria–Hungary sports relations": "العلاقات المجرية النمساوية الرياضية",
    "Austria–Italy sports relations": "العلاقات الإيطالية النمساوية الرياضية",
    "Austria–Norway sports relations": "العلاقات النرويجية النمساوية الرياضية",
    "Austria–Peru sports relations": "العلاقات البيروية النمساوية الرياضية",
    "Austria–Slovakia sports relations": "العلاقات السلوفاكية النمساوية الرياضية",
    "Austria–Sweden sports relations": "العلاقات السويدية النمساوية الرياضية",
    "Austria–Switzerland sports relations": "العلاقات السويسرية النمساوية الرياضية",
    "Azerbaijan–France sports relations": "العلاقات الأذربيجانية الفرنسية الرياضية",
    "Azerbaijan–Italy sports relations": "العلاقات الأذربيجانية الإيطالية الرياضية",
    "Bangladesh–New Zealand sports relations": "العلاقات البنغلاديشية النيوزيلندية الرياضية",
    "Bangladesh–Pakistan sports relations": "العلاقات الباكستانية البنغلاديشية الرياضية",
    "Bangladesh–United Kingdom sports relations": "العلاقات البريطانية البنغلاديشية الرياضية",
    "Bangladesh–Zimbabwe sports relations": "العلاقات البنغلاديشية الزيمبابوية الرياضية",
    "Barbados–India sports relations": "العلاقات البربادوسية الهندية الرياضية",
    "Barbados–United Kingdom sports relations": "العلاقات البربادوسية البريطانية الرياضية",
    "Belarus–France sports relations": "العلاقات البيلاروسية الفرنسية الرياضية",
    "Belarus–Italy sports relations": "العلاقات الإيطالية البيلاروسية الرياضية",
    "Belarus–Japan sports relations": "العلاقات البيلاروسية اليابانية الرياضية",
    "Belarus–United States sports relations": "العلاقات الأمريكية البيلاروسية الرياضية",
    "Belgium–Fiji sports relations": "العلاقات البلجيكية الفيجية الرياضية",
    "Belgium–France sports relations": "العلاقات البلجيكية الفرنسية الرياضية",
    "Belgium–Germany sports relations": "العلاقات الألمانية البلجيكية الرياضية",
    "Belgium–Hungary sports relations": "العلاقات البلجيكية المجرية الرياضية",
    "Belgium–Italy sports relations": "العلاقات الإيطالية البلجيكية الرياضية",
    "Belgium–Netherlands sports relations": "العلاقات البلجيكية الهولندية الرياضية",
    "Belgium–Portugal sports relations": "العلاقات البرتغالية البلجيكية الرياضية",
    "Belgium–Samoa sports relations": "العلاقات البلجيكية الساموية الرياضية",
    "Belgium–Slovenia sports relations": "العلاقات البلجيكية السلوفينية الرياضية",
    "Belgium–Spain sports relations": "العلاقات الإسبانية البلجيكية الرياضية",
    "Belgium–United Kingdom sports relations": "العلاقات البريطانية البلجيكية الرياضية",
    "Bolivia–Brazil sports relations": "العلاقات البرازيلية البوليفية الرياضية",
    "Bolivia–Chile sports relations": "العلاقات البوليفية التشيلية الرياضية",
    "Bolivia–Egypt sports relations": "العلاقات البوليفية المصرية الرياضية",
    "Bolivia–Panama sports relations": "العلاقات البنمية البوليفية الرياضية",
    "Bolivia–Paraguay sports relations": "العلاقات البارغوايانية البوليفية الرياضية",
    "Bolivia–Saudi Arabia sports relations": "العلاقات البوليفية السعودية الرياضية",
    "Bolivia–United States sports relations": "العلاقات الأمريكية البوليفية الرياضية",
    "Bolivia–Venezuela sports relations": "العلاقات البوليفية الفنزويلية الرياضية",
    "Bosnia and Herzegovina–Canada sports relations": "العلاقات البوسنية الكندية الرياضية",
    "Bosnia and Herzegovina–France sports relations": "العلاقات البوسنية الفرنسية الرياضية",
    "Bosnia and Herzegovina–Germany sports relations": "العلاقات الألمانية البوسنية الرياضية",
    "Bosnia and Herzegovina–Greece sports relations": "العلاقات البوسنية اليونانية الرياضية",
    "Bosnia and Herzegovina–Italy sports relations": "العلاقات الإيطالية البوسنية الرياضية",
    "Bosnia and Herzegovina–Russia sports relations": "العلاقات البوسنية الروسية الرياضية",
    "Bosnia and Herzegovina–Slovakia sports relations": "العلاقات البوسنية السلوفاكية الرياضية",
    "Botswana–Namibia sports relations": "العلاقات البوتسوانية الناميبية الرياضية",
    "Brazil–Canada sports relations": "العلاقات البرازيلية الكندية الرياضية",
    "Brazil–Croatia sports relations": "العلاقات البرازيلية الكرواتية الرياضية",
    "Brazil–Cuba sports relations": "العلاقات البرازيلية الكوبية الرياضية",
    "Brazil–Ecuador sports relations": "العلاقات الإكوادورية البرازيلية الرياضية",
    "Brazil–France sports relations": "العلاقات البرازيلية الفرنسية الرياضية",
    "Brazil–Germany sports relations": "العلاقات الألمانية البرازيلية الرياضية",
    "Brazil–Hungary sports relations": "العلاقات البرازيلية المجرية الرياضية",
    "Brazil–Italy sports relations": "العلاقات الإيطالية البرازيلية الرياضية",
    "Brazil–Mexico sports relations": "العلاقات البرازيلية المكسيكية الرياضية",
    "Brazil–Netherlands sports relations": "العلاقات البرازيلية الهولندية الرياضية",
    "Brazil–Paraguay sports relations": "العلاقات البارغوايانية البرازيلية الرياضية",
    "Brazil–Peru sports relations": "العلاقات البرازيلية البيروية الرياضية",
    "Brazil–Poland sports relations": "العلاقات البرازيلية البولندية الرياضية",
    "Brazil–Portugal sports relations": "العلاقات البرازيلية البرتغالية الرياضية",
    "Brazil–Slovakia sports relations": "العلاقات البرازيلية السلوفاكية الرياضية",
    "Brazil–Spain sports relations": "العلاقات الإسبانية البرازيلية الرياضية",
    "Brazil–Sweden sports relations": "العلاقات البرازيلية السويدية الرياضية",
    "Brazil–United Kingdom sports relations": "العلاقات البرازيلية البريطانية الرياضية",
    "Brazil–Uruguay sports relations": "العلاقات الأوروغويانية البرازيلية الرياضية",
    "Brazil–Venezuela sports relations": "العلاقات البرازيلية الفنزويلية الرياضية",
    "Brunei–Indonesia relations": "العلاقات الإندونيسية البرونية",
    "Brunei–Jordan relations": "العلاقات الأردنية البرونية",
    "Brunei–Malaysia relations": "العلاقات البرونية الماليزية",
    "Brunei–Maldives relations": "العلاقات البرونية المالديفية",
    "Brunei–Netherlands relations": "العلاقات البرونية الهولندية",
    "Brunei–Pakistan relations": "العلاقات الباكستانية البرونية",
    "Brunei–Philippines relations": "العلاقات البرونية الفلبينية",
    "Brunei–Poland relations": "العلاقات البرونية البولندية",
    "Brunei–Singapore relations": "العلاقات البرونية السنغافورية",
    "Brunei–South Korea relations": "العلاقات البرونية الكورية الجنوبية",
    "Bulgaria–Finland sports relations": "العلاقات البلغارية الفنلندية الرياضية",
    "Bulgaria–Greece sports relations": "العلاقات البلغارية اليونانية الرياضية",
    "Bulgaria–Italy sports relations": "العلاقات الإيطالية البلغارية الرياضية",
    "Bulgaria–North Macedonia sports relations": "العلاقات البلغارية المقدونية الشمالية الرياضية",
    "Bulgaria–Serbia sports relations": "العلاقات البلغارية الصربية الرياضية",
    "Bulgaria–United Kingdom sports relations": "العلاقات البريطانية البلغارية الرياضية",
    "Cameroon–France sports relations": "العلاقات الفرنسية الكاميرونية الرياضية",
    "Canada–Chile sports relations": "العلاقات التشيلية الكندية الرياضية",
    "Canada–Colombia sports relations": "العلاقات الكندية الكولومبية الرياضية",
    "Canada–Fiji sports relations": "العلاقات الفيجية الكندية الرياضية",
    "Canada–Finland sports relations": "العلاقات الفنلندية الكندية الرياضية",
    "Canada–Greece sports relations": "العلاقات الكندية اليونانية الرياضية",
    "Canada–Italy sports relations": "العلاقات الإيطالية الكندية الرياضية",
    "Canada–Jamaica sports relations": "العلاقات الجامايكية الكندية الرياضية",
    "Canada–Japan sports relations": "العلاقات الكندية اليابانية الرياضية",
    "Canada–Kenya sports relations": "العلاقات الكندية الكينية الرياضية",
    "Canada–Latvia sports relations": "العلاقات الكندية اللاتفية الرياضية",
    "Canada–Mexico sports relations": "العلاقات الكندية المكسيكية الرياضية",
    "Canada–Netherlands sports relations": "العلاقات الكندية الهولندية الرياضية",
    "Canada–Panama sports relations": "العلاقات البنمية الكندية الرياضية",
    "Canada–Poland sports relations": "العلاقات البولندية الكندية الرياضية",
    "Canada–Romania sports relations": "العلاقات الرومانية الكندية الرياضية",
    "Canada–Slovakia sports relations": "العلاقات السلوفاكية الكندية الرياضية",
    "Canada–Spain sports relations": "العلاقات الإسبانية الكندية الرياضية",
    "Canada–Sweden sports relations": "العلاقات السويدية الكندية الرياضية",
    "Canada–United States sports relations": "العلاقات الأمريكية الكندية الرياضية",
    "Canada–Uruguay sports relations": "العلاقات الأوروغويانية الكندية الرياضية",
    "Canada–Venezuela sports relations": "العلاقات الفنزويلية الكندية الرياضية",
    "Chile–Colombia sports relations": "العلاقات التشيلية الكولومبية الرياضية",
    "Chile–Ecuador sports relations": "العلاقات الإكوادورية التشيلية الرياضية",
    "Chile–Fiji sports relations": "العلاقات التشيلية الفيجية الرياضية",
    "Chile–Germany sports relations": "العلاقات الألمانية التشيلية الرياضية",
    "Chile–Italy sports relations": "العلاقات الإيطالية التشيلية الرياضية",
    "Chile–Mexico sports relations": "العلاقات التشيلية المكسيكية الرياضية",
    "Chile–Netherlands sports relations": "العلاقات التشيلية الهولندية الرياضية",
    "Chile–Panama sports relations": "العلاقات البنمية التشيلية الرياضية",
    "Chile–Paraguay sports relations": "العلاقات البارغوايانية التشيلية الرياضية",
    "Chile–Peru sports relations": "العلاقات البيروية التشيلية الرياضية",
    "Chile–Uruguay sports relations": "العلاقات الأوروغويانية التشيلية الرياضية",
    "China–Fiji sports relations": "العلاقات الصينية الفيجية الرياضية",
    "China–France sports relations": "العلاقات الصينية الفرنسية الرياضية",
    "China–Greece sports relations": "العلاقات الصينية اليونانية الرياضية",
    "China–Italy sports relations": "العلاقات الإيطالية الصينية الرياضية",
    "China–Slovakia sports relations": "العلاقات السلوفاكية الصينية الرياضية",
    "China–South Korea sports relations": "العلاقات الصينية الكورية الجنوبية الرياضية",
    "Colombia–Costa Rica sports relations": "العلاقات الكوستاريكية الكولومبية الرياضية",
    "Colombia–Italy sports relations": "العلاقات الإيطالية الكولومبية الرياضية",
    "Colombia–Japan sports relations": "العلاقات الكولومبية اليابانية الرياضية",
    "Colombia–Panama sports relations": "العلاقات البنمية الكولومبية الرياضية",
    "Colombia–Peru sports relations": "العلاقات البيروية الكولومبية الرياضية",
    "Colombia–Portugal sports relations": "العلاقات البرتغالية الكولومبية الرياضية",
    "Colombia–Spain sports relations": "العلاقات الإسبانية الكولومبية الرياضية",
    "Colombia–Uruguay sports relations": "العلاقات الأوروغويانية الكولومبية الرياضية",
    "Colombia–Venezuela sports relations": "العلاقات الفنزويلية الكولومبية الرياضية",
    "Costa Rica–Honduras sports relations": "العلاقات الكوستاريكية الهندوراسية الرياضية",
    "Costa Rica–Mexico sports relations": "العلاقات الكوستاريكية المكسيكية الرياضية",
    "Costa Rica–Paraguay sports relations": "العلاقات البارغوايانية الكوستاريكية الرياضية",
    "Croatia–Denmark sports relations": "العلاقات الدنماركية الكرواتية الرياضية",
    "Croatia–Hungary sports relations": "العلاقات الكرواتية المجرية الرياضية",
    "Croatia–Italy sports relations": "العلاقات الإيطالية الكرواتية الرياضية",
    "Croatia–Netherlands sports relations": "العلاقات الكرواتية الهولندية الرياضية",
    "Croatia–Norway sports relations": "العلاقات الكرواتية النرويجية الرياضية",
    "Croatia–Romania sports relations": "العلاقات الرومانية الكرواتية الرياضية",
    "Croatia–Russia sports relations": "العلاقات الروسية الكرواتية الرياضية",
    "Croatia–United Kingdom sports relations": "العلاقات البريطانية الكرواتية الرياضية",
    "Cuba–Japan sports relations": "العلاقات الكوبية اليابانية الرياضية",
    "Cuba–Mexico sports relations": "العلاقات الكوبية المكسيكية الرياضية",
    "Cuba–Nicaragua sports relations": "العلاقات الكوبية النيكاراغوية الرياضية",
    "Cuba–United States sports relations": "العلاقات الأمريكية الكوبية الرياضية",
    "Cuba–Venezuela sports relations": "العلاقات الفنزويلية الكوبية الرياضية",
    "Czech Republic–Denmark sports relations": "العلاقات التشيكية الدنماركية الرياضية",
    "Czech Republic–Finland sports relations": "العلاقات التشيكية الفنلندية الرياضية",
    "Czech Republic–Greece sports relations": "العلاقات التشيكية اليونانية الرياضية",
    "Czech Republic–Hungary sports relations": "العلاقات التشيكية المجرية الرياضية",
    "Czech Republic–Poland sports relations": "العلاقات البولندية التشيكية الرياضية",
    "Czech Republic–Portugal sports relations": "العلاقات البرتغالية التشيكية الرياضية",
    "Czech Republic–Romania sports relations": "العلاقات التشيكية الرومانية الرياضية",
    "Czech Republic–Serbia sports relations": "العلاقات التشيكية الصربية الرياضية",
    "Czech Republic–Slovakia sports relations": "العلاقات التشيكية السلوفاكية الرياضية",
    "Czech Republic–Switzerland sports relations": "العلاقات التشيكية السويسرية الرياضية",
    "Czech Republic–Turkey sports relations": "العلاقات التركية التشيكية الرياضية",
    "Denmark–Finland sports relations": "العلاقات الدنماركية الفنلندية الرياضية",
    "Denmark–Greece sports relations": "العلاقات الدنماركية اليونانية الرياضية",
    "Denmark–Iceland sports relations": "العلاقات الآيسلندية الدنماركية الرياضية",
    "Denmark–Netherlands sports relations": "العلاقات الدنماركية الهولندية الرياضية",
    "Denmark–Norway sports relations": "العلاقات الدنماركية النرويجية الرياضية",
    "Denmark–Poland sports relations": "العلاقات البولندية الدنماركية الرياضية",
    "Denmark–Slovakia sports relations": "العلاقات الدنماركية السلوفاكية الرياضية",
    "Denmark–Sweden sports relations": "العلاقات الدنماركية السويدية الرياضية",
    "Dominican Republic–Mexico sports relations": "العلاقات الدومينيكانية المكسيكية الرياضية",
    "Dominican Republic–Panama sports relations": "العلاقات البنمية الدومينيكانية الرياضية",
    "Dominican Republic–Venezuela sports relations": "العلاقات الدومينيكانية الفنزويلية الرياضية",
    "Ecuador–Haiti sports relations": "العلاقات الإكوادورية الهايتية الرياضية",
    "Ecuador–Jamaica sports relations": "العلاقات الإكوادورية الجامايكية الرياضية",
    "Ecuador–Mexico sports relations": "العلاقات الإكوادورية المكسيكية الرياضية",
    "Ecuador–Peru sports relations": "العلاقات الإكوادورية البيروية الرياضية",
    "Ecuador–United States sports relations": "العلاقات الأمريكية الإكوادورية الرياضية",
    "Ecuador–Venezuela sports relations": "العلاقات الإكوادورية الفنزويلية الرياضية",
    "Egypt–Hungary sports relations": "العلاقات المجرية المصرية الرياضية",
    "Egypt–Mexico sports relations": "العلاقات المصرية المكسيكية الرياضية",
    "El Salvador–Guatemala sports relations": "العلاقات السلفادورية الغواتيمالية الرياضية",
    "El Salvador–Honduras sports relations": "العلاقات السلفادورية الهندوراسية الرياضية",
    "El Salvador–Hungary sports relations": "العلاقات السلفادورية المجرية الرياضية",
    "El Salvador–Uruguay sports relations": "العلاقات الأوروغويانية السلفادورية الرياضية",
    "Estonia–Finland sports relations": "العلاقات الإستونية الفنلندية الرياضية",
    "Estonia–Latvia sports relations": "العلاقات الإستونية اللاتفية الرياضية",
    "Estonia–Lithuania sports relations": "العلاقات الإستونية الليتوانية الرياضية",
    "Estonia–Poland sports relations": "العلاقات الإستونية البولندية الرياضية",
    "Estonia–Ukraine sports relations": "العلاقات الأوكرانية الإستونية الرياضية",
    "Fiji–France sports relations": "العلاقات الفرنسية الفيجية الرياضية",
    "Fiji–Japan sports relations": "العلاقات الفيجية اليابانية الرياضية",
    "Fiji–Portugal sports relations": "العلاقات البرتغالية الفيجية الرياضية",
    "Fiji–United Kingdom sports relations": "العلاقات البريطانية الفيجية الرياضية",
    "Fiji–United States sports relations": "العلاقات الأمريكية الفيجية الرياضية",
    "Fiji–Uruguay sports relations": "العلاقات الأوروغويانية الفيجية الرياضية",
    "Finland–Germany sports relations": "العلاقات الألمانية الفنلندية الرياضية",
    "Finland–Iceland sports relations": "العلاقات الآيسلندية الفنلندية الرياضية",
    "Finland–Italy sports relations": "العلاقات الإيطالية الفنلندية الرياضية",
    "Finland–Latvia sports relations": "العلاقات الفنلندية اللاتفية الرياضية",
    "Finland–Lithuania sports relations": "العلاقات الفنلندية الليتوانية الرياضية",
    "Finland–Norway sports relations": "العلاقات الفنلندية النرويجية الرياضية",
    "Finland–Poland sports relations": "العلاقات البولندية الفنلندية الرياضية",
    "Finland–Romania sports relations": "العلاقات الرومانية الفنلندية الرياضية",
    "Finland–Russia sports relations": "العلاقات الروسية الفنلندية الرياضية",
    "Finland–Sweden sports relations": "العلاقات السويدية الفنلندية الرياضية",
    "Finland–Switzerland sports relations": "العلاقات السويسرية الفنلندية الرياضية",
    "Finland–United States sports relations": "العلاقات الأمريكية الفنلندية الرياضية",
    "France–Kazakhstan sports relations": "العلاقات الفرنسية الكازاخستانية الرياضية",
    "France–Lithuania sports relations": "العلاقات الفرنسية الليتوانية الرياضية",
    "France–Paraguay sports relations": "العلاقات البارغوايانية الفرنسية الرياضية",
    "France–Portugal sports relations": "العلاقات البرتغالية الفرنسية الرياضية",
    "France–Romania sports relations": "العلاقات الرومانية الفرنسية الرياضية",
    "France–Samoa sports relations": "العلاقات الساموية الفرنسية الرياضية",
    "France–Slovakia sports relations": "العلاقات السلوفاكية الفرنسية الرياضية",
    "France–Slovenia sports relations": "العلاقات السلوفينية الفرنسية الرياضية",
    "France–Tonga sports relations": "العلاقات التونغانية الفرنسية الرياضية",
    "France–Ukraine sports relations": "العلاقات الأوكرانية الفرنسية الرياضية",
    "France–Uruguay sports relations": "العلاقات الأوروغويانية الفرنسية الرياضية",
    "France–Uzbekistan sports relations": "العلاقات الأوزبكستانية الفرنسية الرياضية",
    "France–Zimbabwe sports relations": "العلاقات الزيمبابوية الفرنسية الرياضية",
    "Georgia (country)–Germany sports relations": "العلاقات الألمانية الجورجية الرياضية",
    "Georgia (country)–Italy sports relations": "العلاقات الإيطالية الجورجية الرياضية",
    "Georgia (country)–Namibia sports relations": "العلاقات الجورجية الناميبية الرياضية",
    "Georgia (country)–Romania sports relations": "العلاقات الجورجية الرومانية الرياضية",
    "Georgia (country)–Russia sports relations": "العلاقات الجورجية الروسية الرياضية",
    "Georgia (country)–Spain sports relations": "العلاقات الإسبانية الجورجية الرياضية",
    "Georgia (country)–United Kingdom sports relations": "العلاقات البريطانية الجورجية الرياضية",
    "Georgia (country)–Uruguay sports relations": "العلاقات الأوروغويانية الجورجية الرياضية",
    "Germany–Greece sports relations": "العلاقات الألمانية اليونانية الرياضية",
    "Germany–Hungary sports relations": "العلاقات الألمانية المجرية الرياضية",
    "Germany–Netherlands sports relations": "العلاقات الألمانية الهولندية الرياضية",
    "Germany–Norway sports relations": "العلاقات الألمانية النرويجية الرياضية",
    "Germany–Poland sports relations": "العلاقات الألمانية البولندية الرياضية",
    "Germany–Portugal sports relations": "العلاقات الألمانية البرتغالية الرياضية",
    "Germany–Samoa sports relations": "العلاقات الألمانية الساموية الرياضية",
    "Germany–Slovakia sports relations": "العلاقات الألمانية السلوفاكية الرياضية",
    "Germany–Switzerland sports relations": "العلاقات الألمانية السويسرية الرياضية",
    "Germany–United Kingdom sports relations": "العلاقات الألمانية البريطانية الرياضية",
    "Greece–Netherlands sports relations": "العلاقات الهولندية اليونانية الرياضية",
    "Greece–Portugal sports relations": "العلاقات البرتغالية اليونانية الرياضية",
    "Greece–Romania sports relations": "العلاقات الرومانية اليونانية الرياضية",
    "Greece–Serbia sports relations": "العلاقات الصربية اليونانية الرياضية",
    "Greece–Slovakia sports relations": "العلاقات السلوفاكية اليونانية الرياضية",
    "Greece–Uruguay sports relations": "العلاقات الأوروغويانية اليونانية الرياضية",
    "Guatemala–Mexico sports relations": "العلاقات الغواتيمالية المكسيكية الرياضية",
    "Guyana–India sports relations": "العلاقات الغيانية الهندية الرياضية",
    "Guyana–United Kingdom sports relations": "العلاقات البريطانية الغيانية الرياضية",
    "Honduras–United States sports relations": "العلاقات الأمريكية الهندوراسية الرياضية",
    "Hungary–Italy sports relations": "العلاقات الإيطالية المجرية الرياضية",
    "Hungary–Poland sports relations": "العلاقات البولندية المجرية الرياضية",
    "Hungary–Portugal sports relations": "العلاقات البرتغالية المجرية الرياضية",
    "Hungary–Romania sports relations": "العلاقات الرومانية المجرية الرياضية",
    "Hungary–Russia sports relations": "العلاقات الروسية المجرية الرياضية",
    "Hungary–Slovakia sports relations": "العلاقات السلوفاكية المجرية الرياضية",
    "Hungary–Spain sports relations": "العلاقات الإسبانية المجرية الرياضية",
    "Hungary–Switzerland sports relations": "العلاقات السويسرية المجرية الرياضية",
    "Hungary–Ukraine sports relations": "العلاقات الأوكرانية المجرية الرياضية",
    "Iceland–Norway sports relations": "العلاقات الآيسلندية النرويجية الرياضية",
    "Iceland–Sweden sports relations": "العلاقات الآيسلندية السويدية الرياضية",
    "India–Jamaica sports relations": "العلاقات الجامايكية الهندية الرياضية",
    "India–Nepal sports relations": "العلاقات النيبالية الهندية الرياضية",
    "India–Trinidad and Tobago sports relations": "العلاقات الترنيدادية الهندية الرياضية",
    "India–Zimbabwe sports relations": "العلاقات الزيمبابوية الهندية الرياضية",
    "Italy–Lithuania sports relations": "العلاقات الإيطالية الليتوانية الرياضية",
    "Italy–Malta sports relations": "العلاقات الإيطالية المالطية الرياضية",
    "Italy–Montenegro sports relations": "العلاقات الإيطالية المونتينيغرية الرياضية",
    "Italy–Namibia sports relations": "العلاقات الإيطالية الناميبية الرياضية",
    "Italy–North Macedonia sports relations": "العلاقات الإيطالية المقدونية الشمالية الرياضية",
    "Italy–Norway sports relations": "العلاقات الإيطالية النرويجية الرياضية",
    "Italy–Paraguay sports relations": "العلاقات الإيطالية البارغوايانية الرياضية",
    "Italy–Poland sports relations": "العلاقات الإيطالية البولندية الرياضية",
    "Italy–Romania sports relations": "العلاقات الإيطالية الرومانية الرياضية",
    "Italy–Samoa sports relations": "العلاقات الإيطالية الساموية الرياضية",
    "Italy–Serbia sports relations": "العلاقات الإيطالية الصربية الرياضية",
    "Italy–Slovakia sports relations": "العلاقات الإيطالية السلوفاكية الرياضية",
    "Italy–Slovenia sports relations": "العلاقات الإيطالية السلوفينية الرياضية",
    "Italy–Switzerland sports relations": "العلاقات الإيطالية السويسرية الرياضية",
    "Italy–Tonga sports relations": "العلاقات الإيطالية التونغانية الرياضية",
    "Italy–Uruguay sports relations": "العلاقات الأوروغويانية الإيطالية الرياضية",
    "Italy–Zimbabwe sports relations": "العلاقات الإيطالية الزيمبابوية الرياضية",
    "Jamaica–Mexico sports relations": "العلاقات الجامايكية المكسيكية الرياضية",
    "Jamaica–New Zealand sports relations": "العلاقات الجامايكية النيوزيلندية الرياضية",
    "Jamaica–Panama sports relations": "العلاقات البنمية الجامايكية الرياضية",
    "Jamaica–United Kingdom sports relations": "العلاقات البريطانية الجامايكية الرياضية",
    "Jamaica–United States sports relations": "العلاقات الأمريكية الجامايكية الرياضية",
    "Jamaica–Uruguay sports relations": "العلاقات الأوروغويانية الجامايكية الرياضية",
    "Jamaica–Venezuela sports relations": "العلاقات الجامايكية الفنزويلية الرياضية",
    "Japan–New Zealand sports relations": "العلاقات النيوزيلندية اليابانية الرياضية",
    "Japan–Romania sports relations": "العلاقات الرومانية اليابانية الرياضية",
    "Japan–Slovenia sports relations": "العلاقات السلوفينية اليابانية الرياضية",
    "Japan–Tonga sports relations": "العلاقات التونغانية اليابانية الرياضية",
    "Kenya–Namibia sports relations": "العلاقات الكينية الناميبية الرياضية",
    "Kenya–Tanzania sports relations": "العلاقات التنزانية الكينية الرياضية",
    "Kenya–Uganda sports relations": "العلاقات الأوغندية الكينية الرياضية",
    "Kenya–United Kingdom sports relations": "العلاقات البريطانية الكينية الرياضية",
    "Kenya–Zimbabwe sports relations": "العلاقات الزيمبابوية الكينية الرياضية",
    "Latvia–Lithuania sports relations": "العلاقات اللاتفية الليتوانية الرياضية",
    "Latvia–Slovenia sports relations": "العلاقات السلوفينية اللاتفية الرياضية",
    "Latvia–United States sports relations": "العلاقات الأمريكية اللاتفية الرياضية",
    "Lithuania–Slovenia sports relations": "العلاقات السلوفينية الليتوانية الرياضية",
    "Lithuania–Spain sports relations": "العلاقات الإسبانية الليتوانية الرياضية",
    "Luxembourg–United Kingdom sports relations": "العلاقات البريطانية اللوكسمبورغية الرياضية",
    "Malaysia–Singapore sports relations": "العلاقات السنغافورية الماليزية الرياضية",
    "Mexico–Panama sports relations": "العلاقات البنمية المكسيكية الرياضية",
    "Mexico–Paraguay sports relations": "العلاقات البارغوايانية المكسيكية الرياضية",
    "Mexico–United States sports relations": "العلاقات الأمريكية المكسيكية الرياضية",
    "Mexico–Venezuela sports relations": "العلاقات الفنزويلية المكسيكية الرياضية",
    "Montenegro–North Macedonia sports relations": "العلاقات المقدونية الشمالية المونتينيغرية الرياضية",
    "Montenegro–Russia sports relations": "العلاقات الروسية المونتينيغرية الرياضية",
    "Montenegro–Slovenia sports relations": "العلاقات السلوفينية المونتينيغرية الرياضية",
    "Montenegro–United States sports relations": "العلاقات الأمريكية المونتينيغرية الرياضية",
    "Namibia–Portugal sports relations": "العلاقات البرتغالية الناميبية الرياضية",
    "Namibia–Romania sports relations": "العلاقات الرومانية الناميبية الرياضية",
    "Namibia–Russia sports relations": "العلاقات الروسية الناميبية الرياضية",
    "Namibia–Spain sports relations": "العلاقات الإسبانية الناميبية الرياضية",
    "Namibia–Tonga sports relations": "العلاقات التونغانية الناميبية الرياضية",
    "Namibia–United Kingdom sports relations": "العلاقات البريطانية الناميبية الرياضية",
    "Namibia–Uruguay sports relations": "العلاقات الأوروغويانية الناميبية الرياضية",
    "Namibia–Zimbabwe sports relations": "العلاقات الزيمبابوية الناميبية الرياضية",
    "Netherlands–Peru sports relations": "العلاقات البيروية الهولندية الرياضية",
    "Netherlands–Qatar sports relations": "العلاقات القطرية الهولندية الرياضية",
    "Netherlands–Slovakia sports relations": "العلاقات السلوفاكية الهولندية الرياضية",
    "Netherlands–Slovenia sports relations": "العلاقات السلوفينية الهولندية الرياضية",
    "Netherlands–Uruguay sports relations": "العلاقات الأوروغويانية الهولندية الرياضية",
    "New Zealand–Papua New Guinea sports relations": "العلاقات الغينية النيوزيلندية الرياضية",
    "New Zealand–Romania sports relations": "العلاقات الرومانية النيوزيلندية الرياضية",
    "New Zealand–Samoa sports relations": "العلاقات الساموية النيوزيلندية الرياضية",
    "New Zealand–Tonga sports relations": "العلاقات التونغانية النيوزيلندية الرياضية",
    "New Zealand–Uganda sports relations": "العلاقات الأوغندية النيوزيلندية الرياضية",
    "New Zealand–Zimbabwe sports relations": "العلاقات الزيمبابوية النيوزيلندية الرياضية",
    "North Macedonia–Slovenia sports relations": "العلاقات السلوفينية المقدونية الشمالية الرياضية",
    "Oman–United Arab Emirates sports relations": "العلاقات الإماراتية العمانية الرياضية",
    "Panama–Peru sports relations": "العلاقات البنمية البيروية الرياضية",
    "Panama–United States sports relations": "العلاقات الأمريكية البنمية الرياضية",
    "Panama–Uruguay sports relations": "العلاقات الأوروغويانية البنمية الرياضية",
    "Paraguay–Portugal sports relations": "العلاقات البارغوايانية البرتغالية الرياضية",
    "Paraguay–Spain sports relations": "العلاقات الإسبانية البارغوايانية الرياضية",
    "Paraguay–United Kingdom sports relations": "العلاقات البارغوايانية البريطانية الرياضية",
    "Paraguay–Uruguay sports relations": "العلاقات الأوروغويانية البارغوايانية الرياضية",
    "Paraguay–Venezuela sports relations": "العلاقات البارغوايانية الفنزويلية الرياضية",
    "Peru–Romania sports relations": "العلاقات البيروية الرومانية الرياضية",
    "Peru–Uruguay sports relations": "العلاقات الأوروغويانية البيروية الرياضية",
    "Peru–Venezuela sports relations": "العلاقات البيروية الفنزويلية الرياضية",
    "Poland–Slovenia sports relations": "العلاقات البولندية السلوفينية الرياضية",
    "Poland–Sweden sports relations": "العلاقات البولندية السويدية الرياضية",
    "Portugal–Uruguay sports relations": "العلاقات الأوروغويانية البرتغالية الرياضية",
    "Romania–Russia sports relations": "العلاقات الروسية الرومانية الرياضية",
    "Romania–Samoa sports relations": "العلاقات الرومانية الساموية الرياضية",
    "Romania–Slovakia sports relations": "العلاقات الرومانية السلوفاكية الرياضية",
    "Romania–United States sports relations": "العلاقات الأمريكية الرومانية الرياضية",
    "Romania–Uruguay sports relations": "العلاقات الأوروغويانية الرومانية الرياضية",
    "Russia–Slovakia sports relations": "العلاقات الروسية السلوفاكية الرياضية",
    "Russia–Turkey sports relations": "العلاقات التركية الروسية الرياضية",
    "Russia–Uruguay sports relations": "العلاقات الأوروغويانية الروسية الرياضية",
    "Samoa–United Kingdom sports relations": "العلاقات البريطانية الساموية الرياضية",
    "Serbia–Slovakia sports relations": "العلاقات السلوفاكية الصربية الرياضية",
    "Serbia–Slovenia sports relations": "العلاقات السلوفينية الصربية الرياضية",
    "Slovakia–Spain sports relations": "العلاقات الإسبانية السلوفاكية الرياضية",
    "Slovakia–Switzerland sports relations": "العلاقات السلوفاكية السويسرية الرياضية",
    "Slovakia–Turkey sports relations": "العلاقات التركية السلوفاكية الرياضية",
    "Slovakia–Ukraine sports relations": "العلاقات الأوكرانية السلوفاكية الرياضية",
    "Slovakia–United Kingdom sports relations": "العلاقات البريطانية السلوفاكية الرياضية",
    "Slovenia–South Korea sports relations": "العلاقات السلوفينية الكورية الجنوبية الرياضية",
    "South Korea–Venezuela sports relations": "العلاقات الفنزويلية الكورية الجنوبية الرياضية",
    "Spain–Uruguay sports relations": "العلاقات الأوروغويانية الإسبانية الرياضية",
    "Suriname–United States sports relations": "العلاقات الأمريكية السورينامية الرياضية",
    "Tanzania–Uganda sports relations": "العلاقات الأوغندية التنزانية الرياضية",
    "Tanzania–United Kingdom sports relations": "العلاقات البريطانية التنزانية الرياضية",
    "Tonga–United Kingdom sports relations": "العلاقات البريطانية التونغانية الرياضية",
    "Tonga–Zimbabwe sports relations": "العلاقات التونغانية الزيمبابوية الرياضية",
    "Trinidad and Tobago–United Kingdom sports relations": "العلاقات البريطانية الترنيدادية الرياضية",
    "Trinidad and Tobago–United States sports relations": "العلاقات الأمريكية الترنيدادية الرياضية",
    "Tunisia–United Kingdom sports relations": "العلاقات البريطانية التونسية الرياضية",
    "Uganda–United Kingdom sports relations": "العلاقات الأوغندية البريطانية الرياضية",
    "United Arab Emirates–Zimbabwe sports relations": "العلاقات الإماراتية الزيمبابوية الرياضية",
    "United Kingdom–Uruguay sports relations": "العلاقات الأوروغويانية البريطانية الرياضية",
    "United Kingdom–Zambia sports relations": "العلاقات البريطانية الزامبية الرياضية",
    "United Kingdom–Zimbabwe sports relations": "العلاقات البريطانية الزيمبابوية الرياضية",
    "United States–Uruguay sports relations": "العلاقات الأمريكية الأوروغويانية الرياضية",
    "United States–Venezuela sports relations": "العلاقات الأمريكية الفنزويلية الرياضية",
}

test_data = {
    "ireland–spain military relations": "العلاقات الأيرلندية الإسبانية العسكرية",
    "ireland–united kingdom military relations": "العلاقات الأيرلندية البريطانية العسكرية",
    "iran–iraq war films": "أفلام الحرب الإيرانية العراقية",
    "mexican–american war films": "أفلام الحرب الأمريكية المكسيكية",
    "soviet–afghan war films": "أفلام الحرب الأفغانية السوفيتية",
    "soviet–afghan war video games": "ألعاب فيديو الحرب الأفغانية السوفيتية",
    "spanish–american war films": "أفلام الحرب الأمريكية الإسبانية",
}


@pytest.mark.parametrize("category, expected", big_data.items(), ids=big_data.keys())
@pytest.mark.slow
def test_relations_big_data(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data.items(), ids=test_data.keys())
@pytest.mark.fast
def test_work_relations_female(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


@pytest.mark.unit
def test_burma_cambodia_relations_from_country_table() -> None:
    """Female 'relations' using countries_nat_en_key women demonyms."""
    value = "burma-cambodia relations"
    result = new_relations_resolvers(value)
    assert result == "العلاقات البورمية الكمبودية"


@pytest.mark.unit
def test_burundi_canada_military_relations() -> None:
    """Female 'military relations' with two countries from country table."""
    value = "burundi-canada military relations"
    result = new_relations_resolvers(value)
    # بوروندية + كندية
    assert result == "العلاقات البوروندية الكندية العسكرية"


@pytest.mark.unit
def test_nat_women_fallback_for_singapore_luxembourg() -> None:
    """Female 'relations' using Nat_women fallback (no entry in main country table)."""
    value = "singapore-luxembourg relations"
    result = new_relations_resolvers(value)
    # سنغافورية + لوكسمبورغية
    assert result == "العلاقات السنغافورية اللوكسمبورغية"


@pytest.mark.unit
def test_dash_variants_en_dash() -> None:
    """Relations using en dash instead of hyphen."""
    value = "burma–cambodia relations"
    result = new_relations_resolvers(value)
    assert result == "العلاقات البورمية الكمبودية"


@pytest.mark.unit
def test_dash_variants_minus_sign() -> None:
    """Relations using minus sign instead of hyphen."""
    value = "burma−cambodia relations"
    result = new_relations_resolvers(value)
    assert result == "العلاقات البورمية الكمبودية"


def test_nato_relations_special_case() -> None:
    """Special-case NATO handling for plain 'relations'."""
    value = "nato-afghanistan relations"
    result = new_relations_resolvers(value)
    # Uses hard-coded "الناتو" plus country label
    assert result == "علاقات أفغانستان والناتو"


@pytest.mark.unit
def test_female_suffix_not_matched_returns_empty() -> None:
    """No recognized female or male suffix should return empty string."""
    value = "burma-cambodia partnership"
    result = new_relations_resolvers(value)
    assert result == ""
