import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.relations_resolver import new_relations_resolvers

test_same = {
    "angola–seychelles relations": "العلاقات الأنغولية السيشلية",
    "australia–seychelles relations": "العلاقات الأسترالية السيشلية",
    "bangladesh–seychelles relations": "العلاقات البنغلاديشية السيشلية",
    "belgium–seychelles relations": "العلاقات البلجيكية السيشلية",
    "burundi–seychelles relations": "العلاقات البوروندية السيشلية",
    "canada–seychelles relations": "العلاقات السيشلية الكندية",
    "china–seychelles relations": "العلاقات السيشلية الصينية",
    "cuba–seychelles relations": "العلاقات السيشلية الكوبية",
    "ethiopia–seychelles relations": "العلاقات الإثيوبية السيشلية",
    "france–seychelles relations": "العلاقات السيشلية الفرنسية",
    "germany–seychelles relations": "العلاقات الألمانية السيشلية",
    "ghana–seychelles relations": "العلاقات السيشلية الغانية",
    "india–seychelles relations": "العلاقات السيشلية الهندية",
    "israel–seychelles relations": "العلاقات الإسرائيلية السيشلية",
    "italy–seychelles relations": "العلاقات الإيطالية السيشلية",
    "japan–seychelles relations": "العلاقات السيشلية اليابانية",
    "kenya–seychelles relations": "العلاقات السيشلية الكينية",
    "lesotho–seychelles relations": "العلاقات السيشلية الليسوتية",
    "luxembourg–seychelles relations": "العلاقات السيشلية اللوكسمبورغية",
    "madagascar–seychelles relations": "العلاقات السيشلية المدغشقرية",
    "malaysia–seychelles relations": "العلاقات السيشلية الماليزية",
    "mauritius–seychelles relations": "العلاقات السيشلية الموريشيوسية",
    "norway–seychelles relations": "العلاقات السيشلية النرويجية",
    "pakistan–seychelles relations": "العلاقات الباكستانية السيشلية",
    "palestine–seychelles relations": "العلاقات السيشلية الفلسطينية",
    "poland–seychelles relations": "العلاقات البولندية السيشلية",
    "russia–seychelles relations": "العلاقات الروسية السيشلية",
    "seychelles–south korea relations": "العلاقات السيشلية الكورية الجنوبية",
    "seychelles–sri lanka relations": "العلاقات السريلانكية السيشلية",
    "seychelles–sweden relations": "العلاقات السويدية السيشلية",
    "seychelles–tanzania relations": "العلاقات التنزانية السيشلية",
    "seychelles–uganda relations": "العلاقات الأوغندية السيشلية",
    "seychelles–united kingdom relations": "العلاقات البريطانية السيشلية",
    "seychelles–united states relations": "العلاقات الأمريكية السيشلية",
    "seychelles–yemen relations": "العلاقات السيشلية اليمنية",
    "antigua and barbuda–saint vincent and grenadines relations": "علاقات أنتيغوا وباربودا وسانت فنسنت وجزر غرينادين",
    "barbados–saint vincent and grenadines relations": "علاقات بربادوس وسانت فنسنت وجزر غرينادين",
    "belize–saint vincent and grenadines relations": "علاقات بليز وسانت فنسنت وجزر غرينادين",
    "canada–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وكندا",
    "chile–saint vincent and grenadines relations": "علاقات تشيلي وسانت فنسنت وجزر غرينادين",
    "china–saint vincent and grenadines relations": "علاقات الصين وسانت فنسنت وجزر غرينادين",
    "czech republic–saint vincent and grenadines relations": "علاقات التشيك وسانت فنسنت وجزر غرينادين",
    "dominica–saint vincent and grenadines relations": "علاقات دومينيكا وسانت فنسنت وجزر غرينادين",
    "finland–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وفنلندا",
    "france–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وفرنسا",
    "germany–saint vincent and grenadines relations": "علاقات ألمانيا وسانت فنسنت وجزر غرينادين",
    "ghana–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وغانا",
    "grenada–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وغرينادا",
    "india–saint vincent and grenadines relations": "علاقات الهند وسانت فنسنت وجزر غرينادين",
    "ireland–saint vincent and grenadines relations": "علاقات أيرلندا وسانت فنسنت وجزر غرينادين",
    "italy–saint vincent and grenadines relations": "علاقات إيطاليا وسانت فنسنت وجزر غرينادين",
    "jamaica–saint vincent and grenadines relations": "علاقات جامايكا وسانت فنسنت وجزر غرينادين",
    "japan–saint vincent and grenadines relations": "علاقات اليابان وسانت فنسنت وجزر غرينادين",
    "malaysia–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وماليزيا",
    "netherlands–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وهولندا",
    "new zealand–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين ونيوزيلندا",
    "philippines–saint vincent and grenadines relations": "علاقات الفلبين وسانت فنسنت وجزر غرينادين",
    "poland–saint vincent and grenadines relations": "علاقات بولندا وسانت فنسنت وجزر غرينادين",
    "portugal–saint vincent and grenadines relations": "علاقات البرتغال وسانت فنسنت وجزر غرينادين",
    "saint kitts and nevis–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وسانت كيتس ونيفيس",
    "saint lucia–saint vincent and grenadines relations": "علاقات سانت فنسنت وجزر غرينادين وسانت لوسيا",
    "saint vincent and grenadines–spain relations": "علاقات إسبانيا وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–switzerland relations": "علاقات سانت فنسنت وجزر غرينادين وسويسرا",
    "saint vincent and grenadines–taiwan relations": "علاقات تايوان وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–trinidad and tobago relations": "علاقات ترينيداد وتوباغو وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–tunisia relations": "علاقات تونس وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–turkey relations": "علاقات تركيا وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–united kingdom relations": "علاقات المملكة المتحدة وسانت فنسنت وجزر غرينادين",
    "saint vincent and grenadines–united states relations": "علاقات الولايات المتحدة وسانت فنسنت وجزر غرينادين",
    "angola–são tomé and príncipe relations": "علاقات أنغولا وساو تومي وبرينسيب",
    "argentina–são tomé and príncipe relations": "علاقات الأرجنتين وساو تومي وبرينسيب",
    "australia–são tomé and príncipe relations": "علاقات أستراليا وساو تومي وبرينسيب",
    "belgium–são tomé and príncipe relations": "علاقات بلجيكا وساو تومي وبرينسيب",
    "brazil–são tomé and príncipe relations": "علاقات البرازيل وساو تومي وبرينسيب",
    "canada–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وكندا",
    "cape verde–são tomé and príncipe relations": "علاقات الرأس الأخضر وساو تومي وبرينسيب",
    "china–são tomé and príncipe relations": "علاقات الصين وساو تومي وبرينسيب",
    "colombia–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وكولومبيا",
    "cyprus–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وقبرص",
    "equatorial guinea–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وغينيا الاستوائية",
    "finland–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وفنلندا",
    "france–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وفرنسا",
    "gabon–são tomé and príncipe relations": "علاقات الغابون وساو تومي وبرينسيب",
    "germany–são tomé and príncipe relations": "علاقات ألمانيا وساو تومي وبرينسيب",
    "india–são tomé and príncipe relations": "علاقات الهند وساو تومي وبرينسيب",
    "indonesia–são tomé and príncipe relations": "علاقات إندونيسيا وساو تومي وبرينسيب",
    "iran–são tomé and príncipe relations": "علاقات إيران وساو تومي وبرينسيب",
    "italy–são tomé and príncipe relations": "علاقات إيطاليا وساو تومي وبرينسيب",
    "lithuania–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وليتوانيا",
    "mexico–são tomé and príncipe relations": "علاقات المكسيك وساو تومي وبرينسيب",
    "mozambique–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب وموزمبيق",
    "nigeria–são tomé and príncipe relations": "علاقات ساو تومي وبرينسيب ونيجيريا",
    "norway–são tomé and príncipe relations": "علاقات النرويج وساو تومي وبرينسيب",
    "paraguay–são tomé and príncipe relations": "علاقات باراغواي وساو تومي وبرينسيب",
    "portugal–são tomé and príncipe relations": "علاقات البرتغال وساو تومي وبرينسيب",
    "russia–são tomé and príncipe relations": "علاقات روسيا وساو تومي وبرينسيب",
    "são tomé and príncipe–european union relations": "علاقات الاتحاد الأوروبي وساو تومي وبرينسيب",
    "são tomé and príncipe–serbia relations": "علاقات ساو تومي وبرينسيب وصربيا",
    "são tomé and príncipe–spain relations": "علاقات إسبانيا وساو تومي وبرينسيب",
    "são tomé and príncipe–sweden relations": "علاقات السويد وساو تومي وبرينسيب",
    "são tomé and príncipe–taiwan relations": "علاقات تايوان وساو تومي وبرينسيب",
    "são tomé and príncipe–united kingdom relations": "علاقات المملكة المتحدة وساو تومي وبرينسيب",
    "são tomé and príncipe–united states relations": "علاقات الولايات المتحدة وساو تومي وبرينسيب",
    "australia–serbia-and-montenegro relations": "علاقات أستراليا وصربيا والجبل الأسود",
    "bosnia and herzegovina–serbia-and-montenegro relations": "علاقات البوسنة والهرسك وصربيا والجبل الأسود",
    "bulgaria–serbia-and-montenegro relations": "علاقات بلغاريا وصربيا والجبل الأسود",
    "canada–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وكندا",
    "cyprus–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وقبرص",
    "czech republic–serbia-and-montenegro relations": "علاقات التشيك وصربيا والجبل الأسود",
    "egypt–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود ومصر",
    "el salvador–serbia-and-montenegro relations": "علاقات السلفادور وصربيا والجبل الأسود",
    "iceland–serbia-and-montenegro relations": "علاقات آيسلندا وصربيا والجبل الأسود",
    "jordan–serbia-and-montenegro relations": "علاقات الأردن وصربيا والجبل الأسود",
    "kazakhstan–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وكازاخستان",
    "kuwait–serbia-and-montenegro relations": "علاقات الكويت وصربيا والجبل الأسود",
    "lithuania–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وليتوانيا",
    "malaysia–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وماليزيا",
    "myanmar–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود وميانمار",
    "north macedonia–serbia-and-montenegro relations": "علاقات صربيا والجبل الأسود ومقدونيا الشمالية",
    "norway–serbia-and-montenegro relations": "علاقات النرويج وصربيا والجبل الأسود",
    "oman–serbia-and-montenegro relations": "علاقات سلطنة عمان وصربيا والجبل الأسود",
    "portugal–serbia-and-montenegro relations": "علاقات البرتغال وصربيا والجبل الأسود",
    "russia–serbia-and-montenegro relations": "علاقات روسيا وصربيا والجبل الأسود",
    "rwanda–serbia-and-montenegro relations": "علاقات رواندا وصربيا والجبل الأسود",
    "serbia-and-montenegro–singapore relations": "علاقات سنغافورة وصربيا والجبل الأسود",
    "serbia-and-montenegro–slovakia relations": "علاقات سلوفاكيا وصربيا والجبل الأسود",
    "serbia-and-montenegro–south africa relations": "علاقات جنوب إفريقيا وصربيا والجبل الأسود",
    "serbia-and-montenegro–spain relations": "علاقات إسبانيا وصربيا والجبل الأسود",
    "serbia-and-montenegro–sudan relations": "علاقات السودان وصربيا والجبل الأسود",
    "serbia-and-montenegro–tunisia relations": "علاقات تونس وصربيا والجبل الأسود",
    "serbia-and-montenegro–ukraine relations": "علاقات أوكرانيا وصربيا والجبل الأسود",
    "serbia-and-montenegro–united states relations": "علاقات الولايات المتحدة وصربيا والجبل الأسود",
    "serbia-and-montenegro–venezuela relations": "علاقات صربيا والجبل الأسود وفنزويلا",
    "serbia-and-montenegro–yemen relations": "علاقات اليمن وصربيا والجبل الأسود",
    "peru–serbia-and-montenegro relations": "علاقات بيرو وصربيا والجبل الأسود",
    "bahrain–serbia-and-montenegro relations": "علاقات البحرين وصربيا والجبل الأسود",
    "denmark-gambia relations": "العلاقات الدنماركية الغامبية",
    "estonia-gambia relations": "العلاقات الإستونية الغامبية",
    "ethiopia-gambia relations": "العلاقات الإثيوبية الغامبية",
    "finland-gambia relations": "العلاقات الغامبية الفنلندية",
    "france-gambia relations": "العلاقات الغامبية الفرنسية",
    "gabon-gambia relations": "العلاقات الغابونية الغامبية",
    "guinea-gambia relations": "العلاقات الغامبية الغينية",
    "cameroon-gambia relations": "العلاقات الغامبية الكاميرونية",
    "canada-gambia relations": "العلاقات الغامبية الكندية",
    "china-gambia relations": "العلاقات الصينية الغامبية",
    "colombia-gambia relations": "العلاقات الغامبية الكولومبية",
    "cuba-gambia relations": "العلاقات الغامبية الكوبية",
    "cyprus-gambia relations": "العلاقات الغامبية القبرصية",
    "czech republic-gambia relations": "العلاقات التشيكية الغامبية",
    "australia-gambia relations": "العلاقات الأسترالية الغامبية",
    "austria-gambia relations": "العلاقات الغامبية النمساوية",
    "azerbaijan-gambia relations": "العلاقات الأذربيجانية الغامبية",
    "bangladesh-gambia relations": "العلاقات البنغلاديشية الغامبية",
    "belgium-gambia relations": "العلاقات البلجيكية الغامبية",
    "botswana-gambia relations": "العلاقات البوتسوانية الغامبية",
    "brazil-gambia relations": "العلاقات البرازيلية الغامبية",
    "bulgaria-gambia relations": "العلاقات البلغارية الغامبية",
    "burkina faso-gambia relations": "العلاقات البوركينابية الغامبية",
    "Democratic republic of congo-Norway relations": "العلاقات الكونغوية الديمقراطية النرويجية",
    "Albania-Democratic republic of congo relations": "العلاقات الألبانية الكونغوية الديمقراطية",
    "Algeria-Democratic republic of congo relations": "العلاقات الجزائرية الكونغوية الديمقراطية",
    "Angola-Democratic republic of congo border": "الحدود الأنغولية الكونغوية الديمقراطية",
    "Angola-Democratic republic of congo relations": "العلاقات الأنغولية الكونغوية الديمقراطية",
    "Angola-republic of congo border": "الحدود الأنغولية الكونغوية",
    "Argentina-Democratic republic of congo relations": "العلاقات الأرجنتينية الكونغوية الديمقراطية",
    "Australia-Democratic republic of congo relations": "العلاقات الأسترالية الكونغوية الديمقراطية",
    "Austria-Democratic republic of congo relations": "العلاقات الكونغوية الديمقراطية النمساوية",
    "Azerbaijan-Democratic republic of congo relations": "العلاقات الأذربيجانية الكونغوية الديمقراطية",
    "Bahrain-Democratic republic of congo relations": "العلاقات البحرينية الكونغوية الديمقراطية",
    "Bulgaria-Democratic republic of congo relations": "العلاقات البلغارية الكونغوية الديمقراطية",
    "Burkina Faso-Democratic republic of congo relations": "العلاقات البوركينابية الكونغوية الديمقراطية",
    "Burundi-Democratic republic of congo border": "الحدود البوروندية الكونغوية الديمقراطية",
    "Burundi-Democratic republic of congo relations": "العلاقات البوروندية الكونغوية الديمقراطية",
    "Canada-Democratic republic of congo relations": "العلاقات الكندية الكونغوية الديمقراطية",
    "Cape Verde-Democratic republic of congo relations": "العلاقات الرأس الأخضرية الكونغوية الديمقراطية",
    "Central African Republic-Democratic republic of congo relations": "العلاقات الإفريقية الأوسطية الكونغوية الديمقراطية",
    "Chad-Democratic republic of congo relations": "العلاقات التشادية الكونغوية الديمقراطية",
    "China-Democratic republic of congo relations": "العلاقات الصينية الكونغوية الديمقراطية",
    "Croatia-Democratic republic of congo relations": "العلاقات الكرواتية الكونغوية الديمقراطية",
    "Cyprus-Democratic republic of congo relations": "العلاقات القبرصية الكونغوية الديمقراطية",
    "Czech Republic-Democratic republic of congo relations": "العلاقات التشيكية الكونغوية الديمقراطية",
    "Democratic republic of congo-republic of congo border": "الحدود الكونغوية الكونغوية الديمقراطية",
    "Gabon-republic of congo relations": "العلاقات الغابونية الكونغوية",
    "Iran-republic of congo relations": "العلاقات الإيرانية الكونغوية",
    "Malta-republic of congo relations": "العلاقات الكونغوية المالطية",
    "Netherlands-republic of congo relations": "العلاقات الكونغوية الهولندية",
    "Democratic republic of congo-Libya relations": "العلاقات الكونغوية الديمقراطية الليبية",
    "Democratic republic of congo-Netherlands relations": "العلاقات الكونغوية الديمقراطية الهولندية",
    "algeria–eswatini relations": "علاقات إسواتيني والجزائر",
    "angola–eswatini relations": "علاقات أنغولا وإسواتيني",
    "antigua and barbuda–dominica relations": "علاقات أنتيغوا وباربودا ودومينيكا",
    "antigua and barbuda–saint kitts and nevis relations": "علاقات أنتيغوا وباربودا وسانت كيتس ونيفيس",
    "antigua and barbuda–saint lucia relations": "علاقات أنتيغوا وباربودا وسانت لوسيا",
    "australia–eswatini relations": "علاقات أستراليا وإسواتيني",
    "austrian empire–denmark relations": "علاقات الإمبراطورية النمساوية والدنمارك",
    "austrian empire–france relations": "علاقات الإمبراطورية النمساوية وفرنسا",
    "austrian empire–prussia relations": "علاقات الإمبراطورية النمساوية وبروسيا",
    "austrian empire–russia relations": "علاقات الإمبراطورية النمساوية وروسيا",
    "austria–eswatini relations": "علاقات إسواتيني والنمسا",
    "austria–saint kitts and nevis relations": "علاقات النمسا وسانت كيتس ونيفيس",
    "austria–saint lucia relations": "علاقات النمسا وسانت لوسيا",
    "bangladesh–eswatini relations": "علاقات إسواتيني وبنغلاديش",
    "barbados–dominica relations": "علاقات بربادوس ودومينيكا",
    "barbados–saint kitts and nevis relations": "علاقات بربادوس وسانت كيتس ونيفيس",
    "barbados–saint lucia relations": "علاقات بربادوس وسانت لوسيا",
    "belgium–dominica relations": "علاقات بلجيكا ودومينيكا",
    "belgium–eswatini relations": "علاقات إسواتيني وبلجيكا",
    "belize–dominica relations": "علاقات بليز ودومينيكا",
    "benin–eswatini relations": "علاقات إسواتيني وبنين",
    "bolivia–dominica relations": "علاقات بوليفيا ودومينيكا",
    "botswana–eswatini relations": "علاقات إسواتيني وبوتسوانا",
    "brazil–saint kitts and nevis relations": "علاقات البرازيل وسانت كيتس ونيفيس",
    "bulgaria–saint lucia relations": "علاقات بلغاريا وسانت لوسيا",
    "canada–dominica relations": "علاقات دومينيكا وكندا",
    "canada–eswatini relations": "علاقات إسواتيني وكندا",
    "canada–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وكندا",
    "canada–saint lucia relations": "علاقات سانت لوسيا وكندا",
    "china–dominica relations": "علاقات الصين ودومينيكا",
    "china–eswatini relations": "علاقات إسواتيني والصين",
    "china–saint kitts and nevis relations": "علاقات الصين وسانت كيتس ونيفيس",
    "china–saint lucia relations": "علاقات الصين وسانت لوسيا",
    "costa rica–saint lucia relations": "علاقات سانت لوسيا وكوستاريكا",
    "cuba–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وكوبا",
    "cyprus–saint lucia relations": "علاقات سانت لوسيا وقبرص",
    "denmark–saint kitts and nevis relations": "علاقات الدنمارك وسانت كيتس ونيفيس",
    "denmark–saint lucia relations": "علاقات الدنمارك وسانت لوسيا",
    "dominica–egypt relations": "علاقات دومينيكا ومصر",
    "dominica–european union relations": "علاقات الاتحاد الأوروبي ودومينيكا",
    "dominica–france relations": "علاقات دومينيكا وفرنسا",
    "dominica–germany relations": "علاقات ألمانيا ودومينيكا",
    "dominica–greece relations": "علاقات اليونان ودومينيكا",
    "dominica–grenada relations": "علاقات دومينيكا وغرينادا",
    "dominica–guinea relations": "علاقات دومينيكا وغينيا",
    "dominica–guyana relations": "علاقات دومينيكا وغيانا",
    "dominica–haiti relations": "علاقات دومينيكا وهايتي",
    "dominica–india relations": "علاقات الهند ودومينيكا",
    "dominica–iran relations": "علاقات إيران ودومينيكا",
    "dominica–italy relations": "علاقات إيطاليا ودومينيكا",
    "dominica–jamaica relations": "علاقات جامايكا ودومينيكا",
    "dominica–japan relations": "علاقات اليابان ودومينيكا",
    "dominica–malta relations": "علاقات دومينيكا ومالطا",
    "dominica–netherlands relations": "علاقات دومينيكا وهولندا",
    "dominica–saint kitts and nevis relations": "علاقات دومينيكا وسانت كيتس ونيفيس",
    "dominica–saint lucia relations": "علاقات دومينيكا وسانت لوسيا",
    "dominica–switzerland relations": "علاقات دومينيكا وسويسرا",
    "dominica–trinidad and tobago relations": "علاقات ترينيداد وتوباغو ودومينيكا",
    "dominica–united kingdom relations": "علاقات المملكة المتحدة ودومينيكا",
    "dominica–united states relations": "علاقات الولايات المتحدة ودومينيكا",
    "dominica–venezuela relations": "علاقات دومينيكا وفنزويلا",
    "el salvador–saint kitts and nevis relations": "علاقات السلفادور وسانت كيتس ونيفيس",
    "eswatini–european union relations": "علاقات إسواتيني والاتحاد الأوروبي",
    "eswatini–finland relations": "علاقات إسواتيني وفنلندا",
    "eswatini–france relations": "علاقات إسواتيني وفرنسا",
    "eswatini–germany relations": "علاقات ألمانيا وإسواتيني",
    "eswatini–ghana relations": "علاقات إسواتيني وغانا",
    "eswatini–india relations": "علاقات إسواتيني والهند",
    "eswatini–ireland relations": "علاقات أيرلندا وإسواتيني",
    "eswatini–israel relations": "علاقات إسرائيل وإسواتيني",
    "eswatini–lesotho relations": "علاقات إسواتيني وليسوتو",
    "eswatini–malawi relations": "علاقات إسواتيني وملاوي",
    "eswatini–morocco relations": "علاقات إسواتيني والمغرب",
    "eswatini–mozambique relations": "علاقات إسواتيني وموزمبيق",
    "eswatini–netherlands relations": "علاقات إسواتيني وهولندا",
    "eswatini–nigeria relations": "علاقات إسواتيني ونيجيريا",
    "eswatini–norway relations": "علاقات إسواتيني والنرويج",
    "eswatini–pakistan relations": "علاقات إسواتيني وباكستان",
    "eswatini–russia relations": "علاقات إسواتيني وروسيا",
    "eswatini–singapore relations": "علاقات إسواتيني وسنغافورة",
    "eswatini–south africa relations": "علاقات إسواتيني وجنوب إفريقيا",
    "eswatini–south korea relations": "علاقات إسواتيني وكوريا الجنوبية",
    "eswatini–sweden relations": "علاقات إسواتيني والسويد",
    "eswatini–switzerland relations": "علاقات إسواتيني وسويسرا",
    "eswatini–taiwan relations": "علاقات إسواتيني وتايوان",
    "eswatini–thailand relations": "علاقات إسواتيني وتايلاند",
    "eswatini–united kingdom relations": "علاقات إسواتيني والمملكة المتحدة",
    "eswatini–united states relations": "علاقات إسواتيني والولايات المتحدة",
    "eswatini–yugoslavia relations": "علاقات إسواتيني ويوغسلافيا",
    "eswatini–zimbabwe relations": "علاقات إسواتيني وزيمبابوي",
    "finland–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وفنلندا",
    "finland–saint lucia relations": "علاقات سانت لوسيا وفنلندا",
    "france–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وفرنسا",
    "france–saint lucia relations": "علاقات سانت لوسيا وفرنسا",
    "germany–saint lucia relations": "علاقات ألمانيا وسانت لوسيا",
    "ghana–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وغانا",
    "greece–saint kitts and nevis relations": "علاقات اليونان وسانت كيتس ونيفيس",
    "grenada–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وغرينادا",
    "grenada–saint lucia relations": "علاقات سانت لوسيا وغرينادا",
    "guatemala–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وغواتيمالا",
    "guyana–saint lucia relations": "علاقات سانت لوسيا وغيانا",
    "honduras–saint lucia relations": "علاقات سانت لوسيا وهندوراس",
    "india–saint kitts and nevis relations": "علاقات الهند وسانت كيتس ونيفيس",
    "india–saint lucia relations": "علاقات الهند وسانت لوسيا",
    "indonesia–saint kitts and nevis relations": "علاقات إندونيسيا وسانت كيتس ونيفيس",
    "ireland–saint lucia relations": "علاقات أيرلندا وسانت لوسيا",
    "israel–saint lucia relations": "علاقات إسرائيل وسانت لوسيا",
    "italy–saint lucia relations": "علاقات إيطاليا وسانت لوسيا",
    "jamaica–saint kitts and nevis relations": "علاقات جامايكا وسانت كيتس ونيفيس",
    "jamaica–saint lucia relations": "علاقات جامايكا وسانت لوسيا",
    "japan–saint kitts and nevis relations": "علاقات اليابان وسانت كيتس ونيفيس",
    "japan–saint lucia relations": "علاقات اليابان وسانت لوسيا",
    "kenya–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وكينيا",
    "malaysia–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وماليزيا",
    "mexico–saint kitts and nevis relations": "علاقات المكسيك وسانت كيتس ونيفيس",
    "netherlands–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وهولندا",
    "pakistan–saint kitts and nevis relations": "علاقات باكستان وسانت كيتس ونيفيس",
    "philippines–saint kitts and nevis relations": "علاقات الفلبين وسانت كيتس ونيفيس",
    "portugal–saint lucia relations": "علاقات البرتغال وسانت لوسيا",
    "russia–saint kitts and nevis relations": "علاقات روسيا وسانت كيتس ونيفيس",
    "saint kitts and nevis–saint lucia relations": "علاقات سانت كيتس ونيفيس وسانت لوسيا",
    "saint kitts and nevis–south africa relations": "علاقات جنوب إفريقيا وسانت كيتس ونيفيس",
    "saint kitts and nevis–suriname relations": "علاقات سانت كيتس ونيفيس وسورينام",
    "saint kitts and nevis–sweden relations": "علاقات السويد وسانت كيتس ونيفيس",
    "saint kitts and nevis–taiwan relations": "علاقات تايوان وسانت كيتس ونيفيس",
    "saint kitts and nevis–trinidad and tobago relations": "علاقات ترينيداد وتوباغو وسانت كيتس ونيفيس",
    "saint kitts and nevis–united kingdom relations": "علاقات المملكة المتحدة وسانت كيتس ونيفيس",
    "saint kitts and nevis–united states relations": "علاقات الولايات المتحدة وسانت كيتس ونيفيس",
    "saint lucia–taiwan relations": "علاقات تايوان وسانت لوسيا",
    "saint lucia–trinidad and tobago relations": "علاقات ترينيداد وتوباغو وسانت لوسيا",
    "saint lucia–united kingdom relations": "علاقات المملكة المتحدة وسانت لوسيا",
    "saint lucia–united states relations": "علاقات الولايات المتحدة وسانت لوسيا",
    "algeria–vanuatu relations": "العلاقات الجزائرية الفانواتية",
    "australia–vanuatu relations": "العلاقات الأسترالية الفانواتية",
    "austria–vanuatu relations": "العلاقات الفانواتية النمساوية",
    "bangladesh–vanuatu relations": "العلاقات البنغلاديشية الفانواتية",
    "canada–vanuatu relations": "العلاقات الفانواتية الكندية",
    "china–vanuatu relations": "العلاقات الصينية الفانواتية",
    "czech republic–vanuatu relations": "العلاقات التشيكية الفانواتية",
    "federated states-of micronesia–vanuatu relations": "العلاقات الفانواتية الميكرونيزية",
    "fiji–vanuatu relations": "العلاقات الفانواتية الفيجية",
    "france–vanuatu relations": "العلاقات الفانواتية الفرنسية",
    "gambia–vanuatu relations": "العلاقات الغامبية الفانواتية",
    "ghana–vanuatu relations": "العلاقات الغانية الفانواتية",
    "hungary–vanuatu relations": "العلاقات الفانواتية المجرية",
    "india–vanuatu relations": "العلاقات الفانواتية الهندية",
    "indonesia–vanuatu relations": "العلاقات الإندونيسية الفانواتية",
    "italy–vanuatu relations": "العلاقات الإيطالية الفانواتية",
    "japan–vanuatu relations": "العلاقات الفانواتية اليابانية",
    "morocco–vanuatu relations": "العلاقات الفانواتية المغربية",
    "new zealand–vanuatu relations": "العلاقات الفانواتية النيوزيلندية",
    "palestine–vanuatu relations": "العلاقات الفانواتية الفلسطينية",
    "papua new guinea–vanuatu relations": "العلاقات الغينية الفانواتية",
    "philippines–vanuatu relations": "العلاقات الفانواتية الفلبينية",
    "romania–vanuatu relations": "العلاقات الرومانية الفانواتية",
    "russia–vanuatu relations": "العلاقات الروسية الفانواتية",
    "spain–vanuatu relations": "العلاقات الإسبانية الفانواتية",
    "sri lanka–vanuatu relations": "العلاقات السريلانكية الفانواتية",
    "suriname–vanuatu relations": "العلاقات السورينامية الفانواتية",
    "sweden–vanuatu relations": "العلاقات السويدية الفانواتية",
    "switzerland–vanuatu relations": "العلاقات السويسرية الفانواتية",
    "tonga–vanuatu relations": "العلاقات التونغانية الفانواتية",
    "tunisia–vanuatu relations": "العلاقات التونسية الفانواتية",
    "united kingdom–vanuatu relations": "العلاقات البريطانية الفانواتية",
    "united states–vanuatu relations": "العلاقات الأمريكية الفانواتية",
    "uruguay–vanuatu relations": "العلاقات الأوروغويانية الفانواتية",
    "vanuatu–vietnam relations": "العلاقات الفانواتية الفيتنامية",
    "australia–nauru relations": "العلاقات الأسترالية الناورونية",
    "canada–nauru relations": "العلاقات الكندية الناورونية",
    "china–nauru relations": "العلاقات الصينية الناورونية",
    "cuba–nauru relations": "العلاقات الكوبية الناورونية",
    "federated states-of micronesia–nauru relations": "العلاقات الميكرونيزية الناورونية",
    "fiji–nauru relations": "العلاقات الفيجية الناورونية",
    "france–nauru relations": "العلاقات الفرنسية الناورونية",
    "germany–nauru relations": "العلاقات الألمانية الناورونية",
    "india–nauru relations": "العلاقات الناورونية الهندية",
    "iraq–nauru relations": "العلاقات العراقية الناورونية",
    "israel–nauru relations": "العلاقات الإسرائيلية الناورونية",
    "japan–nauru relations": "العلاقات الناورونية اليابانية",
    "kiribati–nauru relations": "العلاقات الكيريباتية الناورونية",
    "malaysia–nauru relations": "العلاقات الماليزية الناورونية",
    "nauru–new zealand relations": "العلاقات الناورونية النيوزيلندية",
    "nauru–philippines relations": "العلاقات الفلبينية الناورونية",
    "nauru–poland relations": "العلاقات البولندية الناورونية",
    "nauru–romania relations": "العلاقات الرومانية الناورونية",
    "nauru–russia relations": "العلاقات الروسية الناورونية",
    "nauru–switzerland relations": "العلاقات السويسرية الناورونية",
    "nauru–taiwan relations": "العلاقات التايوانية الناورونية",
    "nauru–united kingdom relations": "العلاقات البريطانية الناورونية",
    "nauru–united states relations": "العلاقات الأمريكية الناورونية",
    "nauru–venezuela relations": "العلاقات الفنزويلية الناورونية",
    "afghanistan–monaco relations": "العلاقات الأفغانية الموناكية",
    "albania–monaco relations": "العلاقات الألبانية الموناكية",
    "algeria–monaco relations": "العلاقات الجزائرية الموناكية",
    "andorra–monaco relations": "العلاقات الأندورية الموناكية",
    "angola–monaco relations": "العلاقات الأنغولية الموناكية",
    "argentina–monaco relations": "العلاقات الأرجنتينية الموناكية",
    "armenia–monaco relations": "العلاقات الأرمينية الموناكية",
    "australia–monaco relations": "العلاقات الأسترالية الموناكية",
    "austria–monaco relations": "العلاقات الموناكية النمساوية",
    "azerbaijan–monaco relations": "العلاقات الأذربيجانية الموناكية",
    "belarus–monaco relations": "العلاقات البيلاروسية الموناكية",
    "belgium–monaco relations": "العلاقات البلجيكية الموناكية",
    "bosnia and herzegovina–monaco relations": "العلاقات البوسنية الموناكية",
    "brazil–monaco relations": "العلاقات البرازيلية الموناكية",
    "brunei–monaco relations": "العلاقات البرونية الموناكية",
    "bulgaria–monaco relations": "العلاقات البلغارية الموناكية",
    "canada–monaco relations": "العلاقات الكندية الموناكية",
    "china–monaco relations": "العلاقات الصينية الموناكية",
    "colombia–monaco relations": "العلاقات الكولومبية الموناكية",
    "comoros–monaco relations": "العلاقات القمرية الموناكية",
    "czech republic–monaco relations": "العلاقات التشيكية الموناكية",
    "czechoslovakia–monaco relations": "العلاقات التشيكوسلوفاكية الموناكية",
    "denmark–monaco relations": "العلاقات الدنماركية الموناكية",
    "djibouti–monaco relations": "العلاقات الجيبوتية الموناكية",
    "egypt–monaco relations": "العلاقات المصرية الموناكية",
    "el salvador–monaco relations": "العلاقات السلفادورية الموناكية",
    "estonia–monaco relations": "العلاقات الإستونية الموناكية",
    "finland–monaco relations": "العلاقات الفنلندية الموناكية",
    "france–monaco relations": "العلاقات الفرنسية الموناكية",
    "gabon–monaco relations": "العلاقات الغابونية الموناكية",
    "germany–monaco relations": "العلاقات الألمانية الموناكية",
    "guinea–monaco relations": "العلاقات الغينية الموناكية",
    "iceland–monaco relations": "العلاقات الآيسلندية الموناكية",
    "india–monaco relations": "العلاقات الموناكية الهندية",
    "indonesia–monaco relations": "العلاقات الإندونيسية الموناكية",
    "ireland–monaco relations": "العلاقات الأيرلندية الموناكية",
    "israel–monaco relations": "العلاقات الإسرائيلية الموناكية",
    "ivory coast–monaco relations": "العلاقات الإيفوارية الموناكية",
    "jamaica–monaco relations": "العلاقات الجامايكية الموناكية",
    "japan–monaco relations": "العلاقات الموناكية اليابانية",
    "latvia–monaco relations": "العلاقات اللاتفية الموناكية",
    "lesotho–monaco relations": "العلاقات الليسوتية الموناكية",
    "luxembourg–monaco relations": "العلاقات اللوكسمبورغية الموناكية",
    "mexico–monaco relations": "العلاقات المكسيكية الموناكية",
    "monaco–montenegro relations": "العلاقات الموناكية المونتينيغرية",
    "monaco–netherlands relations": "العلاقات الموناكية الهولندية",
    "monaco–nigeria relations": "العلاقات الموناكية النيجيرية",
    "monaco–pakistan relations": "العلاقات الباكستانية الموناكية",
    "monaco–poland relations": "العلاقات البولندية الموناكية",
    "monaco–portugal relations": "العلاقات البرتغالية الموناكية",
    "monaco–qatar relations": "العلاقات القطرية الموناكية",
    "monaco–republic-of-congo relations": "العلاقات الكونغوية الموناكية",
    "monaco–romania relations": "العلاقات الرومانية الموناكية",
    "monaco–russia relations": "العلاقات الروسية الموناكية",
    "monaco–senegal relations": "العلاقات السنغالية الموناكية",
    "monaco–south korea relations": "العلاقات الكورية الجنوبية الموناكية",
    "monaco–spain relations": "العلاقات الإسبانية الموناكية",
    "monaco–sweden relations": "العلاقات السويدية الموناكية",
    "monaco–switzerland relations": "العلاقات السويسرية الموناكية",
    "monaco–syria relations": "العلاقات السورية الموناكية",
    "monaco–togo relations": "العلاقات التوغوية الموناكية",
    "monaco–ukraine relations": "العلاقات الأوكرانية الموناكية",
    "monaco–united kingdom relations": "العلاقات البريطانية الموناكية",
    "monaco–united states relations": "العلاقات الأمريكية الموناكية",
    "monaco–yugoslavia relations": "العلاقات الموناكية اليوغسلافية",
}

big_data2 = {
    "spanish american wars": "الحروب الأمريكية الإسبانية",
    "jewish roman wars": "الحروب الرومانية اليهودية",
    "jewish-roman wars": "الحروب الرومانية اليهودية",
    "Jewish-Roman wars": "الحروب الرومانية اليهودية",
    "cambodian–vietnamese war": "الحرب الفيتنامية الكمبودية",
    "chadian–libyan war": "الحرب التشادية الليبية",
    "dutch–portuguese war": "الحرب البرتغالية الهولندية",
    "ecuadorian–peruvian war": "الحرب الإكوادورية البيروية",
    "egyptian–ottoman war": "الحرب العثمانية المصرية",
    "eritrean–ethiopian war": "الحرب الإثيوبية الإريترية",
    "hungarian–czechoslovak war": "الحرب التشيكوسلوفاكية المجرية",
    "hungarian–romanian war": "الحرب الرومانية المجرية",
    "mexican–american war": "الحرب الأمريكية المكسيكية",
    "philippine–american war": "الحرب الأمريكية الفلبينية",
    "polish–lithuanian war": "الحرب البولندية الليتوانية",
    "polish–soviet war": "الحرب البولندية السوفيتية",
    "polish–ukrainian war": "الحرب الأوكرانية البولندية",
    "scottish–norwegian war": "الحرب الإسكتلندية النرويجية",
    "sinhalese–portuguese war": "الحرب البرتغالية السنهالية",
    "slovak–hungarian war": "الحرب السلوفاكية المجرية",
    "soviet–afghan war": "الحرب الأفغانية السوفيتية",
    "spanish–american war": "الحرب الأمريكية الإسبانية",
    "swedish–norwegian war": "الحرب السويدية النرويجية",
    "ukrainian–soviet war": "الحرب الأوكرانية السوفيتية",
    "algerian–tunisian wars": "الحروب التونسية الجزائرية",
    "arab–byzantine wars": "الحروب البيزنطية العربية",
    "bulgarian–ottoman wars": "الحروب البلغارية العثمانية",
    "bulgarian–serbian wars": "الحروب البلغارية الصربية",
    "byzantine–bulgarian wars": "الحروب البلغارية البيزنطية",
    "byzantine–georgian wars": "الحروب البيزنطية الجورجية",
    "byzantine–hungarian wars": "الحروب البيزنطية المجرية",
    "byzantine–ottoman wars": "الحروب البيزنطية العثمانية",
    "byzantine–sasanian wars": "الحروب البيزنطية الساسانية",
    "byzantine–turkish wars": "الحروب البيزنطية التركية",
    "ecuadorian–peruvian wars": "الحروب الإكوادورية البيروية",
    "hungarian–ottoman wars": "الحروب العثمانية المجرية",
    "jewish–roman wars": "الحروب الرومانية اليهودية",
    "ottoman–persian wars": "الحروب العثمانية الفارسية",
    "ottoman–serbian wars": "الحروب الصربية العثمانية",
    "polish–ottoman wars": "الحروب البولندية العثمانية",
    "polish–russian wars": "الحروب البولندية الروسية",
    "polish–ukrainian wars": "الحروب الأوكرانية البولندية",
    "roman–greek wars": "الحروب الرومانية اليونانية",
    "roman–parthian wars": "الحروب الرومانية الفرثية",
    "roman–persian wars": "الحروب الرومانية الفارسية",
    "roman–sasanian wars": "الحروب الرومانية الساسانية",
    "russian–ukrainian wars": "الحروب الأوكرانية الروسية",
    "japan–south vietnam relations": "علاقات اليابان وفيتنام الجنوبية",
    "philippines–south vietnam relations": "علاقات الفلبين وفيتنام الجنوبية",
    "south korea–south vietnam relations": "علاقات فيتنام الجنوبية وكوريا الجنوبية",
    "south vietnam–taiwan relations": "علاقات تايوان وفيتنام الجنوبية",
    "south vietnam–united states relations": "علاقات الولايات المتحدة وفيتنام الجنوبية",
    "somaliland–taiwan relations": "علاقات أرض الصومال وتايوان",
    "somaliland–united arab emirates relations": "علاقات أرض الصومال والإمارات العربية المتحدة",
    "somaliland–united kingdom relations": "علاقات أرض الصومال والمملكة المتحدة",
    "somaliland–united states relations": "علاقات أرض الصومال والولايات المتحدة",
    "djibouti–somaliland relations": "علاقات أرض الصومال وجيبوتي",
    "ethiopia–somaliland relations": "علاقات أرض الصومال وإثيوبيا",
    "germany–somaliland relations": "علاقات أرض الصومال وألمانيا",
    "israel–somaliland relations": "علاقات أرض الصومال وإسرائيل",
    "kosovo–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وكوسوفو",
    "malta–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس ومالطا",
    "new zealand–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس ونيوزيلندا",
    "norway–saint kitts and nevis relations": "علاقات النرويج وسانت كيتس ونيفيس",
    "portugal–saint kitts and nevis relations": "علاقات البرتغال وسانت كيتس ونيفيس",
    "saint kitts and nevis–romania relations": "علاقات رومانيا وسانت كيتس ونيفيس",
    "saint kitts and nevis–spain relations": "علاقات إسبانيا وسانت كيتس ونيفيس",
    "australia–saint kitts and nevis relations": "علاقات أستراليا وسانت كيتس ونيفيس",
    "honduras–saint kitts and nevis relations": "علاقات سانت كيتس ونيفيس وهندوراس",
    "iceland–saint kitts and nevis relations": "علاقات آيسلندا وسانت كيتس ونيفيس",
    "ireland–saint kitts and nevis relations": "علاقات أيرلندا وسانت كيتس ونيفيس",
    "saint kitts and nevis–thailand relations": "علاقات تايلاند وسانت كيتس ونيفيس",
    "saint kitts and nevis–united kingdom sports relations": "علاقات المملكة المتحدة وسانت كيتس ونيفيس الرياضية",
    "saint kitts and nevis–united states sports relations": "علاقات الولايات المتحدة وسانت كيتس ونيفيس الرياضية",
    "serbia and montenegro–slovakia relations": "علاقات سلوفاكيا وصربيا والجبل الأسود",
    "serbia and montenegro–yemen relations": "علاقات اليمن وصربيا والجبل الأسود",
    "kazakhstan–serbia and montenegro relations": "علاقات صربيا والجبل الأسود وكازاخستان",
    "russia–serbia and montenegro relations": "علاقات روسيا وصربيا والجبل الأسود",
    "czech republic–serbia and montenegro relations": "علاقات التشيك وصربيا والجبل الأسود",
    "austrian empire–kingdom of sardinia relations": "علاقات الإمبراطورية النمساوية ومملكة سردينيا",
    "dominica–mexico relations": "علاقات المكسيك ودومينيكا",
    "eswatini–poland relations": "علاقات إسواتيني وبولندا",
    "saint lucia–sri lanka relations": "علاقات سانت لوسيا وسريلانكا",
    "saint lucia–united kingdom sports relations": "علاقات المملكة المتحدة وسانت لوسيا الرياضية",
    "tokelau–united states relations": "علاقات الولايات المتحدة وتوكيلاو",
}

TEMPORAL_CASES = [
    ("test_same", test_same),
    ("test_big_data2", big_data2),
]


@pytest.mark.parametrize("category, expected", test_same.items(), ids=test_same.keys())
@pytest.mark.slow
def test_same(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", big_data2.items(), ids=big_data2.keys())
@pytest.mark.fast
def test_new_relations_resolvers_big_data(category: str, expected: str) -> None:
    label = new_relations_resolvers(category)
    assert label == expected


@pytest.mark.parametrize("name,data", TEMPORAL_CASES)
@pytest.mark.dump
def test_all_dump(name: str, data: str) -> None:
    expected, diff_result = one_dump_test(data, new_relations_resolvers)

    dump_diff(diff_result, f"test_new_relations_resolvers_big_data_{name}")
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
