# -*- coding: utf-8 -*-
"""
TODO: add tests for the new suffixes added related to sports cups in: ArWikiCats.new.handle_suffixes
"""

import pytest

from ArWikiCats.new.handle_suffixes import combine_value_and_label, resolve_sport_category_suffix_with_mapping
