"""
# TODO: ADD SOME DATA FROM D:/categories_bot/langlinks/z2_data/YEAR.json"""

YEAR_PARAM_NAME = "year1"

YEAR_DATA = {
    "{year1} establishments": "تأسيسات سنة {year1}",  # 1243
    "{year1}s disestablishments": "انحلالات عقد {year1}",  # 699
    "{year1} disestablishments": "انحلالات سنة {year1}",  # 699
    "{year1} disestablishments by continent": "انحلالات سنة {year1} حسب القارة",  # 368
    "{year1} disestablishments by country": "انحلالات سنة {year1} حسب البلد",  # 347
    "{year1} establishments by continent": "تأسيسات سنة {year1} حسب القارة",  # 523
    "{year1} establishments by country": "تأسيسات سنة {year1} حسب البلد",  # 731
    "{year1} establishments in ottoman empire": "تأسيسات سنة {year1} في الدولة العثمانية",  # 211
    "{year1} establishments in russian empire": "تأسيسات سنة {year1} في الإمبراطورية الروسية",  # 152
    "{year1} establishments in spanish empire": "تأسيسات سنة {year1} في الإمبراطورية الإسبانية",  # 256
    "{year1} elections": "انتخابات {year1}",  # 214
    # "{year1} elections": "انتخابات في {year1}",  # 214
    "{year1} novels": "روايات {year1}",  # 317
    "{year1} sports-events": "أحداث {year1} الرياضية",
    "{year1} sports events": "أحداث {year1} الرياضية",  # 1295
    "{year1} censuses": "تعداد السكان في {year1}",
    "{year1} science fiction works": "أعمال خيال علمي {year1}",
    "{year1} controversies": "خلافات {year1}",
    "{year1} floods": "فيضانات {year1}",
    "{year1} mass shootings": "إطلاق نار عشوائي {year1}",
    "{year1} murders": "جرائم قتل في {year1}",
    # "{year1} murders": "قتل في {year1}",  # 300
    "{year1} music": "الموسيقى في {year1}",
    "{year1} theatre": "المسرح في {year1}",
    "{year1} cookbooks": "كتب طبخ {year1}",
    "{year1} musicals": "مسرحيات غنائية {year1}",
    "{year1} racehorse deaths": "خيول سباق نفقت في {year1}",
    "{year1} mining disasters": "كوارث التعدين {year1}",
    "{year1} albums": "ألبومات {year1}",
    "{year1} Christmas albums": "ألبومات عيد الميلاد {year1}",
    "{year1} landslides": "انهيارات أرضية {year1}",
    "{year1} publications": "منشورات {year1}",
    "{year1} revolutions": "ثورات {year1}",
    "{year1} transport disasters": "كوارث نقل في {year1}",
    "{year1} mosques": "مساجد {year1}",
    "{year1} texts": "نصوص {year1}",
    "{year1} executions": "إعدامات في {year1}",
    "{year1} buddhist temples": "معابد بوذية {year1}",
    "{year1} jain temples": "معابد جاينية {year1}",
    "{year1} hindu temples": "معابد هندوسية {year1}",
    "{year1} literature": "أدب {year1}",
    "{year1} essays": "مقالات {year1}",
    "{year1} operas": "أوبيرات {year1}",
    "{year1} missing person cases": "قضايا أشخاص مفقودين في {year1}",
    "{year1} meteorology": "الأرصاد الجوية في {year1}",
    "refugee olympic team in {year1} summer olympics": "فريق الرياضيين الأولمبيين اللاجئين في الألعاب الأولمبية الصيفية {year1}",
    "refugee olympic team in {year1} winter olympics": "فريق الرياضيين الأولمبيين اللاجئين في الألعاب الأولمبية الشتوية {year1}",
    "{year1} television series-debuts": "مسلسلات تلفزيونية بدأ عرضها في {year1}",
    "{year1} television series debuts": "مسلسلات تلفزيونية بدأ عرضها في {year1}",
    "{year1} in mass media": "وسائل الإعلام في {year1}",  # 126
    "airlines established in {year1}": "شركات طيران أسست في {year1}",  # 259
    "animals described in {year1}": "حيوانات وصفت في {year1}",  # 266
    "articles containing potentially dated statements from {year1}": "مقالات فيها عبارات متقادمة منذ {year1}",  # 183
    "articles lacking reliable references from {year1}": "مقالات ينقصها مصادر موثوق بها منذ {year1}",  # 181
    "articles lacking sources from {year1}": "مقالات بدون مصدر منذ {year1}",  # 178
    "articles with dead external links from {year1}": "مقالات ذات وصلات خارجية مكسورة منذ {year1}",  # 171
    "articles with unsourced statements from {year1}": "مقالات ذات عبارات بحاجة لمصادر منذ {year1}",  # 212
    "association football clubs established in {year1}": "أندية كرة قدم أسست في {year1}",  # 167
    "astronomical objects discovered in {year1}": "أجرام فلكية اكتشفت في {year1}",  # 242
    "awards established in {year1}": "جوائز أسست في {year1}",  # 190
    "birds described in {year1}": "طيور وصفت في {year1}",  # 225
    "buildings and structures completed in {year1}": "مبان ومنشآت اكتملت في {year1}",  # 791
    "churches completed in {year1}": "كنائس اكتملت في {year1}",  # 247
    "clean-up categories from {year1}": "تصنيفات تهذيب منذ {year1}",  # 188
    "companies established in {year1} by country": "شركات أسست في {year1} حسب البلد",  # 235
    "companies established in {year1}": "شركات أسست في {year1}",  # 282
    "conflicts in {year1}": "نزاعات في {year1}",  # 817
    "educational institutions established in {year1}": "هيئات تعليمية أسست في {year1}",  # 266
    "educational organizations established in {year1}": "منظمات تعليمية أسست في {year1}",  # 276
    "event venues established in {year1}": "صالات أحداث أسست في {year1}",  # 170
    "fiction set in {year1}": "أعمال خيالية في {year1}",  # 206
    "films set in {year1}": "أفلام تقع أحداثها في {year1}",  # 283
    "fish described in {year1}": "أسماك وصفت في {year1}",  # 222
    "fossil taxa described in {year1}": "أصنوفات أحفورية وصفت في {year1}",  # 201
    "fungi described in {year1}": "فطريات وصفت في {year1}",  # 206
    "government agencies established in {year1}": "وكالات حكومية أسست في {year1}",  # 165
    "houses completed in {year1}": "منازل اكتملت في {year1}",  # 213
    "infrastructure completed in {year1}": "بنية تحتية اكتملت في {year1}",  # 268
    "insects described in {year1}": "حشرات وصفت في {year1}",  # 199
    "mammals described in {year1}": "ثدييات وصفت في {year1}",  # 247
    "manufacturing companies established in {year1}": "شركات تصنيع أسست في {year1}",  # 194
    "maritime incidents in {year1}": "حوادث بحرية في {year1}",  # 256
    "mass murder in {year1}": "قتل جماعي في {year1}",  # 172
    "military units and formations established in {year1}": "وحدات وتشكيلات عسكرية أسست في {year1}",  # 196
    "mosques completed in {year1}": "مساجد اكتملت في {year1}",  # 243
    "murder in {year1}": "قتل في {year1}",  # 241
    "museums established in {year1}": "متاحف أسست في {year1}",  # 129
    "organizations disestablished in {year1}": "منظمات انحلت في {year1}",  # 170
    "organizations established in {year1}": "منظمات أسست في {year1}",  # 259
    "people murdered in {year1}": "أشخاص قتلوا في {year1}",  # 210
    "plants described in {year1}": "نباتات وصفت في {year1}",  # 260
    "political parties established in {year1}": "أحزاب سياسية أسست في {year1}",  # 168
    "populated places established in {year1}": "أماكن مأهولة أسست في {year1}",  # 521
    "publications established in {year1}": "منشورات أسست في {year1}",  # 217
    "railway stations opened in {year1}": "محطات السكك الحديدية افتتحت في {year1}",  # 169
    "religious organizations established in {year1}": "منظمات دينية أسست في {year1}",  # 169
    "reptiles described in {year1}": "زواحف وصفت في {year1}",  # 192
    "residential buildings completed in {year1}": "مبان سكنية اكتملت في {year1}",  # 182
    "species described in {year1}": "أنواع وصفت في {year1}",  # 271
    "sports clubs and teams established in {year1}": "أندية وفرق رياضية أسست في {year1}",  # 152
    "sports organizations established in {year1}": "منظمات رياضية أسست في {year1}",  # 170
    "states and territories disestablished in {year1}": "دول وأقاليم انحلت في {year1}",  # 174
    "states and territories established in {year1}": "دول وأقاليم أسست في {year1}",  # 224
    "taxa described in {year1}": "أصنوفات وصفت في {year1}",  # 270
    "transport companies established in {year1}": "شركات نقل أسست في {year1}",
    "transport disasters in {year1}": "كوارث نقل في {year1}",  # 149
    "transport infrastructure completed in {year1}": "بنية تحتية للنقل اكتملت في {year1}",  # 233
    "universities and colleges established in {year1}": "جامعات وكليات أسست في {year1}",  # 189
    "{year1} architecture": "عمارة {year1}",  # 215
    "{year1} bc deaths": "وفيات {year1} ق م",  # 440
    "{year1} bc": "{year1} ق م",  # 649
    "{year1} beginnings": "بدايات {year1}",  # 1946
    "{year1} attacks": "هجمات {year1}",
    "{year1} births": "مواليد {year1}",  # 1923
    "{year1} books": "كتب {year1}",  # 581
    "{year1} by city": "{year1} حسب المدينة",  # 233
    "{year1} by continent": "{year1} حسب القارة",  # 1098
    "{year1} by country": "{year1} حسب البلد",  # 1111
    "{year1} by month": "أحداث {year1} حسب الشهر",  # 225
    "{year1} conflicts": "نزاعات في {year1}",  # 215
    "{year1} crimes by continent": "جرائم {year1} حسب القارة",  # 285
    "{year1} crimes by country": "جرائم {year1} حسب البلد",  # 224
    "{year1} crimes": "جرائم {year1}",  # 601
    "{year1} deaths": "وفيات {year1}",  # 2045
    "{year1} disasters by country": "كوارث في {year1} حسب البلد",  # 86
    "{year1} disasters": "كوارث {year1}",  # 322
    "{year1} documents": "وثائق في {year1}",  # 179
    "{year1} domestic association football cups": "كؤوس كرة قدم محلية {year1}",  # 288
    "{year1} domestic association football leagues": "دوريات كرة قدم محلية {year1}",  # 142
    "{year1} earthquakes": "زلازل {year1}",  # 171
    "{year1} elections by country": "انتخابات {year1} حسب البلد",  # 189
    "{year1} endings": "نهايات {year1}",  # 1970
    "{year1} events by continent": "أحداث {year1} حسب القارة",  # 967
    "{year1} events by country": "أحداث {year1} حسب البلد",  # 956
    "{year1} events by month": "أحداث {year1} حسب الشهر",  # 228
    "{year1} events": "أحداث {year1}",  # 2020
    "{year1} in art": "الفن في {year1}",  # 449
    "{year1} in association football by continent": "كرة القدم في {year1} حسب القارة",  # 180
    "{year1} in association football": "كرة القدم في {year1}",  # 350
    "{year1} in biology": "علم الأحياء في {year1}",  # 180
    "{year1} in christianity": "المسيحية في {year1}",  # 369
    "{year1} in domestic association football": "كرة قدم محلية في {year1}",  # 285
    # "{year1} in economic history": "الاقتصاد في {year1}",  # 251
    "{year1} in economics": "{year1} في الاقتصاد",  # 287
    "{year1} in education": "التعليم في {year1}",  # 258
    "{year1} in english sport": "رياضة إنجليزية في {year1}",  # 164
    "{year1} in film": "{year1} في الأفلام",  # 140
    "{year1} in football": "{year1} في كرة القدم",  # 163
    "{year1} in health": "الصحة في {year1}",  # 194
    "{year1} in international relations": "علاقات دولية في {year1}",  # 468
    "{year1} in law": "القانون في {year1}",  # 477
    "{year1} in literature": "الأدب في {year1}",  # 474
    "{year1} in military history": "التاريخ العسكري في {year1}",  # 570
    "{year1} in music": "موسيقى في {year1}",  # 169
    "{year1} in paleontology": "علم الأحياء القديمة في {year1}",  # 215
    "{year1} in politics": "السياسة في {year1}",  # 552
    "{year1} in rail transport": "السكك الحديدية في {year1}",  # 182
    "{year1} in religion": "الدين في {year1}",  # 592
    "{year1} in science": "العلم في {year1}",  # 540
    "{year1} in sport by continent": "رياضة في {year1} حسب القارة",  # 181
    "{year1} in sports by country": "ألعاب رياضية في {year1} حسب البلد",  # 190
    "{year1} in sports": "ألعاب رياضية في {year1}",  # 1295
    "{year1} in technology": "التقانة في {year1}",  # 164
    "{year1} in tennis": "كرة المضرب في {year1}",  # 164
    "{year1} in arts": "الفنون في {year1}",  # 734
    "{year1} in environment": "البيئة في {year1}",  # 283
    "{year1} in ottoman empire": "الدولة العثمانية في {year1}",  # 349
    "{year1} in russian empire": "الإمبراطورية الروسية في {year1}",  # 192
    "{year1} in spanish empire": "الإمبراطورية الإسبانية في {year1}",  # 315
    "{year1} in theatre": "المسرح في {year1}",  # 262
    "{year1} in transport": "النقل في {year1}",  # 279
    "{year1} introductions": "استحداثات {year1}",  # 275
    "{year1} murders by continent": "جرائم قتل في {year1} حسب القارة",  # 157
    "{year1} murders by country": "جرائم قتل في {year1} حسب البلد",  # 187
    "{year1} natural disasters": "كوارث طبيعية في {year1}",  # 132
    "{year1} non fiction books": "كتب غير خيالية {year1}",  # 312
    "{year1} non-fiction books": "كتب غير خيالية {year1}",  # 312
    "{year1} paintings": "لوحات {year1}",  # 346
    "{year1} plays": "مسرحيات {year1}",  # 257
    "{year1} poems": "قصائد {year1}",  # 180
    "{year1} sculptures": "منحوتات {year1}",  # 179
    "{year1} ships": "سفن {year1}",  # 200
    "{year1} short stories": "قصص قصيرة {year1}",  # 177
    "{year1} songs": "أغاني {year1}",  # 172
    "{year1} treaties": "معاهدات في {year1}",  # 283
    "{year1} works": "أعمال في {year1}",  # 945
    "{year1}": "{year1}",  # 2387
}
