#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data_skip = {
    "Category:Defunct airports in Papua New Guinea": "تصنيف:مطارات سابقة في بابوا غينيا الجديدة",
    "Category:April 2023 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في أبريل 2023",
    "Category:February 2024 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في فبراير 2024",
    "Category:May 2024 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في مايو 2024",
    "Category:March 2024 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في مارس 2024",
    "Category:January 2024 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في يناير 2024",
    "Category:September 2022 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في سبتمبر 2022",
    "Category:September 2025 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في سبتمبر 2025",
    "Category:October 2022 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في أكتوبر 2022",
    "Category:October 2023 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في أكتوبر 2023",
    "Category:May 2016 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في مايو 2016",
    "Category:July 2022 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في يوليو 2022",
    "Category:June 2016 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في يونيو 2016",
    "Category:2020 in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في 2020",
}

data_0 = {
    "Category:Papua New Guinea men's international soccer players": "تصنيف:لاعبو كرة قدم دوليون من بابوا غينيا الجديدة",
    "Category:Papua New Guinea women's international soccer players": "تصنيف:لاعبات كرة قدم دوليات من بابوا غينيا الجديدة",
    "Category:Buka, Papua New Guinea": "",
    "Category:Southern Region, Papua New Guinea geography stubs": "",
    "Category:Southern Region, Papua New Guinea": "",
    "Category:1982 in Papua New Guinea rugby league": "",
    "Category:1986 in Papua New Guinea rugby league": "",
    "Category:19th-century disasters in Papua New Guinea": "",
    "Category:2009 in Papua New Guinea rugby league": "",
    "Category:2010 in Papua New Guinea rugby league": "",
    "Category:2013 in Papua New Guinea rugby league": "",
    "Category:2014 in Papua New Guinea rugby league": "",
    "Category:2015 in Papua New Guinea rugby league": "",
    "Category:2016 in Papua New Guinea rugby league": "",
    "Category:2017 in Papua New Guinea rugby league": "",
    "Category:2018 in Papua New Guinea rugby league": "",
    "Category:2019 in Papua New Guinea rugby league": "",
    "Category:2020 in Papua New Guinea rugby league": "",
    "Category:2021 in Papua New Guinea rugby league": "",
    "Category:2022 in Papua New Guinea rugby league": "",
    "Category:2023 in Papua New Guinea rugby league": "",
    "Category:A-Class Papua New Guinea articles": "",
    "Category:Airfields of the United States Army Air Forces in Papua New Guinea": "",
    "Category:Apostolic nuncios to Papua New Guinea": "",
    "Category:Articles containing Awa (Papua New Guinea)-language text": "",
    "Category:Articles containing Kela (Papua New Guinea)-language text": "",
    "Category:Articles containing Kele (Papua New Guinea)-language text": "",
    "Category:Articles containing Kol (Papua New Guinea)-language text": "",
    "Category:Articles containing Kuman (Papua New Guinea)-language text": "",
    "Category:Articles containing Sepa (Papua New Guinea)-language text": "",
    "Category:Articles containing Toura (Papua New Guinea)-language text": "",
    "Category:Articles containing Ura (Papua New Guinea)-language text": "",
    "Category:Atolls of Papua New Guinea": "",
    "Category:Attack-class patrol boats of the Papua New Guinea Defence Force": "",
    "Category:Australian judges on the courts of Papua New Guinea": "",
    "Category:Aviation history of Papua New Guinea": "",
    "Category:B-Class Papua New Guinea articles": "",
    "Category:Balikpapan-class landing craft heavy of the Papua New Guinea Defence Force": "",
    "Category:Bilateral sports relations of Papua New Guinea": "",
    "Category:Burials in Commonwealth War Graves Commission cemeteries in Papua New Guinea": "",
    "Category:By-elections in Papua New Guinea": "",
    "Category:C-Class Papua New Guinea articles": "",
    "Category:Calderas of Papua New Guinea": "",
    "Category:Category-Class Papua New Guinea pages": "",
    "Category:Catholic Church in Papua New Guinea": "",
    "Category:Catholic elementary and primary schools in Papua New Guinea": "",
    "Category:Catholic schools in Papua New Guinea": "",
    "Category:Catholic secondary schools in Papua New Guinea": "",
    "Category:Central Province (Papua New Guinea)": "",
    "Category:Chief Ombudsmen of Papua New Guinea": "",
    "Category:Commanders of the Papua New Guinea Defence Force": "",
    "Category:Commissioners of the Royal Papua New Guinea Constabulary": "",
    "Category:Commonwealth War Graves Commission cemeteries in Papua New Guinea": "",
    "Category:Congregationalism in Papua New Guinea": "",
    "Category:Congregationalist missionaries in Papua New Guinea": "",
    "Category:Consumer organisations in Papua New Guinea": "",
    "Category:Cook Island expatriates in Papua New Guinea": "",
    "Category:Cook Islands–Papua New Guinea relations": "",
    "Category:Copper mines in Papua New Guinea": "",
    "Category:Copper mining companies of Papua New Guinea": "",
    "Category:Country data templates of Papua New Guinea": "",
    "Category:Country data templates of subdivisions of Papua New Guinea": "",
    "Category:Cricket grounds in Papua New Guinea": "",
    "Category:Disambig-Class Papua New Guinea pages": "",
    "Category:Draft-Class Papua New Guinea pages": "",
    "Category:Elementary and primary schools in Papua New Guinea": "",
    "Category:Endemic amphibian species of Papua New Guinea": "",
    "Category:Endemic birds of Papua New Guinea": "",
    "Category:Endemic fauna of Papua New Guinea": "",
    "Category:Endemic flora of Papua New Guinea": "",
    "Category:Endemic moth species of Papua New Guinea": "",
    "Category:Endemic reptile species of Papua New Guinea": "",
    "Category:Environmentalism in Papua New Guinea": "",
    "Category:Expatriate judges on the courts of Papua New Guinea": "",
    "Category:Extinct languages of Papua New Guinea": "",
    "Category:FA-Class Papua New Guinea articles": "",
    "Category:File-Class Papua New Guinea pages": "",
    "Category:FL-Class Papua New Guinea articles": "",
    "Category:FM-Class Papua New Guinea pages": "",
    "Category:Folk festivals in Papua New Guinea": "",
    "Category:Foreign charities operating in Papua New Guinea": "",
    "Category:Forestry in Papua New Guinea": "",
    "Category:Fossils of Papua New Guinea": "",
    "Category:Freshwater fish of Papua New Guinea": "",
    "Category:GA-Class Papua New Guinea articles": "",
    "Category:Gold mines in Papua New Guinea": "",
    "Category:Gold mining companies of Papua New Guinea": "",
    "Category:Government departments of Papua New Guinea": "",
    "Category:Governors of Central Province (Papua New Guinea)": "",
    "Category:Governors of the National Capital District (Papua New Guinea)": "",
    "Category:Heads of state of Papua New Guinea": "",
    "Category:High commissioners of Australia to Papua New Guinea": "",
    "Category:High commissioners of Bangladesh to Papua New Guinea": "",
    "Category:High commissioners of Brunei to Papua New Guinea": "",
    "Category:High commissioners of Canada to Papua New Guinea": "",
    "Category:High commissioners of Fiji to Papua New Guinea": "",
    "Category:High commissioners of Ghana to Papua New Guinea": "",
    "Category:High commissioners of Malaysia to Papua New Guinea": "",
    "Category:High commissioners of New Zealand to Papua New Guinea": "",
    "Category:High commissioners of Papua New Guinea": "",
    "Category:High commissioners of Papua New Guinea to Australia": "",
    "Category:High commissioners of Papua New Guinea to Canada": "",
    "Category:High commissioners of Papua New Guinea to Cyprus": "",
    "Category:High commissioners of Papua New Guinea to Fiji": "",
    "Category:High commissioners of Papua New Guinea to New Zealand": "",
    "Category:High commissioners of Papua New Guinea to South Africa": "",
    "Category:High commissioners of Papua New Guinea to the United Kingdom": "",
    "Category:High commissioners of Singapore to Papua New Guinea": "",
    "Category:High commissioners of Sri Lanka to Papua New Guinea": "",
    "Category:High commissioners of the Cook Islands to Papua New Guinea": "",
    "Category:High commissioners of the United Kingdom to Papua New Guinea": "",
    "Category:High commissioners of Tuvalu to Papua New Guinea": "",
    "Category:High commissioners to Papua New Guinea": "",
    "Category:High schools and secondary schools in Papua New Guinea": "",
    "Category:High-importance Papua New Guinea articles": "",
    "Category:Hiking in Papua New Guinea": "",
    "Category:History of sport in Papua New Guinea": "",
    "Category:Holy See–Papua New Guinea relations": "",
    "Category:Important Bird Areas of Papua New Guinea": "",
    "Category:Industry in Papua New Guinea": "",
    "Category:Infectious disease deaths in Papua New Guinea": "",
    "Category:Infobox road instances in Papua New Guinea": "",
    "Category:International Baccalaureate schools in Papua New Guinea": "",
    "Category:International club association football competitions hosted by Papua New Guinea": "",
    "Category:Lagoons of Papua New Guinea": "",
    "Category:Languages of Central Province (Papua New Guinea)": "",
    "Category:Languages of Southern Region (Papua New Guinea)": "",
    "Category:Languages of Western Province (Papua New Guinea)": "",
    "Category:Leaders of the opposition (Papua New Guinea)": "",
    "Category:LGBTQ in Papua New Guinea": "",
    "Category:List-Class Papua New Guinea articles": "",
    "Category:Lists of members of the National Parliament of Papua New Guinea": "",
    "Category:Local-level governments of Central Province (Papua New Guinea)": "",
    "Category:Local-level governments of National Capital District (Papua New Guinea)": "",
    "Category:Local-level governments of Papua New Guinea": "",
    "Category:Local-level governments of Western Province (Papua New Guinea)": "",
    "Category:Low-importance Papua New Guinea articles": "",
    "Category:Lutheran missionaries in Papua New Guinea": "",
    "Category:Lutheranism in Papua New Guinea": "",
    "Category:Masks in Papua New Guinea": "",
    "Category:Members of provincial assemblies of Papua New Guinea": "",
    "Category:Members of the National Parliament of Papua New Guinea": "",
    "Category:Methodism in Papua New Guinea": "",
    "Category:Mid-importance Papua New Guinea articles": "",
    "Category:Military locations of Papua New Guinea": "",
    "Category:Ministers of internal finance of Papua New Guinea": "",
    "Category:Ministers of primary industry of Papua New Guinea": "",
    "Category:Moths of Papua New Guinea": "",
    "Category:NA-Class Papua New Guinea pages": "",
    "Category:NA-importance Papua New Guinea pages": "",
    "Category:National Alliance Party (Papua New Guinea) politicians": "",
    "Category:National Capital District (Papua New Guinea)": "",
    "Category:National high schools in Papua New Guinea": "",
    "Category:National Parliament of Papua New Guinea": "",
    "Category:Nature conservation in Papua New Guinea": "",
    "Category:New Generation Party (Papua New Guinea) politicians": "",
    "Category:New Zealand expatriate sportspeople in Papua New Guinea": "",
    "Category:New Zealand expatriates in Papua New Guinea": "",
    "Category:News media in Papua New Guinea": "",
    "Category:Olympic sailors for Papua New Guinea": "",
    "Category:Orchids of Papua New Guinea": "",
    "Category:Organized events in Papua New Guinea": "",
    "Category:Orogenies of Papua New Guinea": "",
    "Category:Pacific Games bronze medalists for Papua New Guinea": "",
    "Category:Pacific Games gold medalists for Papua New Guinea": "",
    "Category:Pacific Games silver medalists for Papua New Guinea": "",
    "Category:Palm oil production in Papua New Guinea": "",
    "Category:Papua New Guinea and the Commonwealth of Nations": "",
    "Category:Papua New Guinea articles by importance": "",
    "Category:Papua New Guinea articles by quality": "",
    "Category:Papua New Guinea articles missing geocoordinate data": "",
    "Category:Papua New Guinea articles needing attention": "",
    "Category:Papua New Guinea at the 2024 OFC Men's Nations Cup": "",
    "Category:Papua New Guinea at the OFC Men's Nations Cup": "",
    "Category:Papua New Guinea cricket navigational boxes": "",
    "Category:Papua New Guinea cricket templates": "",
    "Category:Papua New Guinea cricket-related lists": "",
    "Category:Papua New Guinea education-related lists": "",
    "Category:Papua New Guinea football team navigational boxes": "",
    "Category:Papua New Guinea geography stubs": "",
    "Category:Papua New Guinea geography-related lists": "",
    "Category:Papua New Guinea history-related lists": "",
    "Category:Papua New Guinea Hunters": "",
    "Category:Papua New Guinea Hunters captains": "",
    "Category:Papua New Guinea Hunters players": "",
    "Category:Papua New Guinea Hunters templates": "",
    "Category:Papua New Guinea island stubs": "",
    "Category:Papua New Guinea location map modules": "",
    "Category:Papua New Guinea modules": "",
    "Category:Papua New Guinea national netball team series": "",
    "Category:Papua New Guinea National Rugby League": "",
    "Category:Papua New Guinea national rugby league team captains": "",
    "Category:Papua New Guinea national rugby league team tours": "",
    "Category:Papua New Guinea One Day International cricketers": "",
    "Category:Papua New Guinea Party politicians": "",
    "Category:Papua New Guinea politics-related lists": "",
    "Category:Papua New Guinea religion-related lists": "",
    "Category:Papua New Guinea river stubs": "",
    "Category:Papua New Guinea rugby union templates": "",
    "Category:Papua New Guinea sport-related lists": "",
    "Category:Papua New Guinea stub templates": "",
    "Category:Papua New Guinea stubs": "",
    "Category:Papua New Guinea transport-related lists": "",
    "Category:Papua New Guinea Twenty20 International cricketers": "",
    "Category:Papua New Guinea University of Technology alumni": "",
    "Category:Papua New Guinea user categories": "",
    "Category:Papua New Guinea user templates": "",
    "Category:Papua New Guinea women One Day International cricketers": "",
    "Category:Papua New Guinea women Twenty20 International cricketers": "",
    "Category:Papua New Guinea–European Union relations": "",
    "Category:Papua New Guinea–Solomon Islands border": "",
    "Category:Papua New Guinea–Solomon Islands relations": "",
    "Category:Papua New Guinea–Vanuatu relations": "",
    "Category:Patrol vessels of the Papua New Guinea Defence Force": "",
    "Category:People from Central Province (Papua New Guinea)": "",
    "Category:People from Southern Region (Papua New Guinea)": "",
    "Category:People from the National Capital District (Papua New Guinea)": "",
    "Category:People from the Western Province (Papua New Guinea)": "",
    "Category:People's First Party (Papua New Guinea) politicians": "",
    "Category:People's National Congress (Papua New Guinea) politicians": "",
    "Category:Permanent representatives of Papua New Guinea to the International Maritime Organization": "",
    "Category:Philately of Papua New Guinea": "",
    "Category:Politics of Central Province (Papua New Guinea)": "",
    "Category:Politics of the National Capital District (Papua New Guinea)": "",
    "Category:Populated places in Central Province (Papua New Guinea)": "",
    "Category:Populated places in Southern Region (Papua New Guinea)": "",
    "Category:Populated places in the Western Province (Papua New Guinea)": "",
    "Category:Portal-Class Papua New Guinea pages": "",
    "Category:Project-Class Papua New Guinea pages": "",
    "Category:Ramsar sites in Papua New Guinea": "",
    "Category:Redirect-Class Papua New Guinea pages": "",
    "Category:Refugees in Papua New Guinea": "",
    "Category:Roman Catholic cathedrals in Papua New Guinea": "",
    "Category:Roman Catholic dioceses in Papua New Guinea": "",
    "Category:Roman Catholic missionaries in Papua New Guinea": "",
    "Category:Rugby league players from Central Province (Papua New Guinea)": "",
    "Category:Rugby league players from the National Capital District (Papua New Guinea)": "",
    "Category:Rugby league tours of Papua New Guinea": "",
    "Category:Scientific organisations based in Papua New Guinea": "",
    "Category:Scouting and Guiding in Papua New Guinea": "",
    "Category:Shield volcanoes of Papua New Guinea": "",
    "Category:Ships of the Papua New Guinea Defence Force": "",
    "Category:Sign languages of Papua New Guinea": "",
    "Category:Social Democratic Party (Papua New Guinea) politicians": "",
    "Category:Solomon Islands expatriate sportspeople in Papua New Guinea": "",
    "Category:Solomon Islands expatriates in Papua New Guinea": "",
    "Category:Speakers of the National Parliament of Papua New Guinea": "",
    "Category:Start-Class Papua New Guinea articles": "",
    "Category:Stub-Class Papua New Guinea articles": "",
    "Category:Surface mines in Papua New Guinea": "",
    "Category:Teaching in Papua New Guinea": "",
    "Category:Template-Class Papua New Guinea pages": "",
    "Category:Top-importance Papua New Guinea articles": "",
    "Category:Trees of Papua New Guinea": "",
    "Category:Unassessed Papua New Guinea articles": "",
    "Category:United Party (Papua New Guinea) politicians": "",
    "Category:Unknown-importance Papua New Guinea articles": "",
    "Category:Vice-chancellors of universities in Papua New Guinea": "",
    "Category:Western Province (Papua New Guinea)": "",
    "Category:Wikipedia categories named after organisations based in Papua New Guinea": "",
    "Category:Wikipedia categories named after populated places in Papua New Guinea": "",
    "Category:Wikipedia requested images of people of Papua New Guinea": "",
    "Category:Wikipedia requested maps in Papua New Guinea": "",
    "Category:Wikipedia requested photographs in Papua New Guinea": "",
    "Category:Wikipedians in Papua New Guinea": "",
    "Category:Wikipedians interested in Papua New Guinea": "",
    "Category:WikiProject Papua New Guinea": "",
    "Category:WikiProject Papua New Guinea articles": "",
    "Category:WikiProject Papua New Guinea participants": "",
    "Category:WikiProject Papua New Guinea templates": "",
    "Category:Women members of the National Parliament of Papua New Guinea": "",
    "Category:Women's rights in Papua New Guinea": "",
    "Category:World Athletics Championships athletes for Papua New Guinea": "",
    "Category:World War I sites in Papua New Guinea": "",
    "Category:World War II airfields in Papua New Guinea": "",
    "Category:World War II sites in Papua New Guinea": "",
}

data_1 = {
    "Category:Chief justices of Papua New Guinea": "تصنيف:رؤساء قضاء بابوا غينيا الجديدة",
    "Category:Coaches of the Papua New Guinea national cricket team": "تصنيف:مدربو منتخب بابوا غينيا الجديدة للكريكت",
    "Category:Foreign relations of Papua New Guinea": "تصنيف:علاقات بابوا غينيا الجديدة الخارجية",
    "Category:National symbols of Papua New Guinea": "تصنيف:رموز بابوا غينيا الجديدة الوطنية",
    "Category:Orders, decorations, and medals of Papua New Guinea": "تصنيف:مراتب تشريفية وأوسمة وميداليات بابوا غينيا الجديدة",
    "Category:1910s establishments in Papua New Guinea": "تصنيف:تأسيسات عقد 1910 في بابوا غينيا الجديدة",
    "Category:1910s in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في عقد 1910",
    "Category:1920s establishments in Papua New Guinea": "تصنيف:تأسيسات عقد 1920 في بابوا غينيا الجديدة",
    "Category:1920s in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في عقد 1920",
    "Category:1927 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1927 في بابوا غينيا الجديدة",
    "Category:1929 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1929 في بابوا غينيا الجديدة",
    "Category:1940s disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في عقد 1940",
    "Category:1940s establishments in Papua New Guinea": "تصنيف:تأسيسات عقد 1940 في بابوا غينيا الجديدة",
    "Category:1940s in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في عقد 1940",
    "Category:1942 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 1942",
    "Category:1948 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1948 في بابوا غينيا الجديدة",
    "Category:1949 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1949 في بابوا غينيا الجديدة",
    "Category:1950s disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في عقد 1950",
    "Category:1950s establishments in Papua New Guinea": "تصنيف:تأسيسات عقد 1950 في بابوا غينيا الجديدة",
    "Category:1950s in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في عقد 1950",
    "Category:1951 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 1951",
    "Category:1952 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1952 في بابوا غينيا الجديدة",
    "Category:1960 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1960 في بابوا غينيا الجديدة",
    "Category:1960s disestablishments in Papua New Guinea": "تصنيف:انحلالات عقد 1960 في بابوا غينيا الجديدة",
    "Category:1960s establishments in Papua New Guinea": "تصنيف:تأسيسات عقد 1960 في بابوا غينيا الجديدة",
    "Category:1960s in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في عقد 1960",
    "Category:1961 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1961 في بابوا غينيا الجديدة",
    "Category:1962 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1962 في بابوا غينيا الجديدة",
    "Category:1963 disestablishments in Papua New Guinea": "تصنيف:انحلالات سنة 1963 في بابوا غينيا الجديدة",
    "Category:1963 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1963 في بابوا غينيا الجديدة",
    "Category:1964 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1964 في بابوا غينيا الجديدة",
    "Category:1965 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1965 في بابوا غينيا الجديدة",
    "Category:1966 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1966 في بابوا غينيا الجديدة",
    "Category:1968 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1968 في بابوا غينيا الجديدة",
    "Category:1969 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1969 في بابوا غينيا الجديدة",
    "Category:1970 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 1970",
    "Category:1970s disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في عقد 1970",
    "Category:1970s disestablishments in Papua New Guinea": "تصنيف:انحلالات عقد 1970 في بابوا غينيا الجديدة",
    "Category:1970s establishments in Papua New Guinea": "تصنيف:تأسيسات عقد 1970 في بابوا غينيا الجديدة",
    "Category:1970s in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في عقد 1970",
    "Category:1971 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 1971",
    "Category:1972 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1972 في بابوا غينيا الجديدة",
    "Category:1973 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1973 في بابوا غينيا الجديدة",
    "Category:1974 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1974 في بابوا غينيا الجديدة",
    "Category:1975 disestablishments in Papua New Guinea": "تصنيف:انحلالات سنة 1975 في بابوا غينيا الجديدة",
    "Category:1975 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1975 في بابوا غينيا الجديدة",
    "Category:1976 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1976 في بابوا غينيا الجديدة",
    "Category:1977 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1977 في بابوا غينيا الجديدة",
    "Category:1978 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1978 في بابوا غينيا الجديدة",
    "Category:1980s disestablishments in Papua New Guinea": "تصنيف:انحلالات عقد 1980 في بابوا غينيا الجديدة",
    "Category:1980s establishments in Papua New Guinea": "تصنيف:تأسيسات عقد 1980 في بابوا غينيا الجديدة",
    "Category:1980s in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في عقد 1980",
    "Category:1981 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1981 في بابوا غينيا الجديدة",
    "Category:1982 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1982 في بابوا غينيا الجديدة",
    "Category:1983 disestablishments in Papua New Guinea": "تصنيف:انحلالات سنة 1983 في بابوا غينيا الجديدة",
    "Category:1984 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1984 في بابوا غينيا الجديدة",
    "Category:1985 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1985 في بابوا غينيا الجديدة",
    "Category:1986 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1986 في بابوا غينيا الجديدة",
    "Category:1987 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1987 في بابوا غينيا الجديدة",
    "Category:1989 disestablishments in Papua New Guinea": "تصنيف:انحلالات سنة 1989 في بابوا غينيا الجديدة",
    "Category:1990 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1990 في بابوا غينيا الجديدة",
    "Category:1990s disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في عقد 1990",
    "Category:1990s establishments in Papua New Guinea": "تصنيف:تأسيسات عقد 1990 في بابوا غينيا الجديدة",
    "Category:1990s in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في عقد 1990",
    "Category:1991 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1991 في بابوا غينيا الجديدة",
    "Category:1992 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1992 في بابوا غينيا الجديدة",
    "Category:1993 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 1993",
    "Category:1994 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1994 في بابوا غينيا الجديدة",
    "Category:1995 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1995 في بابوا غينيا الجديدة",
    "Category:1997 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1997 في بابوا غينيا الجديدة",
    "Category:1998 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 1998",
    "Category:1999 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 1999 في بابوا غينيا الجديدة",
    "Category:19th century in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في القرن 19",
    "Category:2000 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2000",
    "Category:2000s disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في عقد 2000",
    "Category:2000s establishments in Papua New Guinea": "تصنيف:تأسيسات عقد 2000 في بابوا غينيا الجديدة",
    "Category:2000s in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في عقد 2000",
    "Category:2001 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2001 في بابوا غينيا الجديدة",
    "Category:2002 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2002",
    "Category:2003 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2003 في بابوا غينيا الجديدة",
    "Category:2004 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2004 في بابوا غينيا الجديدة",
    "Category:2005 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2005 في بابوا غينيا الجديدة",
    "Category:2006 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2006 في بابوا غينيا الجديدة",
    "Category:2007 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2007 في بابوا غينيا الجديدة",
    "Category:2008 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2008",
    "Category:2008 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2008 في بابوا غينيا الجديدة",
    "Category:2009 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2009",
    "Category:2009 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2009 في بابوا غينيا الجديدة",
    "Category:2010 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2010",
    "Category:2010 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2010 في بابوا غينيا الجديدة",
    "Category:2010s disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في عقد 2010",
    "Category:2010s establishments in Papua New Guinea": "تصنيف:تأسيسات عقد 2010 في بابوا غينيا الجديدة",
    "Category:2010s in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في عقد 2010",
    "Category:2011 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2011",
    "Category:2011 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2011 في بابوا غينيا الجديدة",
    "Category:2012 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2012",
    "Category:2012 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2012 في بابوا غينيا الجديدة",
    "Category:2013 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2013",
    "Category:2013 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2013 في بابوا غينيا الجديدة",
    "Category:2014 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2014 في بابوا غينيا الجديدة",
    "Category:2015 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2015 في بابوا غينيا الجديدة",
    "Category:2016 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2016",
    "Category:2016 in Papua New Guinea by month": "تصنيف:بابوا غينيا الجديدة في 2016 حسب الشهر",
    "Category:2017 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2017",
    "Category:2017 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2017 في بابوا غينيا الجديدة",
    "Category:2018 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2018",
    "Category:2018 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2018 في بابوا غينيا الجديدة",
    "Category:2019 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2019 في بابوا غينيا الجديدة",
    "Category:2020 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2020",
    "Category:2020s disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في عقد 2020",
    "Category:2020s establishments in Papua New Guinea": "تصنيف:تأسيسات عقد 2020 في بابوا غينيا الجديدة",
    "Category:2020s in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في عقد 2020",
    "Category:2021 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2021",
    "Category:2022 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2022",
    "Category:2022 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2022 في بابوا غينيا الجديدة",
    "Category:2022 in Papua New Guinea by month": "تصنيف:بابوا غينيا الجديدة في 2022 حسب الشهر",
    "Category:2023 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2023",
    "Category:2023 establishments in Papua New Guinea": "تصنيف:تأسيسات سنة 2023 في بابوا غينيا الجديدة",
    "Category:2023 in Papua New Guinea by month": "تصنيف:بابوا غينيا الجديدة في 2023 حسب الشهر",
    "Category:2024 disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في 2024",
    "Category:2024 in Papua New Guinea by month": "تصنيف:بابوا غينيا الجديدة في 2024 حسب الشهر",
    "Category:2025 in Papua New Guinea by month": "تصنيف:بابوا غينيا الجديدة في 2025 حسب الشهر",
    "Category:20th century in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في القرن 20",
    "Category:20th-century disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في القرن 20",
    "Category:20th-century disestablishments in Papua New Guinea": "تصنيف:انحلالات القرن 20 في بابوا غينيا الجديدة",
    "Category:20th-century establishments in Papua New Guinea": "تصنيف:تأسيسات القرن 20 في بابوا غينيا الجديدة",
    "Category:20th-century Roman Catholic archbishops in Papua New Guinea": "تصنيف:رؤساء أساقفة رومان كاثوليك في بابوا غينيا الجديدة في القرن 20",
    "Category:20th-century Roman Catholic bishops in Papua New Guinea": "تصنيف:أساقفة كاثوليك رومان في بابوا غينيا الجديدة في القرن 20",
    "Category:21st century in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في القرن 21",
    "Category:21st-century disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة في القرن 21",
    "Category:21st-century establishments in Papua New Guinea": "تصنيف:تأسيسات القرن 21 في بابوا غينيا الجديدة",
    "Category:21st-century Roman Catholic archbishops in Papua New Guinea": "تصنيف:رؤساء أساقفة رومان كاثوليك في بابوا غينيا الجديدة في القرن 21",
    "Category:21st-century Roman Catholic bishops in Papua New Guinea": "تصنيف:أساقفة كاثوليك رومان في بابوا غينيا الجديدة في القرن 21",
    "Category:2nd millennium in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في الألفية 2",
    "Category:2nd-millennium disestablishments in Papua New Guinea": "تصنيف:انحلالات الألفية 2 في بابوا غينيا الجديدة",
    "Category:2nd-millennium establishments in Papua New Guinea": "تصنيف:تأسيسات الألفية 2 في بابوا غينيا الجديدة",
    "Category:3rd millennium in Papua New Guinea": "تصنيف:بابوا غينيا الجديدة في الألفية 3",
    "Category:3rd-millennium establishments in Papua New Guinea": "تصنيف:تأسيسات الألفية 3 في بابوا غينيا الجديدة",
    "Category:Academia in Papua New Guinea": "تصنيف:أكاديمية في بابوا غينيا الجديدة",
    "Category:Academic staff of the University of Papua New Guinea": "تصنيف:أعضاء هيئة تدريس جامعة بابوا غينيا الجديدة",
    "Category:Accidental deaths in Papua New Guinea": "تصنيف:وفيات عرضية في بابوا غينيا الجديدة",
    "Category:Agriculture in Papua New Guinea": "تصنيف:زراعة في بابوا غينيا الجديدة",
    "Category:Airlines of Papua New Guinea": "تصنيف:شركات طيران في بابوا غينيا الجديدة",
    "Category:Airports in Papua New Guinea": "تصنيف:مطارات في بابوا غينيا الجديدة",
    "Category:Alumni by university or college in Papua New Guinea": "تصنيف:خريجون حسب الجامعة أو الكلية في بابوا غينيا الجديدة",
    "Category:Ambassadors of Austria to Papua New Guinea": "تصنيف:سفراء النمسا لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of Chile to Papua New Guinea": "تصنيف:سفراء تشيلي لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of China to Papua New Guinea": "تصنيف:سفراء الصين لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of Germany to Papua New Guinea": "تصنيف:سفراء ألمانيا لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of Hungary to Papua New Guinea": "تصنيف:سفراء المجر لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of Indonesia to Papua New Guinea": "تصنيف:سفراء إندونيسيا لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of Israel to Papua New Guinea": "تصنيف:سفراء إسرائيل لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of Palestine to Papua New Guinea": "تصنيف:سفراء فلسطين لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of Papua New Guinea": "تصنيف:سفراء بابوا غينيا الجديدة",
    "Category:Ambassadors of Papua New Guinea to Belgium": "تصنيف:سفراء بابوا غينيا الجديدة لدى بلجيكا",
    "Category:Ambassadors of Papua New Guinea to Canada": "تصنيف:سفراء بابوا غينيا الجديدة لدى كندا",
    "Category:Ambassadors of Papua New Guinea to China": "تصنيف:سفراء بابوا غينيا الجديدة لدى الصين",
    "Category:Ambassadors of Papua New Guinea to Egypt": "تصنيف:سفراء بابوا غينيا الجديدة لدى مصر",
    "Category:Ambassadors of Papua New Guinea to Greece": "تصنيف:سفراء بابوا غينيا الجديدة لدى اليونان",
    "Category:Ambassadors of Papua New Guinea to Israel": "تصنيف:سفراء بابوا غينيا الجديدة لدى إسرائيل",
    "Category:Ambassadors of Papua New Guinea to Italy": "تصنيف:سفراء بابوا غينيا الجديدة لدى إيطاليا",
    "Category:Ambassadors of Papua New Guinea to Japan": "تصنيف:سفراء بابوا غينيا الجديدة لدى اليابان",
    "Category:Ambassadors of Papua New Guinea to Mexico": "تصنيف:سفراء بابوا غينيا الجديدة لدى المكسيك",
    "Category:Ambassadors of Papua New Guinea to South Korea": "تصنيف:سفراء بابوا غينيا الجديدة لدى كوريا الجنوبية",
    "Category:Ambassadors of Papua New Guinea to the European Union": "تصنيف:سفراء بابوا غينيا الجديدة لدى الاتحاد الأوروبي",
    "Category:Ambassadors of Papua New Guinea to the Netherlands": "تصنيف:سفراء بابوا غينيا الجديدة لدى هولندا",
    "Category:Ambassadors of Papua New Guinea to the Philippines": "تصنيف:سفراء بابوا غينيا الجديدة لدى الفلبين",
    "Category:Ambassadors of Papua New Guinea to the United States": "تصنيف:سفراء بابوا غينيا الجديدة لدى الولايات المتحدة",
    "Category:Ambassadors of Papua New Guinea to Zimbabwe": "تصنيف:سفراء بابوا غينيا الجديدة لدى زيمبابوي",
    "Category:Ambassadors of Poland to Papua New Guinea": "تصنيف:سفراء بولندا لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of Russia to Papua New Guinea": "تصنيف:سفراء روسيا لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of Sweden to Papua New Guinea": "تصنيف:سفراء السويد لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of Thailand to Indonesia and Papua New Guinea": "تصنيف:سفراء تايلاند لدى إندونيسيا وبابوا غينيا الجديدة",
    "Category:Ambassadors of Thailand to Papua New Guinea": "تصنيف:سفراء تايلاند لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of the Soviet Union to Papua New Guinea": "تصنيف:سفراء الاتحاد السوفيتي لدى بابوا غينيا الجديدة",
    "Category:Ambassadors of the United States to Papua New Guinea": "تصنيف:سفراء الولايات المتحدة لدى بابوا غينيا الجديدة",
    "Category:Ambassadors to Papua New Guinea": "تصنيف:سفراء لدى بابوا غينيا الجديدة",
    "Category:American expatriate sportspeople in Papua New Guinea": "تصنيف:رياضيون أمريكيون مغتربون في بابوا غينيا الجديدة",
    "Category:American expatriates in Papua New Guinea": "تصنيف:أمريكيون مغتربون في بابوا غينيا الجديدة",
    "Category:Amphibians of Papua New Guinea": "تصنيف:برمائيات بابوا غينيا الجديدة",
    "Category:Anglican bishops in Papua New Guinea": "تصنيف:أساقفة أنجليكيون في بابوا غينيا الجديدة",
    "Category:Anglican missionaries in Papua New Guinea": "تصنيف:مبشرون أنجليكيون في بابوا غينيا الجديدة",
    "Category:Anglicanism in Papua New Guinea": "تصنيف:أنجليكية في بابوا غينيا الجديدة",
    "Category:Animal breeds originating in Papua New Guinea": "تصنيف:سلالات حيوانية نشأت في بابوا غينيا الجديدة",
    "Category:Archaeological sites in Papua New Guinea": "تصنيف:مواقع أثرية في بابوا غينيا الجديدة",
    "Category:Archaeology of Papua New Guinea": "تصنيف:علم الآثار في بابوا غينيا الجديدة",
    "Category:Archbishops in Papua New Guinea": "تصنيف:رؤساء أساقفة في بابوا غينيا الجديدة",
    "Category:Archipelagoes of Papua New Guinea": "تصنيف:أرخبيلات بابوا غينيا الجديدة",
    "Category:Arts in Papua New Guinea": "تصنيف:الفنون في بابوا غينيا الجديدة",
    "Category:Athletics in Papua New Guinea": "تصنيف:ألعاب القوى في بابوا غينيا الجديدة",
    "Category:Athletics venues in Papua New Guinea": "تصنيف:ملاعب ألعاب القوى في بابوا غينيا الجديدة",
    "Category:Australian emigrants to Papua New Guinea": "تصنيف:أستراليون مهاجرون إلى بابوا غينيا الجديدة",
    "Category:Australian expatriate sportspeople in Papua New Guinea": "تصنيف:رياضيون أستراليون مغتربون في بابوا غينيا الجديدة",
    "Category:Australian expatriates in Papua New Guinea": "تصنيف:أستراليون مغتربون في بابوا غينيا الجديدة",
    "Category:Australian rules football in Papua New Guinea": "تصنيف:كرة القدم الأسترالية في بابوا غينيا الجديدة",
    "Category:Australia–Papua New Guinea border": "تصنيف:الحدود الأسترالية الغينية",
    "Category:Australia–Papua New Guinea relations": "تصنيف:العلاقات الأسترالية الغينية",
    "Category:Australia–Papua New Guinea sports relations": "تصنيف:العلاقات الأسترالية الغينية الرياضية",
    "Category:Austrian expatriates in Papua New Guinea": "تصنيف:نمساويون مغتربون في بابوا غينيا الجديدة",
    "Category:Austria–Papua New Guinea relations": "تصنيف:العلاقات الغينية النمساوية",
    "Category:Aviation accidents and incidents in Papua New Guinea": "تصنيف:حوادث طيران في بابوا غينيا الجديدة",
    "Category:Aviation in Papua New Guinea": "تصنيف:طيران في بابوا غينيا الجديدة",
    "Category:Aviation organisations based in Papua New Guinea": "تصنيف:منظمات طيران مقرها في بابوا غينيا الجديدة",
    "Category:Bangladesh–Papua New Guinea relations": "تصنيف:العلاقات البنغلاديشية الغينية",
    "Category:Banks of Papua New Guinea": "تصنيف:بنوك بابوا غينيا الجديدة",
    "Category:Basketball in Papua New Guinea": "تصنيف:كرة السلة في بابوا غينيا الجديدة",
    "Category:Basketball teams in Papua New Guinea": "تصنيف:فرق كرة السلة في بابوا غينيا الجديدة",
    "Category:Battles and operations of World War II involving Papua New Guinea": "تصنيف:معارك وعمليات الحرب العالمية الثانية تشمل بابوا غينيا الجديدة",
    "Category:Bays of Papua New Guinea": "تصنيف:خلجان بابوا غينيا الجديدة",
    "Category:Beetles of Papua New Guinea": "تصنيف:خنافس في بابوا غينيا الجديدة",
    "Category:Belgian expatriates in Papua New Guinea": "تصنيف:بلجيكيون مغتربون في بابوا غينيا الجديدة",
    "Category:Belgium–Papua New Guinea relations": "تصنيف:العلاقات البلجيكية الغينية",
    "Category:Bilateral relations of Papua New Guinea": "تصنيف:علاقات بابوا غينيا الجديدة الثنائية",
    "Category:Biota of Papua New Guinea": "تصنيف:حيويات بابوا غينيا الجديدة",
    "Category:Birds of Papua New Guinea": "تصنيف:طيور بابوا غينيا الجديدة",
    "Category:Bishops in Papua New Guinea": "تصنيف:أساقفة في بابوا غينيا الجديدة",
    "Category:Bodies of water of Papua New Guinea": "تصنيف:مسطحات مائية في بابوا غينيا الجديدة",
    "Category:Borders of Papua New Guinea": "تصنيف:حدود بابوا غينيا الجديدة",
    "Category:Botanical gardens in Papua New Guinea": "تصنيف:حدائق نباتية في بابوا غينيا الجديدة",
    "Category:Bowling in Papua New Guinea": "تصنيف:بولينج في بابوا غينيا الجديدة",
    "Category:Bowls in Papua New Guinea": "تصنيف:البولينج في بابوا غينيا الجديدة",
    "Category:Brazilian expatriate sportspeople in Papua New Guinea": "تصنيف:رياضيون برازيليون مغتربون في بابوا غينيا الجديدة",
    "Category:Bridges in Papua New Guinea": "تصنيف:جسور في بابوا غينيا الجديدة",
    "Category:British emigrants to Papua New Guinea": "تصنيف:بريطانيون مهاجرون إلى بابوا غينيا الجديدة",
    "Category:British expatriates in Papua New Guinea": "تصنيف:بريطانيون مغتربون في بابوا غينيا الجديدة",
    "Category:Broadcasting in Papua New Guinea": "تصنيف:بث لاسلكي في بابوا غينيا الجديدة",
    "Category:Buildings and structures in Papua New Guinea": "تصنيف:مبان ومنشآت في بابوا غينيا الجديدة",
    "Category:Buildings and structures in Papua New Guinea by city": "تصنيف:مبان ومنشآت في بابوا غينيا الجديدة حسب المدينة",
    "Category:Buildings and structures in Papua New Guinea by type": "تصنيف:مبان ومنشآت في بابوا غينيا الجديدة حسب الفئة",
    "Category:Business organisations based in Papua New Guinea": "تصنيف:منظمات أعمال مقرها في بابوا غينيا الجديدة",
    "Category:Canada–Papua New Guinea relations": "تصنيف:العلاقات الغينية الكندية",
    "Category:Categories by province of Papua New Guinea": "تصنيف:تصنيفات حسب المقاطعة في بابوا غينيا الجديدة",
    "Category:Cathedrals in Papua New Guinea": "تصنيف:كاتدرائيات في بابوا غينيا الجديدة",
    "Category:Caves of Papua New Guinea": "تصنيف:كهوف بابوا غينيا الجديدة",
    "Category:Cemeteries in Papua New Guinea": "تصنيف:مقابر في بابوا غينيا الجديدة",
    "Category:Centuries in Papua New Guinea": "تصنيف:قرون في بابوا غينيا الجديدة",
    "Category:Children's books set in Papua New Guinea": "تصنيف:كتب أطفال تقع أحداثها في بابوا غينيا الجديدة",
    "Category:Chile–Papua New Guinea relations": "تصنيف:العلاقات التشيلية الغينية",
    "Category:China–Papua New Guinea relations": "تصنيف:العلاقات الصينية الغينية",
    "Category:Christian missionaries in Papua New Guinea": "تصنيف:مبشرون مسيحيون في بابوا غينيا الجديدة",
    "Category:Christianity in Papua New Guinea": "تصنيف:المسيحية في بابوا غينيا الجديدة",
    "Category:Churches in Papua New Guinea": "تصنيف:كنائس في بابوا غينيا الجديدة",
    "Category:Cinema of Papua New Guinea": "تصنيف:سينما في بابوا غينيا الجديدة",
    "Category:Civil aviation in Papua New Guinea": "تصنيف:الطيران المدني في بابوا غينيا الجديدة",
    "Category:Commonwealth Games bronze medallists for Papua New Guinea": "تصنيف:فائزون بميداليات برونزية في ألعاب الكومنولث من بابوا غينيا الجديدة",
    "Category:Commonwealth Games competitors for Papua New Guinea": "تصنيف:منافسون في ألعاب الكومنولث من بابوا غينيا الجديدة",
    "Category:Commonwealth Games gold medallists for Papua New Guinea": "تصنيف:فائزون بميداليات ذهبية في ألعاب الكومنولث من بابوا غينيا الجديدة",
    "Category:Commonwealth Games medallists for Papua New Guinea": "تصنيف:فائزون بميداليات ألعاب الكومنولث من بابوا غينيا الجديدة",
    "Category:Commonwealth Games silver medallists for Papua New Guinea": "تصنيف:فائزون بميداليات فضية في ألعاب الكومنولث من بابوا غينيا الجديدة",
    "Category:Communications in Papua New Guinea": "تصنيف:الاتصالات في بابوا غينيا الجديدة",
    "Category:Companies of Papua New Guinea": "تصنيف:شركات في بابوا غينيا الجديدة",
    "Category:Companies of Papua New Guinea by industry": "تصنيف:شركات في بابوا غينيا الجديدة حسب الصناعة",
    "Category:Conservative parties in Papua New Guinea": "تصنيف:أحزاب محافظة في بابوا غينيا الجديدة",
    "Category:COVID-19 pandemic in Papua New Guinea": "تصنيف:جائحة فيروس كورونا في بابوا غينيا الجديدة",
    "Category:Cricket in Papua New Guinea": "تصنيف:الكريكت في بابوا غينيا الجديدة",
    "Category:Cricket in Papua New Guinea by decade": "تصنيف:الكريكت في بابوا غينيا الجديدة حسب العقد",
    "Category:Cricket in Papua New Guinea by year": "تصنيف:الكريكت في بابوا غينيا الجديدة حسب السنة",
    "Category:Crime in Papua New Guinea": "تصنيف:جريمة في بابوا غينيا الجديدة",
    "Category:Crime in Papua New Guinea by type": "تصنيف:جريمة في بابوا غينيا الجديدة حسب الفئة",
    "Category:Cultural festivals in Papua New Guinea": "تصنيف:مهرجانات ثقافية في بابوا غينيا الجديدة",
    "Category:Cultural organisations based in Papua New Guinea": "تصنيف:منظمات ثقافية مقرها في بابوا غينيا الجديدة",
    "Category:Culture of Papua New Guinea": "تصنيف:ثقافة بابوا غينيا الجديدة",
    "Category:Currencies of Papua New Guinea": "تصنيف:عملات في بابوا غينيا الجديدة",
    "Category:Cyprus–Papua New Guinea relations": "تصنيف:العلاقات الغينية القبرصية",
    "Category:Dams in Papua New Guinea": "تصنيف:سدود في بابوا غينيا الجديدة",
    "Category:Dance festivals in Papua New Guinea": "تصنيف:مهرجانات رقص في بابوا غينيا الجديدة",
    "Category:Danish expatriate sportspeople in Papua New Guinea": "تصنيف:رياضيون دنماركيون مغتربون في بابوا غينيا الجديدة",
    "Category:Death in Papua New Guinea": "تصنيف:الموت في بابوا غينيا الجديدة",
    "Category:Deaths by firearm in Papua New Guinea": "تصنيف:وفيات بإطلاق النار في بابوا غينيا الجديدة",
    "Category:Deaths from cancer in Papua New Guinea": "تصنيف:وفيات السرطان في بابوا غينيا الجديدة",
    "Category:Deaths in Papua New Guinea": "تصنيف:وفيات في بابوا غينيا الجديدة",
    "Category:Decades in Papua New Guinea": "تصنيف:عقود في بابوا غينيا الجديدة",
    "Category:Defunct airlines of Papua New Guinea": "تصنيف:شركات طيران سابقة في بابوا غينيا الجديدة",
    "Category:Defunct companies of Papua New Guinea": "تصنيف:شركات سابقة في بابوا غينيا الجديدة",
    "Category:Defunct organisations based in Papua New Guinea": "تصنيف:منظمات سابقة مقرها في بابوا غينيا الجديدة",
    "Category:Defunct political parties in Papua New Guinea": "تصنيف:أحزاب سياسية سابقة في بابوا غينيا الجديدة",
    "Category:Demographics of Papua New Guinea": "تصنيف:التركيبة السكانية في بابوا غينيا الجديدة",
    "Category:Deputy prime ministers of Papua New Guinea": "تصنيف:نواب رؤساء وزراء بابوا غينيا الجديدة",
    "Category:Diplomatic missions of Papua New Guinea": "تصنيف:بعثات بابوا غينيا الجديدة الدبلوماسية",
    "Category:Diplomatic ranks in Papua New Guinea": "تصنيف:درجات دبلوماسية في بابوا غينيا الجديدة",
    "Category:Diplomats for Papua New Guinea": "تصنيف:دبلوماسيون في بابوا غينيا الجديدة",
    "Category:Disability in Papua New Guinea": "تصنيف:إعاقة في بابوا غينيا الجديدة",
    "Category:Disasters in Papua New Guinea": "تصنيف:كوارث في بابوا غينيا الجديدة",
    "Category:Disasters in Papua New Guinea by century": "تصنيف:كوارث في بابوا غينيا الجديدة حسب القرن",
    "Category:Disasters in Papua New Guinea by decade": "تصنيف:كوارث في بابوا غينيا الجديدة حسب العقد",
    "Category:Disasters in Papua New Guinea by year": "تصنيف:كوارث في بابوا غينيا الجديدة حسب السنة",
    "Category:Discrimination in Papua New Guinea": "تصنيف:تمييز في بابوا غينيا الجديدة",
    "Category:Disease outbreaks in Papua New Guinea": "تصنيف:تفشي طبي في بابوا غينيا الجديدة",
    "Category:Disease-related deaths in Papua New Guinea": "تصنيف:وفيات مرتبطة بالمرض في بابوا غينيا الجديدة",
    "Category:Disestablishments in Papua New Guinea": "تصنيف:انحلالات في بابوا غينيا الجديدة",
    "Category:Disestablishments in Papua New Guinea by century": "تصنيف:انحلالات في بابوا غينيا الجديدة حسب القرن",
    "Category:Disestablishments in Papua New Guinea by decade": "تصنيف:انحلالات في بابوا غينيا الجديدة حسب العقد",
    "Category:Disestablishments in Papua New Guinea by millennium": "تصنيف:انحلالات في بابوا غينيا الجديدة حسب الألفية",
    "Category:Disestablishments in Papua New Guinea by year": "تصنيف:انحلالات في بابوا غينيا الجديدة حسب السنة",
    "Category:Districts of Papua New Guinea": "تصنيف:مديريات بابوا غينيا الجديدة",
    "Category:Diving in Papua New Guinea": "تصنيف:الغطس في بابوا غينيا الجديدة",
    "Category:Documentary films about Papua New Guinea": "تصنيف:أفلام وثائقية عن بابوا غينيا الجديدة",
    "Category:Dog breeds originating in Papua New Guinea": "تصنيف:سلالات كلاب نشأت في بابوا غينيا الجديدة",
    "Category:Drug-related deaths in Papua New Guinea": "تصنيف:وفيات مرتبطة بالمخدرات في بابوا غينيا الجديدة",
    "Category:Drugs in Papua New Guinea": "تصنيف:عقاقير في بابوا غينيا الجديدة",
    "Category:Earthquakes in Papua New Guinea": "تصنيف:زلازل في بابوا غينيا الجديدة",
    "Category:Economic history of Papua New Guinea": "تصنيف:تاريخ بابوا غينيا الجديدة الاقتصادي",
    "Category:Economy of Papua New Guinea": "تصنيف:اقتصاد بابوا غينيا الجديدة",
    "Category:Ecoregions of Papua New Guinea": "تصنيف:مناطق بيئية في بابوا غينيا الجديدة",
    "Category:Education in Papua New Guinea": "تصنيف:التعليم في بابوا غينيا الجديدة",
    "Category:Educational organisations based in Papua New Guinea": "تصنيف:منظمات تعليمية مقرها في بابوا غينيا الجديدة",
    "Category:Egypt–Papua New Guinea relations": "تصنيف:العلاقات الغينية المصرية",
    "Category:Elections in Papua New Guinea": "تصنيف:انتخابات في بابوا غينيا الجديدة",
    "Category:Electric power companies of Papua New Guinea": "تصنيف:شركات طاقة كهربائية في بابوا غينيا الجديدة",
    "Category:Electric power in Papua New Guinea": "تصنيف:طاقة كهربائية في بابوا غينيا الجديدة",
    "Category:Electric power infrastructure in Papua New Guinea": "تصنيف:بنية تحتية للقدرة الكهربائية في بابوا غينيا الجديدة",
    "Category:Energy companies of Papua New Guinea": "تصنيف:شركات طاقة في بابوا غينيا الجديدة",
    "Category:Energy in Papua New Guinea": "تصنيف:طاقة في بابوا غينيا الجديدة",
    "Category:Energy infrastructure in Papua New Guinea": "تصنيف:بنية تحتية للطاقة في بابوا غينيا الجديدة",
    "Category:Entertainment events in Papua New Guinea": "تصنيف:أحداث ترفيهية في بابوا غينيا الجديدة",
    "Category:Entertainment in Papua New Guinea": "تصنيف:ترفيه في بابوا غينيا الجديدة",
    "Category:Entertainment venues in Papua New Guinea": "تصنيف:أماكن ترفيه في بابوا غينيا الجديدة",
    "Category:Environment of Papua New Guinea": "تصنيف:بيئة بابوا غينيا الجديدة",
    "Category:Environmental issues in Papua New Guinea": "تصنيف:قضايا بيئية في بابوا غينيا الجديدة",
    "Category:Environmental organisations based in Papua New Guinea": "تصنيف:منظمات بيئية مقرها في بابوا غينيا الجديدة",
    "Category:Establishments in Papua New Guinea": "تصنيف:تأسيسات في بابوا غينيا الجديدة",
    "Category:Establishments in Papua New Guinea by century": "تصنيف:تأسيسات في بابوا غينيا الجديدة حسب القرن",
    "Category:Establishments in Papua New Guinea by decade": "تصنيف:تأسيسات في بابوا غينيا الجديدة حسب العقد",
    "Category:Establishments in Papua New Guinea by millennium": "تصنيف:تأسيسات في بابوا غينيا الجديدة حسب الألفية",
    "Category:Establishments in Papua New Guinea by year": "تصنيف:تأسيسات في بابوا غينيا الجديدة حسب السنة",
    "Category:Ethnic groups in Papua New Guinea": "تصنيف:مجموعات عرقية في بابوا غينيا الجديدة",
    "Category:Expatriate football managers in Papua New Guinea": "تصنيف:مدربو كرة قدم مغتربون في بابوا غينيا الجديدة",
    "Category:Expatriate footballers in Papua New Guinea": "تصنيف:لاعبو كرة قدم مغتربون في بابوا غينيا الجديدة",
    "Category:Expatriate sportspeople in Papua New Guinea": "تصنيف:رياضيون مغتربون في بابوا غينيا الجديدة",
    "Category:Expatriate sportspeople in Papua New Guinea by nationality": "تصنيف:رياضيون مغتربون في بابوا غينيا الجديدة حسب الجنسية",
    "Category:Expatriates in Papua New Guinea": "تصنيف:مغتربون في بابوا غينيا الجديدة",
    "Category:Explorers of Papua New Guinea": "تصنيف:مستكشفو بابوا غينيا الجديدة",
    "Category:Fauna of Papua New Guinea": "تصنيف:حيوانات بابوا غينيا الجديدة",
    "Category:Featured pictures of Papua New Guinea": "تصنيف:صور مميزة عن بابوا غينيا الجديدة",
    "Category:Federated States of Micronesia–Papua New Guinea relations": "تصنيف:العلاقات الغينية الميكرونيزية",
    "Category:Festivals in Papua New Guinea": "تصنيف:مهرجانات في بابوا غينيا الجديدة",
    "Category:Field hockey in Papua New Guinea": "تصنيف:هوكي الميدان في بابوا غينيا الجديدة",
    "Category:Fijian expatriate sportspeople in Papua New Guinea": "تصنيف:رياضيون فيجيون مغتربون في بابوا غينيا الجديدة",
    "Category:Fijian expatriates in Papua New Guinea": "تصنيف:فيجيون مغتربون في بابوا غينيا الجديدة",
    "Category:Fiji–Papua New Guinea relations": "تصنيف:العلاقات الغينية الفيجية",
    "Category:Films set in Papua New Guinea": "تصنيف:أفلام تقع أحداثها في بابوا غينيا الجديدة",
    "Category:Films shot in Papua New Guinea": "تصنيف:أفلام مصورة في بابوا غينيا الجديدة",
    "Category:Financial services companies of Papua New Guinea": "تصنيف:شركات خدمات مالية في بابوا غينيا الجديدة",
    "Category:Financial services in Papua New Guinea": "تصنيف:خدمات مالية في بابوا غينيا الجديدة",
    "Category:Fish of Papua New Guinea": "تصنيف:أسماك بابوا غينيا الجديدة",
    "Category:Flora of Papua New Guinea": "تصنيف:نباتات بابوا غينيا الجديدة",
    "Category:Football competitions in Papua New Guinea": "تصنيف:منافسات كرة قدم في بابوا غينيا الجديدة",
    "Category:Football leagues in Papua New Guinea": "تصنيف:دوريات كرة قدم في بابوا غينيا الجديدة",
    "Category:Football managers in Papua New Guinea": "تصنيف:مدربو كرة قدم في بابوا غينيا الجديدة",
    "Category:Football people in Papua New Guinea": "تصنيف:أعلام كرة قدم في بابوا غينيا الجديدة",
    "Category:Football venues in Papua New Guinea": "تصنيف:ملاعب كرة القدم في بابوا غينيا الجديدة",
    "Category:Footballers in Papua New Guinea": "تصنيف:لاعبو كرة قدم في بابوا غينيا الجديدة",
    "Category:Footballers in Papua New Guinea by club": "تصنيف:لاعبو كرة قدم في بابوا غينيا الجديدة حسب النادي",
    "Category:Former buildings and structures in Papua New Guinea": "تصنيف:مبان ومنشآت سابقة في بابوا غينيا الجديدة",
    "Category:Fossil fuels in Papua New Guinea": "تصنيف:وقود أحفوري في بابوا غينيا الجديدة",
    "Category:France–Papua New Guinea relations": "تصنيف:العلاقات الغينية الفرنسية",
    "Category:France–Papua New Guinea sports relations": "تصنيف:العلاقات الغينية الفرنسية الرياضية",
    "Category:French expatriates in Papua New Guinea": "تصنيف:فرنسيون مغتربون في بابوا غينيا الجديدة",
    "Category:Futsal in Papua New Guinea": "تصنيف:كرة صالات في بابوا غينيا الجديدة",
    "Category:Gender in Papua New Guinea": "تصنيف:الجنس في بابوا غينيا الجديدة",
    "Category:Geography of Papua New Guinea": "تصنيف:جغرافيا بابوا غينيا الجديدة",
    "Category:Geology of Papua New Guinea": "تصنيف:جيولوجيا بابوا غينيا الجديدة",
    "Category:German expatriate sportspeople in Papua New Guinea": "تصنيف:رياضيون ألمان مغتربون في بابوا غينيا الجديدة",
    "Category:German expatriates in Papua New Guinea": "تصنيف:ألمان مغتربون في بابوا غينيا الجديدة",
    "Category:Germany–Papua New Guinea relations": "تصنيف:العلاقات الألمانية الغينية",
    "Category:Ghana–Papua New Guinea relations": "تصنيف:العلاقات الغانية الغينية",
    "Category:Government ministers of Papua New Guinea": "تصنيف:وزراء بابوا غينيا الجديدة",
    "Category:Government of Papua New Guinea": "تصنيف:حكومة بابوا غينيا الجديدة",
    "Category:Governors of the Bank of Papua New Guinea": "تصنيف:حكام من بنك بابوا غينيا الجديدة",
    "Category:Governors-general of Papua New Guinea": "تصنيف:حكام عموم بابوا غينيا الجديدة",
    "Category:Greece–Papua New Guinea relations": "تصنيف:العلاقات الغينية اليونانية",
    "Category:Headlands of Papua New Guinea": "تصنيف:أراضي رأسية في بابوا غينيا الجديدة",
    "Category:Health disasters in Papua New Guinea": "تصنيف:كوارث صحية في بابوا غينيا الجديدة",
    "Category:Health in Papua New Guinea": "تصنيف:الصحة في بابوا غينيا الجديدة",
    "Category:Historic sites in Papua New Guinea": "تصنيف:مواقع تاريخية في بابوا غينيا الجديدة",
    "Category:History of Papua New Guinea": "تصنيف:تاريخ بابوا غينيا الجديدة",
    "Category:History of Papua New Guinea by period": "تصنيف:تاريخ بابوا غينيا الجديدة حسب الحقبة",
    "Category:History of Papua New Guinea by topic": "تصنيف:تاريخ بابوا غينيا الجديدة حسب الموضوع",
    "Category:History of the Papua New Guinea national soccer team": "تصنيف:تاريخ منتخب بابوا غينيا الجديدة لكرة القدم",
    "Category:History of transport in Papua New Guinea": "تصنيف:تاريخ النقل في بابوا غينيا الجديدة",
    "Category:History of women in Papua New Guinea": "تصنيف:تاريخ المرأة في بابوا غينيا الجديدة",
    "Category:Hong Kong–Papua New Guinea relations": "تصنيف:العلاقات الغينية الهونغ الكونغية",
    "Category:Hospitals in Papua New Guinea": "تصنيف:مستشفيات في بابوا غينيا الجديدة",
    "Category:Hotels in Papua New Guinea": "تصنيف:فنادق في بابوا غينيا الجديدة",
    "Category:Human rights abuses in Papua New Guinea": "تصنيف:انتهاك حقوق الإنسان في بابوا غينيا الجديدة",
    "Category:Human rights in Papua New Guinea": "تصنيف:حقوق الإنسان في بابوا غينيا الجديدة",
    "Category:Hungary–Papua New Guinea relations": "تصنيف:العلاقات الغينية المجرية",
    "Category:Hydroelectric power stations in Papua New Guinea": "تصنيف:محطات طاقة كهرمائية في بابوا غينيا الجديدة",
    "Category:Hydroelectricity in Papua New Guinea": "تصنيف:الطاقة الكهرومائية في بابوا غينيا الجديدة",
    "Category:Images of Papua New Guinea": "تصنيف:صور من بابوا غينيا الجديدة",
    "Category:Immigrants to Papua New Guinea": "تصنيف:مهاجرون إلى بابوا غينيا الجديدة",
    "Category:Indian expatriates in Papua New Guinea": "تصنيف:هنود مغتربون في بابوا غينيا الجديدة",
    "Category:India–Papua New Guinea relations": "تصنيف:العلاقات الغينية الهندية",
    "Category:Indonesia-Papua New Guinea relations": "تصنيف:العلاقات الإندونيسية الغينية",
    "Category:Indonesia–Papua New Guinea border": "تصنيف:الحدود الإندونيسية الغينية",
    "Category:Indonesia–Papua New Guinea relations": "تصنيف:العلاقات الإندونيسية الغينية",
    "Category:Industrial buildings in Papua New Guinea": "تصنيف:مبان صناعية في بابوا غينيا الجديدة",
    "Category:Infrastructure in Papua New Guinea": "تصنيف:بنية تحتية في بابوا غينيا الجديدة",
    "Category:Insects of Papua New Guinea": "تصنيف:حشرات بابوا غينيا الجديدة",
    "Category:International association football competitions hosted by Papua New Guinea": "تصنيف:منافسات كرة قدم دولية استضافتها بابوا غينيا الجديدة",
    "Category:International cricket competitions in Papua New Guinea": "تصنيف:منافسات كريكت دولية في بابوا غينيا الجديدة",
    "Category:International netball competitions hosted by Papua New Guinea": "تصنيف:منافسات كرة شبكة دولية استضافتها بابوا غينيا الجديدة",
    "Category:International rugby league competitions hosted by Papua New Guinea": "تصنيف:منافسات دوري رجبي دولية استضافتها بابوا غينيا الجديدة",
    "Category:International rugby union competitions hosted by Papua New Guinea": "تصنيف:منافسات اتحاد رجبي دولية استضافتها بابوا غينيا الجديدة",
    "Category:International schools in Papua New Guinea": "تصنيف:مدارس دولية في بابوا غينيا الجديدة",
    "Category:International sports competitions hosted by Papua New Guinea": "تصنيف:منافسات رياضية دولية استضافتها بابوا غينيا الجديدة",
    "Category:Irish emigrants to Papua New Guinea": "تصنيف:أيرلنديون مهاجرون إلى بابوا غينيا الجديدة",
    "Category:Islam in Papua New Guinea": "تصنيف:الإسلام في بابوا غينيا الجديدة",
    "Category:Islands of Papua New Guinea": "تصنيف:جزر بابوا غينيا الجديدة",
    "Category:Israel–Papua New Guinea relations": "تصنيف:العلاقات الإسرائيلية الغينية",
    "Category:Italian expatriates in Papua New Guinea": "تصنيف:إيطاليون مغتربون في بابوا غينيا الجديدة",
    "Category:Italy–Papua New Guinea relations": "تصنيف:العلاقات الإيطالية الغينية",
    "Category:Japan–Papua New Guinea relations": "تصنيف:العلاقات الغينية اليابانية",
    "Category:Labor disputes in Papua New Guinea": "تصنيف:نزاعات عمالية في بابوا غينيا الجديدة",
    "Category:Lakes of Papua New Guinea": "تصنيف:بحيرات بابوا غينيا الجديدة",
    "Category:Landforms of Papua New Guinea": "تصنيف:تضاريس بابوا غينيا الجديدة",
    "Category:Landmarks in Papua New Guinea": "تصنيف:معالم في بابوا غينيا الجديدة",
    "Category:Languages of Papua New Guinea": "تصنيف:لغات بابوا غينيا الجديدة",
    "Category:Law enforcement in Papua New Guinea": "تصنيف:تطبيق القانون في بابوا غينيا الجديدة",
    "Category:Law of Papua New Guinea": "تصنيف:قانون في بابوا غينيا الجديدة",
    "Category:Leaders of political parties in Papua New Guinea": "تصنيف:قادة أحزاب سياسية في بابوا غينيا الجديدة",
    "Category:Lepidoptera of Papua New Guinea": "تصنيف:حرشفيات الأجنحة في بابوا غينيا الجديدة",
    "Category:Libraries in Papua New Guinea": "تصنيف:مكتبات في بابوا غينيا الجديدة",
    "Category:Lists of ambassadors to Papua New Guinea": "تصنيف:قوائم سفراء لدى بابوا غينيا الجديدة",
    "Category:Lists of biota of Papua New Guinea": "تصنيف:قوائم حيويات بابوا غينيا الجديدة",
    "Category:Lists of buildings and structures in Papua New Guinea": "تصنيف:قوائم مبان ومنشآت في بابوا غينيا الجديدة",
    "Category:Lists of islands of Papua New Guinea": "تصنيف:قوائم جزر بابوا غينيا الجديدة",
    "Category:Lists of landforms of Papua New Guinea": "تصنيف:قوائم تضاريس بابوا غينيا الجديدة",
    "Category:Lists of mass media in Papua New Guinea": "تصنيف:قوائم وسائل إعلام في بابوا غينيا الجديدة",
    "Category:Lists of religious buildings and structures in Papua New Guinea": "تصنيف:قوائم مبان ومنشآت دينية في بابوا غينيا الجديدة",
    "Category:Lists of tourist attractions in Papua New Guinea": "تصنيف:قوائم مواقع جذب سياحي في بابوا غينيا الجديدة",
    "Category:Malaysian emigrants to Papua New Guinea": "تصنيف:ماليزيون مهاجرون إلى بابوا غينيا الجديدة",
    "Category:Malaysian expatriates in Papua New Guinea": "تصنيف:ماليزيون مغتربون في بابوا غينيا الجديدة",
    "Category:Malaysia–Papua New Guinea relations": "تصنيف:العلاقات الغينية الماليزية",
    "Category:Mammals of Papua New Guinea": "تصنيف:ثدييات بابوا غينيا الجديدة",
    "Category:Man-made disasters in Papua New Guinea": "تصنيف:كوارث من صنع الإنسان في بابوا غينيا الجديدة",
    "Category:Maritime history of Papua New Guinea": "تصنيف:تاريخ بابوا غينيا الجديدة البحري",
    "Category:Maritime incidents in Papua New Guinea": "تصنيف:حوادث بحرية في بابوا غينيا الجديدة",
    "Category:Martial arts in Papua New Guinea": "تصنيف:الفنون القتالية في بابوا غينيا الجديدة",
    "Category:Mass media in Papua New Guinea": "تصنيف:وسائل إعلام في بابوا غينيا الجديدة",
    "Category:Medical and health organisations based in Papua New Guinea": "تصنيف:منظمات طبية وصحية مقرها في بابوا غينيا الجديدة",
    "Category:Men in Papua New Guinea": "تصنيف:رجال في بابوا غينيا الجديدة",
    "Category:Men's sport in Papua New Guinea": "تصنيف:رياضة رجالية في بابوا غينيا الجديدة",
    "Category:Methodist missionaries in Papua New Guinea": "تصنيف:مبشرون ميثوديون لاهوتيون في بابوا غينيا الجديدة",
    "Category:Mexico–Papua New Guinea relations": "تصنيف:العلاقات الغينية المكسيكية",
    "Category:Military equipment of Papua New Guinea": "تصنيف:عتاد بابوا غينيا الجديدة العسكري",
    "Category:Military history of Papua New Guinea": "تصنيف:تاريخ بابوا غينيا الجديدة العسكري",
    "Category:Military of Papua New Guinea": "تصنيف:عسكرية بابوا غينيا الجديدة",
    "Category:Military units and formations of Papua New Guinea": "تصنيف:وحدات وتشكيلات بابوا غينيا الجديدة العسكرية",
    "Category:Millennia in Papua New Guinea": "تصنيف:ألفيات في بابوا غينيا الجديدة",
    "Category:Mines in Papua New Guinea": "تصنيف:مناجم في بابوا غينيا الجديدة",
    "Category:Mining companies of Papua New Guinea": "تصنيف:شركات تعدين في بابوا غينيا الجديدة",
    "Category:Mining disasters in Papua New Guinea": "تصنيف:كوارث التعدين في بابوا غينيا الجديدة",
    "Category:Mining in Papua New Guinea": "تصنيف:تعدين في بابوا غينيا الجديدة",
    "Category:Ministers of defence of Papua New Guinea": "تصنيف:وزراء دفاع بابوا غينيا الجديدة",
    "Category:Ministers of finance of Papua New Guinea": "تصنيف:وزراء مالية بابوا غينيا الجديدة",
    "Category:Molluscs of Papua New Guinea": "تصنيف:رخويات بابوا غينيا الجديدة",
    "Category:Mountain ranges of Papua New Guinea": "تصنيف:سلاسل جبلية في بابوا غينيا الجديدة",
    "Category:Mountains of Papua New Guinea": "تصنيف:جبال بابوا غينيا الجديدة",
    "Category:Murder in Papua New Guinea": "تصنيف:قتل في بابوا غينيا الجديدة",
    "Category:Museums in Papua New Guinea": "تصنيف:متاحف في بابوا غينيا الجديدة",
    "Category:Music festivals in Papua New Guinea": "تصنيف:مهرجانات موسيقية في بابوا غينيا الجديدة",
    "Category:Music of Papua New Guinea": "تصنيف:موسيقى بابوا غينيا الجديدة",
    "Category:National sports teams of Papua New Guinea": "تصنيف:منتخبات رياضية وطنية من بابوا غينيا الجديدة",
    "Category:Natural disasters in Papua New Guinea": "تصنيف:كوارث طبيعية في بابوا غينيا الجديدة",
    "Category:Natural gas fields in Papua New Guinea": "تصنيف:حقول غاز طبيعي في بابوا غينيا الجديدة",
    "Category:Natural gas in Papua New Guinea": "تصنيف:غاز طبيعي في بابوا غينيا الجديدة",
    "Category:Natural history of Papua New Guinea": "تصنيف:تاريخ بابوا غينيا الجديدة الطبيعي",
    "Category:Nature reserves in Papua New Guinea": "تصنيف:محميات طبيعية في بابوا غينيا الجديدة",
    "Category:Naval ships of Papua New Guinea": "تصنيف:سفن قوات بحرية في بابوا غينيا الجديدة",
    "Category:Netball competitions in Papua New Guinea": "تصنيف:منافسات كرة شبكة في بابوا غينيا الجديدة",
    "Category:Netball in Papua New Guinea": "تصنيف:كرة الشبكة في بابوا غينيا الجديدة",
    "Category:Netherlands–Papua New Guinea relations": "تصنيف:العلاقات الغينية الهولندية",
    "Category:New Zealand–Papua New Guinea relations": "تصنيف:العلاقات الغينية النيوزيلندية",
    "Category:Newspapers published in Papua New Guinea": "تصنيف:صحف نشرت في بابوا غينيا الجديدة",
    "Category:Novels set in Papua New Guinea": "تصنيف:روايات تقع أحداثها في بابوا غينيا الجديدة",
    "Category:Oil and gas companies of Papua New Guinea": "تصنيف:شركات النفط والغاز في بابوا غينيا الجديدة",
    "Category:Olympic athletes for Papua New Guinea": "تصنيف:لاعبو قوى أولمبيون في بابوا غينيا الجديدة",
    "Category:Olympic boxers for Papua New Guinea": "تصنيف:ملاكمون أولمبيون في بابوا غينيا الجديدة",
    "Category:Olympic competitors for Papua New Guinea": "تصنيف:منافسون أولمبيون من بابوا غينيا الجديدة",
    "Category:Olympic judoka for Papua New Guinea": "تصنيف:لاعبو جودو أولمبيون في بابوا غينيا الجديدة",
    "Category:Olympic shooters for Papua New Guinea": "تصنيف:رماة أولمبيون في بابوا غينيا الجديدة",
    "Category:Olympic swimmers for Papua New Guinea": "تصنيف:سباحون أولمبيون في بابوا غينيا الجديدة",
    "Category:Olympic taekwondo practitioners for Papua New Guinea": "تصنيف:لاعبو تايكوندو أولمبيون في بابوا غينيا الجديدة",
    "Category:Olympic weightlifters for Papua New Guinea": "تصنيف:رباعون أولمبيون في بابوا غينيا الجديدة",
    "Category:Organisations based in Papua New Guinea": "تصنيف:منظمات مقرها في بابوا غينيا الجديدة",
    "Category:Organisations based in Papua New Guinea by subject": "تصنيف:منظمات مقرها في بابوا غينيا الجديدة حسب الموضوع",
    "Category:Pacific Games medalists for Papua New Guinea": "تصنيف:فائزون بميداليات ألعاب المحيط الهادئ من بابوا غينيا الجديدة",
    "Category:Paleontology in Papua New Guinea": "تصنيف:علم الأحياء القديمة في بابوا غينيا الجديدة",
    "Category:Palestine–Papua New Guinea relations": "تصنيف:العلاقات الغينية الفلسطينية",
    "Category:Palestinian expatriates in Papua New Guinea": "تصنيف:فلسطينيون مغتربون في بابوا غينيا الجديدة",
    "Category:Papua New Guinea": "تصنيف:بابوا غينيا الجديدة",
    "Category:Papua New Guinea at the 2016 OFC Nations Cup": "تصنيف:بابوا غينيا الجديدة في كأس أوقيانوسيا للأمم 2016",
    "Category:Papua New Guinea at the Commonwealth Games": "تصنيف:بابوا غينيا الجديدة في ألعاب الكومنولث",
    "Category:Papua New Guinea at the Olympics": "تصنيف:بابوا غينيا الجديدة في الألعاب الأولمبية",
    "Category:Papua New Guinea at the Pacific Games": "تصنيف:بابوا غينيا الجديدة في ألعاب المحيط الهادئ",
    "Category:Papua New Guinea at the Paralympics": "تصنيف:بابوا غينيا الجديدة في الألعاب البارالمبية",
    "Category:Papua New Guinea at the Summer Olympics": "تصنيف:بابوا غينيا الجديدة في الألعاب الأولمبية الصيفية",
    "Category:Papua New Guinea at the Summer Olympics by year": "تصنيف:بابوا غينيا الجديدة في الألعاب الأولمبية الصيفية حسب السنة",
    "Category:Papua New Guinea at the World Aquatics Championships": "تصنيف:بابوا غينيا الجديدة في بطولة العالم للرياضات المائية",
    "Category:Papua New Guinea at the World Athletics Championships": "تصنيف:بابوا غينيا الجديدة في بطولة العالم لألعاب القوى",
    "Category:Papua New Guinea at the Youth Olympics": "تصنيف:بابوا غينيا الجديدة في الألعاب الأولمبية الشبابية",
    "Category:Papua New Guinea communications-related lists": "تصنيف:قوائم متعلقة بالاتصالات الغينية",
    "Category:Papua New Guinea diplomacy-related lists": "تصنيف:قوائم متعلقة بالدبلوماسية الغينية",
    "Category:Papua New Guinea football navigational boxes": "تصنيف:صناديق تصفح كرة القدم الغينية",
    "Category:Papua New Guinea football templates": "تصنيف:قوالب كرة القدم الغينية",
    "Category:Papua New Guinea in fiction": "تصنيف:بابوا غينيا الجديدة في الخيال",
    "Category:Papua New Guinea in international cricket": "تصنيف:بابوا غينيا الجديدة في كريكت دولي",
    "Category:Papua New Guinea in World War I": "تصنيف:بابوا غينيا الجديدة في الحرب العالمية الأولى",
    "Category:Papua New Guinea in World War II": "تصنيف:بابوا غينيا الجديدة في الحرب العالمية الثانية",
    "Category:Papua New Guinea international women's rugby sevens players": "تصنيف:لاعبات سباعيات رجبي دوليات من بابوا غينيا الجديدة",
    "Category:Papua New Guinea national netball team": "تصنيف:منتخب بابوا غينيا الجديدة لكرة الشبكة",
    "Category:Papua New Guinea national rugby league team": "تصنيف:منتخب بابوا غينيا الجديدة لدوري الرجبي",
    "Category:Papua New Guinea national rugby league team coaches": "تصنيف:مدربو منتخب بابوا غينيا الجديدة لدوري الرجبي",
    "Category:Papua New Guinea national rugby league team players": "تصنيف:لاعبو منتخب بابوا غينيا الجديدة لدوري الرجبي",
    "Category:Papua New Guinea national rugby league team templates": "تصنيف:قوالب منتخب بابوا غينيا الجديدة لدوري الرجبي",
    "Category:Papua New Guinea national rugby union team": "تصنيف:منتخب بابوا غينيا الجديدة لاتحاد الرجبي",
    "Category:Papua New Guinea National Soccer League": "تصنيف:دوري بابوا غينيا الجديدة لكرة القدم",
    "Category:Papua New Guinea National Soccer League seasons": "تصنيف:مواسم دوري بابوا غينيا الجديدة لكرة القدم",
    "Category:Papua New Guinea national soccer team": "تصنيف:منتخب بابوا غينيا الجديدة لكرة القدم",
    "Category:Papua New Guinea national soccer team managers": "تصنيف:مدربو منتخب بابوا غينيا الجديدة لكرة القدم",
    "Category:Papua New Guinea national soccer team matches": "تصنيف:مباريات منتخب بابوا غينيا الجديدة لكرة القدم",
    "Category:Papua New Guinea national soccer team navigational boxes": "تصنيف:صناديق تصفح منتخب بابوا غينيا الجديدة لكرة القدم",
    "Category:Papua New Guinea navigational boxes": "تصنيف:صناديق تصفح بابوا غينيا الجديدة",
    "Category:Papua New Guinea sports navigational boxes": "تصنيف:صناديق تصفح الرياضة في بابوا غينيا الجديدة",
    "Category:Papua New Guinea sports templates": "تصنيف:قوالب بابوا غينيا الجديدة الرياضية",
    "Category:Papua New Guinea templates": "تصنيف:قوالب بابوا غينيا الجديدة",
    "Category:Papua New Guinea women's national football team": "تصنيف:منتخب بابوا غينيا الجديدة لكرة القدم للسيدات",
    "Category:Papua New Guinea women's national rugby league team players": "تصنيف:لاعبات منتخب بابوا غينيا الجديدة لدوري الرجبي للسيدات",
    "Category:Papua New Guinea women's national soccer team navigational boxes": "تصنيف:صناديق تصفح منتخب بابوا غينيا الجديدة لكرة القدم للسيدات",
    "Category:Papua New Guinea-related lists": "تصنيف:قوائم متعلقة ببابوا غينيا الجديدة",
    "Category:Papua New Guinea–Philippines relations": "تصنيف:العلاقات الغينية الفلبينية",
    "Category:Papua New Guinea–Poland relations": "تصنيف:العلاقات البولندية الغينية",
    "Category:Papua New Guinea–Singapore relations": "تصنيف:العلاقات السنغافورية الغينية",
    "Category:Papua New Guinea–South Africa relations": "تصنيف:العلاقات الجنوب الإفريقية الغينية",
    "Category:Papua New Guinea–South Korea relations": "تصنيف:العلاقات الغينية الكورية الجنوبية",
    "Category:Papua New Guinea–Sri Lanka relations": "تصنيف:العلاقات السريلانكية الغينية",
    "Category:Papua New Guinea–Sweden relations": "تصنيف:العلاقات السويدية الغينية",
    "Category:Papua New Guinea–Thailand relations": "تصنيف:العلاقات التايلندية الغينية",
    "Category:Papua New Guinea–Tonga relations": "تصنيف:العلاقات التونغانية الغينية",
    "Category:Papua New Guinea–Tuvalu relations": "تصنيف:العلاقات التوفالية الغينية",
    "Category:Papua New Guinea–United Arab Emirates relations": "تصنيف:العلاقات الإماراتية الغينية",
    "Category:Papua New Guinea–United Arab Emirates sports relations": "تصنيف:العلاقات الإماراتية الغينية الرياضية",
    "Category:Papua New Guinea–United Kingdom relations": "تصنيف:العلاقات البريطانية الغينية",
    "Category:Papua New Guinea–United Kingdom sports relations": "تصنيف:العلاقات البريطانية الغينية الرياضية",
    "Category:Papua New Guinea–United States relations": "تصنيف:العلاقات الأمريكية الغينية",
    "Category:Papua New Guinea–Zimbabwe relations": "تصنيف:العلاقات الزيمبابوية الغينية",
    "Category:Paralympic athletes for Papua New Guinea": "تصنيف:لاعبو قوى في الألعاب البارالمبية في بابوا غينيا الجديدة",
    "Category:Paralympic medalists for Papua New Guinea": "تصنيف:فائزون بميداليات الألعاب البارالمبية من بابوا غينيا الجديدة",
    "Category:Paralympic silver medalists for Papua New Guinea": "تصنيف:فائزون بميداليات فضية في الألعاب البارالمبية من بابوا غينيا الجديدة",
    "Category:Paralympic taekwondo practitioners for Papua New Guinea": "تصنيف:لاعبو تايكوندو في الألعاب البارالمبية في بابوا غينيا الجديدة",
    "Category:Patrol vessels of Papua New Guinea": "تصنيف:سفن دورية في بابوا غينيا الجديدة",
    "Category:Penal system in Papua New Guinea": "تصنيف:قانون العقوبات في بابوا غينيا الجديدة",
    "Category:Peninsulas of Papua New Guinea": "تصنيف:أشباه جزر في بابوا غينيا الجديدة",
    "Category:People by educational institution in Papua New Guinea": "تصنيف:أشخاص حسب الهيئة التعليمية في بابوا غينيا الجديدة",
    "Category:People by university or college in Papua New Guinea": "تصنيف:أشخاص حسب الجامعة أو الكلية في بابوا غينيا الجديدة",
    "Category:People murdered in Papua New Guinea": "تصنيف:أشخاص قتلوا في بابوا غينيا الجديدة",
    "Category:Performing arts in Papua New Guinea": "تصنيف:الفنون التمثيلية في بابوا غينيا الجديدة",
    "Category:Permanent representatives of Papua New Guinea to the European Union": "تصنيف:مندوبو بابوا غينيا الجديدة الدائمون إلى الاتحاد الأوروبي",
    "Category:Permanent representatives of Papua New Guinea to the United Nations": "تصنيف:مندوبو بابوا غينيا الجديدة الدائمون لدى الأمم المتحدة",
    "Category:Petroleum in Papua New Guinea": "تصنيف:بترول في بابوا غينيا الجديدة",
    "Category:Polish expatriates in Papua New Guinea": "تصنيف:بولنديون مغتربون في بابوا غينيا الجديدة",
    "Category:Political history of Papua New Guinea": "تصنيف:تاريخ بابوا غينيا الجديدة السياسي",
    "Category:Political movements in Papua New Guinea": "تصنيف:حركات سياسية في بابوا غينيا الجديدة",
    "Category:Political office-holders in Papua New Guinea": "تصنيف:أصحاب مناصب سياسية في بابوا غينيا الجديدة",
    "Category:Political organisations based in Papua New Guinea": "تصنيف:منظمات سياسية مقرها في بابوا غينيا الجديدة",
    "Category:Political parties in Papua New Guinea": "تصنيف:أحزاب سياسية في بابوا غينيا الجديدة",
    "Category:Politics of Papua New Guinea": "تصنيف:سياسة بابوا غينيا الجديدة",
    "Category:Politics of Papua New Guinea by province": "تصنيف:سياسة بابوا غينيا الجديدة حسب المقاطعة",
    "Category:Populated coastal places in Papua New Guinea": "تصنيف:أماكن ساحلية مأهولة في بابوا غينيا الجديدة",
    "Category:Populated places in Papua New Guinea": "تصنيف:أماكن مأهولة في بابوا غينيا الجديدة",
    "Category:Ports and harbours of Papua New Guinea": "تصنيف:مرافئ وموانئ بابوا غينيا الجديدة",
    "Category:Power stations in Papua New Guinea": "تصنيف:محطات طاقة في بابوا غينيا الجديدة",
    "Category:Prime ministers of Papua New Guinea": "تصنيف:رؤساء وزراء بابوا غينيا الجديدة",
    "Category:Prisoners and detainees of Papua New Guinea": "تصنيف:سجناء ومعتقلون في بابوا غينيا الجديدة",
    "Category:Prisoners sentenced to death by Papua New Guinea": "تصنيف:مسجونون حكم عليهم بالإعدام بواسطة بابوا غينيا الجديدة",
    "Category:Protected areas of Papua New Guinea": "تصنيف:مناطق محمية في بابوا غينيا الجديدة",
    "Category:Protestant missionaries in Papua New Guinea": "تصنيف:مبشرون بروتستانتيون في بابوا غينيا الجديدة",
    "Category:Protestantism in Papua New Guinea": "تصنيف:البروتستانتية في بابوا غينيا الجديدة",
    "Category:Provincial capitals in Papua New Guinea": "تصنيف:عواصم محافظات في بابوا غينيا الجديدة",
    "Category:Public holidays in Papua New Guinea": "تصنيف:عطلات رسمية في بابوا غينيا الجديدة",
    "Category:Radio in Papua New Guinea": "تصنيف:راديو في بابوا غينيا الجديدة",
    "Category:Reefs of Papua New Guinea": "تصنيف:شعاب بابوا غينيا الجديدة",
    "Category:Regions of Papua New Guinea": "تصنيف:مناطق بابوا غينيا الجديدة",
    "Category:Religion in Papua New Guinea": "تصنيف:الدين في بابوا غينيا الجديدة",
    "Category:Religious buildings and structures in Papua New Guinea": "تصنيف:مبان ومنشآت دينية في بابوا غينيا الجديدة",
    "Category:Religious organisations based in Papua New Guinea": "تصنيف:منظمات دينية مقرها في بابوا غينيا الجديدة",
    "Category:Renewable energy in Papua New Guinea": "تصنيف:طاقة متجددة في بابوا غينيا الجديدة",
    "Category:Renewable energy power stations in Papua New Guinea": "تصنيف:محطات طاقة متجددة في بابوا غينيا الجديدة",
    "Category:Reptiles of Papua New Guinea": "تصنيف:زواحف بابوا غينيا الجديدة",
    "Category:Research in Papua New Guinea": "تصنيف:أبحاث في بابوا غينيا الجديدة",
    "Category:Research institutes in Papua New Guinea": "تصنيف:معاهد أبحاث في بابوا غينيا الجديدة",
    "Category:Right-wing politics in Papua New Guinea": "تصنيف:سياسة يمينية في بابوا غينيا الجديدة",
    "Category:Rivers of Papua New Guinea": "تصنيف:أنهار بابوا غينيا الجديدة",
    "Category:Road incident deaths in Papua New Guinea": "تصنيف:وفيات حوادث الطرق في بابوا غينيا الجديدة",
    "Category:Road incidents in Papua New Guinea": "تصنيف:حوادث طرق في بابوا غينيا الجديدة",
    "Category:Road transport in Papua New Guinea": "تصنيف:نقل بري في بابوا غينيا الجديدة",
    "Category:Roads in Papua New Guinea": "تصنيف:طرقات في بابوا غينيا الجديدة",
    "Category:Rodents of Papua New Guinea": "تصنيف:قوارض بابوا غينيا الجديدة",
    "Category:Roman Catholic archbishops in Papua New Guinea": "تصنيف:رؤساء أساقفة رومان كاثوليك في بابوا غينيا الجديدة",
    "Category:Roman Catholic church buildings in Papua New Guinea": "تصنيف:مبان كنائس رومانية كاثوليكية في بابوا غينيا الجديدة",
    "Category:Rugby league in Papua New Guinea": "تصنيف:دوري الرجبي في بابوا غينيا الجديدة",
    "Category:Rugby league players in Papua New Guinea by team": "تصنيف:لاعبو دوري رجبي في بابوا غينيا الجديدة حسب الفريق",
    "Category:Rugby league stadiums in Papua New Guinea": "تصنيف:استادات دوري الرجبي في بابوا غينيا الجديدة",
    "Category:Rugby league teams in Papua New Guinea": "تصنيف:فرق دوري الرجبي في بابوا غينيا الجديدة",
    "Category:Rugby union in Papua New Guinea": "تصنيف:اتحاد الرجبي في بابوا غينيا الجديدة",
    "Category:Running in Papua New Guinea": "تصنيف:ركض في بابوا غينيا الجديدة",
    "Category:Sailing in Papua New Guinea": "تصنيف:الإبحار في بابوا غينيا الجديدة",
    "Category:Schools in Papua New Guinea": "تصنيف:مدارس في بابوا غينيا الجديدة",
    "Category:Science and technology in Papua New Guinea": "تصنيف:العلوم والتقانة في بابوا غينيا الجديدة",
    "Category:Separatism in Papua New Guinea": "تصنيف:الانفصالية في بابوا غينيا الجديدة",
    "Category:Service companies of Papua New Guinea": "تصنيف:شركات خدمات في بابوا غينيا الجديدة",
    "Category:Service industries in Papua New Guinea": "تصنيف:صناعات خدمية في بابوا غينيا الجديدة",
    "Category:Sexuality in Papua New Guinea": "تصنيف:الجنسانية في بابوا غينيا الجديدة",
    "Category:Ships of Papua New Guinea": "تصنيف:سفن بابوا غينيا الجديدة",
    "Category:Shipwrecks of Papua New Guinea": "تصنيف:حطام سفن في بابوا غينيا الجديدة",
    "Category:Shooting sports in Papua New Guinea": "تصنيف:الرماية في بابوا غينيا الجديدة",
    "Category:Short stories set in Papua New Guinea": "تصنيف:قصص قصيرة تقع أحداثها في بابوا غينيا الجديدة",
    "Category:Soccer clubs in Papua New Guinea": "تصنيف:أندية كرة قدم في بابوا غينيا الجديدة",
    "Category:Soccer in Papua New Guinea": "تصنيف:كرة القدم في بابوا غينيا الجديدة",
    "Category:Social issues in Papua New Guinea": "تصنيف:قضايا اجتماعية في بابوا غينيا الجديدة",
    "Category:Society of Papua New Guinea": "تصنيف:مجتمع بابوا غينيا الجديدة",
    "Category:Softball in Papua New Guinea": "تصنيف:الكرة اللينة في بابوا غينيا الجديدة",
    "Category:Sport in Papua New Guinea": "تصنيف:الرياضة في بابوا غينيا الجديدة",
    "Category:Sport in Papua New Guinea by sport": "تصنيف:الرياضة في بابوا غينيا الجديدة حسب الرياضة",
    "Category:Sports clubs and teams in Papua New Guinea": "تصنيف:أندية وفرق رياضية في بابوا غينيا الجديدة",
    "Category:Sports competitions in Papua New Guinea": "تصنيف:منافسات رياضية في بابوا غينيا الجديدة",
    "Category:Sports festivals in Papua New Guinea": "تصنيف:مهرجانات رياضية في بابوا غينيا الجديدة",
    "Category:Sports organisations of Papua New Guinea": "تصنيف:منظمات رياضية في بابوا غينيا الجديدة",
    "Category:Sports venues in Papua New Guinea": "تصنيف:ملاعب رياضية في بابوا غينيا الجديدة",
    "Category:Sportspeople in Papua New Guinea": "تصنيف:رياضيون في بابوا غينيا الجديدة",
    "Category:Sportspeople in Papua New Guinea by club or team": "تصنيف:رياضيون في بابوا غينيا الجديدة حسب النادي أو الفريق",
    "Category:Straits of Papua New Guinea": "تصنيف:مضائق بابوا غينيا الجديدة",
    "Category:Stratovolcanoes of Papua New Guinea": "تصنيف:براكين طبقية في بابوا غينيا الجديدة",
    "Category:Subdivisions of Papua New Guinea": "تصنيف:تقسيمات بابوا غينيا الجديدة",
    "Category:Suburbs in Papua New Guinea": "تصنيف:ضواحي في بابوا غينيا الجديدة",
    "Category:Summer Olympics competitors for Papua New Guinea": "تصنيف:منافسون أولمبيون صيفيون من بابوا غينيا الجديدة",
    "Category:Swimming competitions in Papua New Guinea": "تصنيف:منافسات سباحة في بابوا غينيا الجديدة",
    "Category:Swimming in Papua New Guinea": "تصنيف:السباحة في بابوا غينيا الجديدة",
    "Category:Telecommunications in Papua New Guinea": "تصنيف:الاتصالات عن بعد في بابوا غينيا الجديدة",
    "Category:Television episodes set in Papua New Guinea": "تصنيف:حلقات تلفزيونية تقع أحداثها في بابوا غينيا الجديدة",
    "Category:Television in Papua New Guinea": "تصنيف:التلفاز في بابوا غينيا الجديدة",
    "Category:Television in Papua New Guinea by century": "تصنيف:التلفاز في بابوا غينيا الجديدة حسب القرن",
    "Category:Television in Papua New Guinea by decade": "تصنيف:التلفاز في بابوا غينيا الجديدة حسب العقد",
    "Category:Television stations in Papua New Guinea": "تصنيف:محطات تلفزيونية في بابوا غينيا الجديدة",
    "Category:Tennis in Papua New Guinea": "تصنيف:كرة المضرب في بابوا غينيا الجديدة",
    "Category:Theatre in Papua New Guinea": "تصنيف:المسرح في بابوا غينيا الجديدة",
    "Category:Tongan expatriates in Papua New Guinea": "تصنيف:تونغانيون مغتربون في بابوا غينيا الجديدة",
    "Category:Tourism in Papua New Guinea": "تصنيف:سياحة في بابوا غينيا الجديدة",
    "Category:Tourist attractions in Papua New Guinea": "تصنيف:مواقع جذب سياحي في بابوا غينيا الجديدة",
    "Category:Trade unions in Papua New Guinea": "تصنيف:نقابات عمالية في بابوا غينيا الجديدة",
    "Category:Transport buildings and structures in Papua New Guinea": "تصنيف:مبان ومنشآت نقل في بابوا غينيا الجديدة",
    "Category:Transport disasters in Papua New Guinea": "تصنيف:كوارث نقل في بابوا غينيا الجديدة",
    "Category:Transport in Papua New Guinea": "تصنيف:النقل في بابوا غينيا الجديدة",
    "Category:Transport infrastructure in Papua New Guinea": "تصنيف:البنية التحتية للنقل في بابوا غينيا الجديدة",
    "Category:Transport organisations based in Papua New Guinea": "تصنيف:منظمات نقل مقرها في بابوا غينيا الجديدة",
    "Category:Treaties of Papua New Guinea": "تصنيف:معاهدات بابوا غينيا الجديدة",
    "Category:Tropical cyclones in Papua New Guinea": "تصنيف:أعاصير مدارية في بابوا غينيا الجديدة",
    "Category:Tsunamis in Papua New Guinea": "تصنيف:أمواج تسونامي في بابوا غينيا الجديدة",
    "Category:Uninhabited islands of Papua New Guinea": "تصنيف:جزر غير مأهولة في بابوا غينيا الجديدة",
    "Category:United Nations Security Council resolutions concerning Papua New Guinea": "تصنيف:قرارات مجلس الأمن التابع للأمم المتحدة بشأن بابوا غينيا الجديدة",
    "Category:Universities and colleges in Papua New Guinea": "تصنيف:جامعات وكليات في بابوا غينيا الجديدة",
    "Category:Universities in Papua New Guinea": "تصنيف:جامعات في بابوا غينيا الجديدة",
    "Category:University of Papua New Guinea": "تصنيف:جامعة بابوا غينيا الجديدة",
    "Category:University of Papua New Guinea alumni": "تصنيف:خريجو جامعة بابوا غينيا الجديدة",
    "Category:Valleys of Papua New Guinea": "تصنيف:أودية بابوا غينيا الجديدة",
    "Category:Vanuatuan expatriate sportspeople in Papua New Guinea": "تصنيف:رياضيون فانواتيون مغتربون في بابوا غينيا الجديدة",
    "Category:Vanuatuan expatriates in Papua New Guinea": "تصنيف:فانواتيون مغتربون في بابوا غينيا الجديدة",
    "Category:Vertebrates of Papua New Guinea": "تصنيف:فقاريات بابوا غينيا الجديدة",
    "Category:Victims of aviation accidents or incidents in Papua New Guinea": "تصنيف:ضحايا حوادث طيران في بابوا غينيا الجديدة",
    "Category:Video games set in Papua New Guinea": "تصنيف:ألعاب فيديو تقع أحداثها في بابوا غينيا الجديدة",
    "Category:Violence against women in Papua New Guinea": "تصنيف:العنف ضد المرأة في بابوا غينيا الجديدة",
    "Category:Violence in Papua New Guinea": "تصنيف:عنف في بابوا غينيا الجديدة",
    "Category:Violent deaths in Papua New Guinea": "تصنيف:وفيات عنيفة في بابوا غينيا الجديدة",
    "Category:Volcanoes of Papua New Guinea": "تصنيف:براكين بابوا غينيا الجديدة",
    "Category:Volleyball in Papua New Guinea": "تصنيف:كرة الطائرة في بابوا غينيا الجديدة",
    "Category:Wars involving Papua New Guinea": "تصنيف:حروب تشمل بابوا غينيا الجديدة",
    "Category:Water in Papua New Guinea": "تصنيف:مياه في بابوا غينيا الجديدة",
    "Category:Water sports in Papua New Guinea": "تصنيف:رياضات مائية في بابوا غينيا الجديدة",
    "Category:Water transport in Papua New Guinea": "تصنيف:نقل مائي في بابوا غينيا الجديدة",
    "Category:Wetlands of Papua New Guinea": "تصنيف:مناطق رطبة في بابوا غينيا الجديدة",
    "Category:Women government ministers of Papua New Guinea": "تصنيف:وزيرات غينيات",
    "Category:Women in Papua New Guinea": "تصنيف:المرأة في بابوا غينيا الجديدة",
    "Category:Women's basketball in Papua New Guinea": "تصنيف:كرة السلة للسيدات في بابوا غينيا الجديدة",
    "Category:Women's cricket in Papua New Guinea": "تصنيف:الكريكت للسيدات في بابوا غينيا الجديدة",
    "Category:Women's soccer in Papua New Guinea": "تصنيف:كرة القدم للسيدات في بابوا غينيا الجديدة",
    "Category:Women's soccer players in Papua New Guinea": "تصنيف:لاعبات كرة قدم في بابوا غينيا الجديدة",
    "Category:Women's sport in Papua New Guinea": "تصنيف:رياضة نسائية في بابوا غينيا الجديدة",
    "Category:Works about Papua New Guinea": "تصنيف:أعمال عن بابوا غينيا الجديدة",
    "Category:Works set in Papua New Guinea": "تصنيف:أعمال تقع أحداثها في بابوا غينيا الجديدة",
    "Category:World Heritage Sites in Papua New Guinea": "تصنيف:مواقع التراث العالمي في بابوا غينيا الجديدة",
    "Category:Years in Papua New Guinea": "تصنيف:سنوات في بابوا غينيا الجديدة",
    "Category:Years in Papua New Guinea by month": "تصنيف:سنوات في بابوا غينيا الجديدة حسب الشهر",
    "Category:Years of the 20th century in Papua New Guinea": "تصنيف:سنوات القرن 20 في بابوا غينيا الجديدة",
    "Category:Years of the 21st century in Papua New Guinea": "تصنيف:سنوات القرن 21 في بابوا غينيا الجديدة",
    "Category:Youth in Papua New Guinea": "تصنيف:الشباب في بابوا غينيا الجديدة",
    "Category:Youth organisations based in Papua New Guinea": "تصنيف:منظمات شبابية مقرها في بابوا غينيا الجديدة",
    "Category:Youth sport in Papua New Guinea": "تصنيف:رياضة شبابية في بابوا غينيا الجديدة",
}

to_test = [
    # ("test_papua_new_guinea_0", data_0),
    ("test_papua_new_guinea_1", data_1),
]


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
@pytest.mark.fast
def test_papua_new_guinea_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
