"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.legacy_bots.ma_bots2.country2_label_bot import c_1_1_lab

fast_data_c_1_1_lab = [
    {"separator": " by ", "cone_1": "american football teams", "output": "فرق كرة قدم أمريكية"},
    {"separator": " by ", "cone_1": "american rock musicians", "output": "موسيقيو روك أمريكيون"},
    {"separator": " by ", "cone_1": "amphibious warfare vessels", "output": "سفن حربية برمائية"},
    {"separator": " by ", "cone_1": "animated television series", "output": "مسلسلات تلفزيونية رسوم متحركة"},
    {"separator": " by ", "cone_1": "anime and manga", "output": "أنمي ومانغا"},
    {"separator": " by ", "cone_1": "australian open tennis", "output": "بطولة أستراليا المفتوحة للتنس"},
    {"separator": " by ", "cone_1": "australian rules football clubs", "output": "أندية كرة قدم أسترالية"},
    {"separator": " by ", "cone_1": "australian rules football", "output": "كرة القدم الأسترالية"},
    {"separator": " by ", "cone_1": "buildings and structures demolished", "output": "مبان ومنشآت هدمت"},
    {"separator": " by ", "cone_1": "buildings and structures", "output": "مبان ومنشآت"},
    {"separator": " by ", "cone_1": "canadian football teams", "output": "فرق كرة قدم كندية"},
    {"separator": " by ", "cone_1": "christian buildings and structures", "output": "مبان ومنشآت مسيحية"},
    {"separator": " by ", "cone_1": "christian music albums", "output": "ألبومات موسيقى مسيحية"},
    {"separator": " by ", "cone_1": "christian universities and colleges", "output": "جامعات وكليات مسيحية"},
    {"separator": " by ", "cone_1": "dance music albums", "output": "ألبومات موسيقى الرقص"},
    {"separator": " by ", "cone_1": "death metal albums", "output": "ألبومات ديث ميتال"},
    {"separator": " by ", "cone_1": "east german people", "output": "ألمانيون شرقيون"},
    {"separator": " by ", "cone_1": "east german sports-people", "output": "رياضيون ألمانيون شرقيون"},
    {"separator": " by ", "cone_1": "eastern orthodox cathedrals", "output": "كاتدرائيات أرثوذكسية شرقية"},
    {"separator": " by ", "cone_1": "english male actors", "output": "ممثلون ذكور إنجليز"},
    {"separator": " by ", "cone_1": "folk rock albums", "output": "ألبومات فولك روك"},
    {"separator": " by ", "cone_1": "hardcore punk albums", "output": "ألبومات هاردكور بانك"},
    {"separator": " by ", "cone_1": "heavy metal albums", "output": "ألبومات هيفي ميتال"},
    {"separator": " by ", "cone_1": "ice hockey leagues", "output": "دوريات هوكي جليد"},
    {"separator": " by ", "cone_1": "ice hockey teams", "output": "فرق هوكي على الجليد"},
    {"separator": " by ", "cone_1": "indie pop albums", "output": "ألبومات إيندي بوب"},
    {"separator": " by ", "cone_1": "indie rock albums", "output": "ألبومات إيندي روك"},
    {"separator": " by ", "cone_1": "international baseball competitions", "output": "منافسات كرة قاعدة دولية"},
    {"separator": " by ", "cone_1": "latin music albums", "output": "ألبومات موسيقى لاتينية"},
    {"separator": " by ", "cone_1": "law enforcement operations", "output": "عمليات تطبيق القانون"},
    {"separator": " by ", "cone_1": "major league baseball players", "output": "لاعبو دوري كرة القاعدة الرئيسي"},
    {"separator": " by ", "cone_1": "noise music albums", "output": "ألبومات موسيقى نويز"},
    {"separator": " by ", "cone_1": "olympic games bids", "output": "عروض الألعاب الأوليمبية"},
    {"separator": " by ", "cone_1": "palestinian people imprisoned", "output": "فلسطينيون مسجونون"},
    {"separator": " by ", "cone_1": "pop punk albums", "output": "ألبومات بوب بانك"},
    {"separator": " by ", "cone_1": "ports and harbours", "output": "مرافئ وموانئ"},
    {"separator": " by ", "cone_1": "prisoners sentenced to death", "output": "سجناء حكم عليهم بالإعدام"},
    {
        "separator": " by ",
        "cone_1": "prisoners sentenced to life imprisonment",
        "output": "سجناء حكم عليهم بالحبس المؤبد",
    },
    {"separator": " by ", "cone_1": "protestant religious leaders", "output": "قادة دينيون بروتستانتيون"},
    {"separator": " by ", "cone_1": "psychedelic music albums", "output": "ألبومات موسيقى سايكيديلية"},
    {"separator": " by ", "cone_1": "roman catholic archbishops", "output": "رؤساء أساقفة رومان كاثوليك"},
    {"separator": " by ", "cone_1": "roman catholic bishops", "output": "أساقفة كاثوليك رومان"},
    {"separator": " by ", "cone_1": "rugby league coaches", "output": "مدربو دوري رجبي"},
    {"separator": " by ", "cone_1": "science fiction films", "output": "أفلام خيال علمي"},
    {"separator": " by ", "cone_1": "science fiction novels", "output": "روايات خيال علمي"},
    {"separator": " by ", "cone_1": "serbian basketball players", "output": "لاعبو كرة سلة صرب"},
    {"separator": " by ", "cone_1": "sierra leonean people", "output": "سيراليونيون"},
    {"separator": " by ", "cone_1": "south african people", "output": "جنوب إفريقيون"},
    {"separator": " by ", "cone_1": "spoken word albums", "output": "ألبومات كلمة منطوقة"},
    {"separator": " by ", "cone_1": "television series produced", "output": "مسلسلات تلفزيونية أنتجت"},
    {"separator": " by ", "cone_1": "television shows produced", "output": "عروض تلفزيونية أنتجت"},
    {"separator": " by ", "cone_1": "united arab emirates", "output": "الإمارات العربية المتحدة"},
    {"separator": " by ", "cone_1": "united kingdom", "output": "المملكة المتحدة"},
    {"separator": " by ", "cone_1": "united states", "output": "الولايات المتحدة"},
    {
        "separator": " by ",
        "cone_1": "u.s. national championships tennis",
        "output": "البطولات الوطنية الأمريكية لكرة المضرب",
    },
    {"separator": " by ", "cone_1": "united arab emirates", "output": "الإمارات العربية المتحدة"},
    {"separator": " by ", "cone_1": "us open tennis", "output": "بطولة أمريكا المفتوحة للتنس"},
    {"separator": " by ", "cone_1": "world heritage sites", "output": "مواقع التراث العالمي"},
    {"separator": " from ", "cone_1": "australian rules footballers", "output": "لاعبو كرة قدم أسترالية"},
    {"separator": " from ", "cone_1": "field hockey people", "output": "أعلام هوكي ميدان"},
    {"separator": " from ", "cone_1": "field hockey players", "output": "لاعبو هوكي ميدان"},
    {"separator": " from ", "cone_1": "ice hockey people", "output": "أعلام هوكي جليد"},
    {"separator": " from ", "cone_1": "male voice actors", "output": "ممثلو أداء صوتي ذكور"},
    {"separator": " from ", "cone_1": "rugby league players", "output": "لاعبو دوري رجبي"},
    {"separator": " from ", "cone_1": "rugby union players", "output": "لاعبو اتحاد رجبي"},
    {"separator": " from ", "cone_1": "united states house-of-representatives", "output": "مجلس النواب الأمريكي"},
    {"separator": " from ", "cone_1": "water polo players", "output": "لاعبو كرة ماء"},
    {"separator": " in ", "cone_1": "universities and colleges", "output": "جامعات وكليات"},
    {"separator": " in ", "cone_1": "video games set", "output": "ألعاب فيديو تقع أحداثها"},
    {"separator": " in ", "cone_1": "world heritage sites", "output": "مواقع التراث العالمي"},
    {"separator": " of ", "cone_1": "archaeological sites of", "output": "مواقع أثرية في"},
    {"separator": " of ", "cone_1": "battles and operations of", "output": "معارك وعمليات"},
    {"separator": " of ", "cone_1": "burial sites of", "output": "مواقع دفن"},
    {"separator": " of ", "cone_1": "canyons and gorges of", "output": "أخاديد في"},
    {"separator": " of ", "cone_1": "chemical technology of", "output": "تقانة كيميائية في"},
    {"separator": " of ", "cone_1": "chief justices of", "output": "رؤساء قضاء"},
    {"separator": " of ", "cone_1": "congressional districts of", "output": "مقاطعات الكونغرس في"},
    {"separator": " of ", "cone_1": "cultural depictions of", "output": "تصوير ثقافي عن"},
    {"separator": " of ", "cone_1": "drainage basins of", "output": "أحواض تصريف في"},
    {"separator": " of ", "cone_1": "eastern front of", "output": "الجبهة الشرقية في"},
    {"separator": " of ", "cone_1": "featured pictures of", "output": "صور مميزة عن"},
    {"separator": " of ", "cone_1": "fictional depictions of", "output": "تصوير خيالي عن"},
    {"separator": " of ", "cone_1": "government ministers of", "output": "وزراء"},
    {"separator": " of ", "cone_1": "governors general of", "output": "حكام عموم"},
    {"separator": " of ", "cone_1": "indigenous peoples of", "output": "شعوب أصلية في"},
    {"separator": " of ", "cone_1": "lieutenant governors of", "output": "نواب حكام"},
    {"separator": " of ", "cone_1": "mass murder of", "output": "قتل جماعي في"},
    {"separator": " of ", "cone_1": "military operations of", "output": "عمليات عسكرية في"},
    {"separator": " of ", "cone_1": "mountain passes of", "output": "ممرات جبلية في"},
    {"separator": " of ", "cone_1": "mountain ranges of", "output": "سلاسل جبلية في"},
    {"separator": " of ", "cone_1": "mountains and hills of", "output": "جبال وتلال"},
    {"separator": " of ", "cone_1": "national parks of", "output": "متنزهات وطنية في"},
    {"separator": " of ", "cone_1": "national sports teams of", "output": "منتخبات رياضية وطنية في"},
    {"separator": " of ", "cone_1": "native birds of", "output": "طيور محلية في"},
    {"separator": " of ", "cone_1": "naval battles of", "output": "معارك بحرية"},
    {"separator": " of ", "cone_1": "peace treaties of", "output": "معاهدات سلام"},
    {"separator": " of ", "cone_1": "ports and harbours of", "output": "مرافئ وموانئ"},
    {"separator": " of ", "cone_1": "prime ministers of", "output": "رؤساء وزراء"},
    {"separator": " of ", "cone_1": "prisoners and detainees of", "output": "سجناء ومعتقلون في"},
    {"separator": " of ", "cone_1": "protected areas of", "output": "مناطق محمية في"},
    {"separator": " of ", "cone_1": "rock formations of", "output": "تكوينات صخرية في"},
    {"separator": " of ", "cone_1": "sports organizations of", "output": "منظمات رياضية في"},
    {"separator": " of ", "cone_1": "state constitutional officers of", "output": "مسؤولون دستوريون في"},
    {"separator": " of ", "cone_1": "order of", "output": "وسام"},
    {"separator": " of ", "cone_1": "uninhabited islands of", "output": "جزر غير مأهولة في"},
    {"separator": " of ", "cone_1": "vice presidents of", "output": "نواب رؤساء"},
    {"separator": " on ", "cone_1": "art museums and galleries", "output": "متاحف فنية ومعارض"},
    {"separator": " on ", "cone_1": "buildings and structures", "output": "مبان ومنشآت"},
    {"separator": " on ", "cone_1": "demolished buildings and structures", "output": "مبان ومنشآت مهدمة"},
    {"separator": " on ", "cone_1": "disused railway stations", "output": "محطات سكك حديدية مهجورة"},
    {"separator": " on ", "cone_1": "major league baseball", "output": "دوري كرة القاعدة الرئيسي"},
    {"separator": " on ", "cone_1": "military units and formations", "output": "وحدات وتشكيلات عسكرية"},
    {"separator": " on ", "cone_1": "pakistani people imprisoned", "output": "باكستانيون مسجونون"},
    {"separator": " on ", "cone_1": "parks and open spaces", "output": "متنزهات ومساحات مفتوحة"},
    {"separator": " on ", "cone_1": "roman catholic churches", "output": "كنائس رومانية كاثوليكية"},
    {"separator": " on ", "cone_1": "sierra leonean judges", "output": "قضاة سيراليونيون"},
    {"separator": " on ", "cone_1": "south african judges", "output": "قضاة جنوب إفريقيون"},
    {"separator": " on ", "cone_1": "television series set", "output": "مسلسلات تلفزيونية تقع أحداثها"},
    {"separator": " on ", "cone_1": "united states capitol", "output": "كابيتول الولايات المتحدة"},
    {"separator": " on ", "cone_1": "video games set", "output": "ألعاب فيديو تقع أحداثها"},
    {"separator": " to ", "cone_1": "monuments and memorials", "output": "معالم أثرية ونصب تذكارية"},
    {"separator": " to ", "cone_1": "united states navy", "output": "البحرية الأمريكية"},
    {"separator": "-of ", "cone_1": "cabinet secretaries of", "output": "أعضاء مجلس وزراء"},
    {"separator": "-of ", "cone_1": "state cabinet secretaries of", "output": "أعضاء مجلس وزراء"},
]


@pytest.mark.parametrize("data", fast_data_c_1_1_lab, ids=lambda x: x["cone_1"])
@pytest.mark.fast
def test_c_1_1_lab(data) -> None:
    label = c_1_1_lab(data["separator"], data["cone_1"], with_years=False)
    assert label == data["output"]
