"""
Static translations used for tennis and tournament related keys.
"""

from ...helps import len_print

TENNIS_KEYS: dict[str, str] = {
    "european athletics championships": "بطولة أوروبا لألعاب القوى",
    "deaflympics": "ديفلمبياد",
    "badminton in the summer olympics": "تنس الريشة في الألعاب الأولمبية الصيفية",
    "asian athletics championships": "بطولة آسيا لألعاب القوى",
    "racewalking": "سباق المشي",
    "european athletics indoor championships": "بطولة أوروبا لألعاب القوى داخل الصالات",
    "european championships": "بطولات أوروبا",
    "swiss cup": "كأس سويسرا لكرة القدم",
    "world championships-in-athletics athletes": "عداؤو بطولة العالم لألعاب القوى",
    "world championships in athletics athletes": "عداؤو بطولة العالم لألعاب القوى",
    "world championships in athletics": "بطولة العالم لألعاب القوى",
    "world championships-in-athletics": "بطولة العالم لألعاب القوى",
    "dutch tt": "كأس هولندا السياحية",
    "world table tennis championships": "بطولات عالمية لتنس الطاولة",
    "world touring car championship": "بطولة العالم لسيارات السياحة",
    "gcc champions league": "كأس الخليج للأندية",
    "german formula three championship": "بطولة فورمولا 3 الألمانية",
    "800 metres": "800 متر",
    "world champions": "أبطال العالم",
    "world championships": "بطولات العالم",
    "association football leagues": "دوريات كرة قدم",
    "figure skating in the winter universiade": "التزلج الفني في الألعاب الجامعية الشتوية",
    "copa argentina": "كوبا أرجنتينا",
    "golf tournaments": "بطولات غولف",
    "cycle racing": "سباق دراجات",
    "cycling competitions": "مسابقات الدراجات",
    "motorcycle racing": "سباق الدراجات النارية",
    "motorcycle racing series": "سلسلة سباقات الدراجات النارية",
    "horse races": "سباقات الخيل",
    "national championships": "بطولات وطنية",
    "rowing competitions": "منافسات تجديف",
    "arab athletics championships": "البطولة العربية لألعاب القوى",
    "badminton in the 2016 summer olympics": "كرة الريشة في الألعاب الأولمبية الصيفية 2016",
    "sports in the summer olympics": "رياضات في الألعاب الأولمبية الصيفية",
    "ice hockey tournaments": "منافسات هوكي للجليد",
    "ligue 1": "الدوري الفرنسي الدرجة الأولى",
    "world baseball classic": "عالم البيسبول الكلاسيكي",
    "international association football competitions": "منافسات كرة قدم دولية",
    "formula e": "فورمولا إي",
    "formula one": "فورمولا ون",
    "portuguese grand prix": "جائزة البرتغال الكبرى",
    "six nations championship": "بطولة الأمم الستة",
    "combination events": "مزيج أحداث",
    "auto racing": "سباق سيارات",
    "auto racing series": "سلسة سباق سيارات",
    "brd năstase țiriac trophy": "بطولة بوخارست للتنس",
    "brisbane international": "بطولة برزبين للتنس",
    "chennai open": "بطولة تشيناي المفتوحة للتنس",
    "australian open (tennis)": "بطولة أستراليا المفتوحة للتنس",
    "barcelona open (tennis)": "بطولة برشلونة للتنس",
    "canadian open (tennis)": "بطولة كندا للأساتذة",
    "chile open (tennis)": "بطولة تشيلي للتنس",
    "china open (tennis)": "بطولة الصين المفتوحة",
    "italian open (tennis)": "روما للماسترز",
    "madrid open (tennis)": "مدريد للماسترز",
    "mexican open (tennis)": "بطولة أكابولكو للتنس",
    "miami open (tennis)": "ميامي للماسترز",
    "qatar open (tennis)": "بطولة قطر المفتوحة للتنس",
    "shanghai masters (tennis)": "شنغهاي للماسترز",
    "australian open tennis": "بطولة أستراليا المفتوحة للتنس",
    "barcelona open tennis": "بطولة برشلونة للتنس",
    "canadian open tennis": "بطولة كندا للأساتذة",
    "chile open tennis": "بطولة تشيلي للتنس",
    "china open tennis": "بطولة الصين المفتوحة",
    "italian open tennis": "روما للماسترز",
    "madrid open tennis": "مدريد للماسترز",
    "mexican open tennis": "بطولة أكابولكو للتنس",
    "miami open tennis": "ميامي للماسترز",
    "qatar open tennis": "بطولة قطر المفتوحة للتنس",
    "shanghai masters tennis": "شنغهاي للماسترز",
    "cincinnati masters": "سنسيناتي للماسترز",
    "citi open": "بطولة واشنطن المفتوحة",
    "davis cup": "كأس ديفيز",
    "delray beach international tennis championships": "بطولة دلراي بيتش الدولية للتنس",
    "dubai tennis championships": "بطولة دبي للتنس",
    "fed cups": "كأس فيد",
    "fed cup": "كأس فيد",
    "french open": "دورة رولان غاروس الدولية",
    "geneva open": "بطولة جنيف المفتوحة",
    "gerry weber open": "بطولة هالي المفتوحة",
    "grand prix hassan ii": "بطولة الدار البيضاء للتنس",
    "hopman cup": "كأس هوبمان",
    "indian wells masters": "إنديان ويلز للماسترز",
    "istanbul open": "بطولة إسطنبول المفتوحة",
    "kremlin cup": "كأس الكرملين",
    "monte-carlo masters": "مونتي كارلو للماسترز",
    "nottingham open": "بطولة نوتنغهام المفتوحة",
    "open sud de france": "بطولة مونبلييه المفتوحة للتنس",
    "open de nice côte d'azur": "بطولة نيس المفتوحة للتنس",
    "paris masters": "باريس للماسترز",
    "portugal open": "البرتغال المفتوحة",
    "rai open": "راي المفتوحة",
    "rio open": "بطولة ريو للتنس",
    "rosmalen grass court championships": "بطولة روزمالين العشبية للتنس",
    "seoul open": "سول المفتوحة",
    "stockholm open": "بطولة ستوكهولم المفتوحة للتنس",
    "stuttgart open": "بطولة شتوتغارت المفتوحة",
    "swedish open": "بطولة السويد المفتوحة للتنس",
    "swiss indoors": "بطولة بازل للتنس",
    "sydney international": "بطولة سيدني للتنس",
    "tennis napoli cup": "كأس نابولي لكرة المضرب",
    "the championships, wimbledon": "بطولة ويمبلدون",
    "tunis open": "دورة تونس المفتوحة للتنس",
    "u.s. men's clay court championships": "بطولة هيوستن للتنس",
    "u.s. national indoor tennis championships": "بطولة ممفيس المفتوحة للتنس",
    "valencia open": "بطولة فالنسيا المفتوحة",
    "world tennis championship": "بطولة مبادلة العالمية للتنس",
    "zagreb indoors": "بطولة زغرب للتنس",
    "itf women's world tennis tour": "الجولة العالمية لتنس السيدات",
}

__all__ = ["TENNIS_KEYS"]

len_print.data_len(
    "tennis.py",
    {
        "TENNIS_KEYS": TENNIS_KEYS,
    },
)
