#
import pytest
from load_one_data import dump_diff, dump_diff_text, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data_empty_value = {
    "Category:Scheduled multi-sport events": "تصنيف:أحداث رياضية متعددة مقررة",
    "Category:Defunct multi-sport events": "تصنيف:أحداث رياضية متعددة سابقة",
    "Category:Disabled multi-sport events": "تصنيف:أحداث رياضية متعددة معاقون",
    "Category:Timor-Leste at multi-sport events": "تصنيف:أحداث رياضية متعددة في تيمور الشرقية",
    "Category:Wikipedia categories named after multi-sport events": "تصنيف:تصنيفات سميت بأسماء أحداث رياضية متعددة",
    "Category:Youth multi-sport events": "تصنيف:أحداث رياضية متعددة شبابية",
}

data_0 = {
    "Category:1896 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1896",
    "Category:1900 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1900",
    "Category:1904 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1904",
    "Category:1906 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1906",
    "Category:1908 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1908",
    "Category:1912 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1912",
    "Category:1916 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1916",
    "Category:1920 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1920",
    "Category:1924 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1924",
    "Category:1926 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1926",
    "Category:1928 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1928",
    "Category:1930 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1930",
    "Category:1932 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1932",
    "Category:1933 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1933",
    "Category:1934 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1934",
    "Category:1935 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1935",
    "Category:1936 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1936",
    "Category:1938 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1938",
    "Category:1940 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1940",
    "Category:1944 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1944",
    "Category:1946 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1946",
    "Category:1948 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1948",
    "Category:1950 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1950",
    "Category:1951 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1951",
    "Category:1952 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1952",
    "Category:1953 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1953",
    "Category:1954 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1954",
    "Category:1955 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1955",
    "Category:1956 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1956",
    "Category:1957 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1957",
    "Category:1958 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1958",
    "Category:1959 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1959",
    "Category:1960 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1960",
    "Category:1961 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1961",
    "Category:1962 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1962",
    "Category:1963 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1963",
    "Category:1964 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1964",
    "Category:1965 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1965",
    "Category:1966 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1966",
    "Category:1967 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1967",
    "Category:1968 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1968",
    "Category:1969 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1969",
    "Category:1970 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1970",
    "Category:1971 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1971",
    "Category:1972 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1972",
    "Category:1973 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1973",
    "Category:1974 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1974",
    "Category:1975 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1975",
    "Category:1976 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1976",
    "Category:1977 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1977",
    "Category:1978 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1978",
    "Category:1979 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1979",
    "Category:1980 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1980",
    "Category:1981 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1981",
    "Category:1982 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1982",
    "Category:1983 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1983",
    "Category:1984 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1984",
    "Category:1985 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1985",
    "Category:1986 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1986",
    "Category:1987 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1987",
    "Category:1988 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1988",
    "Category:1989 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1989",
    "Category:1990 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1990",
    "Category:1991 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1991",
    "Category:1992 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1992",
    "Category:1993 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1993",
    "Category:1994 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1994",
    "Category:1995 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1995",
    "Category:1996 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1996",
    "Category:1997 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1997",
    "Category:1998 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1998",
    "Category:1999 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 1999",
    "Category:2000 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2000",
    "Category:2001 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2001",
    "Category:2002 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2002",
    "Category:2003 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2003",
    "Category:2004 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2004",
    "Category:2005 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2005",
    "Category:2006 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2006",
    "Category:2007 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2007",
    "Category:2008 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2008",
    "Category:2009 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2009",
    "Category:2010 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2010",
    "Category:2011 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2011",
    "Category:2012 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2012",
    "Category:2013 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2013",
    "Category:2014 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2014",
    "Category:2015 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2015",
    "Category:2016 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2016",
    "Category:2017 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2017",
    "Category:2018 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2018",
    "Category:2019 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2019",
    "Category:2020 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2020",
    "Category:2021 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2021",
    "Category:2022 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2022",
    "Category:2024 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2024",
    "Category:2025 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2025",
    "Category:2026 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2026",
    "Category:2028 in multi-sport events": "تصنيف:الأحداث الرياضية المتعددة في 2028",
}


data_1 = {
    "Category:Albania at winter multi-sport events": "تصنيف:ألبانيا في أحداث رياضية متعددة شتوية",
    "Category:Algeria at winter multi-sport events": "تصنيف:الجزائر في أحداث رياضية متعددة شتوية",
    "Category:American Samoa at winter multi-sport events": "تصنيف:ساموا الأمريكية في أحداث رياضية متعددة شتوية",
    "Category:Argentina at winter multi-sport events": "تصنيف:الأرجنتين في أحداث رياضية متعددة شتوية",
    "Category:Australia at winter multi-sport events": "تصنيف:أستراليا في أحداث رياضية متعددة شتوية",
    "Category:Austria at winter multi-sport events": "تصنيف:النمسا في أحداث رياضية متعددة شتوية",
    "Category:Brazil at winter multi-sport events": "تصنيف:البرازيل في أحداث رياضية متعددة شتوية",
    "Category:Canada at winter multi-sport events": "تصنيف:كندا في أحداث رياضية متعددة شتوية",
    "Category:China at winter multi-sport events": "تصنيف:الصين في أحداث رياضية متعددة شتوية",
    "Category:Czech Republic at winter multi-sport events": "تصنيف:التشيك في أحداث رياضية متعددة شتوية",
    "Category:East Germany at winter multi-sport events": "تصنيف:ألمانيا الشرقية في أحداث رياضية متعددة شتوية",
    "Category:France at winter multi-sport events": "تصنيف:فرنسا في أحداث رياضية متعددة شتوية",
    "Category:Germany at winter multi-sport events": "تصنيف:ألمانيا في أحداث رياضية متعددة شتوية",
    "Category:Hong Kong at winter multi-sport events": "تصنيف:هونغ كونغ في أحداث رياضية متعددة شتوية",
    "Category:India at winter multi-sport events": "تصنيف:الهند في أحداث رياضية متعددة شتوية",
    "Category:Iran at winter multi-sport events": "تصنيف:إيران في أحداث رياضية متعددة شتوية",
    "Category:Israel at winter multi-sport events": "تصنيف:إسرائيل في أحداث رياضية متعددة شتوية",
    "Category:Italy at winter multi-sport events": "تصنيف:إيطاليا في أحداث رياضية متعددة شتوية",
    "Category:Japan at winter multi-sport events": "تصنيف:اليابان في أحداث رياضية متعددة شتوية",
    "Category:Kazakhstan at winter multi-sport events": "تصنيف:كازاخستان في أحداث رياضية متعددة شتوية",
    "Category:Kyrgyzstan at winter multi-sport events": "تصنيف:قيرغيزستان في أحداث رياضية متعددة شتوية",
    "Category:Lebanon at winter multi-sport events": "تصنيف:لبنان في أحداث رياضية متعددة شتوية",
    "Category:Lithuania at winter multi-sport events": "تصنيف:ليتوانيا في أحداث رياضية متعددة شتوية",
    "Category:Malaysia at winter multi-sport events": "تصنيف:ماليزيا في أحداث رياضية متعددة شتوية",
    "Category:Mongolia at winter multi-sport events": "تصنيف:منغوليا في أحداث رياضية متعددة شتوية",
    "Category:Multi-sport events": "تصنيف:أحداث رياضية متعددة",
    "Category:Multi-sport events-related lists": "تصنيف:قوائم متعلقة بأحداث رياضية متعددة",
    "Category:Multi-sport events bids": "تصنيف:ترشيحات أحداث رياضية متعددة",
    "Category:Multi-sport events by country": "تصنيف:أحداث رياضية متعددة حسب البلد",
    "Category:Multi-sport events by year": "تصنيف:أحداث رياضية متعددة حسب السنة",
    "Category:Multi-sport events cancelled due to the COVID-19 pandemic": "تصنيف:أحداث رياضية متعددة ألغيت بسبب جائحة فيروس كورونا",
    "Category:Multi-sport events in Africa by country": "تصنيف:أحداث رياضية متعددة في إفريقيا حسب البلد",
    "Category:Multi-sport events in Andorra": "تصنيف:أحداث رياضية متعددة في أندورا",
    "Category:Multi-sport events in Argentina": "تصنيف:أحداث رياضية متعددة في الأرجنتين",
    "Category:Multi-sport events in Asia": "تصنيف:أحداث رياضية متعددة في آسيا",
    "Category:Multi-sport events in Asia by country": "تصنيف:أحداث رياضية متعددة في آسيا حسب البلد",
    "Category:Multi-sport events in Australia": "تصنيف:أحداث رياضية متعددة في أستراليا",
    "Category:Multi-sport events in Austria": "تصنيف:أحداث رياضية متعددة في النمسا",
    "Category:Multi-sport events in Azerbaijan": "تصنيف:أحداث رياضية متعددة في أذربيجان",
    "Category:Multi-sport events in Bahrain": "تصنيف:أحداث رياضية متعددة في البحرين",
    "Category:Multi-sport events in Belgium": "تصنيف:أحداث رياضية متعددة في بلجيكا",
    "Category:Multi-sport events in Bolivia": "تصنيف:أحداث رياضية متعددة في بوليفيا",
    "Category:Multi-sport events in Brazil": "تصنيف:أحداث رياضية متعددة في البرازيل",
    "Category:Multi-sport events in Bulgaria": "تصنيف:أحداث رياضية متعددة في بلغاريا",
    "Category:Multi-sport events in Canada": "تصنيف:أحداث رياضية متعددة في كندا",
    "Category:Multi-sport events in Chile": "تصنيف:أحداث رياضية متعددة في تشيلي",
    "Category:Multi-sport events in China": "تصنيف:أحداث رياضية متعددة في الصين",
    "Category:Multi-sport events in Colombia": "تصنيف:أحداث رياضية متعددة في كولومبيا",
    "Category:Multi-sport events in Croatia": "تصنيف:أحداث رياضية متعددة في كرواتيا",
    "Category:Multi-sport events in Cuba": "تصنيف:أحداث رياضية متعددة في كوبا",
    "Category:Multi-sport events in Cyprus": "تصنيف:أحداث رياضية متعددة في قبرص",
    "Category:Multi-sport events in Czechoslovakia": "تصنيف:أحداث رياضية متعددة في تشيكوسلوفاكيا",
    "Category:Multi-sport events in Denmark": "تصنيف:أحداث رياضية متعددة في الدنمارك",
    "Category:Multi-sport events in East Germany": "تصنيف:أحداث رياضية متعددة في ألمانيا الشرقية",
    "Category:Multi-sport events in Ecuador": "تصنيف:أحداث رياضية متعددة في الإكوادور",
    "Category:Multi-sport events in El Salvador": "تصنيف:أحداث رياضية متعددة في السلفادور",
    "Category:Multi-sport events in Europe": "تصنيف:أحداث رياضية متعددة في أوروبا",
    "Category:Multi-sport events in Europe by country": "تصنيف:أحداث رياضية متعددة في أوروبا حسب البلد",
    "Category:Multi-sport events in Finland": "تصنيف:أحداث رياضية متعددة في فنلندا",
    "Category:Multi-sport events in France": "تصنيف:أحداث رياضية متعددة في فرنسا",
    "Category:Multi-sport events in Germany": "تصنيف:أحداث رياضية متعددة في ألمانيا",
    "Category:Multi-sport events in Greece": "تصنيف:أحداث رياضية متعددة في اليونان",
    "Category:Multi-sport events in Hungary": "تصنيف:أحداث رياضية متعددة في المجر",
    "Category:Multi-sport events in Iceland": "تصنيف:أحداث رياضية متعددة في آيسلندا",
    "Category:Multi-sport events in India": "تصنيف:أحداث رياضية متعددة في الهند",
    "Category:Multi-sport events in Indonesia": "تصنيف:أحداث رياضية متعددة في إندونيسيا",
    "Category:Multi-sport events in insular areas of the United States": "تصنيف:أحداث رياضية متعددة في المناطق المعزولة في الولايات المتحدة",
    "Category:Multi-sport events in Iran": "تصنيف:أحداث رياضية متعددة في إيران",
    "Category:Multi-sport events in Israel": "تصنيف:أحداث رياضية متعددة في إسرائيل",
    "Category:Multi-sport events in Italy": "تصنيف:أحداث رياضية متعددة في إيطاليا",
    "Category:Multi-sport events in Jamaica": "تصنيف:أحداث رياضية متعددة في جامايكا",
    "Category:Multi-sport events in Japan": "تصنيف:أحداث رياضية متعددة في اليابان",
    "Category:Multi-sport events in Jordan": "تصنيف:أحداث رياضية متعددة في الأردن",
    "Category:Multi-sport events in Kazakhstan": "تصنيف:أحداث رياضية متعددة في كازاخستان",
    "Category:Multi-sport events in Kenya": "تصنيف:أحداث رياضية متعددة في كينيا",
    "Category:Multi-sport events in Kuwait": "تصنيف:أحداث رياضية متعددة في الكويت",
    "Category:Multi-sport events in Lebanon": "تصنيف:أحداث رياضية متعددة في لبنان",
    "Category:Multi-sport events in Liechtenstein": "تصنيف:أحداث رياضية متعددة في ليختنشتاين",
    "Category:Multi-sport events in Luxembourg": "تصنيف:أحداث رياضية متعددة في لوكسمبورغ",
    "Category:Multi-sport events in Macau": "تصنيف:أحداث رياضية متعددة في ماكاو",
    "Category:Multi-sport events in Malaysia": "تصنيف:أحداث رياضية متعددة في ماليزيا",
    "Category:Multi-sport events in Malta": "تصنيف:أحداث رياضية متعددة في مالطا",
    "Category:Multi-sport events in Mexico": "تصنيف:أحداث رياضية متعددة في المكسيك",
    "Category:Multi-sport events in Monaco": "تصنيف:أحداث رياضية متعددة في موناكو",
    "Category:Multi-sport events in Mongolia": "تصنيف:أحداث رياضية متعددة في منغوليا",
    "Category:Multi-sport events in Montenegro": "تصنيف:أحداث رياضية متعددة في الجبل الأسود",
    "Category:Multi-sport events in Mozambique": "تصنيف:أحداث رياضية متعددة في موزمبيق",
    "Category:Multi-sport events in New Zealand": "تصنيف:أحداث رياضية متعددة في نيوزيلندا",
    "Category:Multi-sport events in Nigeria": "تصنيف:أحداث رياضية متعددة في نيجيريا",
    "Category:Multi-sport events in North America": "تصنيف:أحداث رياضية متعددة في أمريكا الشمالية",
    "Category:Multi-sport events in North Korea": "تصنيف:أحداث رياضية متعددة في كوريا الشمالية",
    "Category:Multi-sport events in Norway": "تصنيف:أحداث رياضية متعددة في النرويج",
    "Category:Multi-sport events in Oceania": "تصنيف:أحداث رياضية متعددة في أوقيانوسيا",
    "Category:Multi-sport events in Oman": "تصنيف:أحداث رياضية متعددة في سلطنة عمان",
    "Category:Multi-sport events in Panama": "تصنيف:أحداث رياضية متعددة في بنما",
    "Category:Multi-sport events in Peru": "تصنيف:أحداث رياضية متعددة في بيرو",
    "Category:Multi-sport events in Poland": "تصنيف:أحداث رياضية متعددة في بولندا",
    "Category:Multi-sport events in Puerto Rico": "تصنيف:أحداث رياضية متعددة في بورتوريكو",
    "Category:Multi-sport events in Qatar": "تصنيف:أحداث رياضية متعددة في قطر",
    "Category:Multi-sport events in Romania": "تصنيف:أحداث رياضية متعددة في رومانيا",
    "Category:Multi-sport events in Russia": "تصنيف:أحداث رياضية متعددة في روسيا",
    "Category:Multi-sport events in Samoa": "تصنيف:أحداث رياضية متعددة في ساموا",
    "Category:Multi-sport events in San Marino": "تصنيف:أحداث رياضية متعددة في سان مارينو",
    "Category:Multi-sport events in Serbia": "تصنيف:أحداث رياضية متعددة في صربيا",
    "Category:Multi-sport events in Singapore": "تصنيف:أحداث رياضية متعددة في سنغافورة",
    "Category:Multi-sport events in Slovakia": "تصنيف:أحداث رياضية متعددة في سلوفاكيا",
    "Category:Multi-sport events in South America": "تصنيف:أحداث رياضية متعددة في أمريكا الجنوبية",
    "Category:Multi-sport events in South Korea": "تصنيف:أحداث رياضية متعددة في كوريا الجنوبية",
    "Category:Multi-sport events in Spain": "تصنيف:أحداث رياضية متعددة في إسبانيا",
    "Category:Multi-sport events in Sweden": "تصنيف:أحداث رياضية متعددة في السويد",
    "Category:Multi-sport events in Switzerland": "تصنيف:أحداث رياضية متعددة في سويسرا",
    "Category:Multi-sport events in Syria": "تصنيف:أحداث رياضية متعددة في سوريا",
    "Category:Multi-sport events in Taiwan": "تصنيف:أحداث رياضية متعددة في تايوان",
    "Category:Multi-sport events in Thailand": "تصنيف:أحداث رياضية متعددة في تايلاند",
    "Category:Multi-sport events in the Netherlands": "تصنيف:أحداث رياضية متعددة في هولندا",
    "Category:Multi-sport events in the Republic of the Congo": "تصنيف:أحداث رياضية متعددة في جمهورية الكونغو",
    "Category:Multi-sport events in the Soviet Union": "تصنيف:أحداث رياضية متعددة في الاتحاد السوفيتي",
    "Category:Multi-sport events in the United Kingdom": "تصنيف:أحداث رياضية متعددة في المملكة المتحدة",
    "Category:Multi-sport events in the United States": "تصنيف:أحداث رياضية متعددة في الولايات المتحدة",
    "Category:Multi-sport events in Turkey": "تصنيف:أحداث رياضية متعددة في تركيا",
    "Category:Multi-sport events in Turkmenistan": "تصنيف:أحداث رياضية متعددة في تركمانستان",
    "Category:Multi-sport events in Venezuela": "تصنيف:أحداث رياضية متعددة في فنزويلا",
    "Category:Multi-sport events in Vietnam": "تصنيف:أحداث رياضية متعددة في فيتنام",
    "Category:Multi-sport events in West Germany": "تصنيف:أحداث رياضية متعددة في ألمانيا الغربية",
    "Category:Multi-sport events in Yugoslavia": "تصنيف:أحداث رياضية متعددة في يوغسلافيا",
    "Category:Multi-sport events in Zimbabwe": "تصنيف:أحداث رياضية متعددة في زيمبابوي",
    "Category:Multi-sport events templates": "تصنيف:قوالب أحداث رياضية متعددة",
    "Category:Multi-sport events venues": "تصنيف:ملاعب أحداث رياضية متعددة",
    "Category:National multi-sport events": "تصنيف:أحداث رياضية متعددة وطنية",
    "Category:Nations at winter multi-sport events": "تصنيف:بلدان في أحداث رياضية متعددة شتوية",
    "Category:Nepal at winter multi-sport events": "تصنيف:نيبال في أحداث رياضية متعددة شتوية",
    "Category:New Zealand at winter multi-sport events": "تصنيف:نيوزيلندا في أحداث رياضية متعددة شتوية",
    "Category:North Korea at winter multi-sport events": "تصنيف:كوريا الشمالية في أحداث رياضية متعددة شتوية",
    "Category:Pakistan at winter multi-sport events": "تصنيف:باكستان في أحداث رياضية متعددة شتوية",
    "Category:Philippines at winter multi-sport events": "تصنيف:الفلبين في أحداث رياضية متعددة شتوية",
    "Category:Singapore at winter multi-sport events": "تصنيف:سنغافورة في أحداث رياضية متعددة شتوية",
    "Category:South Korea at winter multi-sport events": "تصنيف:كوريا الجنوبية في أحداث رياضية متعددة شتوية",
    "Category:Spain at winter multi-sport events": "تصنيف:إسبانيا في أحداث رياضية متعددة شتوية",
    "Category:Summer multi-sport events": "تصنيف:أحداث رياضية متعددة صيفية",
    "Category:Tajikistan at winter multi-sport events": "تصنيف:طاجيكستان في أحداث رياضية متعددة شتوية",
    "Category:Thailand at winter multi-sport events": "تصنيف:تايلاند في أحداث رياضية متعددة شتوية",
    "Category:Turkey at winter multi-sport events": "تصنيف:تركيا في أحداث رياضية متعددة شتوية",
    "Category:Ukraine at winter multi-sport events": "تصنيف:أوكرانيا في أحداث رياضية متعددة شتوية",
    "Category:United States at winter multi-sport events": "تصنيف:الولايات المتحدة في أحداث رياضية متعددة شتوية",
    "Category:Uzbekistan at winter multi-sport events": "تصنيف:أوزبكستان في أحداث رياضية متعددة شتوية",
    "Category:West Germany at winter multi-sport events": "تصنيف:ألمانيا الغربية في أحداث رياضية متعددة شتوية",
    "Category:Winter multi-sport events by country": "تصنيف:أحداث رياضية متعددة شتوية حسب البلد",
    "Category:Winter multi-sport events in Germany": "تصنيف:أحداث رياضية متعددة شتوية في ألمانيا",
    "Category:Winter multi-sport events in Norway": "تصنيف:أحداث رياضية متعددة شتوية في النرويج",
    "Category:Winter multi-sport events in Russia": "تصنيف:أحداث رياضية متعددة شتوية في روسيا",
    "Category:Winter multi-sport events in the United States": "تصنيف:أحداث رياضية متعددة شتوية في الولايات المتحدة",
    "Category:Multi-sport clubs in Egypt": "تصنيف:أندية متعددة الرياضات في مصر",
    "Category:Multi-sport clubs in Finland": "تصنيف:أندية متعددة الرياضات في فنلندا",
    "Category:Multi-sport clubs in France": "تصنيف:أندية متعددة الرياضات في فرنسا",
    "Category:Multi-sport clubs in Germany": "تصنيف:أندية متعددة الرياضات في ألمانيا",
    "Category:Multi-sport clubs in Greece": "تصنيف:أندية متعددة الرياضات في اليونان",
    "Category:Multi-sport clubs in Iceland": "تصنيف:أندية متعددة الرياضات في آيسلندا",
    "Category:Multi-sport clubs in India": "تصنيف:أندية متعددة الرياضات في الهند",
    "Category:Soviet Union at multi-sport events": "تصنيف:الاتحاد السوفيتي في الأحداث الرياضية المتعددة",
    "Category:Swaziland at multi-sport events": "تصنيف:سوازيلاند في الأحداث الرياضية المتعددة",
    "Category:Wheelchair tennis at multi-sport events": "تصنيف:كرة المضرب على الكراسي المتحركة في الأحداث الرياضية المتعددة",
    "category:soviet union in multi-sport events": "تصنيف:الاتحاد السوفيتي في الأحداث الرياضية المتعددة",
    "Category:Afghanistan at multi-sport events": "تصنيف:أفغانستان في الأحداث الرياضية المتعددة",
    "Category:Algeria at multi-sport events": "تصنيف:الجزائر في الأحداث الرياضية المتعددة",
    "Category:Angola at multi-sport events": "تصنيف:أنغولا في الأحداث الرياضية المتعددة",
    "Category:Antigua and Barbuda at multi-sport events": "تصنيف:أنتيغوا وباربودا في الأحداث الرياضية المتعددة",
    "Category:Bahamas at multi-sport events": "تصنيف:باهاماس في الأحداث الرياضية المتعددة",
    "Category:Bahrain at multi-sport events": "تصنيف:البحرين في الأحداث الرياضية المتعددة",
    "Category:Barbados at multi-sport events": "تصنيف:بربادوس في الأحداث الرياضية المتعددة",
    "Category:Belarus at multi-sport events": "تصنيف:روسيا البيضاء في الأحداث الرياضية المتعددة",
    "Category:Belize at multi-sport events": "تصنيف:بليز في الأحداث الرياضية المتعددة",
    "Category:Benin at multi-sport events": "تصنيف:بنين في الأحداث الرياضية المتعددة",
    "Category:Bermuda at multi-sport events": "تصنيف:برمودا في الأحداث الرياضية المتعددة",
    "Category:Bhutan at multi-sport events": "تصنيف:بوتان في الأحداث الرياضية المتعددة",
    "Category:Burkina Faso at multi-sport events": "تصنيف:بوركينا فاسو في الأحداث الرياضية المتعددة",
    "Category:Burundi at multi-sport events": "تصنيف:بوروندي في الأحداث الرياضية المتعددة",
    "Category:Cambodia at multi-sport events": "تصنيف:كمبوديا في الأحداث الرياضية المتعددة",
    "Category:Cameroon at multi-sport events": "تصنيف:الكاميرون في الأحداث الرياضية المتعددة",
    "Category:Cape Verde at multi-sport events": "تصنيف:الرأس الأخضر في الأحداث الرياضية المتعددة",
    "Category:Central African Republic at multi-sport events": "تصنيف:جمهورية إفريقيا الوسطى في الأحداث الرياضية المتعددة",
    "Category:Chad at multi-sport events": "تصنيف:تشاد في الأحداث الرياضية المتعددة",
    "Category:Chess at multi-sport events": "تصنيف:الشطرنج في الأحداث الرياضية المتعددة",
    "Category:Comoros at multi-sport events": "تصنيف:جزر القمر في الأحداث الرياضية المتعددة",
    "Category:Competitors at multi-sport events": "تصنيف:منافسون في الأحداث الرياضية المتعددة",
    "Category:Competitors at multi-sport events by country": "تصنيف:منافسون في الأحداث الرياضية المتعددة حسب البلد",
    "Category:Competitors at multi-sport events by sport": "تصنيف:منافسون في الأحداث الرياضية المتعددة حسب الرياضة",
    "Category:Competitors at multi-sport events by year": "تصنيف:منافسون في الأحداث الرياضية المتعددة حسب السنة",
    "Category:Czech Republic at multi-sport events": "تصنيف:التشيك في الأحداث الرياضية المتعددة",
    "Category:Dependent territories of the United Kingdom at multi-sport events": "تصنيف:أقاليم ما وراء البحار البريطانية في الأحداث الرياضية المتعددة",
    "Category:Djibouti at multi-sport events": "تصنيف:جيبوتي في الأحداث الرياضية المتعددة",
    "Category:Dominica at multi-sport events": "تصنيف:دومينيكا في الأحداث الرياضية المتعددة",
    "Category:Dominican Republic at multi-sport events": "تصنيف:جمهورية الدومينيكان في الأحداث الرياضية المتعددة",
    "Category:Egypt at multi-sport events": "تصنيف:مصر في الأحداث الرياضية المتعددة",
    "Category:Equatorial Guinea at multi-sport events": "تصنيف:غينيا الاستوائية في الأحداث الرياضية المتعددة",
    "Category:Equestrian sports at multi-sport events": "تصنيف:رياضات فروسية في الأحداث الرياضية المتعددة",
    "Category:Eritrea at multi-sport events": "تصنيف:إرتريا في الأحداث الرياضية المتعددة",
    "Category:Eswatini at multi-sport events": "تصنيف:إسواتيني في الأحداث الرياضية المتعددة",
    "Category:Ethiopia at multi-sport events": "تصنيف:إثيوبيا في الأحداث الرياضية المتعددة",
    "Category:Fiji at multi-sport events": "تصنيف:فيجي في الأحداث الرياضية المتعددة",
    "Category:Gabon at multi-sport events": "تصنيف:الغابون في الأحداث الرياضية المتعددة",
    "Category:Ghana at multi-sport events": "تصنيف:غانا في الأحداث الرياضية المتعددة",
    "Category:Gibraltar at multi-sport events": "تصنيف:جبل طارق في الأحداث الرياضية المتعددة",
    "Category:Go at multi-sport events": "تصنيف:غو في الأحداث الرياضية المتعددة",
    "Category:Grenada at multi-sport events": "تصنيف:غرينادا في الأحداث الرياضية المتعددة",
    "Category:Guinea-Bissau at multi-sport events": "تصنيف:غينيا بيساو في الأحداث الرياضية المتعددة",
    "Category:Guinea at multi-sport events": "تصنيف:غينيا في الأحداث الرياضية المتعددة",
    "Category:Guyana at multi-sport events": "تصنيف:غيانا في الأحداث الرياضية المتعددة",
    "Category:Haiti at multi-sport events": "تصنيف:هايتي في الأحداث الرياضية المتعددة",
    "Category:Insular areas of the United States at multi-sport events": "تصنيف:المناطق المعزولة في الولايات المتحدة في الأحداث الرياضية المتعددة",
    "Category:Iraq at multi-sport events": "تصنيف:العراق في الأحداث الرياضية المتعددة",
    "Category:Ivory Coast at multi-sport events": "تصنيف:ساحل العاج في الأحداث الرياضية المتعددة",
    "Category:Ju-jitsu at multi-sport events": "تصنيف:جوجوتسو في الأحداث الرياضية المتعددة",
    "Category:Judo at multi-sport events": "تصنيف:الجودو في الأحداث الرياضية المتعددة",
    "Category:Kiribati at multi-sport events": "تصنيف:كيريباتي في الأحداث الرياضية المتعددة",
    "Category:Kosovo at multi-sport events": "تصنيف:كوسوفو في الأحداث الرياضية المتعددة",
    "Category:Lesotho at multi-sport events": "تصنيف:ليسوتو في الأحداث الرياضية المتعددة",
    "Category:Liberia at multi-sport events": "تصنيف:ليبيريا في الأحداث الرياضية المتعددة",
    "Category:Libya at multi-sport events": "تصنيف:ليبيا في الأحداث الرياضية المتعددة",
    "Category:Malawi at multi-sport events": "تصنيف:ملاوي في الأحداث الرياضية المتعددة",
    "Category:Maldives at multi-sport events": "تصنيف:جزر المالديف في الأحداث الرياضية المتعددة",
    "Category:Mali at multi-sport events": "تصنيف:مالي في الأحداث الرياضية المتعددة",
    "Category:Marshall Islands at multi-sport events": "تصنيف:جزر مارشال في الأحداث الرياضية المتعددة",
    "Category:Mauritania at multi-sport events": "تصنيف:موريتانيا في الأحداث الرياضية المتعددة",
    "Category:Mauritius at multi-sport events": "تصنيف:موريشيوس في الأحداث الرياضية المتعددة",
    "Category:Medalists at multi-sport events by year": "تصنيف:فائزون بميداليات في الأحداث الرياضية المتعددة حسب السنة",
    "Category:Modern pentathlon at multi-sport events": "تصنيف:الخماسي الحديث في الأحداث الرياضية المتعددة",
    "Category:Moldova at multi-sport events": "تصنيف:مولدوفا في الأحداث الرياضية المتعددة",
    "Category:Morocco at multi-sport events": "تصنيف:المغرب في الأحداث الرياضية المتعددة",
    "Category:Multi-sport events by continent": "تصنيف:أحداث رياضية متعددة حسب القارة",
    "Category:Multi-sport events in Africa": "تصنيف:أحداث رياضية متعددة في إفريقيا",
    "Category:Multi-sport events in Algeria": "تصنيف:أحداث رياضية متعددة في الجزائر",
    "Category:Multi-sport events in Egypt": "تصنيف:أحداث رياضية متعددة في مصر",
    "Category:Multi-sport events in Morocco": "تصنيف:أحداث رياضية متعددة في المغرب",
    "Category:Multi-sport events in Saudi Arabia": "تصنيف:أحداث رياضية متعددة في السعودية",
    "Category:Multi-sport events in Tunisia": "تصنيف:أحداث رياضية متعددة في تونس",
    "Category:Multi-sport events navigational boxes": "تصنيف:صناديق تصفح أحداث رياضية متعددة",
    "Category:Namibia at multi-sport events": "تصنيف:ناميبيا في الأحداث الرياضية المتعددة",
    "Category:Nations at multi-sport events": "تصنيف:بلدان في الأحداث الرياضية المتعددة",
    "Category:Nations at multi-sport events by country": "تصنيف:بلدان في الأحداث الرياضية المتعددة حسب البلد",
    "Category:Netherlands Antilles at multi-sport events": "تصنيف:جزر الأنتيل الهولندية في الأحداث الرياضية المتعددة",
    "Category:North Macedonia at multi-sport events": "تصنيف:مقدونيا الشمالية في الأحداث الرياضية المتعددة",
    "Category:Palestine at multi-sport events": "تصنيف:فلسطين في الأحداث الرياضية المتعددة",
    "Category:Papua New Guinea at multi-sport events": "تصنيف:بابوا غينيا الجديدة في الأحداث الرياضية المتعددة",
    "Category:Paraguay at multi-sport events": "تصنيف:باراغواي في الأحداث الرياضية المتعددة",
    "Category:Philippines at multi-sport events": "تصنيف:الفلبين في الأحداث الرياضية المتعددة",
    "Category:Rwanda at multi-sport events": "تصنيف:رواندا في الأحداث الرياضية المتعددة",
    "Category:Saint Kitts and Nevis at multi-sport events": "تصنيف:سانت كيتس ونيفيس في الأحداث الرياضية المتعددة",
    "Category:Saint Lucia at multi-sport events": "تصنيف:سانت لوسيا في الأحداث الرياضية المتعددة",
    "Category:Saint Vincent and the Grenadines at multi-sport events": "تصنيف:سانت فنسنت وجزر غرينادين في الأحداث الرياضية المتعددة",
    "Category:Senegal at multi-sport events": "تصنيف:السنغال في الأحداث الرياضية المتعددة",
    "Category:Seychelles at multi-sport events": "تصنيف:سيشل في الأحداث الرياضية المتعددة",
    "Category:Skeleton at multi-sport events": "تصنيف:الزلاجات الصدرية في الأحداث الرياضية المتعددة",
    "Category:Slovenia at multi-sport events": "تصنيف:سلوفينيا في الأحداث الرياضية المتعددة",
    "Category:Snooker at multi-sport events": "تصنيف:السنوكر في الأحداث الرياضية المتعددة",
    "Category:Solomon Islands at multi-sport events": "تصنيف:جزر سليمان في الأحداث الرياضية المتعددة",
    "Category:Somalia at multi-sport events": "تصنيف:الصومال في الأحداث الرياضية المتعددة",
    "Category:South Sudan at multi-sport events": "تصنيف:جنوب السودان في الأحداث الرياضية المتعددة",
    "Category:Sport climbing at multi-sport events": "تصنيف:التسلق في الأحداث الرياضية المتعددة",
    "Category:Sudan at multi-sport events": "تصنيف:السودان في الأحداث الرياضية المتعددة",
    "Category:Surfing at multi-sport events": "تصنيف:الركمجة في الأحداث الرياضية المتعددة",
    "Category:Suriname at multi-sport events": "تصنيف:سورينام في الأحداث الرياضية المتعددة",
    "Category:São Tomé and Príncipe at multi-sport events": "تصنيف:ساو تومي وبرينسيب في الأحداث الرياضية المتعددة",
    "Category:Tanzania at multi-sport events": "تصنيف:تنزانيا في الأحداث الرياضية المتعددة",
    "Category:Tennis at multi-sport events": "تصنيف:كرة المضرب في الأحداث الرياضية المتعددة",
    "Category:The Gambia at multi-sport events": "تصنيف:غامبيا في الأحداث الرياضية المتعددة",
    "Category:Togo at multi-sport events": "تصنيف:توغو في الأحداث الرياضية المتعددة",
    "Category:Tonga at multi-sport events": "تصنيف:تونغا في الأحداث الرياضية المتعددة",
    "Category:Trinidad and Tobago at multi-sport events": "تصنيف:ترينيداد وتوباغو في الأحداث الرياضية المتعددة",
    "Category:Tunisia at multi-sport events": "تصنيف:تونس في الأحداث الرياضية المتعددة",
    "Category:Tuvalu at multi-sport events": "تصنيف:توفالو في الأحداث الرياضية المتعددة",
    "Category:Uganda at multi-sport events": "تصنيف:أوغندا في الأحداث الرياضية المتعددة",
    "Category:Ukraine at multi-sport events": "تصنيف:أوكرانيا في الأحداث الرياضية المتعددة",
    "Category:United Arab Emirates at multi-sport events": "تصنيف:الإمارات العربية المتحدة في الأحداث الرياضية المتعددة",
    "Category:Vanuatu at multi-sport events": "تصنيف:فانواتو في الأحداث الرياضية المتعددة",
    "Category:Wheelchair basketball at multi-sport events": "تصنيف:كرة السلة على الكراسي المتحركة في الأحداث الرياضية المتعددة",
    "Category:Winter multi-sport events": "تصنيف:أحداث رياضية متعددة شتوية",
    "Category:Winter multi-sport events in Austria": "تصنيف:أحداث رياضية متعددة شتوية في النمسا",
    "Category:Winter multi-sport events in Canada": "تصنيف:أحداث رياضية متعددة شتوية في كندا",
    "Category:Xiangqi at multi-sport events": "تصنيف:الشطرنج الصيني في الأحداث الرياضية المتعددة",
}

to_test = [
    ("test_multi_sport_0", data_0),
    ("test_multi_sport_1", data_1),
]


@pytest.mark.parametrize("category, expected", data_1.items(), ids=data_1.keys())
def test_multi_sport_0(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    # dump_same_and_not_same(data, diff_result, name)

    dump_diff(diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
