#
import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_arabic_category_label

empty_data = {
    "Category:Abandoned military aircraft projects of Russia": "",
    "Category:Abandoned military projects of Russia": "",
    "Category:Academicians of the National Academy of Motion Picture Arts and Sciences of Russia": "",
    "Category:Academic staff of the D. Mendeleev University of Chemical Technology of Russia": "",
    "Category:Academic staff of the Peoples' Friendship University of Russia": "",
    "Category:Academies of Russia": "",
    "Category:Acting heads of the federal subjects of Russia": "",
    "Category:Administrative divisions of Russia": "",
    "Category:Administrative divisions of the federal subjects of Russia": "",
    "Category:Advisers to the president of Russia": "",
    "Category:Aerial bombs of Russia": "",
    "Category:Aerospace companieszz of Russia": "",
    "Category:Agricultural machinery manufacturers of Russia": "",
    "Category:Aides to the president of Russia": "",
    "Category:Airborne divisions of Russia": "",
    "Category:Airborne infantry brigades of Russia": "",
    "Category:Airborne units and formations of Russia": "",
    "Category:Aircraft engine manufacturers of Russia": "",
    "Category:Aircraft industry of Russia": "",
    "Category:Aircraft manufacturers of Russia": "",
    "Category:Air guns of Russia": "",
    "Category:Airport operators of Russia": "",
    "Category:Airships of Russia": "",
    "Category:Air-to-air missile manufacturers of Russia": "",
    "Category:Air-to-air missiles of Russia": "",
    "Category:Air-to-surface missiles of Russia": "",
    "Category:Alexis of Russia": "",
    "Category:Amendments to the Constitution of Russia": "",
    "Category:Ancient peoples of Russia": "",
    "Category:Anna of Russia": "",
    "Category:Anti-aircraft weapons of Russia": "",
    "Category:Anti-ballistic missiles of Russia": "",
    "Category:Anti-ship cruise missiles of Russia": "",
    "Category:Anti-ship missiles of Russia": "",
    "Category:Anti-submarine missiles of Russia": "",
    "Category:Anti-tank guided missiles of Russia": "",
    "Category:Armoured fighting vehicles of Russia": "",
    "Category:Armoured personnel carriers of Russia": "",
    "Category:Armoured units and formations of Russia": "",
    "Category:Arms industry of Russia": "",
    "Category:Arms trading companieszz of Russia": "",
    "Category:Army training units and formations of Russia": "",
    "Category:Army units and formations of Russia": "",
    "Category:Artillery units and formations of Russia": "",
    "Category:Assault rifles of Russia": "",
    "Category:Audio equipment manufacturers of Russia": "",
    "Category:Autonomous okrugs of Russia": "",
    "Category:Auto parts suppliers of Russia": "",
    "Category:Aviation history of Russia": "",
    "Category:Ballistic missiles of Russia": "",
    "Category:Barges of Russia": "",
    "Category:Battalions of Russia": "",
    "Category:Bilateral sports relations of Russia": "",
    "Category:Bilateral treaties of Russia": "",
    "Category:Biosphere reserves of Russia": "",
    "Category:Bishops of the Russian Orthodox Church Outside of Russia": "",
    "Category:Bolt-action rifles of Russia": "",
    "Category:Book publishing companieszz of Russia": "",
    "Category:Books by publishing company of Russia": "",
    "Category:Bookstores of Russia": "",
    "Category:Boycotts of Russia": "",
    "Category:Brigades of Russia": "",
    "Category:Bullion coins of Russia": "",
    "Category:Buses of Russia": "",
    "Category:Cable television companieszz of Russia": "",
    "Category:Calderas of Russia": "",
    "Category:Capitals of republics of Russia": "",
    "Category:Car manufacturers of Russia": "",
    "Category:Categories by federal subject of Russia": "",
    "Category:Central Bank of Russia": "",
    "Category:Ceramics manufacturers of Russia": "",
    "Category:Chief Muftis of Russia": "",
    "Category:Chief rabbis of Russia": "",
    "Category:Circassian people of Russia": "",
    "Category:City districts of Russia": "",
    "Category:Client states of Russia": "",
    "Category:Climbing areas of Russia": "",
    "Category:Clothing brands of Russia": "",
    "Category:Coins of Russia": "",
    "Category:Combat helmets of Russia": "",
    "Category:Comic book publishing companieszz of Russia": "",
    "Category:Communications satellites of Russia": "",
    "Category:Concert tours of Russia": "",
    "Category:Constitutional history of Russia": "",
    "Category:Constitutions and charters of federal subjects of Russia": "",
    "Category:Construction equipment manufacturers of Russia": "",
    "Category:Continental shelves of Russia": "",
    "Category:Copper mining companieszz of Russia": "",
    "Category:Corps of Russia": "",
    "Category:Country data templates of former subdivisions of Russia": "",
    "Category:Country data templates of Russia": "",
    "Category:Country data templates of subdivisions of Russia": "",
    "Category:Court of Elizabeth of Russia": "",
    "Category:Crewed space program of Russia": "",
    "Category:Cruise missiles of Russia": "",
    "Category:Cultural heritage of Russia": "",
    "Category:Defunct aircraft manufacturers of Russia": "",
    "Category:Defunct diplomatic missions of Russia": "",
    "Category:Defunct federal ministries of Russia": "",
    "Category:Defunct government agencies of Russia": "",
    "Category:Defunct law enforcement agencies of Russia": "",
    "Category:Defunct motorcycle manufacturers of Russia": "",
    "Category:Department stores of Russia": "",
    "Category:Deputy defence ministers of Russia": "",
    "Category:Deputy foreign ministers of Russia": "",
    "Category:Deputy ministers of Russia": "",
    "Category:Diatremes of Russia": "",
    "Category:Diesel–electric locomotives of Russia": "",
    "Category:Diesel locomotives of Russia": "",
    "Category:Diesel multiple units of Russia": "",
    "Category:Divisions of Russia": "",
    "Category:D. Mendeleev University of Chemical Technology of Russia": "",
    "Category:Double-barreled shotguns of Russia": "",
    "Category:Earth observation satellites of Russia": "",
    "Category:Economic regions of Russia": "",
    "Category:Electric locomotives of Russia": "",
    "Category:Electric multiple units of Russia": "",
    "Category:Electric vehicle manufacturers of Russia": "",
    "Category:Emperors of Russia": "",
    "Category:Empresses consort of Russia": "",
    "Category:Empresses of Russia": "",
    "Category:Empresses regnant of Russia": "",
    "Category:Endemic birds of Russia": "",
    "Category:Endemic fauna of Russia": "",
    "Category:Endemic flora of Russia": "",
    "Category:Energy policy of Russia": "",
    "Category:Engine manufacturers of Russia": "",
    "Category:Estuaries of Russia": "",
    "Category:Eurovision songs of Russia": "",
    "Category:Event management companieszz of Russia": "",
    "Category:Extinct animals of Russia": "",
    "Category:Extreme points of Russia": "",
    "Category:Federal cities of Russia": "",
    "Category:Federal districts of Russia": "",
    "Category:Federal executive bodies of Russia": "",
    "Category:Federal law enforcement agencies of Russia": "",
    "Category:Federal ministries of Russia": "",
    "Category:Federal State Unitary Enterprises of Russia": "",
    "Category:Ferns of Russia": "",
    "Category:Ferry companieszz of Russia": "",
    "Category:Fertilizer companieszz of Russia": "",
    "Category:Field marshals of Russia": "",
    "Category:Film production companieszz of Russia": "",
    "Category:Financial regulatory authorities of Russia": "",
    "Category:Firearm manufacturers of Russia": "",
    "Category:Firearms of Russia": "",
    "Category:Fjords of Russia": "",
    "Category:Food provision ministers of Russia": "",
    "Category:Food retailers of Russia": "",
    "Category:Foreign trade of Russia": "",
    "Category:Former administrative units of Russia": "",
    "Category:Former federal subjects of Russia": "",
    "Category:Former islands of Russia": "",
    "Category:Former subdivisions of Russia": "",
    "Category:Fossils of Russia": "",
    "Category:Geologic formations of Russia": "",
    "Category:Geologic history of Russia": "",
    "Category:Geysers of Russia": "",
    "Category:Glacial lakes of Russia": "",
    "Category:Gold mining companieszz of Russia": "",
    "Category:Government-owned banks of Russia": "",
    "Category:Government spokespersons of Russia": "",
    "Category:Governors of the Central Bank of Russia": "",
    "Category:Grand duchesses of Russia": "",
    "Category:Grand dukes of Russia": "",
    "Category:Grasses of Russia": "",
    "Category:Grenade launchers of Russia": "",
    "Category:Guided missiles of Russia": "",
    "Category:Heads of former federal subjects of Russia": "",
    "Category:Heavy machine guns of Russia": "",
    "Category:Helicopter manufacturers of Russia": "",
    "Category:Helicopter regiments of Russia": "",
    "Category:High-speed trains of Russia": "",
    "Category:Historical ethnic groups of Russia": "",
    "Category:Historical geography of Russia": "",
    "Category:History of the administrative divisions of Russia": "",
    "Category:Home appliance manufacturers of Russia": "",
    "Category:Honorary titles of Russia": "",
    "Category:Howitzers of Russia": "",
    "Category:Hydroelectric power companieszz of Russia": "",
    "Category:Icebreakers of Russia": "",
    "Category:Ice caps of Russia": "",
    "Category:Identified objects of cultural heritage of Russia": "",
    "Category:Impact craters of Russia": "",
    "Category:Important Bird Areas of Russia": "",
    "Category:Independent Psychiatric Association of Russia": "",
    "Category:Indigenous languages of Russia": "",
    "Category:Infantry brigades of Russia": "",
    "Category:Infantry divisions of Russia": "",
    "Category:Infantry fighting vehicles of Russia": "",
    "Category:Infantry units and formations of Russia": "",
    "Category:Information technology consulting firms of Russia": "",
    "Category:Intercontinental ballistic missiles of Russia": "",
    "Category:Intermediate-range ballistic missiles of Russia": "",
    "Category:Internet technology companieszz of Russia": "",
    "Category:Investment management companieszz of Russia": "",
    "Category:Isthmuses of Russia": "",
    "Category:Judges of the Constitutional Court of Russia": "",
    "Category:Krais of Russia": "",
    "Category:Krivak-class frigates of the Border Guard Service of Russia": "",
    "Category:Lagoons of Russia": "",
    "Category:Lake groups of Russia": "",
    "Category:Lake islands of Russia": "",
    "Category:Land cultivation ministers of Russia": "",
    "Category:Law enforcement agencies of the republics of Russia": "",
    "Category:Liberal Democratic Party of Russia": "",
    "Category:Light tanks of Russia": "",
    "Category:Liquefied natural gas plants of Russia": "",
    "Category:Lists of commemorative coins of Russia": "",
    "Category:Lists of moths of Russia": "",
    "Category:Lithostratigraphy of Russia": "",
    "Category:Locomotives of Russia": "",
    "Category:Lost submarines of Russia": "",
    "Category:Machine guns of Russia": "",
    "Category:Main battle tanks of Russia": "",
    "Category:Maps of Russia": "",
    "Category:Mechanical engineering companieszz of Russia": "",
    "Category:Mechanised infantry brigades of Russia": "",
    "Category:Medical technology companieszz of Russia": "",
    "Category:Medieval history of Russia": "",
    "Category:Members of the Supreme Soviet of Russia": "",
    "Category:Merchant ships of Russia": "",
    "Category:Metallurgical industry of Russia": "",
    "Category:Metropolitan areas of Russia": "",
    "Category:Military aircraft procurement programs of Russia": "",
    "Category:Military awards and decorations of Russia": "",
    "Category:Military electronics of Russia": "",
    "Category:Military locations of Russia": "",
    "Category:Military satellites of Russia": "",
    "Category:Military vehicles of Russia": "",
    "Category:Model manufacturers of Russia": "",
    "Category:Modern anti-tank rockets of Russia": "",
    "Category:Modern incendiary weapons of Russia": "",
    "Category:Modern military equipment of Russia": "",
    "Category:Modern thermobaric weapons of Russia": "",
    "Category:Monasteries of the Russian Orthodox Church Outside of Russia": "",
    "Category:Monitors of Russia": "",
    "Category:Motorcycle manufacturers of Russia": "",
    "Category:Motorcycles of Russia": "",
    "Category:Multilateral relations of Russia": "",
    "Category:Multiple units of Russia": "",
    "Category:Municipal districts of Russia": "",
    "Category:Municipal divisions of the federal subjects of Russia": "",
    "Category:Museums-Reserves of Russia": "",
    "Category:Musical instrument manufacturing companieszz of Russia": "",
    "Category:Named passenger trains of Russia": "",
    "Category:Nanotechnology companieszz of Russia": "",
    "Category:National orchestras of Russia": "",
    "Category:Natural monuments of Russia": "",
    "Category:Natural Resources and environment ministers of Russia": "",
    "Category:Naval guns of Russia": "",
    "Category:Naval infantry brigades of Russia": "",
    "Category:Naval weapons of Russia": "",
    "Category:Navigation satellites of Russia": "",
    "Category:Nicholas I of Russia": "",
    "Category:Night trains of Russia": "",
    "Category:Noble titles of Russia": "",
    "Category:Non-lethal firearms of Russia": "",
    "Category:Nuclear cruise missiles of Russia": "",
    "Category:Nuclear power companieszz of Russia": "",
    "Category:Nuclear technology companieszz of Russia": "",
    "Category:Nuclear weapons program of Russia": "",
    "Category:Oblasts of Russia": "",
    "Category:Online companieszz of Russia": "",
    "Category:Online dating services of Russia": "",
    "Category:Online financial services companieszz of Russia": "",
    "Category:Online gambling companieszz of Russia": "",
    "Category:Online marketplaces of Russia": "",
    "Category:Online music stores of Russia": "",
    "Category:Online retailers of Russia": "",
    "Category:Optics manufacturing companieszz of Russia": "",
    "Category:Orchids of Russia": "",
    "Category:Orders of chivalry of Russia": "",
    "Category:Pacific Coast of Russia": "",
    "Category:Parties affiliated with the Liberal Democratic Party of Russia": "",
    "Category:People's Artists of Russia": "",
    "Category:Peoples' Friendship University of Russia": "",
    "Category:Philately of Russia": "",
    "Category:Photography companieszz of Russia": "",
    "Category:Photography equipment manufacturers of Russia": "",
    "Category:Pistols of Russia": "",
    "Category:Political divisions of Russia": "",
    "Category:Political families of Russia": "",
    "Category:Postage stamps of Russia": "",
    "Category:Postal history of Russia": "",
    "Category:Postal system of Russia": "",
    "Category:Post–Cold War weapons of Russia": "",
    "Category:Presidential Administration of Russia": "",
    "Category:Presidents of the Constitutional Court of Russia": "",
    "Category:Presidents of the Handball Union of Russia": "",
    "Category:Priests of the Russian Orthodox Church Outside of Russia": "",
    "Category:Private equity firms of Russia": "",
    "Category:Proposed aircraft of Russia": "",
    "Category:Proposed military aircraft of Russia": "",
    "Category:Prosecutors-general of Russia": "",
    "Category:Railcars of Russia": "",
    "Category:Rail transport navigational boxes of Russia": "",
    "Category:Rail vehicle manufacturers of Russia": "",
    "Category:Railway coaches of Russia": "",
    "Category:Reconnaissance satellites of Russia": "",
    "Category:Regalia of Russia": "",
    "Category:Regents of Russia": "",
    "Category:Republics of Russia": "",
    "Category:Research vessels of Russia": "",
    "Category:Revolvers of Russia": "",
    "Category:Rifles of Russia": "",
    "Category:River islands of Russia": "",
    "Category:Road-inaccessible communities of Russia": "",
    "Category:Robots of Russia": "",
    "Category:Rocket divisions of Russia": "",
    "Category:Rocket engine manufacturers of Russia": "",
    "Category:Rocket-propelled grenade launchers of Russia": "",
    "Category:Rural settlements of Russia": "",
    "Category:Russian Orthodox Church Outside of Russia": "",
    "Category:Russo-Japanese War battleships of Russia": "",
    "Category:Russo-Japanese War cruisers of Russia": "",
    "Category:Russo-Japanese War naval ships of Russia": "",
    "Category:Russo-Japanese war weapons of Russia": "",
    "Category:Sacred lakes of Russia": "",
    "Category:Sberbank of Russia": "",
    "Category:Sedimentary basins of Russia": "",
    "Category:Self-propelled anti-aircraft weapons of Russia": "",
    "Category:Self-propelled artillery of Russia": "",
    "Category:Semi-automatic pistols of Russia": "",
    "Category:Semi-automatic rifles of Russia": "",
    "Category:Semi-automatic shotguns of Russia": "",
    "Category:Semiconductor companieszz of Russia": "",
    "Category:Shield volcanoes of Russia": "",
    "Category:Ships of the Border Guard Service of Russia": "",
    "Category:Ships of the line of Russia": "",
    "Category:Shotguns of Russia": "",
    "Category:Single-shot shotguns of Russia": "",
    "Category:Sniper rifles of Russia": "",
    "Category:Sounding rockets of Russia": "",
    "Category:Space industry companieszz of Russia": "",
    "Category:Space launch vehicles of Russia": "",
    "Category:Space program of Russia": "",
    "Category:Special Economic Zones of Russia": "",
    "Category:Special envoys of the president of Russia": "",
    "Category:Special forces of Russia": "",
    "Category:Specialist law enforcement agencies of Russia": "",
    "Category:Specialist police agencies of Russia": "",
    "Category:Spetsnaz brigades of Russia": "",
    "Category:Spits of Russia": "",
    "Category:Sports titles of Russia": "",
    "Category:Standards of Russia": "",
    "Category:State controllers of Russia": "",
    "Category:Steam locomotives of Russia": "",
    "Category:Steamships of Russia": "",
    "Category:Steel companieszz of Russia": "",
    "Category:Submachine guns of Russia": "",
    "Category:Submarine-launched ballistic missiles of Russia": "",
    "Category:Submarine-launched cruise missiles of Russia": "",
    "Category:Supreme Soviet of Russia": "",
    "Category:Surface-to-air missiles of Russia": "",
    "Category:Surface-to-surface missiles of Russia": "",
    "Category:Tank brigades of Russia": "",
    "Category:Tank divisions of Russia": "",
    "Category:Tankers of Russia": "",
    "Category:Tank regiments of Russia": "",
    "Category:Tatar people of Russia": "",
    "Category:Telecommunications companieszz of Russia": "",
    "Category:Television production companieszz of Russia": "",
    "Category:Templates by federal subject of Russia": "",
    "Category:Territorial disputes of Russia": "",
    "Category:Textile arts of Russia": "",
    "Category:Theatre rocket brigades of Russia": "",
    "Category:Third-level administrative divisions of Russia": "",
    "Category:Toy companieszz of Russia": "",
    "Category:Tractor manufacturers of Russia": "",
    "Category:Trading companieszz of Russia": "",
    "Category:Tram vehicles of Russia": "",
    "Category:Trees of Russia": "",
    "Category:Trial and research firearms of Russia": "",
    "Category:Tsareviches of Russia": "",
    "Category:Tsarevnas of Russia": "",
    "Category:Tsarinas of Russia": "",
    "Category:Tsars of Russia": "",
    "Category:Tsesarevichs of Russia": "",
    "Category:Unitary Enterprises of Russia": "",
    "Category:Units and formations of the National Guard of Russia": "",
    "Category:Uranium mining companieszz of Russia": "",
    "Category:Urban okrugs of Russia": "",
    "Category:Urban settlements of Russia": "",
    "Category:Vasili IV of Russia": "",
    "Category:Venture capital firms of Russia": "",
    "Category:Volcanism of Russia": "",
    "Category:Watch manufacturing companieszz of Russia": "",
    "Category:Weapons of Russia": "",
    "Category:Weather satellites of Russia": "",
    "Category:Wikipedia categories named after companieszz of Russia": "",
    "Category:Wikipedia categories named after manufacturing companieszz of Russia": "",
    "Category:Wikipedia categories named after presidents of Russia": "",
    "Category:Wikipedia featured topics Battlecruisers of Russia": "",
    "Category:Wikipedia requested images of people of Russia": "",
    "Category:Wikipedias by languages of Russia": "",
    "Category:Wine regions of Russia": "",
    "Category:Wineries of Russia": "",
    "Category:Women heads of federal subjects of Russia": "",
    "Category:Wooden architecture of Russia": "",
    "Category:World War I armoured fighting vehicles of Russia": "",
    "Category:World War I artillery of Russia": "",
    "Category:World War I battlecruisers of Russia": "",
    "Category:World War I battleships of Russia": "",
    "Category:World War I cruisers of Russia": "",
    "Category:World War I destroyers of Russia": "",
    "Category:World War I merchant ships of Russia": "",
    "Category:World War I military equipment of Russia": "",
    "Category:World War I mortars of Russia": "",
    "Category:World War I naval ships of Russia": "",
    "Category:World War I passenger ships of Russia": "",
    "Category:World War I ships of Russia": "",
    "Category:World War I submarines of Russia": "",
    "Category:World War I tanks of Russia": "",
    "Category:World War I torpedo boats of Russia": "",
    "Category:World War I weapons of Russia": "",
}

data1 = {
    "Category:Agriculture ministers of Russia": "تصنيف:وزراء زراعة روسيا",
    "Category:Culture ministers of Russia": "تصنيف:وزراء ثقافة روسيا",
    "Category:Economy ministers of Russia": "تصنيف:وزراء اقتصاد روسيا",
    "Category:Education ministers of Russia": "تصنيف:وزراء تعليم روسيا",
    "Category:Energy ministers of Russia": "تصنيف:وزراء طاقة روسيا",
    "Category:Finance ministers of Russia": "تصنيف:وزراء مالية روسيا",
    "Category:Health ministers of Russia": "تصنيف:وزراء صحة روسيا",
    "Category:Justice ministers of Russia": "تصنيف:وزراء عدل روسيا",
    "Category:Military personnel of the Tsardom of Russia": "تصنيف:أفراد عسكريون من روسيا القيصرية",
    "Category:Immigrants to the Tsardom of Russia": "تصنيف:مهاجرون إلى روسيا القيصرية",
    "Category:Generals of the Tsardom of Russia": "تصنيف:جنرالات روسيا القيصرية",
    "Category:Foreign relations of the Tsardom of Russia": "تصنيف:علاقات روسيا القيصرية الخارجية",
    "Category:Foreign ministers of the Tsardom of Russia": "تصنيف:وزراء خارجية روسيا القيصرية",
    "Category:Battles involving the Tsardom of Russia": "تصنيف:معارك تشمل روسيا القيصرية",
    "Category:Battles of the French invasion of Russia": "تصنيف:معارك الغزو الفرنسي لروسيا",
    "Category:Rebels from the Tsardom of Russia": "تصنيف:متمردون من روسيا القيصرية",
    "Category:People from the Tsardom of Russia": "تصنيف:أشخاص من روسيا القيصرية",
    "Category:Nuns from the Tsardom of Russia": "تصنيف:راهبات من روسيا القيصرية",
    "Category:Nobility from the Tsardom of Russia": "تصنيف:نبلاء من روسيا القيصرية",
    "Category:English expatriates in the Tsardom of Russia": "تصنيف:إنجليز مغتربون في روسيا القيصرية",
    "Category:Expatriates in the Tsardom of Russia": "تصنيف:مغتربون في روسيا القيصرية",
    "Category:Explorers from the Tsardom of Russia": "تصنيف:مستكشفون من روسيا القيصرية",
    "Category:Expatriates from the Dutch Republic in the Tsardom of Russia": "تصنيف:مغتربون من جمهورية هولندا في روسيا القيصرية",
    "Category:Artists from the Tsardom of Russia": "تصنيف:فنانون من روسيا القيصرية",
    "Category:Writers from the Tsardom of Russia": "تصنيف:كتاب من روسيا القيصرية",
    "Category:Ambassadors of Safavid Iran to the Tsardom of Russia": "تصنيف:سفراء إيران الصفوية لدى روسيا القيصرية",
    "Category:Ambassadors of Sweden to the Tsardom of Russia": "تصنيف:سفراء السويد لدى روسيا القيصرية",
    "Category:Ambassadors of the Tsardom of Russia": "تصنيف:سفراء روسيا القيصرية",
    "Category:Ambassadors to the Tsardom of Russia": "تصنيف:سفراء لدى روسيا القيصرية",
    "Category:15th-century military history of Russia": "تصنيف:تاريخ روسيا العسكري في القرن 15",
    "Category:16th-century military history of Russia": "تصنيف:تاريخ روسيا العسكري في القرن 16",
    "Category:17th-century military history of Russia": "تصنيف:تاريخ روسيا العسكري في القرن 17",
    "Category:20th-century military history of Russia": "تصنيف:تاريخ روسيا العسكري في القرن 20",
    "Category:21st-century military history of Russia": "تصنيف:تاريخ روسيا العسكري في القرن 21",
    "Category:Accidents and incidents by airline of Russia": "تصنيف:حوادث حسب شركة الطيران في روسيا",
    "Category:Acting presidents of Russia": "تصنيف:رؤساء روسيا بالإنابة",
    "Category:Aircraft carriers of Russia": "تصنيف:حاملات طائرات في روسيا",
    "Category:Air defence units and formations of Russia": "تصنيف:وحدات وتشكيلات دفاع جوي في روسيا",
    "Category:Airlines of Russia": "تصنيف:شركات طيران في روسيا",
    "Category:Ambassadors of Russia": "تصنيف:سفراء روسيا",
    "Category:Amphibians of Russia": "تصنيف:برمائيات روسيا",
    "Category:Amphibious warfare vessels of Russia": "تصنيف:سفن حربية برمائية في روسيا",
    "Category:Archaeology of Russia": "تصنيف:علم الآثار في روسيا",
    "Category:Archipelagoes of Russia": "تصنيف:أرخبيلات روسيا",
    "Category:Architecture firms of Russia": "تصنيف:شركات هندسة معمارية في روسيا",
    "Category:Arthropods of Russia": "تصنيف:مفصليات روسيا",
    "Category:Artificial islands of Russia": "تصنيف:جزر اصطناعية في روسيا",
    "Category:Artillery of Russia": "تصنيف:مدفعية في روسيا",
    "Category:Auxiliary ships of Russia": "تصنيف:سفن مساعدة في روسيا",
    "Category:Banks of Russia": "تصنيف:بنوك روسيا",
    "Category:Battlecruisers of Russia": "تصنيف:طرادات معركة في روسيا",
    "Category:Battleships of Russia": "تصنيف:بوارج في روسيا",
    "Category:Bays of Russia": "تصنيف:خلجان روسيا",
    "Category:Beaches of Russia": "تصنيف:شواطئ روسيا",
    "Category:Bibliographies of Russia": "تصنيف:ببليوجرافيات روسيا",
    "Category:Bilateral military relations of Russia": "تصنيف:علاقات روسيا الثنائية العسكرية",
    "Category:Bilateral relations of Russia": "تصنيف:علاقات روسيا الثنائية",
    "Category:Biota of Russia": "تصنيف:حيويات روسيا",
    "Category:Birds of Russia": "تصنيف:طيور روسيا",
    "Category:Bodies of ice of Russia": "تصنيف:هيئات جليد في روسيا",
    "Category:Bodies of water of Russia": "تصنيف:مسطحات مائية في روسيا",
    "Category:Border crossings of Russia": "تصنيف:معابر حدودية في روسيا",
    "Category:Borders of Russia": "تصنيف:حدود روسيا",
    "Category:Bus manufacturers of Russia": "تصنيف:مصانع الباصات في روسيا",
    "Category:Candidates for President of Russia": "تصنيف:مرشحون لمنصب رئيس روسيا",
    "Category:Canyons and gorges of Russia": "تصنيف:أخاديد في روسيا",
    "Category:Cargo airlines of Russia": "تصنيف:شحن جوي في روسيا",
    "Category:Cargo ships of Russia": "تصنيف:سفن بضائع روسيا",
    "Category:Cars of Russia": "تصنيف:سيارات في روسيا",
    "Category:Caves of Russia": "تصنيف:كهوف روسيا",
    "Category:Charter airlines of Russia": "تصنيف:طيران عارض في روسيا",
    "Category:Chief justices of Russia": "تصنيف:رؤساء قضاء روسيا",
    "Category:Children of presidents of Russia": "تصنيف:أبناء رؤساء روسيا",
    "Category:Children of prime ministers of Russia": "تصنيف:أبناء رؤساء وزراء روسيا",
    "Category:Cinema of Russia": "تصنيف:سينما في روسيا",
    "Category:Citizenship of Russia": "تصنيف:المواطنة في روسيا",
    "Category:Civil awards and decorations of Russia": "تصنيف:جوائز وأوسمة مدنية في روسيا",
    "Category:Climate of Russia": "تصنيف:مناخ روسيا",
    "Category:Coasts of Russia": "تصنيف:سواحل روسيا",
    "Category:Constitutions of Russia": "تصنيف:دساتير في روسيا",
    "Category:Construction industry of Russia": "تصنيف:صناعة بناء في روسيا",
    "Category:Corvettes of Russia": "تصنيف:فرقيطات في روسيا",
    "Category:Cruisers of Russia": "تصنيف:طرادات في روسيا",
    "Category:Crustaceans of Russia": "تصنيف:قشريات روسيا",
    "Category:Cultural depictions of presidents of Russia": "تصنيف:تصوير ثقافي عن رؤساء روسيا",
    "Category:Cultural history of Russia": "تصنيف:تاريخ روسيا الثقافي",
    "Category:Culture of Russia": "تصنيف:ثقافة روسيا",
    "Category:Currencies of Russia": "تصنيف:عملات في روسيا",
    "Category:Defence agencies of Russia": "تصنيف:وكالات دفاع في روسيا",
    "Category:Defunct airlines of Russia": "تصنيف:شركات طيران سابقة في روسيا",
    "Category:Defunct banks of Russia": "تصنيف:بنوك سابقة في روسيا",
    "Category:Defunct motor vehicle manufacturers of Russia": "تصنيف:مصانع سيارات سابقة في روسيا",
    "Category:Demographics of Russia": "تصنيف:التركيبة السكانية في روسيا",
    "Category:Depressions of Russia": "تصنيف:منخفضات روسيا",
    "Category:Deserts of Russia": "تصنيف:صحاري روسيا",
    "Category:Destroyers of Russia": "تصنيف:مدمرات في روسيا",
    "Category:Dinosaurs of Russia": "تصنيف:ديناصورات في روسيا",
    "Category:Diplomatic missions of Russia": "تصنيف:بعثات روسيا الدبلوماسية",
    "Category:Districts of Russia": "تصنيف:مديريات روسيا",
    "Category:Drainage basins of Russia": "تصنيف:أحواض تصريف في روسيا",
    "Category:Drug policy of Russia": "تصنيف:سياسة المخدرات في روسيا",
    "Category:Dunes of Russia": "تصنيف:كثبان رملية في روسيا",
    "Category:Early modern history of Russia": "تصنيف:تاريخ روسيا الحديث المبكر",
    "Category:Economic history of Russia": "تصنيف:تاريخ روسيا الاقتصادي",
    "Category:Economy of Russia": "تصنيف:اقتصاد روسيا",
    "Category:Ecoregions of Russia": "تصنيف:مناطق بيئية في روسيا",
    "Category:Elizabeth of Russia": "تصنيف:إليزابيث إمبراطورة روسيا",
    "Category:Environment of Russia": "تصنيف:بيئة روسيا",
    "Category:Escort ships of Russia": "تصنيف:سفن مرافقة في روسيا",
    "Category:Fast-food chains of Russia": "تصنيف:سلاسل وجبات سريعة في روسيا",
    "Category:Fauna of Russia": "تصنيف:حيوانات روسيا",
    "Category:Featured pictures of Russia": "تصنيف:صور مميزة عن روسيا",
    "Category:Federal subjects of Russia": "تصنيف:كيانات روسيا الاتحادية",
    "Category:Federal universities of Russia": "تصنيف:جامعات فيدرالية في روسيا",
    "Category:Female candidates for President of Russia": "تصنيف:مرشحات لمنصب رئيس روسيا",
    "Category:Ferries of Russia": "تصنيف:عبارات في روسيا",
    "Category:First ladies of Russia": "تصنيف:السيدات الأولى في روسيا",
    "Category:Fish of Russia": "تصنيف:أسماك روسيا",
    "Category:Flags of Russia": "تصنيف:أعلام روسيا",
    "Category:Flags of the federal subjects of Russia": "تصنيف:أعلام كيانات روسيا الاتحادية",
    "Category:Flora of Russia": "تصنيف:نباتات روسيا",
    "Category:Folklore of Russia": "تصنيف:فلكور في روسيا",
    "Category:Forests of Russia": "تصنيف:غابات روسيا",
    "Category:French invasion of Russia": "تصنيف:الغزو الفرنسي لروسيا",
    "Category:Frigates of Russia": "تصنيف:فرقاطات في روسيا",
    "Category:Fungi of Russia": "تصنيف:فطريات روسيا",
    "Category:Geography of Russia": "تصنيف:جغرافيا روسيا",
    "Category:Geology of Russia": "تصنيف:جيولوجيا روسيا",
    "Category:Glaciers of Russia": "تصنيف:أنهار جليدية في روسيا",
    "Category:Golden Ring of Russia": "تصنيف:الجولدن رنج في روسيا",
    "Category:Government agencies of Russia": "تصنيف:وكالات حكومية في روسيا",
    "Category:Government ministers of Russia": "تصنيف:وزراء روسيا",
    "Category:Government ministries of federal subjects of Russia": "تصنيف:وزارات حكومة كيانات روسيا الاتحادية",
    "Category:Government of Russia": "تصنيف:حكومة روسيا",
    "Category:Grand Duchess Anastasia Nikolaevna of Russia": "تصنيف:الدوقة الكبرى أناستاسيا نيكولايفنا من روسيا",
    "Category:Grasslands of Russia": "تصنيف:أراضي عشبية في روسيا",
    "Category:Gulfs of Russia": "تصنيف:خلجان روسيا",
    "Category:Headlands of Russia": "تصنيف:أراضي رأسية في روسيا",
    "Category:Heads of government of Russia": "تصنيف:قادة حكومة روسيا",
    "Category:Heads of state of Russia": "تصنيف:قادة روسيا",
    "Category:Heads of the federal subjects of Russia": "تصنيف:قادة كيانات روسيا الاتحادية",
    "Category:Hills of Russia": "تصنيف:تلال روسيا",
    "Category:Historians of Russia": "تصنيف:مؤرخو روسيا",
    "Category:Historiography of Russia": "تصنيف:تأريخ روسيا",
    "Category:History of Russia": "تصنيف:تاريخ روسيا",
    "Category:Hot springs of Russia": "تصنيف:ينابيع حارة في روسيا",
    "Category:Images of Russia": "تصنيف:صور من روسيا",
    "Category:Indigenous peoples of Russia": "تصنيف:شعوب أصلية في روسيا",
    "Category:Insects of Russia": "تصنيف:حشرات روسيا",
    "Category:Internet service providers of Russia": "تصنيف:تزويد خدمة الإنترنت في روسيا",
    "Category:Invasions of Russia": "تصنيف:غزوات في روسيا",
    "Category:Invertebrates of Russia": "تصنيف:لافقاريات روسيا",
    "Category:Islands of Russia": "تصنيف:جزر روسيا",
    "Category:Judiciary of Russia": "تصنيف:النظام القضائي روسيا",
    "Category:Lakes of Russia": "تصنيف:بحيرات روسيا",
    "Category:Landforms of Russia": "تصنيف:تضاريس روسيا",
    "Category:Languages of Russia": "تصنيف:لغات روسيا",
    "Category:Law enforcement agencies of Russia": "تصنيف:وكالات تطبيق القانون في روسيا",
    "Category:Law of Russia": "تصنيف:قانون في روسيا",
    "Category:Learned societies of Russia": "تصنيف:جمعيات علمية في روسيا",
    "Category:Legal history of Russia": "تصنيف:تاريخ روسيا القانوني",
    "Category:Legislatures of the federal subjects of Russia": "تصنيف:هيئات تشريعية في كيانات روسيا الاتحادية",
    "Category:Lists of ambassadors of Russia": "تصنيف:قوائم سفراء روسيا",
    "Category:Lists of biota of Russia": "تصنيف:قوائم حيويات روسيا",
    "Category:Lists of candidates for President of Russia": "تصنيف:قوائم مرشحون لمنصب رئيس روسيا",
    "Category:Lists of flags of Russia": "تصنيف:قوائم أعلام روسيا",
    "Category:Lists of government ministers of Russia": "تصنيف:قوائم وزراء روسيا",
    "Category:Lists of heads of the federal subjects of Russia": "تصنيف:قوائم قادة كيانات روسيا الاتحادية",
    "Category:Lists of indigenous peoples of Russia": "تصنيف:قوائم شعوب أصلية في روسيا",
    "Category:Lists of landforms of Russia": "تصنيف:قوائم تضاريس روسيا",
    "Category:Lists of ships of Russia": "تصنيف:قوائم سفن روسيا",
    "Category:Lists of subdivisions of Russia": "تصنيف:قوائم تقسيمات روسيا",
    "Category:Locomotive manufacturers of Russia": "تصنيف:مصانع القاطرات في روسيا",
    "Category:Mammals of Russia": "تصنيف:ثدييات روسيا",
    "Category:Maritime history of Russia": "تصنيف:تاريخ روسيا البحري",
    "Category:Military academies of Russia": "تصنيف:أكاديميات عسكرية في روسيا",
    "Category:Military communications of Russia": "تصنيف:اتصالات عسكرية في روسيا",
    "Category:Military equipment of Russia": "تصنيف:عتاد روسيا العسكري",
    "Category:Military history of Russia": "تصنيف:تاريخ روسيا العسكري",
    "Category:Military installations of Russia": "تصنيف:منشآت روسيا العسكرية",
    "Category:Military logistics of Russia": "تصنيف:لوجستية عسكرية في روسيا",
    "Category:Military of Russia": "تصنيف:عسكرية روسيا",
    "Category:Military ranks of Russia": "تصنيف:رتب عسكرية في روسيا",
    "Category:Military research facilities of Russia": "تصنيف:مرافق بحثية عسكرية في روسيا",
    "Category:Military research of Russia": "تصنيف:أبحاث عسكرية في روسيا",
    "Category:Military units and formations of Russia": "تصنيف:وحدات وتشكيلات روسيا العسكرية",
    "Category:Minesweepers of Russia": "تصنيف:كاسحات ألغام في روسيا",
    "Category:Mine warfare vessels of Russia": "تصنيف:سفن حرب ألغام في روسيا",
    "Category:Ministers of defence of Russia": "تصنيف:وزراء دفاع روسيا",
    "Category:Ministers of foreign affairs of Russia": "تصنيف:وزراء شؤون خارجية روسيا",
    "Category:Ministers of internal affairs of Russia": "تصنيف:وزراء شؤون داخلية روسيا",
    "Category:Missile boats of Russia": "تصنيف:قوارب صواريخ في روسيا",
    "Category:Modern history of Russia": "تصنيف:تاريخ روسيا الحديث",
    "Category:Motor vehicle manufacturers of Russia": "تصنيف:مصانع السيارات في روسيا",
    "Category:Mountain passes of Russia": "تصنيف:ممرات جبلية في روسيا",
    "Category:Mountain ranges of Russia": "تصنيف:سلاسل جبلية في روسيا",
    "Category:Mountains of Russia": "تصنيف:جبال روسيا",
    "Category:Municipalities of Russia": "تصنيف:بلديات روسيا",
    "Category:Music of Russia": "تصنيف:موسيقى روسيا",
    "Category:Muslim communities of Russia": "تصنيف:مجتمعات إسلامية في روسيا",
    "Category:National Guard of Russia": "تصنيف:الحرس الوطني في روسيا",
    "Category:National parks of Russia": "تصنيف:متنزهات وطنية في روسيا",
    "Category:National trade union centers of Russia": "تصنيف:مراكز نقابية وطنية في روسيا",
    "Category:Natural history of Russia": "تصنيف:تاريخ روسيا الطبيعي",
    "Category:Naturalized citizens of Russia": "تصنيف:متجنسون في روسيا",
    "Category:Naval history of Russia": "تصنيف:تاريخ روسيا العسكري البحري",
    "Category:Naval ships of Russia": "تصنيف:سفن قوات بحرية في روسيا",
    "Category:Naval units and formations of Russia": "تصنيف:وحدات وتشكيلات روسيا البحرية",
    "Category:Nuclear history of Russia": "تصنيف:تاريخ روسيا النووي",
    "Category:Nuclear missiles of Russia": "تصنيف:صواريخ نووية في روسيا",
    "Category:Nuclear weapons of Russia": "تصنيف:أسلحة نووية في روسيا",
    "Category:Oil fields of Russia": "تصنيف:حقول نفط في روسيا",
    "Category:Orders, decorations, and medals of Russia": "تصنيف:مراتب تشريفية وأوسمة وميداليات روسيا",
    "Category:Passenger ships of Russia": "تصنيف:سفن ركاب في روسيا",
    "Category:Patrol vessels of Russia": "تصنيف:سفن دورية في روسيا",
    "Category:Peace treaties of Russia": "تصنيف:معاهدات سلام روسيا",
    "Category:Peninsulas of Russia": "تصنيف:أشباه جزر في روسيا",
    "Category:People of Russia": "تصنيف:أشخاص من روسيا",
    "Category:Plains of Russia": "تصنيف:سهول روسيا",
    "Category:Plateaus of Russia": "تصنيف:هضاب روسيا",
    "Category:Political history of Russia": "تصنيف:تاريخ روسيا السياسي",
    "Category:Politics of Russia": "تصنيف:سياسة روسيا",
    "Category:Ports and harbours of Russia": "تصنيف:مرافئ وموانئ روسيا",
    "Category:Presidency of Russia": "تصنيف:رئاسة روسيا",
    "Category:Presidents of Russia": "تصنيف:رؤساء روسيا",
    "Category:Prisoners and detainees of Russia": "تصنيف:سجناء ومعتقلون في روسيا",
    "Category:Protected areas of Russia": "تصنيف:مناطق محمية في روسيا",
    "Category:Regions of Russia": "تصنيف:مناطق روسيا",
    "Category:Reptiles of Russia": "تصنيف:زواحف روسيا",
    "Category:Ridges of Russia": "تصنيف:نتوئات جبلية في روسيا",
    "Category:Rivers of Russia": "تصنيف:أنهار روسيا",
    "Category:Rocket engines of Russia": "تصنيف:محركات صواريخ في روسيا",
    "Category:Rock formations of Russia": "تصنيف:تكوينات صخرية في روسيا",
    "Category:Rolling stock of Russia": "تصنيف:القطارات في روسيا",
    "Category:Satellites of Russia": "تصنيف:أقمار صناعية تتبع روسيا",
    "Category:Seas of Russia": "تصنيف:بحار روسيا",
    "Category:Service vessels of Russia": "تصنيف:سفن خدمة في روسيا",
    "Category:Ships of Russia": "تصنيف:سفن روسيا",
    "Category:Shipwrecks of Russia": "تصنيف:حطام سفن في روسيا",
    "Category:Shipyards of Russia": "تصنيف:حوض بناء سفن في روسيا",
    "Category:Social groups of Russia": "تصنيف:مجموعات اجتماعية في روسيا",
    "Category:Social history of Russia": "تصنيف:تاريخ روسيا الاجتماعي",
    "Category:Society of Russia": "تصنيف:مجتمع روسيا",
    "Category:Spiders of Russia": "تصنيف:عناكب في روسيا",
    "Category:Sports organisations of Russia": "تصنيف:منظمات رياضية في روسيا",
    "Category:Sports organizations of Russia": "تصنيف:منظمات رياضية في روسيا",
    "Category:Springs of Russia": "تصنيف:ينابيع روسيا",
    "Category:Straits of Russia": "تصنيف:مضائق روسيا",
    "Category:Stratovolcanoes of Russia": "تصنيف:براكين طبقية في روسيا",
    "Category:Submarines of Russia": "تصنيف:غواصات روسيا",
    "Category:Supermarkets of Russia": "تصنيف:محلات سوبر ماركت في روسيا",
    "Category:Swamps of Russia": "تصنيف:مستنقعات في روسيا",
    "Category:Tall ships of Russia": "تصنيف:سفن طويلة في روسيا",
    "Category:Tanks of Russia": "تصنيف:دبابات روسيا",
    "Category:Territorial evolution of Russia": "تصنيف:الحركة الاستعمارية الروسية",
    "Category:Torpedoes of Russia": "تصنيف:الطوربيدات في روسيا",
    "Category:Training units and formations of Russia": "تصنيف:وحدات وتشكيلات تدريبية في روسيا",
    "Category:Treaties of Russia": "تصنيف:معاهدات روسيا",
    "Category:Truck manufacturers of Russia": "تصنيف:مصانع الشاحنات في روسيا",
    "Category:Uninhabited islands of Russia": "تصنيف:جزر غير مأهولة في روسيا",
    "Category:Unmanned aerial vehicles of Russia": "تصنيف:طائرات بدون طيار روسية",
    "Category:Unmanned military aircraft of Russia": "تصنيف:طائرات عسكرية بدون طيار روسية",
    "Category:Valleys of Russia": "تصنيف:أودية روسيا",
    "Category:Vehicles of Russia": "تصنيف:مركبات روسيا",
    "Category:Vertebrates of Russia": "تصنيف:فقاريات روسيا",
    "Category:Vice presidents of Russia": "تصنيف:نواب رؤساء روسيا",
    "Category:Volcanoes of Russia": "تصنيف:براكين روسيا",
    "Category:Waterfalls of Russia": "تصنيف:شلالات روسيا",
    "Category:Wetlands of Russia": "تصنيف:مناطق رطبة في روسيا",
    "Category:Women government ministers of Russia": "تصنيف:وزيرات روسيات",
    "Category:National youth sports teams of Russia": "تصنيف:منتخبات رياضية وطنية شبابية روسيا",
    "Category:National sports teams of Russia": "تصنيف:منتخبات رياضية وطنية من روسيا",
    "Category:Members of learned societies of Russia": "تصنيف:أعضاء جمعيات علمية في روسيا",
    "Category:Members of legislatures of the federal subjects of Russia": "تصنيف:أعضاء هيئات تشريعية في كيانات روسيا الاتحادية",
    "Category:Men's national sports teams of Russia": "تصنيف:منتخبات رياضية وطنية رجالية روسيا",
    "Category:Women's national sports teams of Russia": "تصنيف:منتخبات رياضية وطنية نسائية روسيا",
    "Category:Works about the French invasion of Russia": "تصنيف:أعمال عن الغزو الفرنسي في روسيا",
    "Category:History books about the Tsardom of Russia": "تصنيف:كتب تاريخ عن روسيا القيصرية",
    "Category:Films about the French invasion of Russia": "تصنيف:أفلام عن الغزو الفرنسي في روسيا",
    "Category:Books about presidents of Russia": "تصنيف:كتب عن رؤساء روسيا",
    "Category:Mass media by language of Russia": "تصنيف:وسائل إعلام حسب لغة روسيا",
    "Category:Categories by language of Russia": "تصنيف:تصنيفات حسب لغة روسيا",
}

companies_data = {
    "Category:Agriculture companies of Russia": "تصنيف:شركات زراعة في روسيا",
    "Category:Aluminium companies of Russia": "تصنيف:شركات ألومنيوم في روسيا",
    "Category:Automotive companies of Russia": "تصنيف:شركات سيارات في روسيا",
    "Category:Biotechnology companies of Russia": "تصنيف:شركات تقانة حيوية في روسيا",
    "Category:Building materials companies of Russia": "تصنيف:شركات مواد بناء في روسيا",
    "Category:Bus companies of Russia": "تصنيف:شركات الباصات في روسيا",
    "Category:Cement companies of Russia": "تصنيف:شركات أسمنت في روسيا",
    "Category:Chemical companies of Russia": "تصنيف:شركات كيميائية في روسيا",
    "Category:Clothing companies of Russia": "تصنيف:شركات ملابس في روسيا",
    "Category:Coal companies of Russia": "تصنيف:شركات فحم في روسيا",
    "Category:companies of Russia": "تصنيف:شركات في روسيا",
    "Category:Computer companies of Russia": "تصنيف:شركات حوسبة في روسيا",
    "Category:Conglomerate companies of Russia": "تصنيف:تكتل شركات في روسيا",
    "Category:Construction and civil engineering companies of Russia": "تصنيف:شركات بناء وهندسة مدنية في روسيا",
    "Category:Cosmetics companies of Russia": "تصنيف:شركات مستحضرات التجميل في روسيا",
    "Category:Defence companies of Russia": "تصنيف:شركات دفاعية في روسيا",
    "Category:Defunct companies of Russia": "تصنيف:شركات سابقة في روسيا",
    "Category:Defunct electric power companies of Russia": "تصنيف:شركات طاقة كهربائية سابقة في روسيا",
    "Category:Defunct energy companies of Russia": "تصنيف:شركات طاقة سابقة في روسيا",
    "Category:Defunct manufacturing companies of Russia": "تصنيف:شركات تصنيع سابقة في روسيا",
    "Category:Defunct oil companies of Russia": "تصنيف:شركات زيت الوقود سابقة في روسيا",
    "Category:Defunct shipping companies of Russia": "تصنيف:شركات نقل بحري سابقة في روسيا",
    "Category:Defunct transport companies of Russia": "تصنيف:شركات نقل سابقة في روسيا",
    "Category:Defunct video game companies of Russia": "تصنيف:شركات ألعاب فيديو سابقة في روسيا",
    "Category:Design companies of Russia": "تصنيف:شركات تصميم في روسيا",
    "Category:Drink companies of Russia": "تصنيف:شركات مشروبات في روسيا",
    "Category:Electrical engineering companies of Russia": "تصنيف:شركات هندسة كهربائية في روسيا",
    "Category:Electric power companies of Russia": "تصنيف:شركات طاقة كهربائية في روسيا",
    "Category:Electronics companies of Russia": "تصنيف:شركات إلكترونيات في روسيا",
    "Category:Energy companies of Russia": "تصنيف:شركات طاقة في روسيا",
    "Category:Engineering companies of Russia": "تصنيف:شركات هندسية في روسيا",
    "Category:Entertainment companies of Russia": "تصنيف:شركات ترفيه في روسيا",
    "Category:Financial services companies of Russia": "تصنيف:شركات خدمات مالية في روسيا",
    "Category:Food and drink companies of Russia": "تصنيف:شركات أطعمة ومشروبات في روسيا",
    "Category:Government-owned companies of Russia": "تصنيف:شركات مملوكة للحكومة في روسيا",
    "Category:Holding companies of Russia": "تصنيف:شركات قابضة في روسيا",
    "Category:Information technology companies of Russia": "تصنيف:شركات تقانة المعلومات في روسيا",
    "Category:Insurance companies of Russia": "تصنيف:شركات تأمين في روسيا",
    "Category:Investment companies of Russia": "تصنيف:شركات استثمارية في روسيا",
    "Category:Jewellery companies of Russia": "تصنيف:شركات مجوهرات في روسيا",
    "Category:Lists of companies of Russia": "تصنيف:قوائم شركات في روسيا",
    "Category:Manufacturing companies of Russia": "تصنيف:شركات تصنيع في روسيا",
    "Category:Mass media companies of Russia": "تصنيف:شركات وسائل إعلام في روسيا",
    "Category:Metal companies of Russia": "تصنيف:شركات معادن في روسيا",
    "Category:Mining companies of Russia": "تصنيف:شركات تعدين في روسيا",
    "Category:Mobile phone companies of Russia": "تصنيف:شركات هاتف محمول في روسيا",
    "Category:Natural gas companies of Russia": "تصنيف:شركات غاز طبيعي في روسيا",
    "Category:Nuclear companies of Russia": "تصنيف:شركات نووية في روسيا",
    "Category:Oil and gas companies of Russia": "تصنيف:شركات النفط والغاز في روسيا",
    "Category:Oil companies of Russia": "تصنيف:شركات زيت الوقود في روسيا",
    "Category:Pharmaceutical companies of Russia": "تصنيف:شركات أدوية في روسيا",
    "Category:Privately held companies of Russia": "تصنيف:شركات خاصة في روسيا",
    "Category:Publishing companies of Russia": "تصنيف:شركات نشر في روسيا",
    "Category:Pulp and paper companies of Russia": "تصنيف:شركات اللب والورق في روسيا",
    "Category:Railway companies of Russia": "تصنيف:شركات سكك حديدية في روسيا",
    "Category:Real estate companies of Russia": "تصنيف:شركات عقارية في روسيا",
    "Category:Retail companies of Russia": "تصنيف:شركات تجارة التجزئة في روسيا",
    "Category:Security companies of Russia": "تصنيف:شركات أمن في روسيا",
    "Category:Service companies of Russia": "تصنيف:شركات خدمات في روسيا",
    "Category:Shipbuilding companies of Russia": "تصنيف:شركات سفن في روسيا",
    "Category:Shipping companies of Russia": "تصنيف:شركات نقل بحري في روسيا",
    "Category:Software companies of Russia": "تصنيف:شركات برمجيات في روسيا",
    "Category:Technology companies of Russia": "تصنيف:شركات تقانة في روسيا",
    "Category:Television companies of Russia": "تصنيف:شركات تلفاز في روسيا",
    "Category:Transport companies of Russia": "تصنيف:شركات نقل في روسيا",
    "Category:Travel and holiday companies of Russia": "تصنيف:شركات السفر والعطلات في روسيا",
    "Category:Vehicle manufacturing companies of Russia": "تصنيف:شركات تصنيع مركبات في روسيا",
    "Category:Video game companies of Russia": "تصنيف:شركات ألعاب فيديو في روسيا",
    "Category:Water companies of Russia": "تصنيف:شركات مياه في روسيا",
}

to_test = [
    ("test_all_russia", data1),
    ("test_companies_russia", companies_data),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
@pytest.mark.slow
def test_all_russia(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_peoples(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    dump_diff(diff_result, name)
    # dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
