#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data_0 = {}

data_1 = {
    "Category:1960s in Papua New Guinean sport": "x",
    "Category:1962 in Papua New Guinean sport": "x",
    "Category:1969 in Papua New Guinean sport": "x",
    "Category:1970s in Papua New Guinean sport": "x",
    "Category:1975 in Papua New Guinean sport": "x",
    "Category:1976 in Papua New Guinean sport": "x",
    "Category:1980s in Papua New Guinean sport": "x",
    "Category:1982 in Papua New Guinean sport": "x",
    "Category:1983 in Papua New Guinean sport": "x",
    "Category:1984 in Papua New Guinean sport": "x",
    "Category:1985 in Papua New Guinean sport": "x",
    "Category:1986 in Papua New Guinean sport": "x",
    "Category:1988 in Papua New Guinean rugby league": "x",
    "Category:1988 in Papua New Guinean sport": "x",
    "Category:1989 in Papua New Guinean sport": "x",
    "Category:1990 in Papua New Guinean rugby league": "x",
    "Category:1990 in Papua New Guinean sport": "x",
    "Category:1990s in Papua New Guinean sport": "x",
    "Category:1990s in Papua New Guinean television": "x",
    "Category:1990s Papua New Guinean television series": "x",
    "Category:1991 in Papua New Guinean rugby league": "x",
    "Category:1991 in Papua New Guinean sport": "x",
    "Category:1992 in Papua New Guinean rugby league": "x",
    "Category:1992 in Papua New Guinean sport": "x",
    "Category:1994 in Papua New Guinean rugby league": "x",
    "Category:1994 in Papua New Guinean sport": "x",
    "Category:1996 in Papua New Guinean rugby league": "x",
    "Category:1996 in Papua New Guinean sport": "x",
    "Category:1997 in Papua New Guinean sport": "x",
    "Category:2000 in Papua New Guinean sport": "x",
    "Category:2000s in Papua New Guinean sport": "x",
    "Category:2001 in Papua New Guinean rugby league": "x",
    "Category:2001 in Papua New Guinean soccer": "x",
    "Category:2001 in Papua New Guinean sport": "x",
    "Category:2003 in Papua New Guinean sport": "x",
    "Category:2004 in Papua New Guinean sport": "x",
    "Category:2005 in Papua New Guinean sport": "x",
    "Category:2006 in Papua New Guinean sport": "x",
    "Category:2007 in Papua New Guinean sport": "x",
    "Category:2008 in Papua New Guinean sport": "x",
    "Category:2009 in Papua New Guinean sport": "x",
    "Category:2010 in Papua New Guinean sport": "x",
    "Category:2010s in Papua New Guinean sport": "x",
    "Category:2011 in Papua New Guinean sport": "x",
    "Category:2011–2012 Papua New Guinean constitutional crisis": "x",
    "Category:2012 in Papua New Guinean sport": "x",
    "Category:2013 in Papua New Guinean sport": "x",
    "Category:2014 in Papua New Guinean sport": "x",
    "Category:2015 in Papua New Guinean sport": "x",
    "Category:2016 in Papua New Guinean cricket": "x",
    "Category:2016 in Papua New Guinean sport": "x",
    "Category:2017 in Papua New Guinean cricket": "x",
    "Category:2017 in Papua New Guinean sport": "x",
    "Category:2018 in Papua New Guinean sport": "x",
    "Category:2019 in Papua New Guinean cricket": "x",
    "Category:2019 in Papua New Guinean sport": "x",
    "Category:2020 in Papua New Guinean sport": "x",
    "Category:2020s in Papua New Guinean cricket": "x",
    "Category:2020s in Papua New Guinean sport": "x",
    "Category:2021 in Papua New Guinean cricket": "x",
    "Category:2021 in Papua New Guinean sport": "x",
    "Category:2022 in Papua New Guinean cricket": "x",
    "Category:2022 in Papua New Guinean sport": "x",
    "Category:2023 in Papua New Guinean cricket": "x",
    "Category:2023 in Papua New Guinean sport": "x",
    "Category:2024 in Papua New Guinean cricket": "x",
    "Category:2024 in Papua New Guinean sport": "x",
    "Category:2025 in Papua New Guinean sport": "x",
    "Category:20th century in Papua New Guinean television": "x",
    "Category:20th-century Papua New Guinean businesspeople": "x",
    "Category:20th-century Papua New Guinean painters": "x",
    "Category:20th-century Papua New Guinean people": "x",
    "Category:20th-century Papua New Guinean politicians": "x",
    "Category:20th-century Papua New Guinean sportsmen": "x",
    "Category:20th-century Papua New Guinean sportspeople": "x",
    "Category:20th-century Papua New Guinean sportswomen": "x",
    "Category:20th-century Papua New Guinean television series": "x",
    "Category:21st-century Papua New Guinean people": "x",
    "Category:21st-century Papua New Guinean politicians": "x",
    "Category:21st-century Papua New Guinean sportsmen": "x",
    "Category:21st-century Papua New Guinean sportspeople": "x",
    "Category:21st-century Papua New Guinean sportswomen": "x",
    "Category:Albums by Papua New Guinean artists": "x",
    "Category:Albums by Papua New Guinean artists by genre": "x",
    "Category:Assassinated Papua New Guinean politicians": "x",
    "Category:Australian people of Papua New Guinean descent": "x",
    "Category:British people of Papua New Guinean descent": "x",
    "Category:Fijian people of Papua New Guinean descent": "x",
    "Category:Hip-hop albums by Papua New Guinean artists": "x",
    "Category:Japanese people of Papua New Guinean descent": "x",
    "Category:Lists of Papua New Guinean ambassadors": "x",
    "Category:Lists of Papua New Guinean cricketers": "x",
    "Category:Lists of Papua New Guinean people": "x",
    "Category:Lists of Papua New Guinean sportspeople": "x",
    "Category:New Zealand people of Papua New Guinean descent": "x",
    "Category:Papua New Guinean academics": "x",
    "Category:Papua New Guinean accountants": "x",
    "Category:Papua New Guinean activists": "x",
    "Category:Papua New Guinean actor-politicians": "x",
    "Category:Papua New Guinean actors": "x",
    "Category:Papua New Guinean airport stubs": "x",
    "Category:Papua New Guinean Anglicans": "x",
    "Category:Papua New Guinean anti-corruption activists": "x",
    "Category:Papua New Guinean anti-war activists": "x",
    "Category:Papua New Guinean archaeologists": "x",
    "Category:Papua New Guinean artists": "x",
    "Category:Papua New Guinean athletes": "x",
    "Category:Papua New Guinean aviators": "x",
    "Category:Papua New Guinean award winners": "x",
    "Category:Papua New Guinean awards": "x",
    "Category:Papua New Guinean badminton players": "x",
    "Category:Papua New Guinean bankers": "x",
    "Category:Papua New Guinean basketball players": "x",
    "Category:Papua New Guinean beatified people": "x",
    "Category:Papua New Guinean biologists": "x",
    "Category:Papua New Guinean bishops": "x",
    "Category:Papua New Guinean bowling players": "x",
    "Category:Papua New Guinean bowls players": "x",
    "Category:Papua New Guinean boxers": "x",
    "Category:Papua New Guinean broadcasters": "x",
    "Category:Papua New Guinean building and structure stubs": "x",
    "Category:Papua New Guinean businesspeople": "x",
    "Category:Papua New Guinean businesswomen": "x",
    "Category:Papua New Guinean cardinals": "x",
    "Category:Papua New Guinean chess players": "x",
    "Category:Papua New Guinean Christian missionaries": "x",
    "Category:Papua New Guinean Christians": "x",
    "Category:Papua New Guinean civil servants": "x",
    "Category:Papua New Guinean clergy": "x",
    "Category:Papua New Guinean climate activists": "x",
    "Category:Papua New Guinean Commanders of the Order of the British Empire": "x",
    "Category:Papua New Guinean competitors by sports event": "x",
    "Category:Papua New Guinean cricket captains": "x",
    "Category:Papua New Guinean cricket coaches": "x",
    "Category:Papua New Guinean cricket people": "x",
    "Category:Papua New Guinean cricket tours abroad": "x",
    "Category:Papua New Guinean cricket tours of Australia": "x",
    "Category:Papua New Guinean cricket tours of Hong Kong": "x",
    "Category:Papua New Guinean cricket tours of the United Arab Emirates": "x",
    "Category:Papua New Guinean cricket umpires": "x",
    "Category:Papua New Guinean cricketers": "x",
    "Category:Papua New Guinean criminals": "x",
    "Category:Papua New Guinean cuisine": "x",
    "Category:Papua New Guinean curators": "x",
    "Category:Papua New Guinean dancers": "x",
    "Category:Papua New Guinean decathletes": "x",
    "Category:Papua New Guinean deities": "x",
    "Category:Papua New Guinean designers": "x",
    "Category:Papua New Guinean diaspora": "x",
    "Category:Papua New Guinean diplomats": "x",
    "Category:Papua New Guinean dramatists and playwrights": "x",
    "Category:Papua New Guinean economists": "x",
    "Category:Papua New Guinean editors": "x",
    "Category:Papua New Guinean educators": "x",
    "Category:Papua New Guinean emigrants": "x",
    "Category:Papua New Guinean emigrants to Australia": "x",
    "Category:Papua New Guinean emigrants to Canada": "x",
    "Category:Papua New Guinean emigrants to Japan": "x",
    "Category:Papua New Guinean emigrants to New Zealand": "x",
    "Category:Papua New Guinean environmentalists": "x",
    "Category:Papua New Guinean evangelicals": "x",
    "Category:Papua New Guinean expatriate judges": "x",
    "Category:Papua New Guinean expatriate men's soccer players": "x",
    "Category:Papua New Guinean expatriate rugby league players": "x",
    "Category:Papua New Guinean expatriate rugby league players in Australia": "x",
    "Category:Papua New Guinean expatriate rugby league players in England": "x",
    "Category:Papua New Guinean expatriate rugby union players": "x",
    "Category:Papua New Guinean expatriate soccer players": "x",
    "Category:Papua New Guinean expatriate sportspeople": "x",
    "Category:Papua New Guinean expatriate sportspeople by country of residence": "x",
    "Category:Papua New Guinean expatriate sportspeople in Australia": "x",
    "Category:Papua New Guinean expatriate sportspeople in England": "x",
    "Category:Papua New Guinean expatriate sportspeople in Finland": "x",
    "Category:Papua New Guinean expatriate sportspeople in France": "x",
    "Category:Papua New Guinean expatriate sportspeople in Malaysia": "x",
    "Category:Papua New Guinean expatriate sportspeople in New Zealand": "x",
    "Category:Papua New Guinean expatriate sportspeople in the Netherlands": "x",
    "Category:Papua New Guinean expatriate sportspeople in the Philippines": "x",
    "Category:Papua New Guinean expatriate sportspeople in the Solomon Islands": "x",
    "Category:Papua New Guinean expatriate sportspeople in the United Kingdom": "x",
    "Category:Papua New Guinean expatriate sportspeople in the United States": "x",
    "Category:Papua New Guinean expatriate sportspeople in Wales": "x",
    "Category:Papua New Guinean expatriate women's soccer players": "x",
    "Category:Papua New Guinean expatriates": "x",
    "Category:Papua New Guinean expatriates in Australia": "x",
    "Category:Papua New Guinean expatriates in Belgium": "x",
    "Category:Papua New Guinean expatriates in England": "x",
    "Category:Papua New Guinean expatriates in Fiji": "x",
    "Category:Papua New Guinean expatriates in Finland": "x",
    "Category:Papua New Guinean expatriates in France": "x",
    "Category:Papua New Guinean expatriates in New Zealand": "x",
    "Category:Papua New Guinean expatriates in the Netherlands": "x",
    "Category:Papua New Guinean expatriates in the Solomon Islands": "x",
    "Category:Papua New Guinean expatriates in the United Kingdom": "x",
    "Category:Papua New Guinean expatriates in the United States": "x",
    "Category:Papua New Guinean expatriates in Wales": "x",
    "Category:Papua New Guinean farmers": "x",
    "Category:Papua New Guinean fashion designers": "x",
    "Category:Papua New Guinean female bowls players": "x",
    "Category:Papua New Guinean female freestyle swimmers": "x",
    "Category:Papua New Guinean female martial artists": "x",
    "Category:Papua New Guinean female rugby league players": "x",
    "Category:Papua New Guinean female rugby union players": "x",
    "Category:Papua New Guinean female sailors (sport)": "x",
    "Category:Papua New Guinean female swimmers": "x",
    "Category:Papua New Guinean female taekwondo practitioners": "x",
    "Category:Papua New Guinean female tennis players": "x",
    "Category:Papua New Guinean female weightlifters": "x",
    "Category:Papua New Guinean football biography stubs": "x",
    "Category:Papua New Guinean football managers": "x",
    "Category:Papua New Guinean gospel singers": "x",
    "Category:Papua New Guinean heptathletes": "x",
    "Category:Papua New Guinean high jumpers": "x",
    "Category:Papua New Guinean historians": "x",
    "Category:Papua New Guinean hurdlers": "x",
    "Category:Papua New Guinean javelin throwers": "x",
    "Category:Papua New Guinean journalists": "x",
    "Category:Papua New Guinean judges": "x",
    "Category:Papua New Guinean judges on the courts of Fiji": "x",
    "Category:Papua New Guinean judoka": "x",
    "Category:Papua New Guinean knights": "x",
    "Category:Papua New Guinean Knights Bachelor": "x",
    "Category:Papua New Guinean Knights Commander of the Order of St Michael and St George": "x",
    "Category:Papua New Guinean Knights Commander of the Order of the British Empire": "x",
    "Category:Papua New Guinean lawyers": "x",
    "Category:Papua New Guinean librarians": "x",
    "Category:Papua New Guinean literature": "x",
    "Category:Papua New Guinean long jumpers": "x",
    "Category:Papua New Guinean long-distance runners": "x",
    "Category:Papua New Guinean male bowls players": "x",
    "Category:Papua New Guinean male boxers": "x",
    "Category:Papua New Guinean male judoka": "x",
    "Category:Papua New Guinean male martial artists": "x",
    "Category:Papua New Guinean male sailors (sport)": "x",
    "Category:Papua New Guinean male sport shooters": "x",
    "Category:Papua New Guinean male swimmers": "x",
    "Category:Papua New Guinean male taekwondo practitioners": "x",
    "Category:Papua New Guinean male weightlifters": "x",
    "Category:Papua New Guinean marathon runners": "x",
    "Category:Papua New Guinean martial artists": "x",
    "Category:Papua New Guinean mass media people": "x",
    "Category:Papua New Guinean media personalities": "x",
    "Category:Papua New Guinean members of the Privy Council of the United Kingdom": "x",
    "Category:Papua New Guinean men": "x",
    "Category:Papua New Guinean men athletes": "x",
    "Category:Papua New Guinean men hurdlers": "x",
    "Category:Papua New Guinean men javelin throwers": "x",
    "Category:Papua New Guinean men long-distance runners": "x",
    "Category:Papua New Guinean men marathon runners": "x",
    "Category:Papua New Guinean men middle-distance runners": "x",
    "Category:Papua New Guinean men sprinters": "x",
    "Category:Papua New Guinean men's basketball players": "x",
    "Category:Papua New Guinean men's soccer players": "x",
    "Category:Papua New Guinean middle-distance runners": "x",
    "Category:Papua New Guinean military personnel": "x",
    "Category:Papua New Guinean miners": "x",
    "Category:Papua New Guinean missionaries": "x",
    "Category:Papua New Guinean murder victims": "x",
    "Category:Papua New Guinean murderers": "x",
    "Category:Papua New Guinean musical instruments": "x",
    "Category:Papua New Guinean musicians": "x",
    "Category:Papua New Guinean mythology": "x",
    "Category:Papua New Guinean netball players": "x",
    "Category:Papua New Guinean newspaper editors": "x",
    "Category:Papua New Guinean novelists": "x",
    "Category:Papua New Guinean officials of the United Nations": "x",
    "Category:Papua New Guinean One Day International cricket umpires": "x",
    "Category:Papua New Guinean painters": "x",
    "Category:Papua New Guinean para-badminton players": "x",
    "Category:Papua New Guinean people": "x",
    "Category:Papua New Guinean people by descent": "x",
    "Category:Papua New Guinean people by occupation": "x",
    "Category:Papua New Guinean people by political orientation": "x",
    "Category:Papua New Guinean people by province": "x",
    "Category:Papua New Guinean people by region": "x",
    "Category:Papua New Guinean people by religion": "x",
    "Category:Papua New Guinean people in sports": "x",
    "Category:Papua New Guinean people of Asian descent": "x",
    "Category:Papua New Guinean people of Australian descent": "x",
    "Category:Papua New Guinean people of Austrian descent": "x",
    "Category:Papua New Guinean people of British descent": "x",
    "Category:Papua New Guinean people of Chinese descent": "x",
    "Category:Papua New Guinean people of Cypriot descent": "x",
    "Category:Papua New Guinean people of English descent": "x",
    "Category:Papua New Guinean people of European descent": "x",
    "Category:Papua New Guinean people of Filipino descent": "x",
    "Category:Papua New Guinean people of German descent": "x",
    "Category:Papua New Guinean people of Greek Cypriot descent": "x",
    "Category:Papua New Guinean people of Greek descent": "x",
    "Category:Papua New Guinean people of Irish descent": "x",
    "Category:Papua New Guinean people of Japanese descent": "x",
    "Category:Papua New Guinean people of Lithuanian descent": "x",
    "Category:Papua New Guinean people of Malaysian descent": "x",
    "Category:Papua New Guinean people of Oceanian descent": "x",
    "Category:Papua New Guinean people of Sri Lankan descent": "x",
    "Category:Papua New Guinean people of Tongan descent": "x",
    "Category:Papua New Guinean people of Welsh descent": "x",
    "Category:Papua New Guinean people stubs": "x",
    "Category:Papua New Guinean people with disabilities": "x",
    "Category:Papua New Guinean philosophers": "x",
    "Category:Papua New Guinean physicians": "x",
    "Category:Papua New Guinean players of Australian rules football": "x",
    "Category:Papua New Guinean poets": "x",
    "Category:Papua New Guinean police officers": "x",
    "Category:Papua New Guinean political people": "x",
    "Category:Papua New Guinean politicians": "x",
    "Category:Papua New Guinean politicians by party": "x",
    "Category:Papua New Guinean politicians of Chinese descent": "x",
    "Category:Papua New Guinean prisoners and detainees": "x",
    "Category:Papua New Guinean prisoners sentenced to death": "x",
    "Category:Papua New Guinean Protestant missionaries": "x",
    "Category:Papua New Guinean Protestants": "x",
    "Category:Papua New Guinean radio people": "x",
    "Category:Papua New Guinean radio personalities": "x",
    "Category:Papua New Guinean recipients of British honours": "x",
    "Category:Papua New Guinean recipients of British titles": "x",
    "Category:Papua New Guinean recipients of the British Empire Medal": "x",
    "Category:Papua New Guinean records": "x",
    "Category:Papua New Guinean referees and umpires": "x",
    "Category:Papua New Guinean religious leaders": "x",
    "Category:Papua New Guinean Roman Catholic archbishops": "x",
    "Category:Papua New Guinean Roman Catholic bishops": "x",
    "Category:Papua New Guinean Roman Catholic priests": "x",
    "Category:Papua New Guinean Roman Catholics": "x",
    "Category:Papua New Guinean rugby league administrators": "x",
    "Category:Papua New Guinean rugby league coaches": "x",
    "Category:Papua New Guinean rugby league players": "x",
    "Category:Papua New Guinean rugby league players by province": "x",
    "Category:Papua New Guinean rugby league seasons": "x",
    "Category:Papua New Guinean rugby union players": "x",
    "Category:Papua New Guinean runners": "x",
    "Category:Papua New Guinean sailors (sport)": "x",
    "Category:Papua New Guinean schoolteachers": "x",
    "Category:Papua New Guinean scientists": "x",
    "Category:Papua New Guinean Seventh-day Adventists": "x",
    "Category:Papua New Guinean shot putters": "x",
    "Category:Papua New Guinean singers": "x",
    "Category:Papua New Guinean soccer logos": "x",
    "Category:Papua New Guinean soccer players": "x",
    "Category:Papua New Guinean soccer referees": "x",
    "Category:Papua New Guinean social democrats": "x",
    "Category:Papua New Guinean social workers": "x",
    "Category:Papua New Guinean sport by decade": "x",
    "Category:Papua New Guinean sport by year": "x",
    "Category:Papua New Guinean sport shooters": "x",
    "Category:Papua New Guinean sport stubs": "x",
    "Category:Papua New Guinean sports coaches": "x",
    "Category:Papua New Guinean sportsmen": "x",
    "Category:Papua New Guinean sportspeople": "x",
    "Category:Papua New Guinean sportspeople by province": "x",
    "Category:Papua New Guinean sportspeople by sport": "x",
    "Category:Papua New Guinean sportspeople stubs": "x",
    "Category:Papua New Guinean sportsperson-politicians": "x",
    "Category:Papua New Guinean sportswomen": "x",
    "Category:Papua New Guinean sprinters": "x",
    "Category:Papua New Guinean steeplechase runners": "x",
    "Category:Papua New Guinean swimmers": "x",
    "Category:Papua New Guinean taekwondo practitioners": "x",
    "Category:Papua New Guinean television series": "x",
    "Category:Papua New Guinean television series by century": "x",
    "Category:Papua New Guinean television series by decade": "x",
    "Category:Papua New Guinean television shows": "x",
    "Category:Papua New Guinean tennis players": "x",
    "Category:Papua New Guinean theatre people": "x",
    "Category:Papua New Guinean trade unionists": "x",
    "Category:Papua New Guinean triple jumpers": "x",
    "Category:Papua New Guinean Twenty20 International cricket umpires": "x",
    "Category:Papua New Guinean victims of crime": "x",
    "Category:Papua New Guinean weightlifters": "x",
    "Category:Papua New Guinean Wikipedians": "x",
    "Category:Papua New Guinean women": "x",
    "Category:Papua New Guinean women academics": "x",
    "Category:Papua New Guinean women activists": "x",
    "Category:Papua New Guinean women artists": "x",
    "Category:Papua New Guinean women athletes": "x",
    "Category:Papua New Guinean women by occupation": "x",
    "Category:Papua New Guinean women civil servants": "x",
    "Category:Papua New Guinean women cricketers": "x",
    "Category:Papua New Guinean women diplomats": "x",
    "Category:Papua New Guinean women environmentalists": "x",
    "Category:Papua New Guinean women fashion designers": "x",
    "Category:Papua New Guinean women hurdlers": "x",
    "Category:Papua New Guinean women in politics": "x",
    "Category:Papua New Guinean women javelin throwers": "x",
    "Category:Papua New Guinean women lawyers": "x",
    "Category:Papua New Guinean women long-distance runners": "x",
    "Category:Papua New Guinean women middle-distance runners": "x",
    "Category:Papua New Guinean women runners": "x",
    "Category:Papua New Guinean women scientists": "x",
    "Category:Papua New Guinean women shot putters": "x",
    "Category:Papua New Guinean women sprinters": "x",
    "Category:Papua New Guinean women writers": "x",
    "Category:Papua New Guinean women's basketball players": "x",
    "Category:Papua New Guinean women's rights activists": "x",
    "Category:Papua New Guinean women's soccer players": "x",
    "Category:Papua New Guinean writers": "x",
    "Category:People of Papua New Guinean descent": "x",
    "Category:Reggae albums by Papua New Guinean artists": "x",
    "Category:Seasons in Papua New Guinean soccer": "x",
    "Category:Seasons in Papua New Guinean sport": "x",
    "Category:Surnames of Papua New Guinean origin": "x",
    "Category:Works by Papua New Guinean people": "x",
}
to_test = [
    ("test_papua_new_guinean_0", data_0),
    ("test_papua_new_guinean_1", data_1),
]


@pytest.mark.parametrize("category, expected", data_0.items(), ids=data_0.keys())
@pytest.mark.skip2
def test_papua_new_guinean_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.skip2
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
