"""
Tests
"""

import pytest

from ArWikiCats import resolve_label_ar

fix_title_all = False


test_historic = {
    "railway stations on national-register-of-historic-places": "محطات السكك الحديدية في السجل الوطني للأماكن التاريخية",
    "residential buildings on national-register-of-historic-places": "مبان سكنية في السجل الوطني للأماكن التاريخية",
    "opera houses on national-register-of-historic-places": "دور أوبرا في السجل الوطني للأماكن التاريخية",
    "military facilities on national-register-of-historic-places": "مرافق عسكرية في السجل الوطني للأماكن التاريخية",
    "museums on national-register-of-historic-places": "متاحف في السجل الوطني للأماكن التاريخية",
    "fire stations on national-register-of-historic-places": "محطات الإطفاء في السجل الوطني للأماكن التاريخية",
    "forts on national-register-of-historic-places": "حصون في السجل الوطني للأماكن التاريخية",
    "houses on national-register-of-historic-places": "منازل في السجل الوطني للأماكن التاريخية",
    "cemeteries on national-register-of-historic-places": "مقابر في السجل الوطني للأماكن التاريخية",
    "buildings and structures on national-register-of-historic-places": "مبان ومنشآت في السجل الوطني للأماكن التاريخية",
    "bank buildings on national-register-of-historic-places": "مباني بنوك في السجل الوطني للأماكن التاريخية",
    "archaeological sites on national-register-of-historic-places": "مواقع أثرية في السجل الوطني للأماكن التاريخية",
    "agricultural buildings and structures on national-register-of-historic-places": "مبان ومنشآت زراعية في السجل الوطني للأماكن التاريخية",
    "clubhouses on national-register-of-historic-places": "نوادي في السجل الوطني للأماكن التاريخية",
    "courthouses on national-register-of-historic-places": "محاكم في السجل الوطني للأماكن التاريخية",
}

data_fast = {
    "kingdom-of italy": "مملكة إيطاليا",
    "11th century": "القرن 11",
    "12th century": "القرن 12",
    "1330 by country": "1330 حسب البلد",
    "1330 elections in united states": "انتخابات 1330 في الولايات المتحدة",
    "1330 in canada": "كندا في 1330",
    "1330 in china": "الصين في 1330",
    "1330 in football": "كرة القدم في 1330",
    "1330 in men's football": "كرة القدم للرجال في 1330",
    "1330 in north america": "أمريكا الشمالية في 1330",
    "1330 in rugby union": "اتحاد الرجبي في 1330",
    "1330 in south american football": "كرة القدم الأمريكية الجنوبية في 1330",
    "1330 in sports": "ألعاب رياضية في 1330",
    "1330 in taiwan": "تايوان في 1330",
    "1330 in television": "التلفاز في 1330",
    "1330 in united states": "الولايات المتحدة في 1330",
    "1330 in yemen": "اليمن في 1330",
    "1330 in youth football": "كرة القدم للشباب في 1330",
    "1330s in united states": "الولايات المتحدة في عقد 1330",
    "24th century": "القرن 24",
    "actors by religion": "ممثلون حسب الدين",
    "air force": "قوات جوية",
    "al bayda governorate": "محافظة البيضاء (اليمن)",
    "al rayyan": "الريان",
    "alabama politicians": "سياسيو ألاباما",
    "alvark tokyo": "تويوتا ألفارك طوكيو",
    "amateur football competitions": "منافسات كرة قدم للهواة",
    "ambassadors of afghanistan": "سفراء أفغانستان",
    "ambassadors of algeria": "سفراء الجزائر",
    "ambassadors to ottoman empire": "سفراء لدى الدولة العثمانية",
    "american television series basedon british television series": "مسلسلات تلفزيونية أمريكية مبنية على مسلسلات تلفزيونية بريطانية",
    "april 1330": "أبريل 1330",
    "archaeological sites on national-register-of-historic-places": "مواقع أثرية في السجل الوطني للأماكن التاريخية",
    "architecture in israel": "هندسة معمارية في إسرائيل",
    "armenia–colombia relations": "العلاقات الأرمينية الكولومبية",
    "asian football by country": "كرة القدم الآسيوية حسب البلد",
    "athletics competitions": "منافسات ألعاب قوى",
    "attacks on barracks": "هجمات على ثكنات",
    "attacks on buildings and structures": "هجمات على مبان ومنشآت",
    "attacks on diplomatic missions": "هجمات على بعثات دبلوماسية",
    "attacks on hospitals": "هجمات على مستشفيات",
    "attacks on malacañang palace": "هجمات على قصر مالاكانانغ",
    "august 1330": "أغسطس 1330",
    "australia by century": "أستراليا حسب القرن",
    "australian rules football clubs": "أندية كرة قدم أسترالية",
    "austria by decade": "النمسا حسب العقد",
    "badminton venues": "ملاعب تنس ريشة",
    "bahamas–ivory coast relations": "العلاقات الإيفوارية البهامية",
    "bahrain–netherlands relations": "العلاقات البحرينية الهولندية",
    "balakan district": "مقاطعة بالاكن",
    "bangladesh–iraq relations": "العلاقات البنغلاديشية العراقية",
    "bank of korea": "بنك كوريا",
    "barracks in spain": "ثكنات في إسبانيا",
}

data_slow = {
    "people from santa fe province": "أشخاص من محافظة سانتا في",
    # "presidents of greece": "رؤساء اليونان",
    # "presidents of maldives": "رؤساء جزر المالديف",
    "bas-sassandra district": "مقاطعة باس-ساساندرا",
    "baseball players from maine": "لاعبو كرة قاعدة من مين",
    "basketball competitions": "منافسات كرة سلة",
    "basketball people": "أعلام كرة سلة",
    "belgium by decade": "بلجيكا حسب العقد",
    "belgium–czechoslovakia relations": "العلاقات البلجيكية التشيكوسلوفاكية",
    "books about automobiles": "كتب عن سيارات",
    "books about politics": "كتب عن سياسة",
    "boxing competitions": "منافسات بوكسينغ",
    "brain cancer in south korea": "سرطان الدماغ في كوريا الجنوبية",
    "brazilian comics adapted into films": "قصص مصورة برازيلية تم تحويلها إلى أفلام",
    "bridges in wales": "جسور في ويلز",
    "british emigrants to switzerland": "بريطانيون مهاجرون إلى سويسرا",
    "british emigrants to zimbabwe": "بريطانيون مهاجرون إلى زيمبابوي",
    "british television series characters by series": "شخصيات مسلسلات تلفزيونية بريطانية حسب السلسلة",
    "buildings and structures in 1330": "مبان ومنشآت في 1330",
    "buildings and structures in australia": "مبان ومنشآت في أستراليا",
    "buildings and structures in chile": "مبان ومنشآت في تشيلي",
    "buildings and structures in florida": "مبان ومنشآت في فلوريدا",
    "buildings and structures in quebec": "مبان ومنشآت في كيبك",
    "buildings and structures in united arab emirates": "مبان ومنشآت في الإمارات العربية المتحدة",
    "buildings and structures in united states": "مبان ومنشآت في الولايات المتحدة",
    "buildings and structures in veneto": "مبان ومنشآت في فينيتو",
    "bulgaria–qatar relations": "العلاقات البلغارية القطرية",
    "burials in amsterdam": "مدفونون في أمستردام",
    "by city in afghanistan": "حسب المدينة في أفغانستان",
    "by city in jharkhand": "حسب المدينة في جهارخاند",
    "by instrument from northern ireland": "حسب الآلة من أيرلندا الشمالية",
    "by period by state": "حسب الحقبة حسب الولاية",
    "by person in alabama": "حسب الشخص في ألاباما",
    "by person in austria": "حسب الشخص في النمسا",
    "by person in tonga": "حسب الشخص في تونغا",
    "by province of saudi arabia": "حسب المقاطعة في السعودية",
    "by stabbing in philippines": "بالطعن في الفلبين",
    "by state in united states": "حسب الولاية في الولايات المتحدة",
    "by university or college in ghana": "حسب الجامعة أو الكلية في غانا",
    "cabinet of philippines": "مجلس وزراء الفلبين",
    "campeonato paraibano": "بطولة بارايبانو",
    "canada by city": "كندا حسب المدينة",
    "canada by month": "كندا حسب الشهر",
    "canada–gabon relations": "العلاقات الغابونية الكندية",
    "cancer in hungary": "السرطان في المجر",
    "cancer in philippines": "السرطان في الفلبين",
    "cancer in singapore": "السرطان في سنغافورة",
    "canoeing and kayaking competitions": "منافسات كانو-كاياك",
    "cape verde": "الرأس الأخضر",
    "categories of haryana": "تصنيفات في هاريانا",
    "caves in india": "كهوف في الهند",
    "cemeteries on national-register-of-historic-places": "مقابر في السجل الوطني للأماكن التاريخية",
    "centuries in united states": "قرون في الولايات المتحدة",
    "china by month": "الصين حسب الشهر",
    "chinese emigrants to thailand": "صينيون مهاجرون إلى تايلاند",
    "christina aguilera video albums": "ألبومات فيديو كريستينا أغيليرا",
    "churches in france": "كنائس في فرنسا",
    "churches in nicaragua": "كنائس في نيكاراغوا",
    "colombia–united states relations": "العلاقات الأمريكية الكولومبية",
    "comics adapted into films": "قصص مصورة تم تحويلها إلى أفلام",
    "comics basedon films": "قصص مصورة مبنية على أفلام",
    "commonwealth games weightlifters for england": "رباعون في ألعاب الكومنولث في إنجلترا",
    "communications in united states": "الاتصالات في الولايات المتحدة",
    "companies of bahamas": "شركات في باهاماس",
    "constructivism (art)": "بنائية (فنون)",
    "county longford": "مقاطعة لونجفورد",
    "cricket clubs": "أندية كريكت",
    "crimes in belgium": "جرائم في بلجيكا",
    "crimes in united states": "جرائم في الولايات المتحدة",
    "croatian emigrants to netherlands": "كروات مهاجرون إلى هولندا",
    "cycling clubs": "أندية سباق دراجات هوائية",
    "cypriot emigrants to israel": "قبرصيون مهاجرون إلى إسرائيل",
    "deaths from covid-19 pandemic": "وفيات من جائحة فيروس كورونا",
    "deaths from tuberculosis": "وفيات من السل",
    "decades in united states": "عقود في الولايات المتحدة",
    "december 1330": "ديسمبر 1330",
    "defunct football cup competitions": "منافسات كؤوس كرة قدم سابقة",
    "defunct ice hockey competitions": "منافسات هوكي جليد سابقة",
    "demographics of united states": "التركيبة السكانية في الولايات المتحدة",
    "denmark–vietnam relations": "العلاقات الدنماركية الفيتنامية",
    "disasters in united states": "كوارث في الولايات المتحدة",
    "disestablishments in australia": "انحلالات في أستراليا",
    "disestablishments in dominica": "انحلالات في دومينيكا",
    "disestablishments in new zealand": "انحلالات في نيوزيلندا",
    "disestablishments in ottoman empire": "انحلالات في الدولة العثمانية",
    "disestablishments in papua new guinea": "انحلالات في بابوا غينيا الجديدة",
    "disestablishments in spain": "انحلالات في إسبانيا",
    "documentaries about crime": "وثائقيات عن جريمة",
    "documentary films about federico fellini": "أفلام وثائقية عن فيديريكو فليني",
    "documentary films about south carolina": "أفلام وثائقية عن كارولاينا الجنوبية",
    "domestic football": "كرة قدم محلية",
    "dominica by year": "دومينيكا حسب السنة",
    "dukes in europe": "دوقات في أوروبا",
    "dutch basketball league by club": "الدوري الهولندي لكرة السلة حسب النادي",
    "economic history of united states": "تاريخ الولايات المتحدة الاقتصادي",
    "economy of united states": "اقتصاد الولايات المتحدة",
    "ecuador–guyana relations": "العلاقات الإكوادورية الغيانية",
    "ed sheeran albums": "ألبومات إد شيران",
    "education in france": "التعليم في فرنسا",
    "education in israel": "التعليم في إسرائيل",
    "education in united states": "التعليم في الولايات المتحدة",
    "elections in austria": "انتخابات في النمسا",
    "electro house remix albums": "ألبومات ريمكس إلكتروهاوس",
    "environment of united states": "بيئة الولايات المتحدة",
    "eritrea–ukraine relations": "العلاقات الأوكرانية الإريترية",
    "establishments in north macedonia": "تأسيسات في مقدونيا الشمالية",
    "establishments in republic-of venice": "تأسيسات في جمهورية البندقية",
    "establishments in sint maarten": "تأسيسات في سينت مارتن",
    "establishments in socialist republic-of macedonia": "تأسيسات في جمهورية مقدونيا الاشتراكية",
    "estonia–south sudan relations": "العلاقات الإستونية السودانية الجنوبية",
    "ethiopian basketball players": "لاعبو كرة سلة إثيوبيون",
    "euroleague by club": "الدوري الأوروبي لكرة السلة حسب النادي",
    "european games gold medalists for slovakia": "فائزون بميداليات ذهبية في الألعاب الأوروبية من سلوفاكيا",
    "european games medalists for poland": "فائزون بميداليات الألعاب الأوروبية من بولندا",
    "european rugby union by country": "اتحاد الرجبي الأوروبي حسب البلد",
    "executions in washington (state)": "إعدامات في ولاية واشنطن",
    "expatriate sports-people from northern ireland": "رياضيون مغتربون من أيرلندا الشمالية",
    "expatriates from georgia (country)": "مغتربون من جورجيا",
    "experimental music remix albums": "ألبومات ريمكس موسيقى تجريبية",
    "explosions in europe": "انفجارات في أوروبا",
    "fauna of africa": "حيوانات إفريقيا",
    "february 1330": "فبراير 1330",
    "figure skating films": "أفلام تزلج فني",
    "figure skating media": "إعلام تزلج فني",
    "figure skating people": "أعلام تزلج فني",
    "figure skating": "التزلج الفني",
    "films about automobiles": "أفلام عن سيارات",
    "films about chinese canadians": "أفلام عن صينيون كنديون",
    "films about higher education": "أفلام عن تعليم عال",
    "films about lizards": "أفلام عن سحالي",
    "films about olympic boxing": "أفلام عن بوكسينغ أولمبي",
    "films about olympic figure skating": "أفلام عن تزلج فني أولمبي",
    "films about olympic games": "أفلام عن الألعاب الأولمبية",
    "films about olympic gymnastics": "أفلام عن جمباز أولمبي",
    "films about olympic skiing": "أفلام عن تزلج أولمبي",
    "films about olympic track and field": "أفلام عن سباقات مضمار وميدان أولمبي",
    "films about weather": "أفلام عن الطقس",
    "films basedon american comics": "أفلام مبنية على قصص مصورة أمريكية",
    "films basedon comics": "أفلام مبنية على قصص مصورة",
    "films basedon television series": "أفلام مبنية على مسلسلات تلفزيونية",
    "films basedon works": "أفلام مبنية على أعمال",
    "films in yemen": "أفلام في اليمن",
    "finland–united states relations": "العلاقات الأمريكية الفنلندية",
    "fire stations on national-register-of-historic-places": "محطات الإطفاء في السجل الوطني للأماكن التاريخية",
    "football by country": "كرة القدم حسب البلد",
    "football cup competitions in england": "منافسات كؤوس كرة قدم في إنجلترا",
    "football cup competitions": "منافسات كؤوس كرة قدم",
    "football people": "أعلام كرة قدم",
    "football players by national team": "لاعبو كرة قدم حسب المنتخب الوطني",
    "forts in united states": "حصون في الولايات المتحدة",
    "forts on national-register-of-historic-places": "حصون في السجل الوطني للأماكن التاريخية",
    "gaelic football competitions": "منافسات كرة قدم غالية",
    "gaelic football": "كرة القدم الغالية",
    "gaelic footballers in county kildare": "لاعبو كرة قدم غيلية في مقاطعة كيلدير",
    "geography of tokyo": "جغرافيا طوكيو",
    "geography of united states": "جغرافيا الولايات المتحدة",
    "georgia (u.s. state)": "ولاية جورجيا",
    "german emigrants to scotland": "ألمان مهاجرون إلى إسكتلندا",
    "german footballers": "لاعبو كرة قدم ألمان",
    "german novels of 20th century": "روايات ألمانية في القرن 20",
    "golf in united states": "الغولف في الولايات المتحدة",
    "government ministers of azerbaijan": "وزراء أذربيجان",
    "great britain": "بريطانيا العظمى",
    "gymnastics competitions": "منافسات جمباز",
    "gymnastics organizations": "منظمات جمباز",
    "handball competitions": "منافسات كرة يد",
    "heads of schools": "قادة مدارس",
    "heads of universities and colleges": "قادة جامعات وكليات",
    "health in united states": "الصحة في الولايات المتحدة",
    "heavy metal video albums": "ألبومات فيديو هيفي ميتال",
    "high schools in illinois": "مدارس ثانوية في إلينوي",
    "hindu temples in andhra pradesh": "معابد هندوسية في أندرا برديش",
    "historic sites in united states": "مواقع تاريخية في الولايات المتحدة",
    "historic trails and roads in united states": "طرق وممرات تاريخية في الولايات المتحدة",
    "history books about printing": "كتب تاريخ عن طباعة",
    "history of american revolution": "تاريخ الثورة الأمريكية",
    "history of caribbean": "تاريخ الكاريبي",
    "history of human rights": "تاريخ حقوق الإنسان",
    "history of united states": "تاريخ الولايات المتحدة",
    "history of women": "تاريخ المرأة",
    "hospitals in uganda": "مستشفيات في أوغندا",
    "houses on national-register-of-historic-places": "منازل في السجل الوطني للأماكن التاريخية",
    "hungarian people imprisoned-in germany": "مجريون مسجونون في ألمانيا",
    "ice hockey people": "أعلام هوكي جليد",
    "ice skating": "تزلج على الجليد",
    "icelandic emigrants to new zealand": "آيسلنديون مهاجرون إلى نيوزيلندا",
    "images of united states": "صور من الولايات المتحدة",
    "immigrants to american samoa": "مهاجرون إلى ساموا الأمريكية",
    "immigrants to new zealand": "مهاجرون إلى نيوزيلندا",
    "immigration to new zealand": "الهجرة إلى نيوزيلندا",
    "indian cricketers": "لاعبو كريكت هنود",
    "insular areas of united states": "المناطق المعزولة في الولايات المتحدة",
    "international aquatics competitions": "منافسات رياضات مائية دولية",
    "international athletics competitions": "منافسات ألعاب قوى دولية",
    "international baseball competitions": "منافسات كرة قاعدة دولية",
    "international field hockey competitions in africa": "منافسات هوكي ميدان دولية في إفريقيا",
    "international field hockey competitions": "منافسات هوكي ميدان دولية",
    "international football": "كرة قدم دولية",
    "international schools in united arab emirates": "مدارس دولية في الإمارات العربية المتحدة",
    "international women's basketball competitions": "منافسات كرة سلة دولية للسيدات",
    "iowa territory": "إقليم آيوا",
    "islands of greece": "جزر اليونان",
    "italian defectors to soviet union": "إيطاليون منشقون إلى الاتحاد السوفيتي",
    "italian emigrants to finland": "إيطاليون مهاجرون إلى فنلندا",
    "italy–liechtenstein relations": "العلاقات الإيطالية الليختنشتانية",
    "january 1330": "يناير 1330",
    "japan–switzerland relations": "العلاقات السويسرية اليابانية",
    "jews from ottoman empire": "يهود من الدولة العثمانية",
    "july 1330": "يوليو 1330",
    "june 1330": "يونيو 1330",
    "kansas house-of-representatives": "مجلس نواب ولاية كانساس",
    "kentucky ballot measures": "إجراءات اقتراع كنتاكي",
    "kingdom-of italy": "مملكة إيطاليا",
    "kingdom-of sicily": "مملكة صقلية",
    "kings of italy": "ملوك إيطاليا",
    "kosovan victims of crime": "ضحايا جرائم كوسوفيون",
    "kuwait–turkey relations": "العلاقات التركية الكويتية",
    "kütahya province": "محافظة كوتاهية",
    "landmarks in united states": "معالم في الولايات المتحدة",
    "las vegas": "لاس فيغاس (نيفادا)",
    "latvia–uruguay relations": "العلاقات الأوروغويانية اللاتفية",
    "law about religion": "قانون عن الدين",
    "lawn bowls": "البولينغ العشبي",
    "learned societies of china": "جمعيات علمية في الصين",
    "legal events": "أحداث قانونية",
    "legal history of united states": "تاريخ الولايات المتحدة القانوني",
    "liechtenstein football": "كرة القدم الليختنشتانية",
    "lists of 1330 films": "قوائم أفلام في 1330",
    "lists of british television series characters": "قوائم شخصيات مسلسلات تلفزيونية بريطانية",
    "lists of buildings and structures": "قوائم مبان ومنشآت",
    "lists of caves": "قوائم كهوف",
    "lists of countries": "قوائم بلدان",
    "lists of football players": "قوائم لاعبو كرة قدم",
    "lists of german people": "قوائم ألمان",
    "lists of mayors of places": "قوائم رؤساء بلديات",
    "lists of schools": "قوائم مدارس",
    "lists of television characters": "قوائم شخصيات تلفزيونية",
    "lists of tourist attractions": "قوائم مواقع جذب سياحي",
    "lists of universities and colleges": "قوائم جامعات وكليات",
    "loire valley": "وادي اللوار",
    "mackinac island": "جزيرة ماكيناك",
    "mahasamund district": "مقاطعة مهاساموند",
    "malaysia in fiction": "ماليزيا في الخيال",
    "malaysia in summer olympics": "ماليزيا في الألعاب الأولمبية الصيفية",
    "manufacturing in united states": "تصنيع في الولايات المتحدة",
    "marathi films remade-in other languages": "أفلام باللغة الماراثية أعيد إنتاجها في لغات أخرى",
    "march 1330": "مارس 1330",
    "martial arts": "الفنون القتالية",
    "mass shootings in europe": "إطلاق نار عشوائي في أوروبا",
    "massachusetts know nothings": "أعضاء حزب لا أدري في ماساتشوستس",
    "matn district": "قضاء المتن",
    "may 1330": "مايو 1330",
    "mayors of places in alabama": "رؤساء بلديات في ألاباما",
    "mayors of places in estonia": "رؤساء بلديات في إستونيا",
    "mayors of places in new jersey": "رؤساء بلديات في نيوجيرسي",
    "mecha anime and manga": "أنمي ميكا",
    "medley swimming": "سباحة متنوعة",
    "members of pan-african parliament": "أعضاء البرلمان الإفريقي",
    "men in united states": "رجال في الولايات المتحدة",
    "men's basketball": "كرة السلة للرجال",
    "men's football by continent": "كرة القدم للرجال حسب القارة",
    "men's football competitions": "منافسات كرة قدم رجالية",
    "men's football": "كرة القدم للرجال",
    "men's footballers in djibouti": "لاعبو كرة قدم في جيبوتي",
    "men's footballers in montenegro": "لاعبو كرة قدم في الجبل الأسود",
    "men's soccer": "كرة القدم للرجال",
    "michigan legislature": "هيئة ميشيغان التشريعية",
    "michigan territory": "إقليم ميشيغان",
    "mike & molly": "مايك ومولي",
    "military alliances involving algeria": "تحالفات عسكرية تشمل الجزائر",
    "military history of africa": "تاريخ إفريقيا العسكري",
    "military history of croatia": "تاريخ كرواتيا العسكري",
    "military history of united states": "تاريخ الولايات المتحدة العسكري",
    "military pentathlon": "خماسي عسكرية",
    "mississippi territory": "إقليم مسيسيبي",
    "mixed martial arts": "فنون القتال المختلطة",
    "moldova–south korea relations": "العلاقات الكورية الجنوبية المولدوفية",
    "monmouth university": "جامعة مونموث",
    "moose jaw": "موسجاو",
    "motorsport competitions": "منافسات رياضة محركات",
    "mountains of greece": "جبال اليونان",
    "muay thai": "موياي تاي",
    "murders by country": "جرائم قتل حسب البلد",
    "murders in asia": "جرائم قتل في آسيا",
    "murders in belarus": "جرائم قتل في روسيا البيضاء",
    "murders in iraq": "جرائم قتل في العراق",
    "murders in philippines": "جرائم قتل في الفلبين",
    "murders in republic-of ireland": "جرائم قتل في جمهورية أيرلندا",
    "murders in south africa": "جرائم قتل في جنوب إفريقيا",
    "murders in spain": "جرائم قتل في إسبانيا",
    "murders in united kingdom": "جرائم قتل في المملكة المتحدة",
    "museums in north carolina": "متاحف في كارولاينا الشمالية",
    "museums of ancient greece": "متاحف في اليونان القديمة",
    "museums of ancient rome": "متاحف في روما القديمة",
    "museums on national-register-of-historic-places": "متاحف في السجل الوطني للأماكن التاريخية",
    "music of jean sibelius": "موسيقى جان سيبيليوس",
    "nascar races": "سباقات ناسكار",
    "national cricket teams": "منتخبات كريكت وطنية",
    "national wheelchair rugby league teams": "منتخبات دوري رجبي على كراسي متحركة وطنية",
    "nature reserves in united states": "محميات طبيعية في الولايات المتحدة",
    "naval battles involving united states": "معارك بحرية تشمل الولايات المتحدة",
    "navoiy region": "ولاية نواوي",
    "nazis sentenced to death": "نازيون حكم عليهم بالإعدام",
    "nba season by team": "الدوري الأمريكي لكرة السلة للمحترفين حسب الفريق",
    "new hampshire": "نيوهامشير",
    "new jersey": "نيوجيرسي",
    "new mexico": "نيومكسيكو",
    "new york (state)": "ولاية نيويورك",
    "new zealand by decade": "نيوزيلندا حسب العقد",
    "nobility from holy roman empire": "نبلاء من الإمبراطورية الرومانية المقدسة",
    "nordic combined": "التزلج النوردي المزدوج",
    "north america by month": "أمريكا الشمالية حسب الشهر",
    "north carolina": "كارولاينا الشمالية",
    "north dakota": "داكوتا الشمالية",
    "north macedonia by century": "مقدونيا الشمالية حسب القرن",
    "northern ireland of canadian descent": "أيرلندا الشمالية من أصل كندي",
    "november 1330": "نوفمبر 1330",
    "october 1330": "أكتوبر 1330",
    "olympic archers for jordan": "نبالون أولمبيون في الأردن",
    "olympic biathletes for lithuania": "لاعبو بياثلون أولمبيون في ليتوانيا",
    "olympic boxers for australia": "ملاكمون أولمبيون في أستراليا",
    "olympic competitors for cape verde": "منافسون أولمبيون من الرأس الأخضر",
    "olympic competitors for guam": "منافسون أولمبيون من غوام",
    "olympic equestrians for cambodia": "فرسان خيول أولمبيون في كمبوديا",
    "olympic fencers for china": "مبارزون أولمبيون في الصين",
    "olympic figure skating": "تزلج فني أولمبي",
    "olympic gold medalists for south africa": "فائزون بميداليات ذهبية أولمبية من جنوب إفريقيا",
    "olympic gold medalists for united states": "فائزون بميداليات ذهبية أولمبية من الولايات المتحدة",
    "olympic ice hockey players for belgium": "لاعبو هوكي جليد أولمبيون في بلجيكا",
    "olympic judoka for italy": "لاعبو جودو أولمبيون في إيطاليا",
    "olympic medalists for united states": "فائزون بميداليات أولمبية من الولايات المتحدة",
    "olympic medalists": "فائزون بميداليات أولمبية",
    "olympic skeleton racers for great britain": "متزلجون صدريون أولمبيون في بريطانيا العظمى",
    "olympic swimming": "سباحة أولمبية",
    "olympic wheelchair racers for australia": "متسابقو كراسي متحركة أولمبيون في أستراليا",
    "olympic wheelchair racers for canada": "متسابقو كراسي متحركة أولمبيون في كندا",
    "organizations based in overseas france": "منظمات مقرها في مقاطعات وأقاليم ما وراء البحار الفرنسية",
    "organizations based in turks and caicos islands": "منظمات مقرها في جزر توركس وكايكوس",
    "ottoman–persian wars": "الحروب العثمانية الفارسية",
    "painters from holy roman empire": "رسامون من الإمبراطورية الرومانية المقدسة",
    "pan american games medalists for bermuda": "فائزون بميداليات دورة الألعاب الأمريكية من برمودا",
    "pan american games medalists for guyana": "فائزون بميداليات دورة الألعاب الأمريكية من غيانا",
    "pan american games medalists": "فائزون بميداليات دورة الألعاب الأمريكية",
    "pan american games swimmers for brazil": "سباحون في دورة الألعاب الأمريكية في البرازيل",
    "pan-african democratic party politicians": "سياسيو الحزب الديمقراطي الوحدوي الإفريقي",
    "pan-african parliament": "البرلمان الإفريقي",
    "pan-africanist political parties": "أحزاب سياسية وحدوية إفريقية",
    "papua new guinea by year": "بابوا غينيا الجديدة حسب السنة",
    "paralympic athletes for colombia": "لاعبو قوى في الألعاب البارالمبية في كولومبيا",
    "paralympic judoka for uzbekistan": "لاعبو جودو في الألعاب البارالمبية في أوزبكستان",
    "paralympic medalists for serbia": "فائزون بميداليات الألعاب البارالمبية من صربيا",
    "paralympic medalists": "فائزون بميداليات الألعاب البارالمبية",
    "paralympic wheelchair basketball players for australia": "لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في أستراليا",
    "paralympic wheelchair basketball players for canada": "لاعبو كرة سلة على كراسي متحركة في الألعاب البارالمبية في كندا",
    "paralympic wheelchair rugby players for new zealand": "لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية في نيوزيلندا",
    "paralympic wheelchair rugby players for united states": "لاعبو رجبي على كراسي متحركة في الألعاب البارالمبية في الولايات المتحدة",
    "parapan american games medalists": "فائزون بميداليات ألعاب بارابان الأمريكية",
    "parliament for loiret": "برلمان في لواريت (إقليم فرنسي)",
    "parliament of england 1330": "برلمان إنجلترا 1330",
    "parliament of united kingdom": "برلمان المملكة المتحدة",
    "people by religion": "أشخاص حسب الدين",
    "people from asturias": "أشخاص من منطقة أستورياس",
    "people from hawaii": "أشخاص من هاواي",
    "people from madhya pradesh": "أشخاص من ماديا براديش",
    "people from ottoman empire": "أشخاص من الدولة العثمانية",
    "people from saxony": "أشخاص من ساكسونيا",
    "people from south lanarkshire": "أشخاص من جنوب لاناركشاير",
    "people from westchester county, new york": "أشخاص من مقاطعة ويستتشستر (نيويورك)",
    "people of dutch empire": "أشخاص من الإمبراطورية الهولندية",
    "people of el salvador": "أشخاص من السلفادور",
    "people of nicaragua": "أشخاص من نيكاراغوا",
    "perennial philosophy": "فلسفة خالدة",
    "permanent representatives of jamaica": "مندوبو جامايكا الدائمون",
    "philmont scout ranch": "مزرعة فيلمونت الكشفية",
    "physicians from bohemia": "أطباء من بوهيميا",
    "polish emigrants to brazil": "بولنديون مهاجرون إلى البرازيل",
    "political history of united states": "تاريخ الولايات المتحدة السياسي",
    "politics of united states": "سياسة الولايات المتحدة",
    "populated places in latvia": "أماكن مأهولة في لاتفيا",
    "populated places in portugal": "أماكن مأهولة في البرتغال",
    "populated places in uruguay": "أماكن مأهولة في أوروغواي",
    "prime ministers of malaysia": "رؤساء وزراء ماليزيا",
    "protected areas of united states": "مناطق محمية في الولايات المتحدة",
    "provinces of saudi arabia": "مقاطعات السعودية",
    "puerto rico": "بورتوريكو",
    "rail transport in sri lanka": "السكك الحديدية في سريلانكا",
    "railway stations in australia": "محطات السكك الحديدية في أستراليا",
    "railway stations in cambodia": "محطات السكك الحديدية في كمبوديا",
    "railway stations on national-register-of-historic-places": "محطات السكك الحديدية في السجل الوطني للأماكن التاريخية",
    "ray tracing (graphics)": "اقتفاء الشعاع",
    "religious buildings and structures in trinidad and tobago": "مبان ومنشآت دينية في ترينيداد وتوباغو",
    "rhode island": "رود آيلاند",
    "rhodope mountains": "جبال رودوب",
    "riots and civil disorder in united states": "شغب وعصيان مدني في الولايات المتحدة",
    "rivers of brazil": "أنهار البرازيل",
    "road incident deaths in washington (state)": "وفيات حوادث الطرق في ولاية واشنطن",
    "roman catholic archbishops in austria": "رؤساء أساقفة رومان كاثوليك في النمسا",
    "roman catholic archbishops in ireland": "رؤساء أساقفة رومان كاثوليك في أيرلندا",
    "roman catholic archbishops in singapore": "رؤساء أساقفة رومان كاثوليك في سنغافورة",
    "roman catholic church buildings in italy": "مبان كنائس رومانية كاثوليكية في إيطاليا",
    "roman catholic church buildings in malta": "مبان كنائس رومانية كاثوليكية في مالطا",
    "rowing clubs": "أندية تجديف",
    "rugby league in england": "دوري الرجبي في إنجلترا",
    "rugby union by country": "اتحاد الرجبي حسب البلد",
    "rugby union competitions": "منافسات اتحاد رجبي",
    "rugby union tournaments": "بطولات اتحاد رجبي",
    "russia–sri lanka relations": "العلاقات الروسية السريلانكية",
    "rwanda–tanzania relations": "العلاقات التنزانية الرواندية",
    "sailing for puerto rico": "الإبحار في بورتوريكو",
    "school districts in california": "مناطق تعليمية في كاليفورنيا",
    "schools in delaware": "مدارس في ديلاوير",
    "science and technology in united states": "العلوم والتقانة في الولايات المتحدة",
    "science fiction literature": "أدب خيال علمي",
    "scientists from ottoman empire": "علماء من الدولة العثمانية",
    "sculptures of men": "منحوتات في رجال",
    "september 1330": "سبتمبر 1330",
    "sexual violence in asia": "عنف جنسي في آسيا",
    "ships built-in montreal": "سفن بنيت في مونتريال",
    "shooting competitions": "منافسات رماية",
    "sieges involving austria": "حصارات تشمل النمسا",
    "sierra morena": "سييرا مورينا",
    "sint maarten by decade": "سينت مارتن حسب العقد",
    "ski jumping": "القفز التزلجي",
    "slavery in united states": "العبودية في الولايات المتحدة",
    "soccer matches": "مباريات كرة قدم",
    "socialist party-of serbia": "الحزب الاشتراكي في صربيا",
    "society of united states": "مجتمع الولايات المتحدة",
    "songs about automobiles": "أغاني عن سيارات",
    "songs about busan": "أغاني عن بوسان",
    "songs about new mexico": "أغاني عن نيومكسيكو",
    "songs about south dakota": "أغاني عن داكوتا الجنوبية",
    "south africa": "جنوب إفريقيا",
    "south american football by country": "كرة القدم الأمريكية الجنوبية حسب البلد",
    "south carolina politicians": "سياسيو كارولاينا الجنوبية",
    "south carolina": "كارولاينا الجنوبية",
    "south dakota politics": "سياسة داكوتا الجنوبية",
    "south dakota": "داكوتا الجنوبية",
    "south west africa": "جنوب غرب إفريقيا",
    "spain by decade": "إسبانيا حسب العقد",
    "speed skating": "التزلج السريع",
    "sports clubs and teams in brazil": "أندية وفرق رياضية في البرازيل",
    "sports clubs and teams": "أندية وفرق رياضية",
    "sports teams": "فرق رياضية",
    "sports-people from saxony": "رياضيون من ساكسونيا",
    "squares in london": "ساحات في لندن",
    "sri lankan emigrants to india": "سريلانكيون مهاجرون إلى الهند",
    "sri lanka–vietnam relations": "العلاقات السريلانكية الفيتنامية",
    "summer olympics competitors for canada": "منافسون أولمبيون صيفيون من كندا",
    "synagogues in france": "كنس في فرنسا",
    "sánchez ramírez province": "محافظة سانشيز راميريز",
    "table tennis clubs": "أندية كرة طاولة",
    "table tennis": "كرة الطاولة",
    "taiwan by month": "تايوان حسب الشهر",
    "taiwanese emigrants to argentina": "تايوانيون مهاجرون إلى الأرجنتين",
    "tanger-tetouan-al hoceima": "جهة طنجة تطوان الحسيمة",
    "telecommunications in asia": "الاتصالات عن بعد في آسيا",
    "television by country": "التلفاز حسب البلد",
    "television characters by series": "شخصيات تلفزيونية حسب السلسلة",
    "television episodes about american civil war": "حلقات تلفزيونية عن الحرب الأهلية الأمريكية",
    "television episodes about vietnam war": "حلقات تلفزيونية عن حرب فيتنام",
    "television in ivory coast": "التلفاز في ساحل العاج",
    "television series about chefs": "مسلسلات تلفزيونية عن طباخون",
    "television series about united states navy": "مسلسلات تلفزيونية عن البحرية الأمريكية",
    "television shows basedon french novels": "عروض تلفزيونية مبنية على روايات فرنسية",
    "tennis people": "أعلام كرة مضرب",
    "terrorist incidents in oceania": "حوادث إرهابية في أوقيانوسيا",
    "the canary islands": "جزر الكناري",
    "the city of": "مدينة",
    "the covid-19 pandemic in paraná (state)": "جائحة فيروس كورونا في ولاية بارانا",
    "the crown dependencies": "ملحقات التاج البريطاني",
    "the democratic-republic-of-congo": "جمهورية الكونغو الديمقراطية",
    "the mamluk sultanate": "مماليك مصر",
    "the ottoman empire by decade": "الدولة العثمانية حسب العقد",
    "the parliament of united kingdom": "برلمان المملكة المتحدة",
    "the roman republic": "الجمهورية الرومانية",
    "the russian empire": "الإمبراطورية الروسية",
    "the scarlet letter": "الحرف القرمزي",
    "the united kingdom": "المملكة المتحدة",
    "the united states by state or territory": "الولايات المتحدة حسب الولاية أو الإقليم",
    "the united states by state": "الولايات المتحدة حسب الولاية",
    "the united states in 1330": "الولايات المتحدة في 1330",
    "the valencian community": "منطقة بلنسية",
    "tourist attractions in nepal": "مواقع جذب سياحي في نيبال",
    "tourist attractions in new zealand": "مواقع جذب سياحي في نيوزيلندا",
    "tourist attractions in nicaragua": "مواقع جذب سياحي في نيكاراغوا",
    "tourist attractions in united states": "مواقع جذب سياحي في الولايات المتحدة",
    "track and field competitions": "منافسات سباقات مضمار وميدان",
    "transport museums in canada": "متاحف نقل في كندا",
    "transportation in united states": "النقل في الولايات المتحدة",
    "treaties extended to curaçao": "اتفاقيات امتدت إلى كوراساو",
    "ukraine–united states military relations": "العلاقات الأمريكية الأوكرانية العسكرية",
    "united kingdom from aden": "المملكة المتحدة من عدن",
    "united nations security council resolutions concerning eritrea": "قرارات مجلس الأمن التابع للأمم المتحدة بشأن إرتريا",
    "united states by state": "الولايات المتحدة حسب الولاية",
    "united states house-of-representatives from missouri territory": "مجلس النواب الأمريكي من إقليم ميزوري",
    "united states in 1330": "الولايات المتحدة في 1330",
    "universities and colleges in canada": "جامعات وكليات في كندا",
    "universities and colleges in italy": "جامعات وكليات في إيطاليا",
    "university of alabama": "جامعة ألاباما",
    "university of arkansas": "جامعة أركنساس",
    "university of kent": "جامعة كنت",
    "vallès occidental": "فالس أوكيدنتل",
    "victims of aviation accidents or incidents": "ضحايا حوادث طيران",
    "video games about diseases": "ألعاب فيديو عن الأمراض",
    "video games about slavery": "ألعاب فيديو عن العبودية",
    "video games basedon egyptian mythology": "ألعاب فيديو مبنية على أساطير مصرية",
    "video games basedon mythology": "ألعاب فيديو مبنية على أساطير",
    "volleyball clubs": "أندية كرة طائرة",
    "war in romania": "الحرب في رومانيا",
    "washington (state)": "ولاية واشنطن",
    "washington territory": "إقليم واشنطن",
    "water polo": "كرة الماء",
    "web colors": "ألوان الويب",
    "west bank premier league": "الدوري الفلسطيني الممتاز للضفة الغربية",
    "west virginia": "فرجينيا الغربية",
    "wheelchair basketball competitions between national teams": "منافسات كرة سلة على كراسي متحركة بين منتخبات وطنية",
    "wheelchair basketball competitions": "منافسات كرة سلة على كراسي متحركة",
    "wheelchair basketball leagues": "دوريات كرة سلة على كراسي متحركة",
    "wisconsin territory": "إقليم ويسكونسن",
    "women's bmx": "سباق البي إم إكس للسيدات",
    "women's football by country": "كرة القدم للسيدات حسب البلد",
    "women's football": "كرة القدم للسيدات",
    "women's volleyball": "كرة الطائرة للسيدات",
    "works about automobiles": "أعمال عن سيارات",
    "works about countries": "أعمال عن بلدان",
    "works about guinea-bissau": "أعمال عن غينيا بيساو",
    "works about obesity": "أعمال عن السمنة",
    "works about people": "أعمال عن أشخاص",
    "works adapted for other media": "أعمال تم تحويلها إلى وسائط أخرى",
    "works basedon mythology": "أعمال مبنية على أساطير",
    "world judo championships": "بطولة العالم للجودو",
    "yamanashi prefecture": "محافظة ياماناشي",
    "years in united states": "سنوات في الولايات المتحدة",
    "years of 20th century": "سنوات القرن 20",
    "years of 21st century": "سنوات القرن 21",
    "youth athletics competitions": "منافسات ألعاب قوى شبابية",
    "youth athletics": "ألعاب القوى للشباب",
    "youth football by continent": "كرة القدم للشباب حسب القارة",
    "youth football competitions": "منافسات كرة قدم شبابية",
    "youth football": "كرة القدم للشباب",
    "youth olympic gold medalists for turkey": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية من تركيا",
    "youth olympic gold medalists": "فائزون بميداليات ذهبية في الألعاب الأولمبية الشبابية",
    "youth sports competitions": "منافسات رياضية شبابية",
    "zambian emigrants to sweden": "زامبيون مهاجرون إلى السويد",
    "zürich eprix": "زيورخ إي بريكس",
}


@pytest.mark.parametrize("category, expected", data_fast.items(), ids=data_fast.keys())
@pytest.mark.fast
def test_Get_country2_fast(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data_slow.items(), ids=data_slow.keys())
@pytest.mark.slow
def test_Get_country2_slow(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_historic.items(), ids=test_historic.keys())
@pytest.mark.slow
def test_historic_places(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected
