#!/usr/bin/python3
"""
!
"""

translation_category_relations = {
    "for-deaf": "للصم",
    "for-deafblind": "للصم وللمكفوفون",
    "for-blind": "للمكفوفون",
    "manufactured-by": "صنعتها",
    "manufactured by": "صنعتها",
    "manufactured in": "صنعت في",
    "manufactured-in": "صنعت في",
    "published-by": "نشرتها",
    "published by": "نشرتها",
    "published in": "نشرت في",
    "launched in": "أطلقت في",
    "imprisoned-in": "مسجونون في",
    "imprisoned in": "مسجونون في",
    "launched-in": "أطلقت في",
    "launched by": "أطلقتها",
    "launched-by": "أطلقتها",
    "transferred-from": "نقلت من",
    "transferred from": "نقلت من",
    "built-in": "بنيت في",
    "built in": "بنيت في",
    "built by": "بنتها",
    "built-by": "بنتها",
    "caused by": "بسبب",
    "who defected to": "انشقوا إلى",
    "regarding": "عن",
    "spies for": "لصالح",
    "concerning": "بشأن",
    "shot dead-by-law enforcement officers in": "قتلوا برصاص ضباط إنفاذ القانون في",
    "with physical disabilities": "بإعاقات جسدية",
    "qualification for": "تصفيات مؤهلة إلى",
    "with screenplays by": "كتب نصها السينمائي",
    "with disabilities": "بإعاقات",
    "concluded in": "أبرمت في",
    "used in": "تستخدم في",
    "entered into force in": "دخلت حيز التنفيذ في",
    "invented in": "اخترعت في",
    # "introduced in": "استحدثت في",
    "introduced in": "عرضت في",
    "that uses": "تستخدم",
    "using": "تستخدم",
    "created in": "أنشئت في",
    "written by": "كتبها",
    "opened in": "افتتحت في",
    "originating in": "نشأت في",
    "of works by": "أعمال بواسطة",
    "named after": "سميت بأسماء",
    "that closed in": "أغلقت في",
    "conducted by": "نفذت بواسطة",
    "acquired by": "حصل عليها",
    "destroyed during": "دمرت خلال",
    "during": "خلال",
    "written": "كتبت",
    "closed in": "أغلقت في",
    "demolished in": "هدمت في",
    "in-sport-in": "في الرياضة في",
    "in-sports-in": "في الرياضة في",
    "by language of": "حسب لغة",
    "by-firearm-in": "بإطلاق النار في",
    "by-car-bomb": "بسيارة مفخخة",
    "who died in": "توفوا في",
    "killed while": "قتلوا أثناء",
    "related to": "متعلقة ب",
    "designated for": "خصصت ل",
    "suspended due to": "معلقة بسبب",
    "curtailed and voided due to": "اختصرت وألغيت بسبب",
    "curtailed due to": "اختصرت بسبب",
    "voided due to": "ألغيت بسبب",
    "cancelled due to": "ألغيت بسبب",
    "postponed due to": "تأجلت بسبب",
    "killed in": "قتلوا في",
    "murdered in": "قتلوا في",
    "sentenced to": "حكم عليهم",
    # "sentenced-to-death" : "حكم عليهم بالإعدام",
    "executed-burning by": "أعدموا شنقاً من قبل",
    "executed-hanging by": "أعدموا حرقاً من قبل",
    "executed-decapitation by": "أعدموا بقطع الرأس من قبل",
    "executed-firearm by": "أعدموا بسلاح ناري من قبل",
    "who served in": "خدموا في",
    "collaborators with": "متعاونون مع",
    "charged with": "أتهموا بتهمة",
    "executed for treason against": "أعدموا بتهمة الخيانة العظمى ضد",
    "executed for": "أعدموا بتهمة",
    # "executed by" : "أعدمتهم",
    "executed by": "أعدموا من قبل",
    "deported": "تم ترحيلهم",
    "executed": "أعدموا",
    "disestablished in": "انحلت في",
    # "established in" : "أنشئت في",
    "reestablished in": "أعيد تأسيسها في",
    "involved in": "مرتبطة مع",
    "established in": "أسست في",
    "collapses in": "انهارت في",
    "associated with": "مرتبطة مع",  # مرتبطين مع
    "presented by": "قدمها",
    "directed by": "أخرجها",
    "named by": "سماها",
    "scored by": "سجلها",
    # "hosted by" : "تستضيفها",
    "hosted by": "استضافتها",
    "discontinued in": "توقفت في",
    "developed in": "مطورة في",
    "described in": "وصفت في",
    "discovered in": "اكتشفت في",
    "completed in": "اكتملت في",
    "scheduled for": "مقررة في",
    "headquartered in": "مقرها الرئيسي في",
    "based in": "مقرها في",
    # "remade in" : "أعيد إنتاجها في",
    "remade-in": "أعيد إنتاجها في",
    # "based on" : "مبنية على",
    "basedon": "مبنية على",
    "set in": "تقع أحداثها في",
    "set on": "تقع أحداثها على",
    "filmed in": "صورت في",
    "shot in": "مصورة في",
    "adapted into": "تم تحويلها إلى",  #
    "adapted for": "تم تحويلها إلى",  #
    "recorded in": "سُجلت في",
    "recorded at": "سُجلت في",
    "produced in": "أنتجت في",
    "produced by": "من إنتاج",
    # "impacted by": "تأثرت بـ",
    "who compete in": "يتنافسون في",
    "extended to": "امتدت إلى",
    "involving the": "تشمل",
    "involving": "تشمل",
    "between": "بين",
    "into": "إلى",
    "to": "إلى",
    "by": "حسب",
    "in": "في",
    "elections in": "انتخابات في",
    "from": "من",
    "of": "",
    "for": "في",
    "at": "",
    # "on" : "على",
    "on": "في",
    "about": "عن",
    "outside": "خارج",
    "under": "تحت",
    "against": "ضد",
    # "and": "و",
}

__all__ = [
    "translation_category_relations",
]
