"""
Tests
"""

import pytest

from ArWikiCats.new_resolvers.sports_resolvers.match_labs import find_teams_2025

test_new = {
    "Women's sports": "رياضات نسائية",
    "Women's sports seasons": "مواسم رياضات نسائية",
    "sports seasons": "مواسم رياضات",
}


@pytest.mark.parametrize("category, expected_key", test_new.items(), ids=test_new.keys())
@pytest.mark.fast
def test_new_data(category: str, expected_key: str) -> None:
    label = find_teams_2025(category)
    assert label == ""  # expected_key


data00 = {
    "football": "كرة قدم",
    "sports competitions": "منافسات رياضية",
    "women's sports clubs": "أندية رياضية نسائية",
    "women's sports competitions": "منافسات رياضية نسائية",
    "women's sports leagues": "دوريات رياضية نسائية",
    "women's sports organizations": "منظمات رياضية نسائية",
    "sports films": "أفلام رياضية",
    "women's sports teams": "فرق رياضية نسائية",
}

data6 = {
    "Category:amateur football competitions": "منافسات كرة قدم للهواة",
    "amateur football competitions": "منافسات كرة قدم للهواة",
    "american football teams": "فرق كرة قدم أمريكية",
    "american football venues": "ملاعب كرة قدم أمريكية",
    "athletics competitions": "منافسات ألعاب قوى",
    "athletics navigational boxes": "صناديق تصفح ألعاب قوى",
    "athletics venues": "ملاعب ألعاب قوى",
    "australian rules football clubs": "أندية كرة قدم أسترالية",
    "badminton venues": "ملاعب تنس ريشة",
    "baseball playerss": "لاعبو كرة قاعدة",
    "baseball venues": "ملاعب كرة قاعدة",
    "basketball competitions": "منافسات كرة سلة",
    "basketball leagues": "دوريات كرة سلة",
    "basketball people": "أعلام كرة سلة",
    "basketball playerss": "لاعبو كرة سلة",
    "basketball teams": "فرق كرة سلة",
    "boxing competitions": "منافسات بوكسينغ",
    "canadian football teams": "فرق كرة قدم كندية",
    "canoeing and kayaking competitions": "منافسات كانو-كاياك",
    "cricket clubs": "أندية كريكت",
    "cycling clubs": "أندية سباق دراجات هوائية",
    "cycling events": "أحداث سباق دراجات هوائية",
    "field hockey clubs": "أندية هوكي ميدان",
    "field hockey people": "أعلام هوكي ميدان",
    "field hockey playerss": "لاعبو هوكي ميدان",
    "figure skating films": "أفلام تزلج فني",
    "figure skating people": "أعلام تزلج فني",
    "football people": "أعلام كرة قدم",
    "football venues": "ملاعب كرة قدم",
    "gaelic football clubs": "أندية كرة قدم غالية",
    "gaelic football competitions": "منافسات كرة قدم غالية",
    "gymnastics competitions": "منافسات جمباز",
    "gymnastics organizations": "منظمات جمباز",
    "handball competitions": "منافسات كرة يد",
    "ice hockey leagues": "دوريات هوكي جليد",
    "ice hockey people": "أعلام هوكي جليد",
    "ice hockey playerss": "لاعبو هوكي جليد",
    "ice hockey venues": "ملاعب هوكي جليد",
    "judo competitions": "منافسات جودو",
    "men's football competitions": "منافسات كرة قدم رجالية",
    "men's football leagues": "دوريات كرة قدم رجالية",
    "motorsport competitions": "منافسات رياضة محركات",
    "motorsport venues": "ملاعب رياضة محركات",
    "rowing clubs": "أندية تجديف",
    "rugby league playerss": "لاعبو دوري رجبي",
    "rugby league venues": "ملاعب دوري رجبي",
    "rugby union competitions": "منافسات اتحاد رجبي",
    "rugby union teams": "فرق اتحاد رجبي",
    "rugby union tournaments": "بطولات اتحاد رجبي",
    "shooting competitions": "منافسات رماية",
    "soccer matches": "مباريات كرة قدم",
    "soccer venues": "ملاعب كرة قدم",
    "softball venues": "ملاعب كرة لينة",
    "table tennis clubs": "أندية كرة طاولة",
    "tennis people": "أعلام كرة مضرب",
    "tennis tournaments": "بطولات كرة مضرب",
    "track and field competitions": "منافسات سباقات مضمار وميدان",
    "volleyball clubs": "أندية كرة طائرة",
    "volleyball competitions": "منافسات كرة طائرة",
    "wheelchair basketball competitions": "منافسات كرة سلة على كراسي متحركة",
    "wheelchair basketball leagues": "دوريات كرة سلة على كراسي متحركة",
    "wheelchair basketball playerss": "لاعبو كرة سلة على كراسي متحركة",
    "wheelchair basketball teams": "فرق كرة سلة على كراسي متحركة",
    "wheelchair basketball templates": "قوالب كرة سلة على كراسي متحركة",
    "wheelchair basketball venues": "ملاعب كرة سلة على كراسي متحركة",
    "wheelchair handball competitions": "منافسات كرة يد على كراسي متحركة",
    "wheelchair rugby competitions": "منافسات رجبي على كراسي متحركة",
    "wheelchair rugby people": "أعلام رجبي على كراسي متحركة",
    "wheelchair rugby templates": "قوالب رجبي على كراسي متحركة",
    "wheelchair tennis tournaments": "بطولات كرة مضرب على كراسي متحركة",
    "women's basketball competitions": "منافسات كرة سلة نسائية",
    "women's basketball leagues": "دوريات كرة سلة نسائية",
    "women's cricket teams": "فرق كريكت نسائية",
    "women's football clubs": "أندية كرة قدم نسائية",
    "women's soccer leagues": "دوريات كرة قدم نسائية",
    "youth athletics competitions": "منافسات ألعاب قوى شبابية",
    "youth football competitions": "منافسات كرة قدم شبابية",
}

teams_2025_data_womens = {
    "womens youth football": "كرة قدم للشابات",
    "womens youth football centers": "لاعبات وسط كرة قدم للشابات",
    "womens youth football central defenders": "مدافعات مركزيات كرة قدم للشابات",
    "womens youth football centres": "لاعبات وسط كرة قدم للشابات",
    "womens youth football champions": "أبطال كرة قدم للشابات",
    "womens youth football clubs": "أندية كرة قدم للشابات",
    "womens youth football coaches": "مدربو كرة قدم للشابات",
    "womens youth football competitions": "منافسات كرة قدم للشابات",
    "womens youth football defencemen": "مدافعات كرة قدم للشابات",
    "womens youth football defenders": "مدافعات كرة قدم للشابات",
    "womens youth football defensive backs": "مدافعات خلفيات كرة قدم للشابات",
    "womens youth football defensive linemen": "مدافعات خط كرة قدم للشابات",
    "womens youth football directors": "مدراء كرة قدم للشابات",
    "womens youth football drop kickers": "مسددات ركلات كرة قدم للشابات",
    "womens youth football events": "أحداث كرة قدم للشابات",
    "womens youth football films": "أفلام كرة قدم للشابات",
    "womens youth football finals": "نهائيات كرة قدم للشابات",
    "womens youth football forwards": "مهاجمات كرة قدم للشابات",
    "womens youth football fullbacks": "مدافعات كرة قدم للشابات",
    "womens youth football goalkeepers": "حارسات مرمى كرة قدم للشابات",
    "womens youth football goaltenders": "حارسات مرمى كرة قدم للشابات",
    "womens youth football guards": "حارسات كرة قدم للشابات",
    "womens youth football halfbacks": "ظهيرات مساعدات كرة قدم للشابات",
    "womens youth football home stadiums": "ملاعب كرة قدم للشابات",
    "womens youth football inside forwards": "مهاجمات داخليات كرة قدم للشابات",
    "womens youth football journalists": "صحفيات كرة قدم للشابات",
    "womens youth football kickers": "راكلات كرة قدم للشابات",
    "womens youth football leagues": "دوريات كرة قدم للشابات",
    "womens youth football left wingers": "جناحات يسار كرة قدم للشابات",
    "womens youth football linebackers": "ظهيرات كرة قدم للشابات",
    "womens youth football lists": "قوائم كرة قدم للشابات",
    "womens youth football manager history": "تاريخ مدربو كرة قدم للشابات",
    "womens youth football managers": "مدربو كرة قدم للشابات",
    "womens youth football matches": "مباريات كرة قدم للشابات",
    "womens youth football midfielders": "لاعبات وسط كرة قدم للشابات",
    "womens youth football navigational boxes": "صناديق تصفح كرة قدم للشابات",
    "womens youth football non-profit organizations": "منظمات غير ربحية كرة قدم للشابات",
    "womens youth football non-profit publishers": "ناشرون غير ربحيون كرة قدم للشابات",
    "womens youth football offensive linemen": "مهاجمات خط كرة قدم للشابات",
    "womens youth football organisations": "منظمات كرة قدم للشابات",
    "womens youth football organizations": "منظمات كرة قدم للشابات",
    "womens youth football outside forwards": "مهاجمات خارجيات كرة قدم للشابات",
    "womens youth football peoplee": "أعلام كرة قدم للشابات",
    "womens youth football placekickers": "مسددات كرة قدم للشابات",
    "womens youth football players": "لاعبات كرة قدم للشابات",
    "womens youth football playerss": "لاعبات كرة قدم للشابات",
    "womens youth football point guards": "لاعبات هجوم خلفي كرة قدم للشابات",
    "womens youth football positions": "مراكز كرة قدم للشابات",
    "womens youth football power forwards": "مهاجمات قويات الجسم كرة قدم للشابات",
    "womens youth football quarterbacks": "ظهيرات رباعيات كرة قدم للشابات",
    "womens youth football receivers": "مستقبلات كرة قدم للشابات",
    "womens youth football records": "سجلات كرة قدم للشابات",
    "womens youth football records and statistics": "سجلات وإحصائيات كرة قدم للشابات",
    "womens youth football referees": "حكام كرة قدم للشابات",
    "womens youth football results": "نتائج كرة قدم للشابات",
    "womens youth football right wingers": "جناحات يمين كرة قدم للشابات",
    "womens youth football rivalries": "دربيات كرة قدم للشابات",
    "womens youth football running backs": "راكضات للخلف كرة قدم للشابات",
    "womens youth football scouts": "كشافة كرة قدم للشابات",
    "womens youth football shooting guards": "مدافعات مسددات كرة قدم للشابات",
    "womens youth football small forwards": "مهاجمات صغيرات الجسم كرة قدم للشابات",
    "womens youth football sports-people": "رياضيات كرة قدم للشابات",
    "womens youth football squads": "تشكيلات كرة قدم للشابات",
    "womens youth football statistics": "إحصائيات كرة قدم للشابات",
    "womens youth football tackles": "مصطدمات كرة قدم للشابات",
    "womens youth football teams": "فرق كرة قدم للشابات",
    "womens youth football templates": "قوالب كرة قدم للشابات",
    "womens youth football tournaments": "بطولات كرة قدم للشابات",
    "womens youth football trainers": "مدربو كرة قدم للشابات",
    "womens youth football umpires": "حكام كرة قدم للشابات",
    "womens youth football utility players": "لاعبات مراكز متعددة كرة قدم للشابات",
    "womens youth football venues": "ملاعب كرة قدم للشابات",
    "womens youth football wide receivers": "مستقبلات واسعات كرة قدم للشابات",
    "womens youth football wing halves": "جناحات نصفيات كرة قدم للشابات",
    "womens youth football wingers": "جناحات كرة قدم للشابات",
    "womens football": "كرة قدم نسائية",
    "womens football centers": "لاعبات وسط كرة قدم نسائية",
    "womens football central defenders": "مدافعات مركزيات كرة قدم نسائية",
    "womens football centres": "لاعبات وسط كرة قدم نسائية",
    "womens football champions": "أبطال كرة قدم نسائية",
    "womens football clubs": "أندية كرة قدم نسائية",
    "womens football coaches": "مدربو كرة قدم نسائية",
    "womens football competitions": "منافسات كرة قدم نسائية",
    "womens football defencemen": "مدافعات كرة قدم نسائية",
    "womens football defenders": "مدافعات كرة قدم نسائية",
    "womens football defensive backs": "مدافعات خلفيات كرة قدم نسائية",
    "womens football defensive linemen": "مدافعات خط كرة قدم نسائية",
    "womens football directors": "مدراء كرة قدم نسائية",
    "womens football drop kickers": "مسددات ركلات كرة قدم نسائية",
    "womens football events": "أحداث كرة قدم نسائية",
    "womens football films": "أفلام كرة قدم نسائية",
    "womens football finals": "نهائيات كرة قدم نسائية",
    "womens football forwards": "مهاجمات كرة قدم نسائية",
    "womens football fullbacks": "مدافعات كرة قدم نسائية",
    "womens football goalkeepers": "حارسات مرمى كرة قدم نسائية",
    "womens football goaltenders": "حارسات مرمى كرة قدم نسائية",
    "womens football guards": "حارسات كرة قدم نسائية",
    "womens football halfbacks": "ظهيرات مساعدات كرة قدم نسائية",
    "womens football home stadiums": "ملاعب كرة قدم نسائية",
    "womens football inside forwards": "مهاجمات داخليات كرة قدم نسائية",
    "womens football journalists": "صحفيات كرة قدم نسائية",
    "womens football kickers": "راكلات كرة قدم نسائية",
    "womens football leagues": "دوريات كرة قدم نسائية",
    "womens football left wingers": "جناحات يسار كرة قدم نسائية",
    "womens football linebackers": "ظهيرات كرة قدم نسائية",
    "womens football lists": "قوائم كرة قدم نسائية",
    "womens football manager history": "تاريخ مدربو كرة قدم نسائية",
    "womens football managers": "مدربو كرة قدم نسائية",
    "womens football matches": "مباريات كرة قدم نسائية",
    "womens football midfielders": "لاعبات وسط كرة قدم نسائية",
    "womens football navigational boxes": "صناديق تصفح كرة قدم نسائية",
    "womens football non-profit organizations": "منظمات غير ربحية كرة قدم نسائية",
    "womens football non-profit publishers": "ناشرون غير ربحيون كرة قدم نسائية",
    "womens football offensive linemen": "مهاجمات خط كرة قدم نسائية",
    "womens football organisations": "منظمات كرة قدم نسائية",
    "womens football organizations": "منظمات كرة قدم نسائية",
    "womens football outside forwards": "مهاجمات خارجيات كرة قدم نسائية",
    "womens football peoplee": "أعلام كرة قدم نسائية",
    "womens football placekickers": "مسددات كرة قدم نسائية",
    "womens football players": "لاعبات كرة قدم نسائية",
    "womens football playerss": "لاعبات كرة قدم نسائية",
    "womens football point guards": "لاعبات هجوم خلفي كرة قدم نسائية",
    "womens football positions": "مراكز كرة قدم نسائية",
    "womens football power forwards": "مهاجمات قويات الجسم كرة قدم نسائية",
    "womens football quarterbacks": "ظهيرات رباعيات كرة قدم نسائية",
    "womens football receivers": "مستقبلات كرة قدم نسائية",
    "womens football records": "سجلات كرة قدم نسائية",
    "womens football records and statistics": "سجلات وإحصائيات كرة قدم نسائية",
    "womens football referees": "حكام كرة قدم نسائية",
    "womens football results": "نتائج كرة قدم نسائية",
    "womens football right wingers": "جناحات يمين كرة قدم نسائية",
    "womens football rivalries": "دربيات كرة قدم نسائية",
    "womens football running backs": "راكضات للخلف كرة قدم نسائية",
    "womens football scouts": "كشافة كرة قدم نسائية",
    "womens football shooting guards": "مدافعات مسددات كرة قدم نسائية",
    "womens football small forwards": "مهاجمات صغيرات الجسم كرة قدم نسائية",
    "womens football sports-people": "رياضيات كرة قدم نسائية",
    "womens football squads": "تشكيلات كرة قدم نسائية",
    "womens football statistics": "إحصائيات كرة قدم نسائية",
    "womens football tackles": "مصطدمات كرة قدم نسائية",
    "womens football teams": "فرق كرة قدم نسائية",
    "womens football templates": "قوالب كرة قدم نسائية",
    "womens football tournaments": "بطولات كرة قدم نسائية",
    "womens football trainers": "مدربو كرة قدم نسائية",
    "womens football umpires": "حكام كرة قدم نسائية",
    "womens football utility players": "لاعبات مراكز متعددة كرة قدم نسائية",
    "womens football venues": "ملاعب كرة قدم نسائية",
    "womens football wide receivers": "مستقبلات واسعات كرة قدم نسائية",
    "womens football wing halves": "جناحات نصفيات كرة قدم نسائية",
    "womens football wingers": "جناحات كرة قدم نسائية",
}

teams_2025_data = {
    "amateur football": "كرة قدم للهواة",
    "amateur football centers": "لاعبو وسط كرة قدم للهواة",
    "amateur football central defenders": "قلوب دفاع كرة قدم للهواة",
    "amateur football centres": "لاعبو وسط كرة قدم للهواة",
    "amateur football champions": "أبطال كرة قدم للهواة",
    "amateur football clubs": "أندية كرة قدم للهواة",
    "amateur football coaches": "مدربو كرة قدم للهواة",
    "amateur football competitions": "منافسات كرة قدم للهواة",
    "amateur football defencemen": "مدافعو كرة قدم للهواة",
    "amateur football defenders": "مدافعو كرة قدم للهواة",
    "amateur football defensive backs": "مدافعون خلفيون كرة قدم للهواة",
    "amateur football defensive linemen": "مدافعو خط كرة قدم للهواة",
    "amateur football directors": "مدراء كرة قدم للهواة",
    "amateur football drop kickers": "مسددو ركلات كرة قدم للهواة",
    "amateur football events": "أحداث كرة قدم للهواة",
    "amateur football films": "أفلام كرة قدم للهواة",
    "amateur football finals": "نهائيات كرة قدم للهواة",
    "amateur football forwards": "مهاجمو كرة قدم للهواة",
    "amateur football fullbacks": "مدافعو كرة قدم للهواة",
    "amateur football goalkeepers": "حراس مرمى كرة قدم للهواة",
    "amateur football goaltenders": "حراس مرمى كرة قدم للهواة",
    "amateur football guards": "حراس كرة قدم للهواة",
    "amateur football halfbacks": "أظهرة مساعدون كرة قدم للهواة",
    "amateur football home stadiums": "ملاعب كرة قدم للهواة",
    "amateur football inside forwards": "مهاجمون داخليون كرة قدم للهواة",
    "amateur football journalists": "صحفيو كرة قدم للهواة",
    "amateur football kickers": "راكلو كرة قدم للهواة",
    "amateur football leagues": "دوريات كرة قدم للهواة",
    "amateur football left wingers": "أجنحة يسار كرة قدم للهواة",
    "amateur football linebackers": "أظهرة كرة قدم للهواة",
    "amateur football lists": "قوائم كرة قدم للهواة",
    "amateur football manager history": "تاريخ مدربو كرة قدم للهواة",
    "amateur football managers": "مدربو كرة قدم للهواة",
    "amateur football matches": "مباريات كرة قدم للهواة",
    "amateur football midfielders": "لاعبو وسط كرة قدم للهواة",
    "amateur football navigational boxes": "صناديق تصفح كرة قدم للهواة",
    "amateur football non-profit organizations": "منظمات غير ربحية كرة قدم للهواة",
    "amateur football non-profit publishers": "ناشرون غير ربحيون كرة قدم للهواة",
    "amateur football offensive linemen": "مهاجمو خط كرة قدم للهواة",
    "amateur football organisations": "منظمات كرة قدم للهواة",
    "amateur football organizations": "منظمات كرة قدم للهواة",
    "amateur football outside forwards": "مهاجمون خارجيون كرة قدم للهواة",
    "amateur football peoplee": "أعلام كرة قدم للهواة",
    "amateur football placekickers": "مسددو كرة قدم للهواة",
    "amateur football players": "لاعبو كرة قدم للهواة",
    "amateur football playerss": "لاعبو كرة قدم للهواة",
    "amateur football point guards": "لاعبو هجوم خلفي كرة قدم للهواة",
    "amateur football positions": "مراكز كرة قدم للهواة",
    "amateur football power forwards": "مهاجمون أقوياء الجسم كرة قدم للهواة",
    "amateur football quarterbacks": "أظهرة رباعيون كرة قدم للهواة",
    "amateur football receivers": "مستقبلو كرة قدم للهواة",
    "amateur football records": "سجلات كرة قدم للهواة",
    "amateur football records and statistics": "سجلات وإحصائيات كرة قدم للهواة",
    "amateur football referees": "حكام كرة قدم للهواة",
    "amateur football results": "نتائج كرة قدم للهواة",
    "amateur football right wingers": "أجنحة يمين كرة قدم للهواة",
    "amateur football rivalries": "دربيات كرة قدم للهواة",
    "amateur football running backs": "راكضون للخلف كرة قدم للهواة",
    "amateur football scouts": "كشافة كرة قدم للهواة",
    "amateur football shooting guards": "مدافعون مسددون كرة قدم للهواة",
    "amateur football small forwards": "مهاجمون صغيرو الجسم كرة قدم للهواة",
    "amateur football sports-people": "رياضيو كرة قدم للهواة",
    "amateur football squads": "تشكيلات كرة قدم للهواة",
    "amateur football statistics": "إحصائيات كرة قدم للهواة",
    "amateur football tackles": "مصطدمو كرة قدم للهواة",
    "amateur football teams": "فرق كرة قدم للهواة",
    "amateur football templates": "قوالب كرة قدم للهواة",
    "amateur football tournaments": "بطولات كرة قدم للهواة",
    "amateur football trainers": "مدربو كرة قدم للهواة",
    "amateur football umpires": "حكام كرة قدم للهواة",
    "amateur football utility players": "لاعبو مراكز متعددة كرة قدم للهواة",
    "amateur football venues": "ملاعب كرة قدم للهواة",
    "amateur football wide receivers": "مستقبلون واسعون كرة قدم للهواة",
    "amateur football wing halves": "أنصاف أجنحة كرة قدم للهواة",
    "amateur football wingers": "أجنحة كرة قدم للهواة",
    "mens youth football": "كرة قدم للشباب",
    "mens youth football centers": "لاعبو وسط كرة قدم للشباب",
    "mens youth football central defenders": "قلوب دفاع كرة قدم للشباب",
    "mens youth football centres": "لاعبو وسط كرة قدم للشباب",
    "mens youth football champions": "أبطال كرة قدم للشباب",
    "mens youth football clubs": "أندية كرة قدم للشباب",
    "mens youth football coaches": "مدربو كرة قدم للشباب",
    "mens youth football competitions": "منافسات كرة قدم للشباب",
    "mens youth football defencemen": "مدافعو كرة قدم للشباب",
    "mens youth football defenders": "مدافعو كرة قدم للشباب",
    "mens youth football defensive backs": "مدافعون خلفيون كرة قدم للشباب",
    "mens youth football defensive linemen": "مدافعو خط كرة قدم للشباب",
    "mens youth football directors": "مدراء كرة قدم للشباب",
    "mens youth football drop kickers": "مسددو ركلات كرة قدم للشباب",
    "mens youth football events": "أحداث كرة قدم للشباب",
    "mens youth football films": "أفلام كرة قدم للشباب",
    "mens youth football finals": "نهائيات كرة قدم للشباب",
    "mens youth football forwards": "مهاجمو كرة قدم للشباب",
    "mens youth football fullbacks": "مدافعو كرة قدم للشباب",
    "mens youth football goalkeepers": "حراس مرمى كرة قدم للشباب",
    "mens youth football goaltenders": "حراس مرمى كرة قدم للشباب",
    "mens youth football guards": "حراس كرة قدم للشباب",
    "mens youth football halfbacks": "أظهرة مساعدون كرة قدم للشباب",
    "mens youth football home stadiums": "ملاعب كرة قدم للشباب",
    "mens youth football inside forwards": "مهاجمون داخليون كرة قدم للشباب",
    "mens youth football journalists": "صحفيو كرة قدم للشباب",
    "mens youth football kickers": "راكلو كرة قدم للشباب",
    "mens youth football leagues": "دوريات كرة قدم للشباب",
    "mens youth football left wingers": "أجنحة يسار كرة قدم للشباب",
    "mens youth football linebackers": "أظهرة كرة قدم للشباب",
    "mens youth football lists": "قوائم كرة قدم للشباب",
    "mens youth football manager history": "تاريخ مدربو كرة قدم للشباب",
    "mens youth football managers": "مدربو كرة قدم للشباب",
    "mens youth football matches": "مباريات كرة قدم للشباب",
    "mens youth football midfielders": "لاعبو وسط كرة قدم للشباب",
    "mens youth football navigational boxes": "صناديق تصفح كرة قدم للشباب",
    "mens youth football non-profit organizations": "منظمات غير ربحية كرة قدم للشباب",
    "mens youth football non-profit publishers": "ناشرون غير ربحيون كرة قدم للشباب",
    "mens youth football offensive linemen": "مهاجمو خط كرة قدم للشباب",
    "mens youth football organisations": "منظمات كرة قدم للشباب",
    "mens youth football organizations": "منظمات كرة قدم للشباب",
    "mens youth football outside forwards": "مهاجمون خارجيون كرة قدم للشباب",
    "mens youth football peoplee": "أعلام كرة قدم للشباب",
    "mens youth football placekickers": "مسددو كرة قدم للشباب",
    "mens youth football players": "لاعبو كرة قدم للشباب",
    "mens youth football playerss": "لاعبو كرة قدم للشباب",
    "mens youth football point guards": "لاعبو هجوم خلفي كرة قدم للشباب",
    "mens youth football positions": "مراكز كرة قدم للشباب",
    "mens youth football power forwards": "مهاجمون أقوياء الجسم كرة قدم للشباب",
    "mens youth football quarterbacks": "أظهرة رباعيون كرة قدم للشباب",
    "mens youth football receivers": "مستقبلو كرة قدم للشباب",
    "mens youth football records": "سجلات كرة قدم للشباب",
    "mens youth football records and statistics": "سجلات وإحصائيات كرة قدم للشباب",
    "mens youth football referees": "حكام كرة قدم للشباب",
    "mens youth football results": "نتائج كرة قدم للشباب",
    "mens youth football right wingers": "أجنحة يمين كرة قدم للشباب",
    "mens youth football rivalries": "دربيات كرة قدم للشباب",
    "mens youth football running backs": "راكضون للخلف كرة قدم للشباب",
    "mens youth football scouts": "كشافة كرة قدم للشباب",
    "mens youth football shooting guards": "مدافعون مسددون كرة قدم للشباب",
    "mens youth football small forwards": "مهاجمون صغيرو الجسم كرة قدم للشباب",
    "mens youth football sports-people": "رياضيو كرة قدم للشباب",
    "mens youth football squads": "تشكيلات كرة قدم للشباب",
    "mens youth football statistics": "إحصائيات كرة قدم للشباب",
    "mens youth football tackles": "مصطدمو كرة قدم للشباب",
    "mens youth football teams": "فرق كرة قدم للشباب",
    "mens youth football templates": "قوالب كرة قدم للشباب",
    "mens youth football tournaments": "بطولات كرة قدم للشباب",
    "mens youth football trainers": "مدربو كرة قدم للشباب",
    "mens youth football umpires": "حكام كرة قدم للشباب",
    "mens youth football utility players": "لاعبو مراكز متعددة كرة قدم للشباب",
    "mens youth football venues": "ملاعب كرة قدم للشباب",
    "mens youth football wide receivers": "مستقبلون واسعون كرة قدم للشباب",
    "mens youth football wing halves": "أنصاف أجنحة كرة قدم للشباب",
    "mens youth football wingers": "أجنحة كرة قدم للشباب",
    "mens football": "كرة قدم رجالية",
    "mens football centers": "لاعبو وسط كرة قدم رجالية",
    "mens football central defenders": "قلوب دفاع كرة قدم رجالية",
    "mens football centres": "لاعبو وسط كرة قدم رجالية",
    "mens football champions": "أبطال كرة قدم رجالية",
    "mens football clubs": "أندية كرة قدم رجالية",
    "mens football coaches": "مدربو كرة قدم رجالية",
    "mens football competitions": "منافسات كرة قدم رجالية",
    "mens football defencemen": "مدافعو كرة قدم رجالية",
    "mens football defenders": "مدافعو كرة قدم رجالية",
    "mens football defensive backs": "مدافعون خلفيون كرة قدم رجالية",
    "mens football defensive linemen": "مدافعو خط كرة قدم رجالية",
    "mens football directors": "مدراء كرة قدم رجالية",
    "mens football drop kickers": "مسددو ركلات كرة قدم رجالية",
    "mens football events": "أحداث كرة قدم رجالية",
    "mens football films": "أفلام كرة قدم رجالية",
    "mens football finals": "نهائيات كرة قدم رجالية",
    "mens football forwards": "مهاجمو كرة قدم رجالية",
    "mens football fullbacks": "مدافعو كرة قدم رجالية",
    "mens football goalkeepers": "حراس مرمى كرة قدم رجالية",
    "mens football goaltenders": "حراس مرمى كرة قدم رجالية",
    "mens football guards": "حراس كرة قدم رجالية",
    "mens football halfbacks": "أظهرة مساعدون كرة قدم رجالية",
    "mens football home stadiums": "ملاعب كرة قدم رجالية",
    "mens football inside forwards": "مهاجمون داخليون كرة قدم رجالية",
    "mens football journalists": "صحفيو كرة قدم رجالية",
    "mens football kickers": "راكلو كرة قدم رجالية",
    "mens football leagues": "دوريات كرة قدم رجالية",
    "mens football left wingers": "أجنحة يسار كرة قدم رجالية",
    "mens football linebackers": "أظهرة كرة قدم رجالية",
    "mens football lists": "قوائم كرة قدم رجالية",
    "mens football manager history": "تاريخ مدربو كرة قدم رجالية",
    "mens football managers": "مدربو كرة قدم رجالية",
    "mens football matches": "مباريات كرة قدم رجالية",
    "mens football midfielders": "لاعبو وسط كرة قدم رجالية",
    "mens football navigational boxes": "صناديق تصفح كرة قدم رجالية",
    "mens football non-profit organizations": "منظمات غير ربحية كرة قدم رجالية",
    "mens football non-profit publishers": "ناشرون غير ربحيون كرة قدم رجالية",
    "mens football offensive linemen": "مهاجمو خط كرة قدم رجالية",
    "mens football organisations": "منظمات كرة قدم رجالية",
    "mens football organizations": "منظمات كرة قدم رجالية",
    "mens football outside forwards": "مهاجمون خارجيون كرة قدم رجالية",
    "mens football peoplee": "أعلام كرة قدم رجالية",
    "mens football placekickers": "مسددو كرة قدم رجالية",
    "mens football players": "لاعبو كرة قدم رجالية",
    "mens football playerss": "لاعبو كرة قدم رجالية",
    "mens football point guards": "لاعبو هجوم خلفي كرة قدم رجالية",
    "mens football positions": "مراكز كرة قدم رجالية",
    "mens football power forwards": "مهاجمون أقوياء الجسم كرة قدم رجالية",
    "mens football quarterbacks": "أظهرة رباعيون كرة قدم رجالية",
    "mens football receivers": "مستقبلو كرة قدم رجالية",
    "mens football records": "سجلات كرة قدم رجالية",
    "mens football records and statistics": "سجلات وإحصائيات كرة قدم رجالية",
    "mens football referees": "حكام كرة قدم رجالية",
    "mens football results": "نتائج كرة قدم رجالية",
    "mens football right wingers": "أجنحة يمين كرة قدم رجالية",
    "mens football rivalries": "دربيات كرة قدم رجالية",
    "mens football running backs": "راكضون للخلف كرة قدم رجالية",
    "mens football scouts": "كشافة كرة قدم رجالية",
    "mens football shooting guards": "مدافعون مسددون كرة قدم رجالية",
    "mens football small forwards": "مهاجمون صغيرو الجسم كرة قدم رجالية",
    "mens football sports-people": "رياضيو كرة قدم رجالية",
    "mens football squads": "تشكيلات كرة قدم رجالية",
    "mens football statistics": "إحصائيات كرة قدم رجالية",
    "mens football tackles": "مصطدمو كرة قدم رجالية",
    "mens football teams": "فرق كرة قدم رجالية",
    "mens football templates": "قوالب كرة قدم رجالية",
    "mens football tournaments": "بطولات كرة قدم رجالية",
    "mens football trainers": "مدربو كرة قدم رجالية",
    "mens football umpires": "حكام كرة قدم رجالية",
    "mens football utility players": "لاعبو مراكز متعددة كرة قدم رجالية",
    "mens football venues": "ملاعب كرة قدم رجالية",
    "mens football wide receivers": "مستقبلون واسعون كرة قدم رجالية",
    "mens football wing halves": "أنصاف أجنحة كرة قدم رجالية",
    "mens football wingers": "أجنحة كرة قدم رجالية",
    "youth football": "كرة قدم شبابية",
    "youth football centers": "لاعبو وسط كرة قدم شبابية",
    "youth football central defenders": "قلوب دفاع كرة قدم شبابية",
    "youth football centres": "لاعبو وسط كرة قدم شبابية",
    "youth football champions": "أبطال كرة قدم شبابية",
    "youth football clubs": "أندية كرة قدم شبابية",
    "youth football coaches": "مدربو كرة قدم شبابية",
    "youth football competitions": "منافسات كرة قدم شبابية",
    "youth football defencemen": "مدافعو كرة قدم شبابية",
    "youth football defenders": "مدافعو كرة قدم شبابية",
    "youth football defensive backs": "مدافعون خلفيون كرة قدم شبابية",
    "youth football defensive linemen": "مدافعو خط كرة قدم شبابية",
    "youth football directors": "مدراء كرة قدم شبابية",
    "youth football drop kickers": "مسددو ركلات كرة قدم شبابية",
    "youth football events": "أحداث كرة قدم شبابية",
    "youth football films": "أفلام كرة قدم شبابية",
    "youth football finals": "نهائيات كرة قدم شبابية",
    "youth football forwards": "مهاجمو كرة قدم شبابية",
    "youth football fullbacks": "مدافعو كرة قدم شبابية",
    "youth football goalkeepers": "حراس مرمى كرة قدم شبابية",
    "youth football goaltenders": "حراس مرمى كرة قدم شبابية",
    "youth football guards": "حراس كرة قدم شبابية",
    "youth football halfbacks": "أظهرة مساعدون كرة قدم شبابية",
    "youth football home stadiums": "ملاعب كرة قدم شبابية",
    "youth football inside forwards": "مهاجمون داخليون كرة قدم شبابية",
    "youth football journalists": "صحفيو كرة قدم شبابية",
    "youth football kickers": "راكلو كرة قدم شبابية",
    "youth football leagues": "دوريات كرة قدم شبابية",
    "youth football left wingers": "أجنحة يسار كرة قدم شبابية",
    "youth football linebackers": "أظهرة كرة قدم شبابية",
    "youth football lists": "قوائم كرة قدم شبابية",
    "youth football manager history": "تاريخ مدربو كرة قدم شبابية",
    "youth football managers": "مدربو كرة قدم شبابية",
    "youth football matches": "مباريات كرة قدم شبابية",
    "youth football midfielders": "لاعبو وسط كرة قدم شبابية",
    "youth football navigational boxes": "صناديق تصفح كرة قدم شبابية",
    "youth football non-profit organizations": "منظمات غير ربحية كرة قدم شبابية",
    "youth football non-profit publishers": "ناشرون غير ربحيون كرة قدم شبابية",
    "youth football offensive linemen": "مهاجمو خط كرة قدم شبابية",
    "youth football organisations": "منظمات كرة قدم شبابية",
    "youth football organizations": "منظمات كرة قدم شبابية",
    "youth football outside forwards": "مهاجمون خارجيون كرة قدم شبابية",
    "youth football peoplee": "أعلام كرة قدم شبابية",
    "youth football placekickers": "مسددو كرة قدم شبابية",
    "youth football players": "لاعبو كرة قدم شبابية",
    "youth football playerss": "لاعبو كرة قدم شبابية",
    "youth football point guards": "لاعبو هجوم خلفي كرة قدم شبابية",
    "youth football positions": "مراكز كرة قدم شبابية",
    "youth football power forwards": "مهاجمون أقوياء الجسم كرة قدم شبابية",
    "youth football quarterbacks": "أظهرة رباعيون كرة قدم شبابية",
    "youth football receivers": "مستقبلو كرة قدم شبابية",
    "youth football records": "سجلات كرة قدم شبابية",
    "youth football records and statistics": "سجلات وإحصائيات كرة قدم شبابية",
    "youth football referees": "حكام كرة قدم شبابية",
    "youth football results": "نتائج كرة قدم شبابية",
    "youth football right wingers": "أجنحة يمين كرة قدم شبابية",
    "youth football rivalries": "دربيات كرة قدم شبابية",
    "youth football running backs": "راكضون للخلف كرة قدم شبابية",
    "youth football scouts": "كشافة كرة قدم شبابية",
    "youth football shooting guards": "مدافعون مسددون كرة قدم شبابية",
    "youth football small forwards": "مهاجمون صغيرو الجسم كرة قدم شبابية",
    "youth football sports-people": "رياضيو كرة قدم شبابية",
    "youth football squads": "تشكيلات كرة قدم شبابية",
    "youth football statistics": "إحصائيات كرة قدم شبابية",
    "youth football tackles": "مصطدمو كرة قدم شبابية",
    "youth football teams": "فرق كرة قدم شبابية",
    "youth football templates": "قوالب كرة قدم شبابية",
    "youth football tournaments": "بطولات كرة قدم شبابية",
    "youth football trainers": "مدربو كرة قدم شبابية",
    "youth football umpires": "حكام كرة قدم شبابية",
    "youth football utility players": "لاعبو مراكز متعددة كرة قدم شبابية",
    "youth football venues": "ملاعب كرة قدم شبابية",
    "youth football wide receivers": "مستقبلون واسعون كرة قدم شبابية",
    "youth football wing halves": "أنصاف أجنحة كرة قدم شبابية",
    "youth football wingers": "أجنحة كرة قدم شبابية",
    "football centers": "لاعبو وسط كرة قدم",
    "football central defenders": "قلوب دفاع كرة قدم",
    "football centres": "لاعبو وسط كرة قدم",
    "football champions": "أبطال كرة قدم",
    "football clubs": "أندية كرة قدم",
    "football coaches": "مدربو كرة قدم",
    "football competitions": "منافسات كرة قدم",
    "football defencemen": "مدافعو كرة قدم",
    "football defenders": "مدافعو كرة قدم",
    "football defensive backs": "مدافعون خلفيون كرة قدم",
    "football defensive linemen": "مدافعو خط كرة قدم",
    "football directors": "مدراء كرة قدم",
    "football drop kickers": "مسددو ركلات كرة قدم",
    "football events": "أحداث كرة قدم",
    "football films": "أفلام كرة قدم",
    "football finals": "نهائيات كرة قدم",
    "football forwards": "مهاجمو كرة قدم",
    "football fullbacks": "مدافعو كرة قدم",
    "football goalkeepers": "حراس مرمى كرة قدم",
    "football goaltenders": "حراس مرمى كرة قدم",
    "football guards": "حراس كرة قدم",
    "football halfbacks": "أظهرة مساعدون كرة قدم",
    "football home stadiums": "ملاعب كرة قدم",
    "football inside forwards": "مهاجمون داخليون كرة قدم",
    "football journalists": "صحفيو كرة قدم",
    "football kickers": "راكلو كرة قدم",
    "football leagues": "دوريات كرة قدم",
    "football left wingers": "أجنحة يسار كرة قدم",
    "football linebackers": "أظهرة كرة قدم",
    "football lists": "قوائم كرة قدم",
    "football manager history": "تاريخ مدربو كرة قدم",
    "football managers": "مدربو كرة قدم",
    "football matches": "مباريات كرة قدم",
    "football midfielders": "لاعبو وسط كرة قدم",
    "football navigational boxes": "صناديق تصفح كرة قدم",
    "football non-profit organizations": "منظمات غير ربحية كرة قدم",
    "football non-profit publishers": "ناشرون غير ربحيون كرة قدم",
    "football offensive linemen": "مهاجمو خط كرة قدم",
    "football organisations": "منظمات كرة قدم",
    "football organizations": "منظمات كرة قدم",
    "football outside forwards": "مهاجمون خارجيون كرة قدم",
    "football people": "أعلام كرة قدم",
    "football peoplee": "أعلام كرة قدم",
    "football placekickers": "مسددو كرة قدم",
    "football players": "لاعبو كرة قدم",
    "football playerss": "لاعبو كرة قدم",
    "football point guards": "لاعبو هجوم خلفي كرة قدم",
    "football positions": "مراكز كرة قدم",
    "football power forwards": "مهاجمون أقوياء الجسم كرة قدم",
    "football quarterbacks": "أظهرة رباعيون كرة قدم",
    "football receivers": "مستقبلو كرة قدم",
    "football records": "سجلات كرة قدم",
    "football records and statistics": "سجلات وإحصائيات كرة قدم",
    "football referees": "حكام كرة قدم",
    "football results": "نتائج كرة قدم",
    "football right wingers": "أجنحة يمين كرة قدم",
    "football rivalries": "دربيات كرة قدم",
    "football running backs": "راكضون للخلف كرة قدم",
    "football scouts": "كشافة كرة قدم",
    "football shooting guards": "مدافعون مسددون كرة قدم",
    "football small forwards": "مهاجمون صغيرو الجسم كرة قدم",
    "football sports-people": "رياضيو كرة قدم",
    "football squads": "تشكيلات كرة قدم",
    "football statistics": "إحصائيات كرة قدم",
    "football tackles": "مصطدمو كرة قدم",
    "football teams": "فرق كرة قدم",
    "football templates": "قوالب كرة قدم",
    "football tournaments": "بطولات كرة قدم",
    "football trainers": "مدربو كرة قدم",
    "football umpires": "حكام كرة قدم",
    "football utility players": "لاعبو مراكز متعددة كرة قدم",
    "football venues": "ملاعب كرة قدم",
    "football wide receivers": "مستقبلون واسعون كرة قدم",
    "football wing halves": "أنصاف أجنحة كرة قدم",
    "football wingers": "أجنحة كرة قدم",
}


@pytest.mark.parametrize("category, expected_key", teams_2025_data.items(), ids=teams_2025_data.keys())
@pytest.mark.fast
def test_teams_2025_data(category: str, expected_key: str) -> None:
    label = find_teams_2025(category)
    assert label == expected_key


@pytest.mark.parametrize("category, expected_key", teams_2025_data_womens.items(), ids=teams_2025_data_womens.keys())
@pytest.mark.fast
def test_teams_2025_data_womens(category: str, expected_key: str) -> None:
    label = find_teams_2025(category)
    assert label == expected_key


@pytest.mark.parametrize("category, expected_key", data6.items(), ids=data6.keys())
@pytest.mark.fast
def test_find_teams_2025(category: str, expected_key: str) -> None:
    label = find_teams_2025(category)
    assert label == expected_key
