#
import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_label_ar

fast_data_1 = {
    "April 2020 sports events in Africa": "أحداث أبريل 2020 الرياضية في إفريقيا",
    "April 2020 sports events in Argentina": "أحداث أبريل 2020 الرياضية في الأرجنتين",
    "April 2020 sports events in Asia": "أحداث أبريل 2020 الرياضية في آسيا",
    "April 2020 sports events in Australia": "أحداث أبريل 2020 الرياضية في أستراليا",
    "April 2020 sports events in Austria": "أحداث أبريل 2020 الرياضية في النمسا",
    "April 2020 sports events in Azerbaijan": "أحداث أبريل 2020 الرياضية في أذربيجان",
    "April 2020 sports events in Bahrain": "أحداث أبريل 2020 الرياضية في البحرين",
    "April 2020 sports events in Belgium": "أحداث أبريل 2020 الرياضية في بلجيكا",
    "April 2020 sports events in Brazil": "أحداث أبريل 2020 الرياضية في البرازيل",
    "April 2020 sports events in Bulgaria": "أحداث أبريل 2020 الرياضية في بلغاريا",
    "April 2020 sports events in Canada": "أحداث أبريل 2020 الرياضية في كندا",
    "April 2020 sports events in China": "أحداث أبريل 2020 الرياضية في الصين",
    "April 2020 sports events in Croatia": "أحداث أبريل 2020 الرياضية في كرواتيا",
    "April 2020 sports events in Egypt": "أحداث أبريل 2020 الرياضية في مصر",
    "April 2020 sports events in Europe": "أحداث أبريل 2020 الرياضية في أوروبا",
    "April 2020 sports events in France": "أحداث أبريل 2020 الرياضية في فرنسا",
    "April 2020 sports events in Germany": "أحداث أبريل 2020 الرياضية في ألمانيا",
    "April 2020 sports events in Greece": "أحداث أبريل 2020 الرياضية في اليونان",
    "April 2020 sports events in Hungary": "أحداث أبريل 2020 الرياضية في المجر",
    "April 2020 sports events in India": "أحداث أبريل 2020 الرياضية في الهند",
    "April 2020 sports events in Indonesia": "أحداث أبريل 2020 الرياضية في إندونيسيا",
    "April 2020 sports events in Italy": "أحداث أبريل 2020 الرياضية في إيطاليا",
    "April 2020 sports events in Japan": "أحداث أبريل 2020 الرياضية في اليابان",
    "April 2020 sports events in Malaysia": "أحداث أبريل 2020 الرياضية في ماليزيا",
    "April 2020 sports events in Mexico": "أحداث أبريل 2020 الرياضية في المكسيك",
    "April 2020 sports events in Monaco": "أحداث أبريل 2020 الرياضية في موناكو",
    "April 2020 sports events in Morocco": "أحداث أبريل 2020 الرياضية في المغرب",
    "April 2020 sports events in New Zealand": "أحداث أبريل 2020 الرياضية في نيوزيلندا",
    "April 2020 sports events in Nigeria": "أحداث أبريل 2020 الرياضية في نيجيريا",
    "April 2020 sports events in North America": "أحداث أبريل 2020 الرياضية في أمريكا الشمالية",
    "April 2020 sports events in Oceania": "أحداث أبريل 2020 الرياضية في أوقيانوسيا",
    "April 2020 sports events in Pakistan": "أحداث أبريل 2020 الرياضية في باكستان",
    "April 2020 sports events in Poland": "أحداث أبريل 2020 الرياضية في بولندا",
    "April 2020 sports events in Portugal": "أحداث أبريل 2020 الرياضية في البرتغال",
    "April 2020 sports events in Qatar": "أحداث أبريل 2020 الرياضية في قطر",
    "April 2020 sports events in Romania": "أحداث أبريل 2020 الرياضية في رومانيا",
    "April 2020 sports events in Russia": "أحداث أبريل 2020 الرياضية في روسيا",
    "April 2020 sports events in Saudi Arabia": "أحداث أبريل 2020 الرياضية في السعودية",
    "April 2020 sports events in Serbia": "أحداث أبريل 2020 الرياضية في صربيا",
    "April 2020 sports events in Singapore": "أحداث أبريل 2020 الرياضية في سنغافورة",
    "April 2020 sports events in South Africa": "أحداث أبريل 2020 الرياضية في جنوب إفريقيا",
    "April 2020 sports events in South America": "أحداث أبريل 2020 الرياضية في أمريكا الجنوبية",
    "April 2020 sports events in South Korea": "أحداث أبريل 2020 الرياضية في كوريا الجنوبية",
    "April 2020 sports events in Spain": "أحداث أبريل 2020 الرياضية في إسبانيا",
    "April 2020 sports events in Switzerland": "أحداث أبريل 2020 الرياضية في سويسرا",
    "April 2020 sports events in Taiwan": "أحداث أبريل 2020 الرياضية في تايوان",
    "April 2020 sports events in Thailand": "أحداث أبريل 2020 الرياضية في تايلاند",
    "April 2020 sports events in the Czech Republic": "أحداث أبريل 2020 الرياضية في التشيك",
    "April 2020 sports events in the Netherlands": "أحداث أبريل 2020 الرياضية في هولندا",
    "April 2020 sports events in the Philippines": "أحداث أبريل 2020 الرياضية في الفلبين",
    "April 2020 sports events in the United Arab Emirates": "أحداث أبريل 2020 الرياضية في الإمارات العربية المتحدة",
    "April 2020 sports events in the United Kingdom": "أحداث أبريل 2020 الرياضية في المملكة المتحدة",
    "April 2020 sports events in the United States": "أحداث أبريل 2020 الرياضية في الولايات المتحدة",
    "April 2020 sports events in Tunisia": "أحداث أبريل 2020 الرياضية في تونس",
    "April 2020 sports events in Turkey": "أحداث أبريل 2020 الرياضية في تركيا",
    "April 2020 sports events in Ukraine": "أحداث أبريل 2020 الرياضية في أوكرانيا",
    "april 2020 sports-events in europe": "أحداث أبريل 2020 الرياضية في أوروبا",
    "april 2020 sports-events in france": "أحداث أبريل 2020 الرياضية في فرنسا",
    "april 2020 sports-events in malaysia": "أحداث أبريل 2020 الرياضية في ماليزيا",
    "april 2020 sports-events in north america": "أحداث أبريل 2020 الرياضية في أمريكا الشمالية",
    "april 2020 sports-events in oceania": "أحداث أبريل 2020 الرياضية في أوقيانوسيا",
    "april 2020 sports-events in south america": "أحداث أبريل 2020 الرياضية في أمريكا الجنوبية",
    "april 2020 sports-events in the united kingdom": "أحداث أبريل 2020 الرياضية في المملكة المتحدة",
    "april 2020 sports-events in the united states": "أحداث أبريل 2020 الرياضية في الولايات المتحدة",
    "april 2020 sports-events in united kingdom": "أحداث أبريل 2020 الرياضية في المملكة المتحدة",
    "August 2020 sports events in Africa": "أحداث أغسطس 2020 الرياضية في إفريقيا",
    "August 2020 sports events in Argentina": "أحداث أغسطس 2020 الرياضية في الأرجنتين",
    "August 2020 sports events in Asia": "أحداث أغسطس 2020 الرياضية في آسيا",
    "August 2020 sports events in Australia": "أحداث أغسطس 2020 الرياضية في أستراليا",
    "August 2020 sports events in Austria": "أحداث أغسطس 2020 الرياضية في النمسا",
    "August 2020 sports events in Azerbaijan": "أحداث أغسطس 2020 الرياضية في أذربيجان",
    "August 2020 sports events in Bahrain": "أحداث أغسطس 2020 الرياضية في البحرين",
    "August 2020 sports events in Belgium": "أحداث أغسطس 2020 الرياضية في بلجيكا",
    "August 2020 sports events in Brazil": "أحداث أغسطس 2020 الرياضية في البرازيل",
    "August 2020 sports events in Bulgaria": "أحداث أغسطس 2020 الرياضية في بلغاريا",
    "August 2020 sports events in Canada": "أحداث أغسطس 2020 الرياضية في كندا",
    "August 2020 sports events in China": "أحداث أغسطس 2020 الرياضية في الصين",
    "August 2020 sports events in Croatia": "أحداث أغسطس 2020 الرياضية في كرواتيا",
    "August 2020 sports events in Ecuador": "أحداث أغسطس 2020 الرياضية في الإكوادور",
    "August 2020 sports events in Egypt": "أحداث أغسطس 2020 الرياضية في مصر",
    "August 2020 sports events in Europe": "أحداث أغسطس 2020 الرياضية في أوروبا",
    "August 2020 sports events in France": "أحداث أغسطس 2020 الرياضية في فرنسا",
    "August 2020 sports events in Germany": "أحداث أغسطس 2020 الرياضية في ألمانيا",
    "August 2020 sports events in Greece": "أحداث أغسطس 2020 الرياضية في اليونان",
    "August 2020 sports events in Hungary": "أحداث أغسطس 2020 الرياضية في المجر",
    "August 2020 sports events in India": "أحداث أغسطس 2020 الرياضية في الهند",
    "August 2020 sports events in Indonesia": "أحداث أغسطس 2020 الرياضية في إندونيسيا",
    "August 2020 sports events in Iraq": "أحداث أغسطس 2020 الرياضية في العراق",
    "August 2020 sports events in Ireland": "أحداث أغسطس 2020 الرياضية في أيرلندا",
    "August 2020 sports events in Italy": "أحداث أغسطس 2020 الرياضية في إيطاليا",
    "August 2020 sports events in Japan": "أحداث أغسطس 2020 الرياضية في اليابان",
    "August 2020 sports events in Malaysia": "أحداث أغسطس 2020 الرياضية في ماليزيا",
    "August 2020 sports events in Mexico": "أحداث أغسطس 2020 الرياضية في المكسيك",
    "August 2020 sports events in New Zealand": "أحداث أغسطس 2020 الرياضية في نيوزيلندا",
    "August 2020 sports events in Nigeria": "أحداث أغسطس 2020 الرياضية في نيجيريا",
    "August 2020 sports events in North America": "أحداث أغسطس 2020 الرياضية في أمريكا الشمالية",
    "August 2020 sports events in Oceania": "أحداث أغسطس 2020 الرياضية في أوقيانوسيا",
    "August 2020 sports events in Pakistan": "أحداث أغسطس 2020 الرياضية في باكستان",
    "August 2020 sports events in Poland": "أحداث أغسطس 2020 الرياضية في بولندا",
    "August 2020 sports events in Portugal": "أحداث أغسطس 2020 الرياضية في البرتغال",
    "August 2020 sports events in Romania": "أحداث أغسطس 2020 الرياضية في رومانيا",
    "August 2020 sports events in Russia": "أحداث أغسطس 2020 الرياضية في روسيا",
    "August 2020 sports events in Saudi Arabia": "أحداث أغسطس 2020 الرياضية في السعودية",
    "August 2020 sports events in Serbia": "أحداث أغسطس 2020 الرياضية في صربيا",
    "August 2020 sports events in Singapore": "أحداث أغسطس 2020 الرياضية في سنغافورة",
    "August 2020 sports events in Slovakia": "أحداث أغسطس 2020 الرياضية في سلوفاكيا",
    "August 2020 sports events in South Africa": "أحداث أغسطس 2020 الرياضية في جنوب إفريقيا",
    "August 2020 sports events in South America": "أحداث أغسطس 2020 الرياضية في أمريكا الجنوبية",
    "August 2020 sports events in South Korea": "أحداث أغسطس 2020 الرياضية في كوريا الجنوبية",
    "August 2020 sports events in Spain": "أحداث أغسطس 2020 الرياضية في إسبانيا",
    "August 2020 sports events in Switzerland": "أحداث أغسطس 2020 الرياضية في سويسرا",
    "August 2020 sports events in Taiwan": "أحداث أغسطس 2020 الرياضية في تايوان",
    "August 2020 sports events in Thailand": "أحداث أغسطس 2020 الرياضية في تايلاند",
    "August 2020 sports events in the Czech Republic": "أحداث أغسطس 2020 الرياضية في التشيك",
    "August 2020 sports events in the Netherlands": "أحداث أغسطس 2020 الرياضية في هولندا",
    "August 2020 sports events in the Philippines": "أحداث أغسطس 2020 الرياضية في الفلبين",
    "August 2020 sports events in the United Arab Emirates": "أحداث أغسطس 2020 الرياضية في الإمارات العربية المتحدة",
    "August 2020 sports events in the United Kingdom": "أحداث أغسطس 2020 الرياضية في المملكة المتحدة",
    "August 2020 sports events in the United States": "أحداث أغسطس 2020 الرياضية في الولايات المتحدة",
    "August 2020 sports events in Tunisia": "أحداث أغسطس 2020 الرياضية في تونس",
    "August 2020 sports events in Turkey": "أحداث أغسطس 2020 الرياضية في تركيا",
    "August 2020 sports events in Ukraine": "أحداث أغسطس 2020 الرياضية في أوكرانيا",
    "August 2020 sports events in Vanuatu": "أحداث أغسطس 2020 الرياضية في فانواتو",
    "August 2020 sports events in Vietnam": "أحداث أغسطس 2020 الرياضية في فيتنام",
    "august 2020 sports-events in australia": "أحداث أغسطس 2020 الرياضية في أستراليا",
    "august 2020 sports-events in france": "أحداث أغسطس 2020 الرياضية في فرنسا",
    "august 2020 sports-events in north america": "أحداث أغسطس 2020 الرياضية في أمريكا الشمالية",
    "august 2020 sports-events in oceania": "أحداث أغسطس 2020 الرياضية في أوقيانوسيا",
    "august 2020 sports-events in south korea": "أحداث أغسطس 2020 الرياضية في كوريا الجنوبية",
    "august 2020 sports-events in spain": "أحداث أغسطس 2020 الرياضية في إسبانيا",
    "august 2020 sports-events in the united kingdom": "أحداث أغسطس 2020 الرياضية في المملكة المتحدة",
    "august 2020 sports-events in the united states": "أحداث أغسطس 2020 الرياضية في الولايات المتحدة",
    "December 2020 sports events in Africa": "أحداث ديسمبر 2020 الرياضية في إفريقيا",
    "December 2020 sports events in Argentina": "أحداث ديسمبر 2020 الرياضية في الأرجنتين",
    "December 2020 sports events in Asia": "أحداث ديسمبر 2020 الرياضية في آسيا",
    "December 2020 sports events in Australia": "أحداث ديسمبر 2020 الرياضية في أستراليا",
    "December 2020 sports events in Austria": "أحداث ديسمبر 2020 الرياضية في النمسا",
    "December 2020 sports events in Bangladesh": "أحداث ديسمبر 2020 الرياضية في بنغلاديش",
    "December 2020 sports events in Brazil": "أحداث ديسمبر 2020 الرياضية في البرازيل",
    "December 2020 sports events in Canada": "أحداث ديسمبر 2020 الرياضية في كندا",
    "December 2020 sports events in China": "أحداث ديسمبر 2020 الرياضية في الصين",
    "December 2020 sports events in Egypt": "أحداث ديسمبر 2020 الرياضية في مصر",
    "December 2020 sports events in El Salvador": "أحداث ديسمبر 2020 الرياضية في السلفادور",
    "December 2020 sports events in Europe": "أحداث ديسمبر 2020 الرياضية في أوروبا",
    "December 2020 sports events in France": "أحداث ديسمبر 2020 الرياضية في فرنسا",
    "December 2020 sports events in Germany": "أحداث ديسمبر 2020 الرياضية في ألمانيا",
    "December 2020 sports events in Greece": "أحداث ديسمبر 2020 الرياضية في اليونان",
    "December 2020 sports events in India": "أحداث ديسمبر 2020 الرياضية في الهند",
    "December 2020 sports events in Indonesia": "أحداث ديسمبر 2020 الرياضية في إندونيسيا",
    "December 2020 sports events in Iran": "أحداث ديسمبر 2020 الرياضية في إيران",
    "December 2020 sports events in Ireland": "أحداث ديسمبر 2020 الرياضية في أيرلندا",
    "December 2020 sports events in Italy": "أحداث ديسمبر 2020 الرياضية في إيطاليا",
    "December 2020 sports events in Japan": "أحداث ديسمبر 2020 الرياضية في اليابان",
    "December 2020 sports events in Malaysia": "أحداث ديسمبر 2020 الرياضية في ماليزيا",
    "December 2020 sports events in Mexico": "أحداث ديسمبر 2020 الرياضية في المكسيك",
    "December 2020 sports events in Morocco": "أحداث ديسمبر 2020 الرياضية في المغرب",
    "December 2020 sports events in New Zealand": "أحداث ديسمبر 2020 الرياضية في نيوزيلندا",
    "December 2020 sports events in North America": "أحداث ديسمبر 2020 الرياضية في أمريكا الشمالية",
    "December 2020 sports events in Oceania": "أحداث ديسمبر 2020 الرياضية في أوقيانوسيا",
    "December 2020 sports events in Pakistan": "أحداث ديسمبر 2020 الرياضية في باكستان",
    "December 2020 sports events in Poland": "أحداث ديسمبر 2020 الرياضية في بولندا",
    "December 2020 sports events in Portugal": "أحداث ديسمبر 2020 الرياضية في البرتغال",
    "December 2020 sports events in Qatar": "أحداث ديسمبر 2020 الرياضية في قطر",
    "December 2020 sports events in Russia": "أحداث ديسمبر 2020 الرياضية في روسيا",
    "December 2020 sports events in Saudi Arabia": "أحداث ديسمبر 2020 الرياضية في السعودية",
    "December 2020 sports events in Singapore": "أحداث ديسمبر 2020 الرياضية في سنغافورة",
    "December 2020 sports events in South Africa": "أحداث ديسمبر 2020 الرياضية في جنوب إفريقيا",
    "December 2020 sports events in South America": "أحداث ديسمبر 2020 الرياضية في أمريكا الجنوبية",
    "December 2020 sports events in South Korea": "أحداث ديسمبر 2020 الرياضية في كوريا الجنوبية",
    "December 2020 sports events in Spain": "أحداث ديسمبر 2020 الرياضية في إسبانيا",
    "December 2020 sports events in Switzerland": "أحداث ديسمبر 2020 الرياضية في سويسرا",
    "December 2020 sports events in Taiwan": "أحداث ديسمبر 2020 الرياضية في تايوان",
    "December 2020 sports events in Thailand": "أحداث ديسمبر 2020 الرياضية في تايلاند",
    "December 2020 sports events in the Czech Republic": "أحداث ديسمبر 2020 الرياضية في التشيك",
    "December 2020 sports events in the Netherlands": "أحداث ديسمبر 2020 الرياضية في هولندا",
    "December 2020 sports events in the Philippines": "أحداث ديسمبر 2020 الرياضية في الفلبين",
    "December 2020 sports events in the United Arab Emirates": "أحداث ديسمبر 2020 الرياضية في الإمارات العربية المتحدة",
    "December 2020 sports events in the United Kingdom": "أحداث ديسمبر 2020 الرياضية في المملكة المتحدة",
    "December 2020 sports events in the United States": "أحداث ديسمبر 2020 الرياضية في الولايات المتحدة",
    "December 2020 sports events in Tunisia": "أحداث ديسمبر 2020 الرياضية في تونس",
    "December 2020 sports events in Turkey": "أحداث ديسمبر 2020 الرياضية في تركيا",
    "December 2020 sports events in Ukraine": "أحداث ديسمبر 2020 الرياضية في أوكرانيا",
    "december 2020 sports-events in the philippines": "أحداث ديسمبر 2020 الرياضية في الفلبين",
    "december 2020 sports-events in the united states": "أحداث ديسمبر 2020 الرياضية في الولايات المتحدة",
    "december 2020 sports-events in united kingdom": "أحداث ديسمبر 2020 الرياضية في المملكة المتحدة",
    "december 2020 sports-events in united states": "أحداث ديسمبر 2020 الرياضية في الولايات المتحدة",
    "February 2020 sports events in Africa": "أحداث فبراير 2020 الرياضية في إفريقيا",
    "February 2020 sports events in Argentina": "أحداث فبراير 2020 الرياضية في الأرجنتين",
    "February 2020 sports events in Asia": "أحداث فبراير 2020 الرياضية في آسيا",
    "February 2020 sports events in Australia": "أحداث فبراير 2020 الرياضية في أستراليا",
    "February 2020 sports events in Austria": "أحداث فبراير 2020 الرياضية في النمسا",
    "February 2020 sports events in Azerbaijan": "أحداث فبراير 2020 الرياضية في أذربيجان",
    "February 2020 sports events in Bahrain": "أحداث فبراير 2020 الرياضية في البحرين",
    "February 2020 sports events in Bangladesh": "أحداث فبراير 2020 الرياضية في بنغلاديش",
    "February 2020 sports events in Belgium": "أحداث فبراير 2020 الرياضية في بلجيكا",
    "February 2020 sports events in Brazil": "أحداث فبراير 2020 الرياضية في البرازيل",
    "February 2020 sports events in Bulgaria": "أحداث فبراير 2020 الرياضية في بلغاريا",
    "February 2020 sports events in Canada": "أحداث فبراير 2020 الرياضية في كندا",
    "February 2020 sports events in China": "أحداث فبراير 2020 الرياضية في الصين",
    "February 2020 sports events in Costa Rica": "أحداث فبراير 2020 الرياضية في كوستاريكا",
    "February 2020 sports events in Croatia": "أحداث فبراير 2020 الرياضية في كرواتيا",
    "February 2020 sports events in Egypt": "أحداث فبراير 2020 الرياضية في مصر",
    "February 2020 sports events in Europe": "أحداث فبراير 2020 الرياضية في أوروبا",
    "February 2020 sports events in Fiji": "أحداث فبراير 2020 الرياضية في فيجي",
    "February 2020 sports events in France": "أحداث فبراير 2020 الرياضية في فرنسا",
    "February 2020 sports events in Germany": "أحداث فبراير 2020 الرياضية في ألمانيا",
    "February 2020 sports events in Hungary": "أحداث فبراير 2020 الرياضية في المجر",
    "February 2020 sports events in India": "أحداث فبراير 2020 الرياضية في الهند",
    "February 2020 sports events in Iran": "أحداث فبراير 2020 الرياضية في إيران",
    "February 2020 sports events in Ireland": "أحداث فبراير 2020 الرياضية في أيرلندا",
    "February 2020 sports events in Italy": "أحداث فبراير 2020 الرياضية في إيطاليا",
    "February 2020 sports events in Japan": "أحداث فبراير 2020 الرياضية في اليابان",
    "February 2020 sports events in Malaysia": "أحداث فبراير 2020 الرياضية في ماليزيا",
    "February 2020 sports events in Mexico": "أحداث فبراير 2020 الرياضية في المكسيك",
    "February 2020 sports events in New Zealand": "أحداث فبراير 2020 الرياضية في نيوزيلندا",
    "February 2020 sports events in Nigeria": "أحداث فبراير 2020 الرياضية في نيجيريا",
    "February 2020 sports events in North America": "أحداث فبراير 2020 الرياضية في أمريكا الشمالية",
    "February 2020 sports events in Oceania": "أحداث فبراير 2020 الرياضية في أوقيانوسيا",
    "February 2020 sports events in Pakistan": "أحداث فبراير 2020 الرياضية في باكستان",
    "February 2020 sports events in Poland": "أحداث فبراير 2020 الرياضية في بولندا",
    "February 2020 sports events in Portugal": "أحداث فبراير 2020 الرياضية في البرتغال",
    "February 2020 sports events in Qatar": "أحداث فبراير 2020 الرياضية في قطر",
    "February 2020 sports events in Romania": "أحداث فبراير 2020 الرياضية في رومانيا",
    "February 2020 sports events in Russia": "أحداث فبراير 2020 الرياضية في روسيا",
    "February 2020 sports events in Saudi Arabia": "أحداث فبراير 2020 الرياضية في السعودية",
    "February 2020 sports events in Serbia": "أحداث فبراير 2020 الرياضية في صربيا",
    "February 2020 sports events in Singapore": "أحداث فبراير 2020 الرياضية في سنغافورة",
    "February 2020 sports events in South Africa": "أحداث فبراير 2020 الرياضية في جنوب إفريقيا",
    "February 2020 sports events in South America": "أحداث فبراير 2020 الرياضية في أمريكا الجنوبية",
    "February 2020 sports events in South Korea": "أحداث فبراير 2020 الرياضية في كوريا الجنوبية",
    "February 2020 sports events in Spain": "أحداث فبراير 2020 الرياضية في إسبانيا",
    "February 2020 sports events in Switzerland": "أحداث فبراير 2020 الرياضية في سويسرا",
    "February 2020 sports events in Taiwan": "أحداث فبراير 2020 الرياضية في تايوان",
    "February 2020 sports events in Thailand": "أحداث فبراير 2020 الرياضية في تايلاند",
    "February 2020 sports events in the Czech Republic": "أحداث فبراير 2020 الرياضية في التشيك",
    "February 2020 sports events in the Netherlands": "أحداث فبراير 2020 الرياضية في هولندا",
    "February 2020 sports events in the Philippines": "أحداث فبراير 2020 الرياضية في الفلبين",
    "February 2020 sports events in the United Arab Emirates": "أحداث فبراير 2020 الرياضية في الإمارات العربية المتحدة",
    "February 2020 sports events in the United Kingdom": "أحداث فبراير 2020 الرياضية في المملكة المتحدة",
    "February 2020 sports events in the United States": "أحداث فبراير 2020 الرياضية في الولايات المتحدة",
    "February 2020 sports events in Tunisia": "أحداث فبراير 2020 الرياضية في تونس",
    "February 2020 sports events in Turkey": "أحداث فبراير 2020 الرياضية في تركيا",
    "February 2020 sports events in Ukraine": "أحداث فبراير 2020 الرياضية في أوكرانيا",
    "february 2020 sports-events in asia": "أحداث فبراير 2020 الرياضية في آسيا",
    "february 2020 sports-events in germany": "أحداث فبراير 2020 الرياضية في ألمانيا",
    "January 2020 sports events in Africa": "أحداث يناير 2020 الرياضية في إفريقيا",
    "January 2020 sports events in Algeria": "أحداث يناير 2020 الرياضية في الجزائر",
    "January 2020 sports events in Argentina": "أحداث يناير 2020 الرياضية في الأرجنتين",
    "January 2020 sports events in Asia": "أحداث يناير 2020 الرياضية في آسيا",
    "January 2020 sports events in Australia": "أحداث يناير 2020 الرياضية في أستراليا",
    "January 2020 sports events in Austria": "أحداث يناير 2020 الرياضية في النمسا",
    "January 2020 sports events in Bahrain": "أحداث يناير 2020 الرياضية في البحرين",
    "January 2020 sports events in Bangladesh": "أحداث يناير 2020 الرياضية في بنغلاديش",
    "January 2020 sports events in Belgium": "أحداث يناير 2020 الرياضية في بلجيكا",
    "January 2020 sports events in Brazil": "أحداث يناير 2020 الرياضية في البرازيل",
    "January 2020 sports events in Bulgaria": "أحداث يناير 2020 الرياضية في بلغاريا",
    "January 2020 sports events in Canada": "أحداث يناير 2020 الرياضية في كندا",
    "January 2020 sports events in China": "أحداث يناير 2020 الرياضية في الصين",
    "January 2020 sports events in Croatia": "أحداث يناير 2020 الرياضية في كرواتيا",
    "January 2020 sports events in Egypt": "أحداث يناير 2020 الرياضية في مصر",
    "January 2020 sports events in Europe": "أحداث يناير 2020 الرياضية في أوروبا",
    "January 2020 sports events in Fiji": "أحداث يناير 2020 الرياضية في فيجي",
    "January 2020 sports events in France": "أحداث يناير 2020 الرياضية في فرنسا",
    "January 2020 sports events in Germany": "أحداث يناير 2020 الرياضية في ألمانيا",
    "January 2020 sports events in Hungary": "أحداث يناير 2020 الرياضية في المجر",
    "January 2020 sports events in India": "أحداث يناير 2020 الرياضية في الهند",
    "January 2020 sports events in Indonesia": "أحداث يناير 2020 الرياضية في إندونيسيا",
    "January 2020 sports events in Ireland": "أحداث يناير 2020 الرياضية في أيرلندا",
    "January 2020 sports events in Italy": "أحداث يناير 2020 الرياضية في إيطاليا",
    "January 2020 sports events in Japan": "أحداث يناير 2020 الرياضية في اليابان",
    "January 2020 sports events in Malaysia": "أحداث يناير 2020 الرياضية في ماليزيا",
    "January 2020 sports events in Mexico": "أحداث يناير 2020 الرياضية في المكسيك",
    "January 2020 sports events in Morocco": "أحداث يناير 2020 الرياضية في المغرب",
    "January 2020 sports events in New Zealand": "أحداث يناير 2020 الرياضية في نيوزيلندا",
    "January 2020 sports events in North America": "أحداث يناير 2020 الرياضية في أمريكا الشمالية",
    "January 2020 sports events in Oceania": "أحداث يناير 2020 الرياضية في أوقيانوسيا",
    "January 2020 sports events in Oman": "أحداث يناير 2020 الرياضية في سلطنة عمان",
    "January 2020 sports events in Pakistan": "أحداث يناير 2020 الرياضية في باكستان",
    "January 2020 sports events in Poland": "أحداث يناير 2020 الرياضية في بولندا",
    "January 2020 sports events in Portugal": "أحداث يناير 2020 الرياضية في البرتغال",
    "January 2020 sports events in Qatar": "أحداث يناير 2020 الرياضية في قطر",
    "January 2020 sports events in Russia": "أحداث يناير 2020 الرياضية في روسيا",
    "January 2020 sports events in Saudi Arabia": "أحداث يناير 2020 الرياضية في السعودية",
    "January 2020 sports events in Serbia": "أحداث يناير 2020 الرياضية في صربيا",
    "January 2020 sports events in Singapore": "أحداث يناير 2020 الرياضية في سنغافورة",
    "January 2020 sports events in Slovakia": "أحداث يناير 2020 الرياضية في سلوفاكيا",
    "January 2020 sports events in South Africa": "أحداث يناير 2020 الرياضية في جنوب إفريقيا",
    "January 2020 sports events in South America": "أحداث يناير 2020 الرياضية في أمريكا الجنوبية",
    "January 2020 sports events in South Korea": "أحداث يناير 2020 الرياضية في كوريا الجنوبية",
    "January 2020 sports events in Spain": "أحداث يناير 2020 الرياضية في إسبانيا",
    "January 2020 sports events in Switzerland": "أحداث يناير 2020 الرياضية في سويسرا",
    "January 2020 sports events in Thailand": "أحداث يناير 2020 الرياضية في تايلاند",
    "January 2020 sports events in the Netherlands": "أحداث يناير 2020 الرياضية في هولندا",
    "January 2020 sports events in the Philippines": "أحداث يناير 2020 الرياضية في الفلبين",
    "January 2020 sports events in the United Arab Emirates": "أحداث يناير 2020 الرياضية في الإمارات العربية المتحدة",
    "January 2020 sports events in the United Kingdom": "أحداث يناير 2020 الرياضية في المملكة المتحدة",
    "January 2020 sports events in the United States": "أحداث يناير 2020 الرياضية في الولايات المتحدة",
    "January 2020 sports events in Tunisia": "أحداث يناير 2020 الرياضية في تونس",
    "January 2020 sports events in Turkey": "أحداث يناير 2020 الرياضية في تركيا",
    "January 2020 sports events in Vietnam": "أحداث يناير 2020 الرياضية في فيتنام",
    "january 2020 sports-events in austria": "أحداث يناير 2020 الرياضية في النمسا",
    "january 2020 sports-events in europe": "أحداث يناير 2020 الرياضية في أوروبا",
    "january 2020 sports-events in germany": "أحداث يناير 2020 الرياضية في ألمانيا",
    "january 2020 sports-events in north america": "أحداث يناير 2020 الرياضية في أمريكا الشمالية",
    "january 2020 sports-events in russia": "أحداث يناير 2020 الرياضية في روسيا",
    "July 2020 sports events in Africa": "أحداث يوليو 2020 الرياضية في إفريقيا",
    "July 2020 sports events in Algeria": "أحداث يوليو 2020 الرياضية في الجزائر",
    "July 2020 sports events in Argentina": "أحداث يوليو 2020 الرياضية في الأرجنتين",
    "July 2020 sports events in Asia": "أحداث يوليو 2020 الرياضية في آسيا",
    "July 2020 sports events in Australia": "أحداث يوليو 2020 الرياضية في أستراليا",
    "July 2020 sports events in Austria": "أحداث يوليو 2020 الرياضية في النمسا",
    "July 2020 sports events in Azerbaijan": "أحداث يوليو 2020 الرياضية في أذربيجان",
    "July 2020 sports events in Bahrain": "أحداث يوليو 2020 الرياضية في البحرين",
    "July 2020 sports events in Bangladesh": "أحداث يوليو 2020 الرياضية في بنغلاديش",
    "July 2020 sports events in Belgium": "أحداث يوليو 2020 الرياضية في بلجيكا",
    "July 2020 sports events in Brazil": "أحداث يوليو 2020 الرياضية في البرازيل",
    "July 2020 sports events in Bulgaria": "أحداث يوليو 2020 الرياضية في بلغاريا",
    "July 2020 sports events in Canada": "أحداث يوليو 2020 الرياضية في كندا",
    "July 2020 sports events in China": "أحداث يوليو 2020 الرياضية في الصين",
    "July 2020 sports events in Croatia": "أحداث يوليو 2020 الرياضية في كرواتيا",
    "July 2020 sports events in Egypt": "أحداث يوليو 2020 الرياضية في مصر",
    "July 2020 sports events in Europe": "أحداث يوليو 2020 الرياضية في أوروبا",
    "July 2020 sports events in Fiji": "أحداث يوليو 2020 الرياضية في فيجي",
    "July 2020 sports events in France": "أحداث يوليو 2020 الرياضية في فرنسا",
    "July 2020 sports events in Germany": "أحداث يوليو 2020 الرياضية في ألمانيا",
    "July 2020 sports events in Greece": "أحداث يوليو 2020 الرياضية في اليونان",
    "July 2020 sports events in Hungary": "أحداث يوليو 2020 الرياضية في المجر",
    "July 2020 sports events in India": "أحداث يوليو 2020 الرياضية في الهند",
    "July 2020 sports events in Indonesia": "أحداث يوليو 2020 الرياضية في إندونيسيا",
    "July 2020 sports events in Iran": "أحداث يوليو 2020 الرياضية في إيران",
    "July 2020 sports events in Iraq": "أحداث يوليو 2020 الرياضية في العراق",
    "July 2020 sports events in Ireland": "أحداث يوليو 2020 الرياضية في أيرلندا",
    "July 2020 sports events in Italy": "أحداث يوليو 2020 الرياضية في إيطاليا",
    "July 2020 sports events in Japan": "أحداث يوليو 2020 الرياضية في اليابان",
    "July 2020 sports events in Lebanon": "أحداث يوليو 2020 الرياضية في لبنان",
    "July 2020 sports events in Malaysia": "أحداث يوليو 2020 الرياضية في ماليزيا",
    "July 2020 sports events in Mexico": "أحداث يوليو 2020 الرياضية في المكسيك",
    "July 2020 sports events in Morocco": "أحداث يوليو 2020 الرياضية في المغرب",
    "July 2020 sports events in New Zealand": "أحداث يوليو 2020 الرياضية في نيوزيلندا",
    "July 2020 sports events in North America": "أحداث يوليو 2020 الرياضية في أمريكا الشمالية",
    "July 2020 sports events in Oceania": "أحداث يوليو 2020 الرياضية في أوقيانوسيا",
    "July 2020 sports events in Pakistan": "أحداث يوليو 2020 الرياضية في باكستان",
    "July 2020 sports events in Poland": "أحداث يوليو 2020 الرياضية في بولندا",
    "July 2020 sports events in Portugal": "أحداث يوليو 2020 الرياضية في البرتغال",
    "July 2020 sports events in Romania": "أحداث يوليو 2020 الرياضية في رومانيا",
    "July 2020 sports events in Russia": "أحداث يوليو 2020 الرياضية في روسيا",
    "July 2020 sports events in Saudi Arabia": "أحداث يوليو 2020 الرياضية في السعودية",
    "July 2020 sports events in Serbia": "أحداث يوليو 2020 الرياضية في صربيا",
    "July 2020 sports events in Singapore": "أحداث يوليو 2020 الرياضية في سنغافورة",
    "July 2020 sports events in Slovakia": "أحداث يوليو 2020 الرياضية في سلوفاكيا",
    "July 2020 sports events in South Africa": "أحداث يوليو 2020 الرياضية في جنوب إفريقيا",
    "July 2020 sports events in South America": "أحداث يوليو 2020 الرياضية في أمريكا الجنوبية",
    "July 2020 sports events in South Korea": "أحداث يوليو 2020 الرياضية في كوريا الجنوبية",
    "July 2020 sports events in Spain": "أحداث يوليو 2020 الرياضية في إسبانيا",
    "July 2020 sports events in Switzerland": "أحداث يوليو 2020 الرياضية في سويسرا",
    "July 2020 sports events in Taiwan": "أحداث يوليو 2020 الرياضية في تايوان",
    "July 2020 sports events in Thailand": "أحداث يوليو 2020 الرياضية في تايلاند",
    "July 2020 sports events in the Czech Republic": "أحداث يوليو 2020 الرياضية في التشيك",
    "July 2020 sports events in the Netherlands": "أحداث يوليو 2020 الرياضية في هولندا",
    "July 2020 sports events in the Philippines": "أحداث يوليو 2020 الرياضية في الفلبين",
    "July 2020 sports events in the United Arab Emirates": "أحداث يوليو 2020 الرياضية في الإمارات العربية المتحدة",
    "July 2020 sports events in the United Kingdom": "أحداث يوليو 2020 الرياضية في المملكة المتحدة",
    "July 2020 sports events in the United States": "أحداث يوليو 2020 الرياضية في الولايات المتحدة",
    "July 2020 sports events in Tunisia": "أحداث يوليو 2020 الرياضية في تونس",
    "July 2020 sports events in Turkey": "أحداث يوليو 2020 الرياضية في تركيا",
    "July 2020 sports events in Ukraine": "أحداث يوليو 2020 الرياضية في أوكرانيا",
    "july 2020 sports-events in africa": "أحداث يوليو 2020 الرياضية في إفريقيا",
    "july 2020 sports-events in asia": "أحداث يوليو 2020 الرياضية في آسيا",
    "july 2020 sports-events in australia": "أحداث يوليو 2020 الرياضية في أستراليا",
    "july 2020 sports-events in austria": "أحداث يوليو 2020 الرياضية في النمسا",
    "july 2020 sports-events in china": "أحداث يوليو 2020 الرياضية في الصين",
    "july 2020 sports-events in indonesia": "أحداث يوليو 2020 الرياضية في إندونيسيا",
    "july 2020 sports-events in north america": "أحداث يوليو 2020 الرياضية في أمريكا الشمالية",
    "June 2020 sports events in Africa": "أحداث يونيو 2020 الرياضية في إفريقيا",
    "June 2020 sports events in Algeria": "أحداث يونيو 2020 الرياضية في الجزائر",
    "June 2020 sports events in Argentina": "أحداث يونيو 2020 الرياضية في الأرجنتين",
    "June 2020 sports events in Asia": "أحداث يونيو 2020 الرياضية في آسيا",
    "June 2020 sports events in Australia": "أحداث يونيو 2020 الرياضية في أستراليا",
    "June 2020 sports events in Austria": "أحداث يونيو 2020 الرياضية في النمسا",
    "June 2020 sports events in Azerbaijan": "أحداث يونيو 2020 الرياضية في أذربيجان",
    "June 2020 sports events in Bahrain": "أحداث يونيو 2020 الرياضية في البحرين",
    "June 2020 sports events in Belgium": "أحداث يونيو 2020 الرياضية في بلجيكا",
    "June 2020 sports events in Brazil": "أحداث يونيو 2020 الرياضية في البرازيل",
    "June 2020 sports events in Bulgaria": "أحداث يونيو 2020 الرياضية في بلغاريا",
    "June 2020 sports events in Canada": "أحداث يونيو 2020 الرياضية في كندا",
    "June 2020 sports events in China": "أحداث يونيو 2020 الرياضية في الصين",
    "June 2020 sports events in Croatia": "أحداث يونيو 2020 الرياضية في كرواتيا",
    "June 2020 sports events in Egypt": "أحداث يونيو 2020 الرياضية في مصر",
    "June 2020 sports events in Europe": "أحداث يونيو 2020 الرياضية في أوروبا",
    "June 2020 sports events in Fiji": "أحداث يونيو 2020 الرياضية في فيجي",
    "June 2020 sports events in France": "أحداث يونيو 2020 الرياضية في فرنسا",
    "June 2020 sports events in Germany": "أحداث يونيو 2020 الرياضية في ألمانيا",
    "June 2020 sports events in Greece": "أحداث يونيو 2020 الرياضية في اليونان",
    "June 2020 sports events in Hungary": "أحداث يونيو 2020 الرياضية في المجر",
    "June 2020 sports events in India": "أحداث يونيو 2020 الرياضية في الهند",
    "June 2020 sports events in Indonesia": "أحداث يونيو 2020 الرياضية في إندونيسيا",
    "June 2020 sports events in Iran": "أحداث يونيو 2020 الرياضية في إيران",
    "June 2020 sports events in Ireland": "أحداث يونيو 2020 الرياضية في أيرلندا",
    "June 2020 sports events in Italy": "أحداث يونيو 2020 الرياضية في إيطاليا",
    "June 2020 sports events in Japan": "أحداث يونيو 2020 الرياضية في اليابان",
    "June 2020 sports events in Malaysia": "أحداث يونيو 2020 الرياضية في ماليزيا",
    "June 2020 sports events in Mexico": "أحداث يونيو 2020 الرياضية في المكسيك",
    "June 2020 sports events in Morocco": "أحداث يونيو 2020 الرياضية في المغرب",
    "June 2020 sports events in New Zealand": "أحداث يونيو 2020 الرياضية في نيوزيلندا",
    "June 2020 sports events in North America": "أحداث يونيو 2020 الرياضية في أمريكا الشمالية",
    "June 2020 sports events in Oceania": "أحداث يونيو 2020 الرياضية في أوقيانوسيا",
    "June 2020 sports events in Papua New Guinea": "أحداث يونيو 2020 الرياضية في بابوا غينيا الجديدة",
    "June 2020 sports events in Poland": "أحداث يونيو 2020 الرياضية في بولندا",
    "June 2020 sports events in Portugal": "أحداث يونيو 2020 الرياضية في البرتغال",
    "June 2020 sports events in Qatar": "أحداث يونيو 2020 الرياضية في قطر",
    "June 2020 sports events in Romania": "أحداث يونيو 2020 الرياضية في رومانيا",
    "June 2020 sports events in Russia": "أحداث يونيو 2020 الرياضية في روسيا",
    "June 2020 sports events in Saudi Arabia": "أحداث يونيو 2020 الرياضية في السعودية",
    "June 2020 sports events in Serbia": "أحداث يونيو 2020 الرياضية في صربيا",
    "June 2020 sports events in Singapore": "أحداث يونيو 2020 الرياضية في سنغافورة",
    "June 2020 sports events in Slovakia": "أحداث يونيو 2020 الرياضية في سلوفاكيا",
    "June 2020 sports events in South Africa": "أحداث يونيو 2020 الرياضية في جنوب إفريقيا",
    "June 2020 sports events in South America": "أحداث يونيو 2020 الرياضية في أمريكا الجنوبية",
    "June 2020 sports events in South Korea": "أحداث يونيو 2020 الرياضية في كوريا الجنوبية",
    "June 2020 sports events in Spain": "أحداث يونيو 2020 الرياضية في إسبانيا",
    "June 2020 sports events in Switzerland": "أحداث يونيو 2020 الرياضية في سويسرا",
    "June 2020 sports events in Taiwan": "أحداث يونيو 2020 الرياضية في تايوان",
    "June 2020 sports events in Thailand": "أحداث يونيو 2020 الرياضية في تايلاند",
    "June 2020 sports events in the Czech Republic": "أحداث يونيو 2020 الرياضية في التشيك",
    "June 2020 sports events in the Netherlands": "أحداث يونيو 2020 الرياضية في هولندا",
    "June 2020 sports events in the Philippines": "أحداث يونيو 2020 الرياضية في الفلبين",
    "June 2020 sports events in the United Kingdom": "أحداث يونيو 2020 الرياضية في المملكة المتحدة",
    "June 2020 sports events in the United States": "أحداث يونيو 2020 الرياضية في الولايات المتحدة",
    "June 2020 sports events in Tunisia": "أحداث يونيو 2020 الرياضية في تونس",
    "June 2020 sports events in Turkey": "أحداث يونيو 2020 الرياضية في تركيا",
    "June 2020 sports events in Ukraine": "أحداث يونيو 2020 الرياضية في أوكرانيا",
    "June 2020 sports events in Vietnam": "أحداث يونيو 2020 الرياضية في فيتنام",
    "june 2020 sports-events in austria": "أحداث يونيو 2020 الرياضية في النمسا",
    "june 2020 sports-events in canada": "أحداث يونيو 2020 الرياضية في كندا",
    "june 2020 sports-events in malaysia": "أحداث يونيو 2020 الرياضية في ماليزيا",
    "june 2020 sports-events in south america": "أحداث يونيو 2020 الرياضية في أمريكا الجنوبية",
    "june 2020 sports-events in the united states": "أحداث يونيو 2020 الرياضية في الولايات المتحدة",
    "March 2020 sports events in Africa": "أحداث مارس 2020 الرياضية في إفريقيا",
    "March 2020 sports events in Argentina": "أحداث مارس 2020 الرياضية في الأرجنتين",
    "March 2020 sports events in Asia": "أحداث مارس 2020 الرياضية في آسيا",
    "March 2020 sports events in Australia": "أحداث مارس 2020 الرياضية في أستراليا",
    "March 2020 sports events in Austria": "أحداث مارس 2020 الرياضية في النمسا",
    "March 2020 sports events in Bahrain": "أحداث مارس 2020 الرياضية في البحرين",
    "March 2020 sports events in Belgium": "أحداث مارس 2020 الرياضية في بلجيكا",
    "March 2020 sports events in Brazil": "أحداث مارس 2020 الرياضية في البرازيل",
    "March 2020 sports events in Bulgaria": "أحداث مارس 2020 الرياضية في بلغاريا",
    "March 2020 sports events in Canada": "أحداث مارس 2020 الرياضية في كندا",
    "March 2020 sports events in China": "أحداث مارس 2020 الرياضية في الصين",
    "March 2020 sports events in Costa Rica": "أحداث مارس 2020 الرياضية في كوستاريكا",
    "March 2020 sports events in Croatia": "أحداث مارس 2020 الرياضية في كرواتيا",
    "March 2020 sports events in Egypt": "أحداث مارس 2020 الرياضية في مصر",
    "March 2020 sports events in Europe": "أحداث مارس 2020 الرياضية في أوروبا",
    "March 2020 sports events in France": "أحداث مارس 2020 الرياضية في فرنسا",
    "March 2020 sports events in Germany": "أحداث مارس 2020 الرياضية في ألمانيا",
    "March 2020 sports events in Greece": "أحداث مارس 2020 الرياضية في اليونان",
    "March 2020 sports events in Hungary": "أحداث مارس 2020 الرياضية في المجر",
    "March 2020 sports events in India": "أحداث مارس 2020 الرياضية في الهند",
    "March 2020 sports events in Indonesia": "أحداث مارس 2020 الرياضية في إندونيسيا",
    "March 2020 sports events in Iran": "أحداث مارس 2020 الرياضية في إيران",
    "March 2020 sports events in Iraq": "أحداث مارس 2020 الرياضية في العراق",
    "March 2020 sports events in Ireland": "أحداث مارس 2020 الرياضية في أيرلندا",
    "March 2020 sports events in Italy": "أحداث مارس 2020 الرياضية في إيطاليا",
    "March 2020 sports events in Japan": "أحداث مارس 2020 الرياضية في اليابان",
    "March 2020 sports events in Kuwait": "أحداث مارس 2020 الرياضية في الكويت",
    "March 2020 sports events in Malaysia": "أحداث مارس 2020 الرياضية في ماليزيا",
    "March 2020 sports events in Mexico": "أحداث مارس 2020 الرياضية في المكسيك",
    "March 2020 sports events in New Zealand": "أحداث مارس 2020 الرياضية في نيوزيلندا",
    "March 2020 sports events in Nigeria": "أحداث مارس 2020 الرياضية في نيجيريا",
    "March 2020 sports events in North America": "أحداث مارس 2020 الرياضية في أمريكا الشمالية",
    "March 2020 sports events in Oceania": "أحداث مارس 2020 الرياضية في أوقيانوسيا",
    "March 2020 sports events in Pakistan": "أحداث مارس 2020 الرياضية في باكستان",
    "March 2020 sports events in Poland": "أحداث مارس 2020 الرياضية في بولندا",
    "March 2020 sports events in Portugal": "أحداث مارس 2020 الرياضية في البرتغال",
    "March 2020 sports events in Qatar": "أحداث مارس 2020 الرياضية في قطر",
    "March 2020 sports events in Romania": "أحداث مارس 2020 الرياضية في رومانيا",
    "March 2020 sports events in Russia": "أحداث مارس 2020 الرياضية في روسيا",
    "March 2020 sports events in Saudi Arabia": "أحداث مارس 2020 الرياضية في السعودية",
    "March 2020 sports events in Serbia": "أحداث مارس 2020 الرياضية في صربيا",
    "March 2020 sports events in Singapore": "أحداث مارس 2020 الرياضية في سنغافورة",
    "March 2020 sports events in Slovakia": "أحداث مارس 2020 الرياضية في سلوفاكيا",
    "March 2020 sports events in South Africa": "أحداث مارس 2020 الرياضية في جنوب إفريقيا",
    "March 2020 sports events in South America": "أحداث مارس 2020 الرياضية في أمريكا الجنوبية",
    "March 2020 sports events in South Korea": "أحداث مارس 2020 الرياضية في كوريا الجنوبية",
    "March 2020 sports events in Spain": "أحداث مارس 2020 الرياضية في إسبانيا",
    "March 2020 sports events in Switzerland": "أحداث مارس 2020 الرياضية في سويسرا",
    "March 2020 sports events in Taiwan": "أحداث مارس 2020 الرياضية في تايوان",
    "March 2020 sports events in Thailand": "أحداث مارس 2020 الرياضية في تايلاند",
    "March 2020 sports events in the Czech Republic": "أحداث مارس 2020 الرياضية في التشيك",
    "March 2020 sports events in the Netherlands": "أحداث مارس 2020 الرياضية في هولندا",
    "March 2020 sports events in the Philippines": "أحداث مارس 2020 الرياضية في الفلبين",
    "March 2020 sports events in the United Arab Emirates": "أحداث مارس 2020 الرياضية في الإمارات العربية المتحدة",
    "March 2020 sports events in the United Kingdom": "أحداث مارس 2020 الرياضية في المملكة المتحدة",
    "March 2020 sports events in the United States": "أحداث مارس 2020 الرياضية في الولايات المتحدة",
    "March 2020 sports events in Turkey": "أحداث مارس 2020 الرياضية في تركيا",
    "March 2020 sports events in Ukraine": "أحداث مارس 2020 الرياضية في أوكرانيا",
    "March 2020 sports events in Uzbekistan": "أحداث مارس 2020 الرياضية في أوزبكستان",
    "march 2020 sports-events in belgium": "أحداث مارس 2020 الرياضية في بلجيكا",
    "march 2020 sports-events in china": "أحداث مارس 2020 الرياضية في الصين",
    "march 2020 sports-events in europe": "أحداث مارس 2020 الرياضية في أوروبا",
    "march 2020 sports-events in mexico": "أحداث مارس 2020 الرياضية في المكسيك",
    "march 2020 sports-events in oceania": "أحداث مارس 2020 الرياضية في أوقيانوسيا",
    "march 2020 sports-events in thailand": "أحداث مارس 2020 الرياضية في تايلاند",
    "march 2020 sports-events in the united kingdom": "أحداث مارس 2020 الرياضية في المملكة المتحدة",
    "May 2020 sports events in Africa": "أحداث مايو 2020 الرياضية في إفريقيا",
    "May 2020 sports events in Algeria": "أحداث مايو 2020 الرياضية في الجزائر",
    "May 2020 sports events in Argentina": "أحداث مايو 2020 الرياضية في الأرجنتين",
    "May 2020 sports events in Asia": "أحداث مايو 2020 الرياضية في آسيا",
    "May 2020 sports events in Australia": "أحداث مايو 2020 الرياضية في أستراليا",
    "May 2020 sports events in Austria": "أحداث مايو 2020 الرياضية في النمسا",
    "May 2020 sports events in Azerbaijan": "أحداث مايو 2020 الرياضية في أذربيجان",
    "May 2020 sports events in Bahrain": "أحداث مايو 2020 الرياضية في البحرين",
    "May 2020 sports events in Belgium": "أحداث مايو 2020 الرياضية في بلجيكا",
    "May 2020 sports events in Brazil": "أحداث مايو 2020 الرياضية في البرازيل",
    "May 2020 sports events in Bulgaria": "أحداث مايو 2020 الرياضية في بلغاريا",
    "May 2020 sports events in Canada": "أحداث مايو 2020 الرياضية في كندا",
    "May 2020 sports events in China": "أحداث مايو 2020 الرياضية في الصين",
    "May 2020 sports events in Costa Rica": "أحداث مايو 2020 الرياضية في كوستاريكا",
    "May 2020 sports events in Croatia": "أحداث مايو 2020 الرياضية في كرواتيا",
    "May 2020 sports events in Egypt": "أحداث مايو 2020 الرياضية في مصر",
    "May 2020 sports events in Europe": "أحداث مايو 2020 الرياضية في أوروبا",
    "May 2020 sports events in France": "أحداث مايو 2020 الرياضية في فرنسا",
    "May 2020 sports events in Germany": "أحداث مايو 2020 الرياضية في ألمانيا",
    "May 2020 sports events in Greece": "أحداث مايو 2020 الرياضية في اليونان",
    "May 2020 sports events in Hungary": "أحداث مايو 2020 الرياضية في المجر",
    "May 2020 sports events in India": "أحداث مايو 2020 الرياضية في الهند",
    "May 2020 sports events in Indonesia": "أحداث مايو 2020 الرياضية في إندونيسيا",
    "May 2020 sports events in Iran": "أحداث مايو 2020 الرياضية في إيران",
    "May 2020 sports events in Ireland": "أحداث مايو 2020 الرياضية في أيرلندا",
    "May 2020 sports events in Italy": "أحداث مايو 2020 الرياضية في إيطاليا",
    "May 2020 sports events in Japan": "أحداث مايو 2020 الرياضية في اليابان",
    "May 2020 sports events in Malaysia": "أحداث مايو 2020 الرياضية في ماليزيا",
    "May 2020 sports events in Mexico": "أحداث مايو 2020 الرياضية في المكسيك",
    "May 2020 sports events in Morocco": "أحداث مايو 2020 الرياضية في المغرب",
    "May 2020 sports events in New Zealand": "أحداث مايو 2020 الرياضية في نيوزيلندا",
    "May 2020 sports events in North America": "أحداث مايو 2020 الرياضية في أمريكا الشمالية",
    "May 2020 sports events in Oceania": "أحداث مايو 2020 الرياضية في أوقيانوسيا",
    "May 2020 sports events in Pakistan": "أحداث مايو 2020 الرياضية في باكستان",
    "May 2020 sports events in Papua New Guinea": "أحداث مايو 2020 الرياضية في بابوا غينيا الجديدة",
    "May 2020 sports events in Poland": "أحداث مايو 2020 الرياضية في بولندا",
    "May 2020 sports events in Portugal": "أحداث مايو 2020 الرياضية في البرتغال",
    "May 2020 sports events in Romania": "أحداث مايو 2020 الرياضية في رومانيا",
    "May 2020 sports events in Russia": "أحداث مايو 2020 الرياضية في روسيا",
    "May 2020 sports events in Saudi Arabia": "أحداث مايو 2020 الرياضية في السعودية",
    "May 2020 sports events in Serbia": "أحداث مايو 2020 الرياضية في صربيا",
    "May 2020 sports events in Singapore": "أحداث مايو 2020 الرياضية في سنغافورة",
    "May 2020 sports events in Slovakia": "أحداث مايو 2020 الرياضية في سلوفاكيا",
    "May 2020 sports events in South Africa": "أحداث مايو 2020 الرياضية في جنوب إفريقيا",
    "May 2020 sports events in South America": "أحداث مايو 2020 الرياضية في أمريكا الجنوبية",
    "May 2020 sports events in South Korea": "أحداث مايو 2020 الرياضية في كوريا الجنوبية",
    "May 2020 sports events in Spain": "أحداث مايو 2020 الرياضية في إسبانيا",
    "May 2020 sports events in Switzerland": "أحداث مايو 2020 الرياضية في سويسرا",
    "May 2020 sports events in Taiwan": "أحداث مايو 2020 الرياضية في تايوان",
    "May 2020 sports events in Thailand": "أحداث مايو 2020 الرياضية في تايلاند",
    "May 2020 sports events in the Czech Republic": "أحداث مايو 2020 الرياضية في التشيك",
    "May 2020 sports events in the Netherlands": "أحداث مايو 2020 الرياضية في هولندا",
    "May 2020 sports events in the Philippines": "أحداث مايو 2020 الرياضية في الفلبين",
    "May 2020 sports events in the United Arab Emirates": "أحداث مايو 2020 الرياضية في الإمارات العربية المتحدة",
    "May 2020 sports events in the United Kingdom": "أحداث مايو 2020 الرياضية في المملكة المتحدة",
    "May 2020 sports events in the United States": "أحداث مايو 2020 الرياضية في الولايات المتحدة",
    "May 2020 sports events in Tunisia": "أحداث مايو 2020 الرياضية في تونس",
    "May 2020 sports events in Turkey": "أحداث مايو 2020 الرياضية في تركيا",
    "May 2020 sports events in Ukraine": "أحداث مايو 2020 الرياضية في أوكرانيا",
    "May 2020 sports events in Uzbekistan": "أحداث مايو 2020 الرياضية في أوزبكستان",
    "May 2020 sports events in Vietnam": "أحداث مايو 2020 الرياضية في فيتنام",
    "may 2020 sports-events in africa": "أحداث مايو 2020 الرياضية في إفريقيا",
    "may 2020 sports-events in asia": "أحداث مايو 2020 الرياضية في آسيا",
    "may 2020 sports-events in europe": "أحداث مايو 2020 الرياضية في أوروبا",
    "may 2020 sports-events in switzerland": "أحداث مايو 2020 الرياضية في سويسرا",
    "may 2020 sports-events in united states": "أحداث مايو 2020 الرياضية في الولايات المتحدة",
    "November 2020 sports events in Africa": "أحداث نوفمبر 2020 الرياضية في إفريقيا",
    "November 2020 sports events in Argentina": "أحداث نوفمبر 2020 الرياضية في الأرجنتين",
    "November 2020 sports events in Asia": "أحداث نوفمبر 2020 الرياضية في آسيا",
    "November 2020 sports events in Australia": "أحداث نوفمبر 2020 الرياضية في أستراليا",
    "November 2020 sports events in Austria": "أحداث نوفمبر 2020 الرياضية في النمسا",
    "November 2020 sports events in Bahrain": "أحداث نوفمبر 2020 الرياضية في البحرين",
    "November 2020 sports events in Bangladesh": "أحداث نوفمبر 2020 الرياضية في بنغلاديش",
    "November 2020 sports events in Brazil": "أحداث نوفمبر 2020 الرياضية في البرازيل",
    "November 2020 sports events in Bulgaria": "أحداث نوفمبر 2020 الرياضية في بلغاريا",
    "November 2020 sports events in Canada": "أحداث نوفمبر 2020 الرياضية في كندا",
    "November 2020 sports events in China": "أحداث نوفمبر 2020 الرياضية في الصين",
    "November 2020 sports events in Croatia": "أحداث نوفمبر 2020 الرياضية في كرواتيا",
    "November 2020 sports events in Egypt": "أحداث نوفمبر 2020 الرياضية في مصر",
    "November 2020 sports events in Europe": "أحداث نوفمبر 2020 الرياضية في أوروبا",
    "November 2020 sports events in France": "أحداث نوفمبر 2020 الرياضية في فرنسا",
    "November 2020 sports events in Germany": "أحداث نوفمبر 2020 الرياضية في ألمانيا",
    "November 2020 sports events in Hungary": "أحداث نوفمبر 2020 الرياضية في المجر",
    "November 2020 sports events in India": "أحداث نوفمبر 2020 الرياضية في الهند",
    "November 2020 sports events in Indonesia": "أحداث نوفمبر 2020 الرياضية في إندونيسيا",
    "November 2020 sports events in Iran": "أحداث نوفمبر 2020 الرياضية في إيران",
    "November 2020 sports events in Iraq": "أحداث نوفمبر 2020 الرياضية في العراق",
    "November 2020 sports events in Ireland": "أحداث نوفمبر 2020 الرياضية في أيرلندا",
    "November 2020 sports events in Italy": "أحداث نوفمبر 2020 الرياضية في إيطاليا",
    "November 2020 sports events in Japan": "أحداث نوفمبر 2020 الرياضية في اليابان",
    "November 2020 sports events in Malaysia": "أحداث نوفمبر 2020 الرياضية في ماليزيا",
    "November 2020 sports events in Mexico": "أحداث نوفمبر 2020 الرياضية في المكسيك",
    "November 2020 sports events in New Zealand": "أحداث نوفمبر 2020 الرياضية في نيوزيلندا",
    "November 2020 sports events in North America": "أحداث نوفمبر 2020 الرياضية في أمريكا الشمالية",
    "November 2020 sports events in Oceania": "أحداث نوفمبر 2020 الرياضية في أوقيانوسيا",
    "November 2020 sports events in Pakistan": "أحداث نوفمبر 2020 الرياضية في باكستان",
    "November 2020 sports events in Poland": "أحداث نوفمبر 2020 الرياضية في بولندا",
    "November 2020 sports events in Portugal": "أحداث نوفمبر 2020 الرياضية في البرتغال",
    "November 2020 sports events in Qatar": "أحداث نوفمبر 2020 الرياضية في قطر",
    "November 2020 sports events in Romania": "أحداث نوفمبر 2020 الرياضية في رومانيا",
    "November 2020 sports events in Russia": "أحداث نوفمبر 2020 الرياضية في روسيا",
    "November 2020 sports events in Saudi Arabia": "أحداث نوفمبر 2020 الرياضية في السعودية",
    "November 2020 sports events in Serbia": "أحداث نوفمبر 2020 الرياضية في صربيا",
    "November 2020 sports events in Singapore": "أحداث نوفمبر 2020 الرياضية في سنغافورة",
    "November 2020 sports events in South Africa": "أحداث نوفمبر 2020 الرياضية في جنوب إفريقيا",
    "November 2020 sports events in South America": "أحداث نوفمبر 2020 الرياضية في أمريكا الجنوبية",
    "November 2020 sports events in South Korea": "أحداث نوفمبر 2020 الرياضية في كوريا الجنوبية",
    "November 2020 sports events in Spain": "أحداث نوفمبر 2020 الرياضية في إسبانيا",
    "November 2020 sports events in Switzerland": "أحداث نوفمبر 2020 الرياضية في سويسرا",
    "November 2020 sports events in Thailand": "أحداث نوفمبر 2020 الرياضية في تايلاند",
    "November 2020 sports events in the Czech Republic": "أحداث نوفمبر 2020 الرياضية في التشيك",
    "November 2020 sports events in the Netherlands": "أحداث نوفمبر 2020 الرياضية في هولندا",
    "November 2020 sports events in the Philippines": "أحداث نوفمبر 2020 الرياضية في الفلبين",
    "November 2020 sports events in the United Arab Emirates": "أحداث نوفمبر 2020 الرياضية في الإمارات العربية المتحدة",
    "November 2020 sports events in the United Kingdom": "أحداث نوفمبر 2020 الرياضية في المملكة المتحدة",
    "November 2020 sports events in the United States": "أحداث نوفمبر 2020 الرياضية في الولايات المتحدة",
    "November 2020 sports events in Turkey": "أحداث نوفمبر 2020 الرياضية في تركيا",
    "November 2020 sports events in Ukraine": "أحداث نوفمبر 2020 الرياضية في أوكرانيا",
    "november 2020 sports-events in canada": "أحداث نوفمبر 2020 الرياضية في كندا",
    "november 2020 sports-events in europe": "أحداث نوفمبر 2020 الرياضية في أوروبا",
    "november 2020 sports-events in germany": "أحداث نوفمبر 2020 الرياضية في ألمانيا",
    "november 2020 sports-events in north america": "أحداث نوفمبر 2020 الرياضية في أمريكا الشمالية",
    "november 2020 sports-events in oceania": "أحداث نوفمبر 2020 الرياضية في أوقيانوسيا",
    "november 2020 sports-events in the united states": "أحداث نوفمبر 2020 الرياضية في الولايات المتحدة",
    "november 2020 sports-events in united kingdom": "أحداث نوفمبر 2020 الرياضية في المملكة المتحدة",
    "October 2020 sports events in Africa": "أحداث أكتوبر 2020 الرياضية في إفريقيا",
    "October 2020 sports events in Argentina": "أحداث أكتوبر 2020 الرياضية في الأرجنتين",
    "October 2020 sports events in Asia": "أحداث أكتوبر 2020 الرياضية في آسيا",
    "October 2020 sports events in Australia": "أحداث أكتوبر 2020 الرياضية في أستراليا",
    "October 2020 sports events in Austria": "أحداث أكتوبر 2020 الرياضية في النمسا",
    "October 2020 sports events in Bahrain": "أحداث أكتوبر 2020 الرياضية في البحرين",
    "October 2020 sports events in Bangladesh": "أحداث أكتوبر 2020 الرياضية في بنغلاديش",
    "October 2020 sports events in Belgium": "أحداث أكتوبر 2020 الرياضية في بلجيكا",
    "October 2020 sports events in Brazil": "أحداث أكتوبر 2020 الرياضية في البرازيل",
    "October 2020 sports events in Bulgaria": "أحداث أكتوبر 2020 الرياضية في بلغاريا",
    "October 2020 sports events in Canada": "أحداث أكتوبر 2020 الرياضية في كندا",
    "October 2020 sports events in Chile": "أحداث أكتوبر 2020 الرياضية في تشيلي",
    "October 2020 sports events in China": "أحداث أكتوبر 2020 الرياضية في الصين",
    "October 2020 sports events in Croatia": "أحداث أكتوبر 2020 الرياضية في كرواتيا",
    "October 2020 sports events in Egypt": "أحداث أكتوبر 2020 الرياضية في مصر",
    "October 2020 sports events in Europe": "أحداث أكتوبر 2020 الرياضية في أوروبا",
    "October 2020 sports events in Fiji": "أحداث أكتوبر 2020 الرياضية في فيجي",
    "October 2020 sports events in France": "أحداث أكتوبر 2020 الرياضية في فرنسا",
    "October 2020 sports events in Germany": "أحداث أكتوبر 2020 الرياضية في ألمانيا",
    "October 2020 sports events in Greece": "أحداث أكتوبر 2020 الرياضية في اليونان",
    "October 2020 sports events in Hungary": "أحداث أكتوبر 2020 الرياضية في المجر",
    "October 2020 sports events in India": "أحداث أكتوبر 2020 الرياضية في الهند",
    "October 2020 sports events in Indonesia": "أحداث أكتوبر 2020 الرياضية في إندونيسيا",
    "October 2020 sports events in Iran": "أحداث أكتوبر 2020 الرياضية في إيران",
    "October 2020 sports events in Ireland": "أحداث أكتوبر 2020 الرياضية في أيرلندا",
    "October 2020 sports events in Italy": "أحداث أكتوبر 2020 الرياضية في إيطاليا",
    "October 2020 sports events in Japan": "أحداث أكتوبر 2020 الرياضية في اليابان",
    "October 2020 sports events in Malaysia": "أحداث أكتوبر 2020 الرياضية في ماليزيا",
    "October 2020 sports events in Mexico": "أحداث أكتوبر 2020 الرياضية في المكسيك",
    "October 2020 sports events in New Zealand": "أحداث أكتوبر 2020 الرياضية في نيوزيلندا",
    "October 2020 sports events in Nigeria": "أحداث أكتوبر 2020 الرياضية في نيجيريا",
    "October 2020 sports events in North America": "أحداث أكتوبر 2020 الرياضية في أمريكا الشمالية",
    "October 2020 sports events in Oceania": "أحداث أكتوبر 2020 الرياضية في أوقيانوسيا",
    "October 2020 sports events in Pakistan": "أحداث أكتوبر 2020 الرياضية في باكستان",
    "October 2020 sports events in Peru": "أحداث أكتوبر 2020 الرياضية في بيرو",
    "October 2020 sports events in Poland": "أحداث أكتوبر 2020 الرياضية في بولندا",
    "October 2020 sports events in Portugal": "أحداث أكتوبر 2020 الرياضية في البرتغال",
    "October 2020 sports events in Qatar": "أحداث أكتوبر 2020 الرياضية في قطر",
    "October 2020 sports events in Romania": "أحداث أكتوبر 2020 الرياضية في رومانيا",
    "October 2020 sports events in Russia": "أحداث أكتوبر 2020 الرياضية في روسيا",
    "October 2020 sports events in Saudi Arabia": "أحداث أكتوبر 2020 الرياضية في السعودية",
    "October 2020 sports events in Serbia": "أحداث أكتوبر 2020 الرياضية في صربيا",
    "October 2020 sports events in Singapore": "أحداث أكتوبر 2020 الرياضية في سنغافورة",
    "October 2020 sports events in Slovakia": "أحداث أكتوبر 2020 الرياضية في سلوفاكيا",
    "October 2020 sports events in South Africa": "أحداث أكتوبر 2020 الرياضية في جنوب إفريقيا",
    "October 2020 sports events in South America": "أحداث أكتوبر 2020 الرياضية في أمريكا الجنوبية",
    "October 2020 sports events in South Korea": "أحداث أكتوبر 2020 الرياضية في كوريا الجنوبية",
    "October 2020 sports events in Spain": "أحداث أكتوبر 2020 الرياضية في إسبانيا",
    "October 2020 sports events in Switzerland": "أحداث أكتوبر 2020 الرياضية في سويسرا",
    "October 2020 sports events in Taiwan": "أحداث أكتوبر 2020 الرياضية في تايوان",
    "October 2020 sports events in Thailand": "أحداث أكتوبر 2020 الرياضية في تايلاند",
    "October 2020 sports events in the Czech Republic": "أحداث أكتوبر 2020 الرياضية في التشيك",
    "October 2020 sports events in the Netherlands": "أحداث أكتوبر 2020 الرياضية في هولندا",
    "October 2020 sports events in the Philippines": "أحداث أكتوبر 2020 الرياضية في الفلبين",
    "October 2020 sports events in the United Arab Emirates": "أحداث أكتوبر 2020 الرياضية في الإمارات العربية المتحدة",
    "October 2020 sports events in the United Kingdom": "أحداث أكتوبر 2020 الرياضية في المملكة المتحدة",
    "October 2020 sports events in the United States": "أحداث أكتوبر 2020 الرياضية في الولايات المتحدة",
    "October 2020 sports events in Tunisia": "أحداث أكتوبر 2020 الرياضية في تونس",
    "October 2020 sports events in Turkey": "أحداث أكتوبر 2020 الرياضية في تركيا",
    "october 2020 sports-events in africa": "أحداث أكتوبر 2020 الرياضية في إفريقيا",
    "october 2020 sports-events in france": "أحداث أكتوبر 2020 الرياضية في فرنسا",
    "october 2020 sports-events in oceania": "أحداث أكتوبر 2020 الرياضية في أوقيانوسيا",
    "october 2020 sports-events in poland": "أحداث أكتوبر 2020 الرياضية في بولندا",
    "october 2020 sports-events in the united states": "أحداث أكتوبر 2020 الرياضية في الولايات المتحدة",
    "october 2020 sports-events": "أحداث أكتوبر 2020 الرياضية",
    "September 2020 sports events in Africa": "أحداث سبتمبر 2020 الرياضية في إفريقيا",
    "September 2020 sports events in Argentina": "أحداث سبتمبر 2020 الرياضية في الأرجنتين",
    "September 2020 sports events in Asia": "أحداث سبتمبر 2020 الرياضية في آسيا",
    "September 2020 sports events in Australia": "أحداث سبتمبر 2020 الرياضية في أستراليا",
    "September 2020 sports events in Austria": "أحداث سبتمبر 2020 الرياضية في النمسا",
    "September 2020 sports events in Azerbaijan": "أحداث سبتمبر 2020 الرياضية في أذربيجان",
    "September 2020 sports events in Bangladesh": "أحداث سبتمبر 2020 الرياضية في بنغلاديش",
    "September 2020 sports events in Belgium": "أحداث سبتمبر 2020 الرياضية في بلجيكا",
    "September 2020 sports events in Brazil": "أحداث سبتمبر 2020 الرياضية في البرازيل",
    "September 2020 sports events in Bulgaria": "أحداث سبتمبر 2020 الرياضية في بلغاريا",
    "September 2020 sports events in Canada": "أحداث سبتمبر 2020 الرياضية في كندا",
    "September 2020 sports events in China": "أحداث سبتمبر 2020 الرياضية في الصين",
    "September 2020 sports events in Croatia": "أحداث سبتمبر 2020 الرياضية في كرواتيا",
    "September 2020 sports events in Egypt": "أحداث سبتمبر 2020 الرياضية في مصر",
    "September 2020 sports events in Europe": "أحداث سبتمبر 2020 الرياضية في أوروبا",
    "September 2020 sports events in Fiji": "أحداث سبتمبر 2020 الرياضية في فيجي",
    "September 2020 sports events in France": "أحداث سبتمبر 2020 الرياضية في فرنسا",
    "September 2020 sports events in Germany": "أحداث سبتمبر 2020 الرياضية في ألمانيا",
    "September 2020 sports events in Greece": "أحداث سبتمبر 2020 الرياضية في اليونان",
    "September 2020 sports events in Hungary": "أحداث سبتمبر 2020 الرياضية في المجر",
    "September 2020 sports events in India": "أحداث سبتمبر 2020 الرياضية في الهند",
    "September 2020 sports events in Indonesia": "أحداث سبتمبر 2020 الرياضية في إندونيسيا",
    "September 2020 sports events in Iran": "أحداث سبتمبر 2020 الرياضية في إيران",
    "September 2020 sports events in Iraq": "أحداث سبتمبر 2020 الرياضية في العراق",
    "September 2020 sports events in Ireland": "أحداث سبتمبر 2020 الرياضية في أيرلندا",
    "September 2020 sports events in Italy": "أحداث سبتمبر 2020 الرياضية في إيطاليا",
    "September 2020 sports events in Japan": "أحداث سبتمبر 2020 الرياضية في اليابان",
    "September 2020 sports events in Lebanon": "أحداث سبتمبر 2020 الرياضية في لبنان",
    "September 2020 sports events in Malaysia": "أحداث سبتمبر 2020 الرياضية في ماليزيا",
    "September 2020 sports events in Mexico": "أحداث سبتمبر 2020 الرياضية في المكسيك",
    "September 2020 sports events in Morocco": "أحداث سبتمبر 2020 الرياضية في المغرب",
    "September 2020 sports events in New Zealand": "أحداث سبتمبر 2020 الرياضية في نيوزيلندا",
    "September 2020 sports events in Nigeria": "أحداث سبتمبر 2020 الرياضية في نيجيريا",
    "September 2020 sports events in North America": "أحداث سبتمبر 2020 الرياضية في أمريكا الشمالية",
    "September 2020 sports events in Oceania": "أحداث سبتمبر 2020 الرياضية في أوقيانوسيا",
    "September 2020 sports events in Pakistan": "أحداث سبتمبر 2020 الرياضية في باكستان",
    "September 2020 sports events in Peru": "أحداث سبتمبر 2020 الرياضية في بيرو",
    "September 2020 sports events in Poland": "أحداث سبتمبر 2020 الرياضية في بولندا",
    "September 2020 sports events in Portugal": "أحداث سبتمبر 2020 الرياضية في البرتغال",
    "September 2020 sports events in Qatar": "أحداث سبتمبر 2020 الرياضية في قطر",
    "September 2020 sports events in Romania": "أحداث سبتمبر 2020 الرياضية في رومانيا",
    "September 2020 sports events in Russia": "أحداث سبتمبر 2020 الرياضية في روسيا",
    "September 2020 sports events in Serbia": "أحداث سبتمبر 2020 الرياضية في صربيا",
    "September 2020 sports events in Singapore": "أحداث سبتمبر 2020 الرياضية في سنغافورة",
    "September 2020 sports events in Slovakia": "أحداث سبتمبر 2020 الرياضية في سلوفاكيا",
    "September 2020 sports events in South Africa": "أحداث سبتمبر 2020 الرياضية في جنوب إفريقيا",
    "September 2020 sports events in South America": "أحداث سبتمبر 2020 الرياضية في أمريكا الجنوبية",
    "September 2020 sports events in South Korea": "أحداث سبتمبر 2020 الرياضية في كوريا الجنوبية",
    "September 2020 sports events in Spain": "أحداث سبتمبر 2020 الرياضية في إسبانيا",
    "September 2020 sports events in Switzerland": "أحداث سبتمبر 2020 الرياضية في سويسرا",
    "September 2020 sports events in Taiwan": "أحداث سبتمبر 2020 الرياضية في تايوان",
    "September 2020 sports events in Thailand": "أحداث سبتمبر 2020 الرياضية في تايلاند",
    "September 2020 sports events in the Czech Republic": "أحداث سبتمبر 2020 الرياضية في التشيك",
    "September 2020 sports events in the Netherlands": "أحداث سبتمبر 2020 الرياضية في هولندا",
    "September 2020 sports events in the Philippines": "أحداث سبتمبر 2020 الرياضية في الفلبين",
    "September 2020 sports events in the Solomon Islands": "أحداث سبتمبر 2020 الرياضية في جزر سليمان",
    "September 2020 sports events in the United Arab Emirates": "أحداث سبتمبر 2020 الرياضية في الإمارات العربية المتحدة",
    "September 2020 sports events in the United Kingdom": "أحداث سبتمبر 2020 الرياضية في المملكة المتحدة",
    "September 2020 sports events in the United States": "أحداث سبتمبر 2020 الرياضية في الولايات المتحدة",
    "September 2020 sports events in Trinidad and Tobago": "أحداث سبتمبر 2020 الرياضية في ترينيداد وتوباغو",
    "September 2020 sports events in Tunisia": "أحداث سبتمبر 2020 الرياضية في تونس",
    "September 2020 sports events in Turkey": "أحداث سبتمبر 2020 الرياضية في تركيا",
    "September 2020 sports events in Ukraine": "أحداث سبتمبر 2020 الرياضية في أوكرانيا",
    "september 2020 sports-events in germany": "أحداث سبتمبر 2020 الرياضية في ألمانيا",
    "september 2020 sports-events in japan": "أحداث سبتمبر 2020 الرياضية في اليابان",
    "september 2020 sports-events in new zealand": "أحداث سبتمبر 2020 الرياضية في نيوزيلندا",
    "september 2020 sports-events in north america": "أحداث سبتمبر 2020 الرياضية في أمريكا الشمالية",
    "september 2020 sports-events in turkey": "أحداث سبتمبر 2020 الرياضية في تركيا",
    "september 2020 sports-events": "أحداث سبتمبر 2020 الرياضية",
}

fast_data_2 = {
    # "Entertainment at sports events": "ترفيه في أحداث رياضية",
    "Sports events cancelled due to the COVID-19 pandemic": "أحداث رياضية ألغيت بسبب جائحة فيروس كورونا",
    "Sports events cancelled due to the Russian invasion of Ukraine": "أحداث رياضية ألغيت بسبب الغزو الروسي لأوكرانيا",
    "Sports events curtailed and voided due to the COVID-19 pandemic": "أحداث رياضية اختصرت وألغيت بسبب جائحة فيروس كورونا",
    "Sports events curtailed due to the COVID-19 pandemic": "أحداث رياضية اختصرت بسبب جائحة فيروس كورونا",
    "Sports events in Africa": "أحداث رياضية في إفريقيا",
    "Sports events in Asia": "أحداث رياضية في آسيا",
    "Sports events in Attica": "أحداث رياضية في أتيكا",
    "Sports events in Bucharest": "أحداث رياضية في بوخارست",
    "Sports events in Cardiff": "أحداث رياضية في كارديف",
    "Sports events in Central Macedonia": "أحداث رياضية في إقليم مقدونيا الوسطى",
    "Sports events in Europe": "أحداث رياضية في أوروبا",
    "Sports events in North America": "أحداث رياضية في أمريكا الشمالية",
    "Sports events in Oceania": "أحداث رياضية في أوقيانوسيا",
    "Sports events in Ponce, Puerto Rico": "أحداث رياضية في بونس، بورتوريكو",
    "Sports events in South America": "أحداث رياضية في أمريكا الجنوبية",
    "Sports events in Western Greece": "أحداث رياضية في غرب اليونان",
    "Sports events postponed due to the COVID-19 pandemic": "أحداث رياضية تأجلت بسبب جائحة فيروس كورونا",
}

to_test = [
    ("test_sports_events_1", fast_data_1),
    ("test_sports_events_2", fast_data_2),
]


@pytest.mark.parametrize("category, expected", fast_data_1.items(), ids=fast_data_1.keys())
@pytest.mark.fast
def test_2_fast_data_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", fast_data_2.items(), ids=fast_data_2.keys())
@pytest.mark.fast
def test_2_fast_data_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
