"""
"Category:Defunct Canadian football teams": "تصنيف:فرق كرة قدم كندية سابقة",
"Category:LGBTQ players of Canadian football": "تصنيف:لاعبو كرة قدم كندية مثليون",
"""
import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {
    "Category:African-American coaches of Canadian football": "تصنيف:مدربو كرة قدم كندية أمريكيون أفارقة",
    "Category:American players of Canadian football by populated place": "تصنيف:لاعبو كرة قدم كندية أمريكيون حسب المكان المأهول",
    "Category:American players of Canadian football by state": "تصنيف:لاعبو كرة قدم كندية أمريكيون حسب الولاية",
    "Category:American players of Canadian football": "تصنيف:لاعبو كرة قدم كندية أمريكيون",
    "Category:Australian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية أستراليون",
    "Category:Bahamian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية بهاميون",
    "Category:Cameroonian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية كاميرونيون",
    "Category:Canadian football venues": "تصنيف:ملاعب كرة قدم كندية",
    "Category:Canadian football templates": "تصنيف:قوالب كرة قدم كندية",
    "Category:Canadian players of Canadian football by populated place": "تصنيف:لاعبو كرة قدم كندية كنديون حسب المكان المأهول",
    "Category:Coaches of Canadian football": "تصنيف:مدربو كرة قدم كندية",
    "Category:Cuban players of Canadian football": "تصنيف:لاعبو كرة قدم كندية كوبيون",
    "Category:Democratic Republic of the Congo players of Canadian football": "تصنيف:لاعبو كرة قدم كندية كونغويون ديمقراطيون",
    "Category:Dominican Republic players of Canadian football": "تصنيف:لاعبو كرة قدم كندية دومينيكانيون",
    "Category:English players of Canadian football": "تصنيف:لاعبو كرة قدم كندية إنجليز",
    "Category:Guyanese players of Canadian football": "تصنيف:لاعبو كرة قدم كندية غيانيون",
    "Category:Honduran players of Canadian football": "تصنيف:لاعبو كرة قدم كندية هندوراسيون",
    "Category:Jamaican players of Canadian football": "تصنيف:لاعبو كرة قدم كندية جامايكيون",
    "Category:Lebanese players of Canadian football": "تصنيف:لاعبو كرة قدم كندية لبنانيون",
    "Category:Nigerian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية نيجيريون",
    "Category:Panamanian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية بنميون",
    "Category:Players of Canadian football by nationality": "تصنيف:لاعبو كرة قدم كندية حسب الجنسية",
    "Category:Players of Canadian football by position": "تصنيف:لاعبو كرة قدم كندية حسب المركز",
    "Category:Players of Canadian football from Alabama": "تصنيف:لاعبو كرة قدم كندية من ألاباما",
    "Category:Players of Canadian football from Alaska": "تصنيف:لاعبو كرة قدم كندية من ألاسكا",
    "Category:Players of Canadian football from Alberta": "تصنيف:لاعبو كرة قدم كندية من ألبرتا",
    "Category:Players of Canadian football from Arizona": "تصنيف:لاعبو كرة قدم كندية من أريزونا",
    "Category:Players of Canadian football from Arkansas": "تصنيف:لاعبو كرة قدم كندية من أركنساس",
    "Category:Players of Canadian football from Atlanta": "تصنيف:لاعبو كرة قدم كندية من أتلانتا (جورجيا)",
    "Category:Players of Canadian football from Baltimore": "تصنيف:لاعبو كرة قدم كندية من بالتيمور",
    "Category:Players of Canadian football from Birmingham, Alabama": "تصنيف:لاعبو كرة قدم كندية من برمنغهام (ألاباما)",
    "Category:Players of Canadian football from Brampton": "تصنيف:لاعبو كرة قدم كندية من برامبتون (أونتاريو)",
    "Category:Players of Canadian football from British Columbia": "تصنيف:لاعبو كرة قدم كندية من كولومبيا البريطانية",
    "Category:Players of Canadian football from Brooklyn": "تصنيف:لاعبو كرة قدم كندية من بروكلين",
    "Category:Players of Canadian football from California": "تصنيف:لاعبو كرة قدم كندية من كاليفورنيا",
    "Category:Players of Canadian football from Chicago": "تصنيف:لاعبو كرة قدم كندية من شيكاغو",
    "Category:Players of Canadian football from Cincinnati": "تصنيف:لاعبو كرة قدم كندية من سينسيناتي",
    "Category:Players of Canadian football from Cleveland": "تصنيف:لاعبو كرة قدم كندية من كليفلاند",
    "Category:Players of Canadian football from Colorado": "تصنيف:لاعبو كرة قدم كندية من كولورادو",
    "Category:Players of Canadian football from Columbia, South Carolina": "تصنيف:لاعبو كرة قدم كندية من كولومبيا (كارولاينا الجنوبية)",
    "Category:Players of Canadian football from Columbus, Ohio": "تصنيف:لاعبو كرة قدم كندية من كولومبوس (أوهايو)",
    "Category:Players of Canadian football from Connecticut": "تصنيف:لاعبو كرة قدم كندية من كونيتيكت",
    "Category:Players of Canadian football from Dallas": "تصنيف:لاعبو كرة قدم كندية من دالاس",
    "Category:Players of Canadian football from Dayton, Ohio": "تصنيف:لاعبو كرة قدم كندية من دايتون (أوهايو)",
    "Category:Players of Canadian football from Delaware": "تصنيف:لاعبو كرة قدم كندية من ديلاوير",
    "Category:Players of Canadian football from Denver": "تصنيف:لاعبو كرة قدم كندية من دنفر (كولورادو)",
    "Category:Players of Canadian football from Detroit": "تصنيف:لاعبو كرة قدم كندية من ديترويت",
    "Category:Players of Canadian football from Florida": "تصنيف:لاعبو كرة قدم كندية من فلوريدا",
    "Category:Players of Canadian football from Fort Lauderdale, Florida": "تصنيف:لاعبو كرة قدم كندية من فورت لاودردال (فلوريدا)",
    "Category:Players of Canadian football from Georgia (U.S. state)": "تصنيف:لاعبو كرة قدم كندية من ولاية جورجيا",
    "Category:Players of Canadian football from Hawaii": "تصنيف:لاعبو كرة قدم كندية من هاواي",
    "Category:Players of Canadian football from Honolulu": "تصنيف:لاعبو كرة قدم كندية من هونولولو",
    "Category:Players of Canadian football from Houston": "تصنيف:لاعبو كرة قدم كندية من هيوستن",
    "Category:Players of Canadian football from Idaho": "تصنيف:لاعبو كرة قدم كندية من أيداهو",
    "Category:Players of Canadian football from Illinois": "تصنيف:لاعبو كرة قدم كندية من إلينوي",
    "Category:Players of Canadian football from Indiana": "تصنيف:لاعبو كرة قدم كندية من إنديانا",
    "Category:Players of Canadian football from Indianapolis": "تصنيف:لاعبو كرة قدم كندية من إنديانابوليس",
    "Category:Players of Canadian football from Jackson, Mississippi": "تصنيف:لاعبو كرة قدم كندية من جاكسون (مسيسيبي)",
    "Category:Players of Canadian football from Jacksonville, Florida": "تصنيف:لاعبو كرة قدم كندية من جاكسونفيل (فلوريدا)",
    "Category:Players of Canadian football from Kansas City, Missouri": "تصنيف:لاعبو كرة قدم كندية من كانساس سيتي (ميزوري)",
    "Category:Players of Canadian football from Kansas": "تصنيف:لاعبو كرة قدم كندية من كانساس",
    "Category:Players of Canadian football from Kentucky": "تصنيف:لاعبو كرة قدم كندية من كنتاكي",
    "Category:Players of Canadian football from Kingston, Jamaica": "تصنيف:لاعبو كرة قدم كندية من كينغستون",
    "Category:Players of Canadian football from Lagos": "تصنيف:لاعبو كرة قدم كندية من ولاية لاغوس",
    "Category:Players of Canadian football from Las Vegas": "تصنيف:لاعبو كرة قدم كندية من لاس فيغاس (نيفادا)",
    "Category:Players of Canadian football from Long Beach, California": "تصنيف:لاعبو كرة قدم كندية من لونغ بيتش (كاليفورنيا)",
    "Category:Players of Canadian football from Los Angeles": "تصنيف:لاعبو كرة قدم كندية من لوس أنجلوس",
    "Category:Players of Canadian football from Louisiana": "تصنيف:لاعبو كرة قدم كندية من لويزيانا",
    "Category:Players of Canadian football from Louisville, Kentucky": "تصنيف:لاعبو كرة قدم كندية من لويفيل (كنتاكي)",
    "Category:Players of Canadian football from Manitoba": "تصنيف:لاعبو كرة قدم كندية من مانيتوبا",
    "Category:Players of Canadian football from Maryland": "تصنيف:لاعبو كرة قدم كندية من ماريلند",
    "Category:Players of Canadian football from Massachusetts": "تصنيف:لاعبو كرة قدم كندية من ماساتشوستس",
    "Category:Players of Canadian football from Memphis, Tennessee": "تصنيف:لاعبو كرة قدم كندية من ممفيس (تينيسي)",
    "Category:Players of Canadian football from Miami": "تصنيف:لاعبو كرة قدم كندية من ميامي",
    "Category:Players of Canadian football from Michigan": "تصنيف:لاعبو كرة قدم كندية من ميشيغان",
    "Category:Players of Canadian football from Minneapolis": "تصنيف:لاعبو كرة قدم كندية من مينيابوليس",
    "Category:Players of Canadian football from Minnesota": "تصنيف:لاعبو كرة قدم كندية من منيسوتا",
    "Category:Players of Canadian football from Mississippi": "تصنيف:لاعبو كرة قدم كندية من مسيسيبي",
    "Category:Players of Canadian football from Missouri": "تصنيف:لاعبو كرة قدم كندية من ميزوري",
    "Category:Players of Canadian football from Montana": "تصنيف:لاعبو كرة قدم كندية من مونتانا",
    "Category:Players of Canadian football from Nevada": "تصنيف:لاعبو كرة قدم كندية من نيفادا",
    "Category:Players of Canadian football from New Brunswick": "تصنيف:لاعبو كرة قدم كندية من نيو برونزويك",
    "Category:Players of Canadian football from New Jersey": "تصنيف:لاعبو كرة قدم كندية من نيوجيرسي",
    "Category:Players of Canadian football from New Mexico": "تصنيف:لاعبو كرة قدم كندية من نيومكسيكو",
    "Category:Players of Canadian football from New Orleans": "تصنيف:لاعبو كرة قدم كندية من نيو أورلينز",
    "Category:Players of Canadian football from New York (state)": "تصنيف:لاعبو كرة قدم كندية من ولاية نيويورك",
    "Category:Players of Canadian football from New York City": "تصنيف:لاعبو كرة قدم كندية من مدينة نيويورك",
    "Category:Players of Canadian football from Newark, New Jersey": "تصنيف:لاعبو كرة قدم كندية من نيوآرك (نيو جيرسي)",
    "Category:Players of Canadian football from Norfolk, Virginia": "تصنيف:لاعبو كرة قدم كندية من نورفولك (فرجينيا)",
    "Category:Players of Canadian football from North Carolina": "تصنيف:لاعبو كرة قدم كندية من كارولاينا الشمالية",
    "Category:Players of Canadian football from North Dakota": "تصنيف:لاعبو كرة قدم كندية من داكوتا الشمالية",
    "Category:Players of Canadian football from Nova Scotia": "تصنيف:لاعبو كرة قدم كندية من نوفا سكوشا",
    "Category:Players of Canadian football from Oakland, California": "تصنيف:لاعبو كرة قدم كندية من أوكلاند (كاليفورنيا)",
    "Category:Players of Canadian football from Ohio": "تصنيف:لاعبو كرة قدم كندية من أوهايو",
    "Category:Players of Canadian football from Oklahoma City": "تصنيف:لاعبو كرة قدم كندية من أوكلاهوما سيتي",
    "Category:Players of Canadian football from Oklahoma": "تصنيف:لاعبو كرة قدم كندية من أوكلاهوما",
    "Category:Players of Canadian football from Ontario": "تصنيف:لاعبو كرة قدم كندية من أونتاريو",
    "Category:Players of Canadian football from Oregon": "تصنيف:لاعبو كرة قدم كندية من أوريغن",
    "Category:Players of Canadian football from Orlando, Florida": "تصنيف:لاعبو كرة قدم كندية من أورلاندو (فلوريدا)",
    "Category:Players of Canadian football from Pasadena, California": "تصنيف:لاعبو كرة قدم كندية من باسادينا (كاليفورنيا)",
    "Category:Players of Canadian football from Pennsylvania": "تصنيف:لاعبو كرة قدم كندية من بنسلفانيا",
    "Category:Players of Canadian football from Pensacola, Florida": "تصنيف:لاعبو كرة قدم كندية من بينساكولا (فلوريدا)",
    "Category:Players of Canadian football from Philadelphia": "تصنيف:لاعبو كرة قدم كندية من فيلادلفيا",
    "Category:Players of Canadian football from Phoenix, Arizona": "تصنيف:لاعبو كرة قدم كندية من فينيكس (أريزونا)",
    "Category:Players of Canadian football from Pittsburgh": "تصنيف:لاعبو كرة قدم كندية من بيتسبرغ",
    "Category:Players of Canadian football from Quebec": "تصنيف:لاعبو كرة قدم كندية من كيبك",
    "Category:Players of Canadian football from Queens, New York": "تصنيف:لاعبو كرة قدم كندية من كوينز (نيويورك)",
    "Category:Players of Canadian football from Sacramento, California": "تصنيف:لاعبو كرة قدم كندية من ساكرامنتو (كاليفورنيا)",
    "Category:Players of Canadian football from San Antonio": "تصنيف:لاعبو كرة قدم كندية من سان أنطونيو",
    "Category:Players of Canadian football from San Diego": "تصنيف:لاعبو كرة قدم كندية من سان دييغو",
    "Category:Players of Canadian football from San Francisco": "تصنيف:لاعبو كرة قدم كندية من سان فرانسيسكو",
    "Category:Players of Canadian football from San Jose, California": "تصنيف:لاعبو كرة قدم كندية من سان خوسيه (كاليفورنيا)",
    "Category:Players of Canadian football from Saskatchewan": "تصنيف:لاعبو كرة قدم كندية من ساسكاتشوان",
    "Category:Players of Canadian football from Seattle": "تصنيف:لاعبو كرة قدم كندية من سياتل",
    "Category:Players of Canadian football from South Carolina": "تصنيف:لاعبو كرة قدم كندية من كارولاينا الجنوبية",
    "Category:Players of Canadian football from St. Louis": "تصنيف:لاعبو كرة قدم كندية من سينت لويس",
    "Category:Players of Canadian football from St. Petersburg, Florida": "تصنيف:لاعبو كرة قدم كندية من سانت بيترسبرغ (فلوريدا)",
    "Category:Players of Canadian football from Stockton, California": "تصنيف:لاعبو كرة قدم كندية من ستوكتون (كاليفورنيا)",
    "Category:Players of Canadian football from Tampa, Florida": "تصنيف:لاعبو كرة قدم كندية من تامبا (فلوريدا)",
    "Category:Players of Canadian football from Tennessee": "تصنيف:لاعبو كرة قدم كندية من تينيسي",
    "Category:Players of Canadian football from Texas": "تصنيف:لاعبو كرة قدم كندية من تكساس",
    "Category:Players of Canadian football from Utah": "تصنيف:لاعبو كرة قدم كندية من يوتا",
    "Category:Players of Canadian football from Vermont": "تصنيف:لاعبو كرة قدم كندية من فيرمونت",
    "Category:Players of Canadian football from Virginia": "تصنيف:لاعبو كرة قدم كندية من فرجينيا",
    "Category:Players of Canadian football from Washington (state)": "تصنيف:لاعبو كرة قدم كندية من ولاية واشنطن",
    "Category:Players of Canadian football from Washington, D.C.": "تصنيف:لاعبو كرة قدم كندية من واشنطن العاصمة",
    "Category:Players of Canadian football from West Virginia": "تصنيف:لاعبو كرة قدم كندية من فرجينيا الغربية",
    "Category:Players of Canadian football from Wisconsin": "تصنيف:لاعبو كرة قدم كندية من ويسكونسن",
    "Category:Players of Canadian football from Wyoming": "تصنيف:لاعبو كرة قدم كندية من وايومنغ",
    "Category:Players of Canadian football": "تصنيف:لاعبو كرة قدم كندية",
    "Category:Puerto Rican players of Canadian football": "تصنيف:لاعبو كرة قدم كندية بورتوريكيون",
    "Category:Samoan players of Canadian football": "تصنيف:لاعبو كرة قدم كندية سامويون",
    "Category:Sierra Leonean players of Canadian football": "تصنيف:لاعبو كرة قدم كندية سيراليونيون",
    "Category:Venezuelan players of Canadian football": "تصنيف:لاعبو كرة قدم كندية فنزويليون",
}

data2 = {
    "Category:Canadian football media": "تصنيف:إعلام كرة قدم كندية",
    "Category:Canadian football people from Calgary": "تصنيف:أعلام كرة قدم كندية من كالغاري",
    "Category:Canadian football people from Edmonton": "تصنيف:أعلام كرة قدم كندية من إدمونتون",
    "Category:Canadian football people from Greater Sudbury": "تصنيف:أعلام كرة قدم كندية من غريتر سودبوري",
    "Category:Canadian football people from Halifax, Nova Scotia": "تصنيف:أعلام كرة قدم كندية من هاليفاكس (نوفا سكوشيا)",
    "Category:Canadian football people from Hamilton, Ontario": "تصنيف:أعلام كرة قدم كندية من هاميلتون",
    "Category:Canadian football people from London, Ontario": "تصنيف:أعلام كرة قدم كندية من لندن (أونتاريو)",
    "Category:Canadian football people from Mississauga": "تصنيف:أعلام كرة قدم كندية من ميسيسوجا",
    "Category:Canadian football people from Montreal": "تصنيف:أعلام كرة قدم كندية من مونتريال",
    "Category:Canadian football people from New Westminster": "تصنيف:أعلام كرة قدم كندية من نيو ويستمينيستر (كولومبيا البريطانية)",
    "Category:Canadian football people from Ottawa": "تصنيف:أعلام كرة قدم كندية من أوتاوا",
    "Category:Canadian football people from Quebec City": "تصنيف:أعلام كرة قدم كندية من مدينة كيبك",
    "Category:Canadian football people from Regina, Saskatchewan": "تصنيف:أعلام كرة قدم كندية من ريجاينا",
    "Category:Canadian football people from Saskatoon": "تصنيف:أعلام كرة قدم كندية من ساسكاتون",
    "Category:Canadian football people from Toronto": "تصنيف:أعلام كرة قدم كندية من تورونتو",
    "Category:Canadian football people from Vancouver": "تصنيف:أعلام كرة قدم كندية من فانكوفر",
    "Category:Canadian football people from Victoria, British Columbia": "تصنيف:أعلام كرة قدم كندية من فيكتوريا (كولومبيا البريطانية)",
    "Category:Canadian football people from Windsor, Ontario": "تصنيف:أعلام كرة قدم كندية من وندسور (أونتاريو)",
    "Category:Canadian football people from Winnipeg": "تصنيف:أعلام كرة قدم كندية من وينيبيغ",
    "Category:Canadian football terminology": "تصنيف:مصطلحات كرة قدم كندية",
}

data3 = {
    "Category:Canadian football by city": "تصنيف:كرة القدم الكندية حسب المدينة",
    "Category:Canadian football by country": "تصنيف:كرة القدم الكندية حسب البلد",
    "Category:Canadian football by province or territory": "تصنيف:كرة القدم الكندية حسب المقاطعة أو الإقليم",
    "Category:Canadian football in Alberta": "تصنيف:كرة القدم الكندية في ألبرتا",
    "Category:Canadian football in British Columbia": "تصنيف:كرة القدم الكندية في كولومبيا البريطانية",
    "Category:Canadian football in Calgary": "تصنيف:كرة القدم الكندية في كالغاري",
    "Category:Canadian football in Canada by city": "تصنيف:كرة القدم الكندية في كندا حسب المدينة",
    "Category:Canadian football in Canada": "تصنيف:كرة القدم الكندية في كندا",
    "Category:Canadian football in Edmonton": "تصنيف:كرة القدم الكندية في إدمونتون",
    "Category:Canadian football in Hamilton, Ontario": "تصنيف:كرة القدم الكندية في هاميلتون",
    "Category:Canadian football in Manitoba": "تصنيف:كرة القدم الكندية في مانيتوبا",
    "Category:Canadian football in Montreal": "تصنيف:كرة القدم الكندية في مونتريال",
    "Category:Canadian football in Nova Scotia": "تصنيف:كرة القدم الكندية في نوفا سكوشا",
    "Category:Canadian football in Ontario": "تصنيف:كرة القدم الكندية في أونتاريو",
    "Category:Canadian football in Ottawa": "تصنيف:كرة القدم الكندية في أوتاوا",
    "Category:Canadian football in Quebec": "تصنيف:كرة القدم الكندية في كيبك",
    "Category:Canadian football in Saskatchewan": "تصنيف:كرة القدم الكندية في ساسكاتشوان",
    "Category:Canadian football in Toronto": "تصنيف:كرة القدم الكندية في تورونتو",
    "Category:Canadian football in Vancouver": "تصنيف:كرة القدم الكندية في فانكوفر",
    "Category:Canadian football in Winnipeg": "تصنيف:كرة القدم الكندية في وينيبيغ",
    "Category:Canadian football teams by city": "تصنيف:فرق كرة القدم الكندية حسب المدينة",
    "Category:Canadian football teams by league": "تصنيف:فرق كرة القدم الكندية حسب الدوري",
    "Category:Canadian football teams by province or territory": "تصنيف:فرق كرة القدم الكندية حسب المقاطعة أو الإقليم",
    "Category:Canadian football teams in Alberta": "تصنيف:فرق كرة القدم الكندية في ألبرتا",
    "Category:Canadian football teams in Calgary": "تصنيف:فرق كرة القدم الكندية في كالغاري",
    "Category:Canadian football teams in Edmonton": "تصنيف:فرق كرة القدم الكندية في إدمونتون",
    "Category:Canadian football teams in Manitoba": "تصنيف:فرق كرة القدم الكندية في مانيتوبا",
    "Category:Canadian football teams in Ontario": "تصنيف:فرق كرة القدم الكندية في أونتاريو",
    "Category:Canadian football teams in Ottawa": "تصنيف:فرق كرة القدم الكندية في أوتاوا",
    "Category:Canadian football teams in Saskatchewan": "تصنيف:فرق كرة القدم الكندية في ساسكاتشوان",
    "Category:Canadian football teams in Toronto": "تصنيف:فرق كرة القدم الكندية في تورونتو",
    "Category:Canadian football teams in Vancouver": "تصنيف:فرق كرة القدم الكندية في فانكوفر",
    "Category:Canadian football teams in Winnipeg": "تصنيف:فرق كرة القدم الكندية في وينيبيغ",
    "Category:Canadian football venues in British Columbia": "تصنيف:ملاعب كرة القدم الكندية في كولومبيا البريطانية",
    "Category:Canadian football venues in Manitoba": "تصنيف:ملاعب كرة القدم الكندية في مانيتوبا",
    "Category:Canadian football venues in Ontario": "تصنيف:ملاعب كرة القدم الكندية في أونتاريو",
    "Category:Canadian football venues in Quebec": "تصنيف:ملاعب كرة القدم الكندية في كيبك",
    "Category:Canadian football venues in the United States": "تصنيف:ملاعب كرة القدم الكندية في الولايات المتحدة",
    "Category:Canadian football": "تصنيف:كرة القدم الكندية",
    "Category:Canadian players of Canadian football": "تصنيف:لاعبو كرة قدم كندية كنديون",
    "Category:Canadian football running backs": "تصنيف:راكضون للخلف كرة قدم كندية",
    "Category:Canadian football linebackers": "تصنيف:أظهرة كرة قدم كندية",
    "Category:Canadian football centres": "تصنيف:لاعبو وسط كرة قدم كندية",
    "Category:Canadian football defensive linemen": "تصنيف:مدافعو خط كرة قدم كندية",
    "Category:Canadian football defensive backs": "تصنيف:مدافعون خلفيون كرة قدم كندية",
    "Category:Canadian football fullbacks": "تصنيف:مدافعو كرة قدم كندية",
    "Category:Canadian football placekickers": "تصنيف:مسددو كرة قدم كندية",
    "Category:Canadian football scouts": "تصنيف:كشافة كرة قدم كندية",
    "Category:Canadian football offensive linemen": "تصنيف:مهاجمو خط كرة قدم كندية",
    "Category:Canadian football tackles": "تصنيف:مصطدمو كرة قدم كندية",
    "Category:Canadian football wide receivers": "تصنيف:مستقبلون واسعون كرة قدم كندية",
    "Category:Canadian football guards": "تصنيف:حراس كرة قدم كندية",
    "Category:Canadian football quarterbacks": "تصنيف:أظهرة رباعيون كرة قدم كندية",
}

to_test = [
    ("test_canadian_football_1", data1),
    ("test_canadian_football_2", data2),
    ("test_canadian_football_3", data3),
]


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
def test_canadian_football_1(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data2.items(), ids=data2.keys())
def test_canadian_football_2(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("category, expected", data3.items(), ids=data3.keys())
def test_canadian_football_3(category: str, expected: str) -> None:
    assert resolve_arabic_category_label(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)
    # dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    # dump_diff_text(expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
