#!/usr/bin/python3
"""
"""

jobs_formatted_data_shared = {
    "{en_sport} competitions": "منافسات {sport_jobs}",
    "domestic {en_sport}": "{sport_jobs} محلية",
    "professional {en_sport}": "{sport_jobs} للمحترفين",
    "indoor {en_sport}": "{sport_jobs} داخل الصالات",
    "defunct indoor {en_sport}": "{sport_jobs} داخل الصالات سابقة",
    "{en_sport} cup": "كؤوس {sport_jobs}",
    "{en_sport} cups": "كؤوس {sport_jobs}",
    "defunct outdoor {en_sport} cups": "كؤوس {sport_jobs} في الهواء الطلق سابقة",
    "defunct {en_sport} cup": "كؤوس {sport_jobs} سابقة",
    "defunct {en_sport} cups": "كؤوس {sport_jobs} سابقة",
    "domestic womens {en_sport} cups": "كؤوس {sport_jobs} محلية للسيدات",
    "domestic {en_sport} cup": "كؤوس {sport_jobs} محلية",
    "domestic {en_sport} cups": "كؤوس {sport_jobs} محلية",
}

jobs_formatted_data = {
    # "{en_sport}": "{sport_jobs}",
    "domestic womens {en_sport} leagues": "دوريات {sport_jobs} محلية للسيدات",
    "domestic womens {en_sport}": "{sport_jobs} محلية للسيدات",
    "domestic {en_sport} leagues": "دوريات {sport_jobs} محلية",
    "defunct indoor {en_sport} cups": "كؤوس {sport_jobs} داخل الصالات سابقة",
    "indoor {en_sport} cups": "كؤوس {sport_jobs} داخل الصالات",
    "indoor {en_sport} leagues": "دوريات {sport_jobs} داخل الصالات",
    "defunct indoor {en_sport} leagues": "دوريات {sport_jobs} داخل الصالات سابقة",
    "outdoor {en_sport} cups": "كؤوس {sport_jobs} في الهواء الطلق",
    "professional {en_sport} cups": "كؤوس {sport_jobs} للمحترفين",
    "professional {en_sport} leagues": "دوريات {sport_jobs} للمحترفين",
    "under-13 {en_sport}": "{sport_jobs} تحت 13 سنة",
    "under-14 {en_sport}": "{sport_jobs} تحت 14 سنة",
    "under-15 {en_sport}": "{sport_jobs} تحت 15 سنة",
    "under-16 {en_sport}": "{sport_jobs} تحت 16 سنة",
    "under-17 {en_sport}": "{sport_jobs} تحت 17 سنة",
    "under-18 {en_sport}": "{sport_jobs} تحت 18 سنة",
    "under-19 {en_sport}": "{sport_jobs} تحت 19 سنة",
    "under-20 {en_sport}": "{sport_jobs} تحت 20 سنة",
    "under-21 {en_sport}": "{sport_jobs} تحت 21 سنة",
    "under-23 {en_sport}": "{sport_jobs} تحت 23 سنة",
    "under-24 {en_sport}": "{sport_jobs} تحت 24 سنة",
    "amateur {en_sport} championships": "بطولات {sport_jobs} للهواة",
    "amateur {en_sport}": "{sport_jobs} للهواة",
    "college {en_sport}": "{sport_jobs} الكليات",
    "current {en_sport} seasons": "مواسم {sport_jobs} حالية",
    "defunct outdoor {en_sport} leagues": "دوريات {sport_jobs} في الهواء الطلق سابقة",
    "defunct outdoor {en_sport}": "{sport_jobs} في الهواء الطلق سابقة",
    "defunct {en_sport} leagues": "دوريات {sport_jobs} سابقة",
    "defunct {en_sport} teams": "فرق {sport_jobs} سابقة",
    "defunct {en_sport}": "{sport_jobs} سابقة",
    "fictional {en_sport}": "{sport_jobs} خيالية",
    "fifth level {en_sport} league": "دوريات {sport_jobs} من الدرجة الخامسة",
    "fifth level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الخامسة",
    "fifth tier {en_sport} league": "دوريات {sport_jobs} من الدرجة الخامسة",
    "fifth tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الخامسة",
    "first level {en_sport} league": "دوريات {sport_jobs} من الدرجة الأولى",
    "first level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الأولى",
    "first tier {en_sport} league": "دوريات {sport_jobs} من الدرجة الأولى",
    "first tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الأولى",
    "first-class {en_sport}": "{sport_jobs} من الدرجة الأولى",
    "first-class {en_sport} teams": "فرق {sport_jobs} من الدرجة الأولى",
    "fourth level {en_sport} league": "دوريات {sport_jobs} من الدرجة الرابعة",
    "fourth level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الرابعة",
    "fourth tier {en_sport} league": "دوريات {sport_jobs} من الدرجة الرابعة",
    "fourth tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الرابعة",
    "grand slam ({en_sport}) tournament champions": "أبطال بطولات {sport_jobs} كبرى",
    "grand slam ({en_sport}) tournaments": "بطولات {sport_jobs} كبرى",
    "grand slam ({en_sport})": "بطولات {sport_jobs} كبرى",
    "international mens {en_sport} players": "لاعبو {sport_jobs} دوليون",
    "international mens {en_sport} playerss": "لاعبو {sport_jobs} دوليون",
    "international mens {en_sport}": "{sport_jobs} دولية للرجال",
    "international womens {en_sport} players": "لاعبات {sport_jobs} دوليات",
    "international womens {en_sport} playerss": "لاعبات {sport_jobs} دوليات",
    "international womens {en_sport}": "{sport_jobs} دولية للسيدات",
    "International {en_sport} competition": "منافسات {sport_jobs} دولية",
    "International {en_sport} competitions": "منافسات {sport_jobs} دولية",
    "international {en_sport} managers": "مدربو {sport_jobs} دوليون",
    "international {en_sport} players": "لاعبو {sport_jobs} دوليون",
    "international {en_sport} playerss": "لاعبو {sport_jobs} دوليون",
    "International {en_sport} races": "سباقات {sport_jobs} دولية",
    "International {en_sport}": "{sport_jobs} دولية",
    "international youth {en_sport}": "{sport_jobs} شبابية دولية",
    "mens international {en_sport} players": "لاعبو {sport_jobs} دوليون",
    "mens international {en_sport} playerss": "لاعبو {sport_jobs} دوليون",
    "mens international {en_sport}": "{sport_jobs} دولية للرجال",
    "mens {en_sport} teams": "فرق {sport_jobs} رجالية",
    "mens {en_sport}": "{sport_jobs} رجالية",
    "military {en_sport}": "{sport_jobs} عسكرية",
    "multi-national {en_sport} championships": "بطولات {sport_jobs} متعددة الجنسيات",
    "multi-national {en_sport} league": "دوريات {sport_jobs} متعددة الجنسيات",
    "multi-national {en_sport} leagues": "دوريات {sport_jobs} متعددة الجنسيات",
    "national a {en_sport} teams": "منتخبات {sport_jobs} للمحليين",
    "national a. {en_sport} teams": "منتخبات {sport_jobs} للمحليين",
    "national b {en_sport} teams": "منتخبات {sport_jobs} رديفة",
    "national b. {en_sport} teams": "منتخبات {sport_jobs} رديفة",
    "national junior mens {en_sport} teams": "منتخبات {sport_jobs} وطنية للناشئين",
    "national junior {en_sport} teams": "منتخبات {sport_jobs} وطنية للناشئين",
    "national mens {en_sport} teams": "منتخبات {sport_jobs} وطنية رجالية",
    "national mens {en_sport}": "منتخبات {sport_jobs} وطنية للرجال",
    "national reserve {en_sport} teams": "منتخبات {sport_jobs} وطنية احتياطية",
    "national under-13 {en_sport}": "منتخبات {sport_jobs} تحت 13 سنة",
    "national under-14 {en_sport}": "منتخبات {sport_jobs} تحت 14 سنة",
    "national under-15 {en_sport}": "منتخبات {sport_jobs} تحت 15 سنة",
    "national under-16 {en_sport}": "منتخبات {sport_jobs} تحت 16 سنة",
    "national under-17 {en_sport}": "منتخبات {sport_jobs} تحت 17 سنة",
    "national under-18 {en_sport}": "منتخبات {sport_jobs} تحت 18 سنة",
    "national under-19 {en_sport}": "منتخبات {sport_jobs} تحت 19 سنة",
    "national under-20 {en_sport}": "منتخبات {sport_jobs} تحت 20 سنة",
    "national under-21 {en_sport}": "منتخبات {sport_jobs} تحت 21 سنة",
    "national under-23 {en_sport}": "منتخبات {sport_jobs} تحت 23 سنة",
    "national under-24 {en_sport}": "منتخبات {sport_jobs} تحت 24 سنة",
    "national womens {en_sport} teams": "منتخبات {sport_jobs} وطنية نسائية",
    "national womens {en_sport}": "منتخبات {sport_jobs} وطنية للسيدات",
    "national {en_sport} champions": "أبطال بطولات {sport_jobs} وطنية",
    "national {en_sport} championships": "بطولات {sport_jobs} وطنية",
    "national {en_sport} league": "دوريات {sport_jobs} وطنية",
    "national {en_sport} leagues": "دوريات {sport_jobs} وطنية",
    "national {en_sport} team results": "نتائج منتخبات {sport_jobs} وطنية",
    "national {en_sport} teams": "منتخبات {sport_jobs} وطنية",
    "national {en_sport}": "منتخبات {sport_jobs} وطنية",
    "national youth {en_sport} teams": "منتخبات {sport_jobs} وطنية شبابية",
    "outdoor {en_sport} leagues": "دوريات {sport_jobs} في الهواء الطلق",
    "outdoor {en_sport}": "{sport_jobs} في الهواء الطلق",
    "premier {en_sport} league": "دوريات {sport_jobs} من الدرجة الممتازة",
    "premier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الممتازة",
    "reserve {en_sport} teams": "فرق {sport_jobs} احتياطية",
    "second level {en_sport} league": "دوريات {sport_jobs} من الدرجة الثانية",
    "second level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الثانية",
    "second tier {en_sport} league": "دوريات {sport_jobs} من الدرجة الثانية",
    "second tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الثانية",
    "seventh level {en_sport} league": "دوريات {sport_jobs} من الدرجة السابعة",
    "seventh level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة السابعة",
    "seventh tier {en_sport} league": "دوريات {sport_jobs} من الدرجة السابعة",
    "seventh tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة السابعة",
    "sixth level {en_sport} league": "دوريات {sport_jobs} من الدرجة السادسة",
    "sixth level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة السادسة",
    "sixth tier {en_sport} league": "دوريات {sport_jobs} من الدرجة السادسة",
    "sixth tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة السادسة",
    "third level {en_sport} league": "دوريات {sport_jobs} من الدرجة الثالثة",
    "third level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الثالثة",
    "third tier {en_sport} league": "دوريات {sport_jobs} من الدرجة الثالثة",
    "third tier {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الثالثة",
    "top level {en_sport} league": "دوريات {sport_jobs} من الدرجة الأولى",
    "top level {en_sport} leagues": "دوريات {sport_jobs} من الدرجة الأولى",
    "womens international {en_sport} players": "لاعبات {sport_jobs} دوليات",
    "womens international {en_sport} playerss": "لاعبات {sport_jobs} دوليات",
    "womens international {en_sport}": "{sport_jobs} دولية للسيدات",
    "womens {en_sport} teams": "فرق {sport_jobs} نسائية",
    "womens {en_sport}": "{sport_jobs} نسائية",
    "{en_sport} chairmen and investors": "رؤساء ومسيرو {sport_jobs}",
    "{en_sport} league teams": "فرق دوري {sport_jobs}",
    "{en_sport} league": "دوري {sport_jobs}",
    "{en_sport} leagues": "دوريات {sport_jobs}",
    "{en_sport} olympic bronze medalists": "ميداليات {sport_jobs} برونزية أولمبية",
    "{en_sport} olympic gold medalists": "ميداليات {sport_jobs} ذهبية أولمبية",
    "{en_sport} olympic silver medalists": "ميداليات {sport_jobs} فضية أولمبية",
    "{en_sport} races": "سباقات {sport_jobs}",
    "{en_sport} super leagues": "دوريات سوبر {sport_jobs}",
    "youth international {en_sport}": "{sport_jobs} دولية شبابية",
    "youth {en_sport}": "{sport_jobs} شبابية",
    # Category:Multi-national women's basketball leagues in Europe
    "multi-national womens {en_sport} leagues": "دوريات {sport_jobs} نسائية متعددة الجنسيات",
    # Category:National junior women's goalball teams
    "national junior womens {en_sport} teams": "منتخبات {sport_jobs} للناشئات",
}

jobs_formatted_data.update(jobs_formatted_data_shared)

# NOTE: used in countries_names_sport_multi_v2.py and nats_and_sports.py
labels_formatted_data = {
    "{en_sport}": "{sport_label}",
    "{en_sport} finals": "نهائيات {sport_label}",
    "olympic gold medalists in {en_sport}": "فائزون بميداليات ذهبية أولمبية في {sport_label}",
    "olympic silver medalists in {en_sport}": "فائزون بميداليات فضية أولمبية في {sport_label}",
    "olympic bronze medalists in {en_sport}": "فائزون بميداليات برونزية أولمبية في {sport_label}",
    "{en_sport} league": "دوري {sport_label}",
    "{en_sport} champions": "أبطال {sport_label}",
    "olympics {en_sport}": "{sport_label} في الألعاب الأولمبية",
    "summer olympics {en_sport}": "{sport_label} في الألعاب الأولمبية الصيفية",
    "winter olympics {en_sport}": "{sport_label} في الألعاب الأولمبية الشتوية",
}


teams_formatted_data = {
    "amateur {en_sport} world cup": "كأس العالم {sport_team} للهواة",
    "mens {en_sport} world cup": "كأس العالم {sport_team} للرجال",
    "womens {en_sport} world cup": "كأس العالم {sport_team} للسيدات",
    "{en_sport} world cup": "كأس العالم {sport_team}",
    "youth {en_sport} world cup": "كأس العالم {sport_team} للشباب",
    "international {en_sport} council": "المجلس الدولي {sport_team}",
    "mens {en_sport} championship": "بطولة {sport_team} للرجال",
    "mens {en_sport} world championship": "بطولة العالم {sport_team} للرجال",
    "outdoor world {en_sport} championship": "بطولة العالم {sport_team} في الهواء الطلق",
    "womens world {en_sport} championship": "بطولة العالم {sport_team} للسيدات",
    "womens {en_sport} championship": "بطولة {sport_team} للسيدات",
    "womens {en_sport} world championship": "بطولة العالم {sport_team} للسيدات",
    "world amateur {en_sport} championship": "بطولة العالم {sport_team} للهواة",
    "world champion national {en_sport} teams": "أبطال بطولة العالم {sport_team}",
    "world junior {en_sport} championship": "بطولة العالم {sport_team} للناشئين",
    "world outdoor {en_sport} championship": "بطولة العالم {sport_team} في الهواء الطلق",
    "world wheelchair {en_sport} championship": "بطولة العالم {sport_team} على الكراسي المتحركة",
    "world {en_sport} amateur championship": "بطولة العالم {sport_team} للهواة",
    "world {en_sport} championship": "بطولة العالم {sport_team}",
    "world {en_sport} championship competitors": "منافسو بطولة العالم {sport_team}",
    "world {en_sport} championship medalists": "فائزون بميداليات بطولة العالم {sport_team}",
    "world {en_sport} junior championship": "بطولة العالم {sport_team} للناشئين",
    "world {en_sport} youth championship": "بطولة العالم {sport_team} للشباب",
    "world youth {en_sport} championship": "بطولة العالم {sport_team} للشباب",
    "{en_sport} amateur world championship": "بطولة العالم {sport_team} للهواة",
    "{en_sport} junior world championship": "بطولة العالم {sport_team} للناشئين",
    "{en_sport} world amateur championship": "بطولة العالم {sport_team} للهواة",
    "{en_sport} world championship": "بطولة العالم {sport_team}",
    "{en_sport} world junior championship": "بطولة العالم {sport_team} للناشئين",
    "{en_sport} world youth championship": "بطولة العالم {sport_team} للشباب",
    "{en_sport} youth world championship": "بطولة العالم {sport_team} للشباب",
}


__all__ = [
    "jobs_formatted_data_shared",
    "jobs_formatted_data",
    "labels_formatted_data",
    "teams_formatted_data",
]
