#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_label_ar

fast_data = {
    "yemeni sports": "ألعاب رياضية يمنية",
    "yemeni sport": "رياضة يمنية",
    "yemeni buildings": "مباني يمنية",
    "yemeni companies": "شركات يمنية",
    "yemeni elections": "انتخابات يمنية",
    "yemeni songs": "أغاني يمنية",
    "yemeni television series": "مسلسلات تلفزيونية يمنية",
    "yemeni sports-events": "أحداث رياضية يمنية",
    "yemeni music": "موسيقى يمنية",
    "yemeni clubs": "أندية يمنية",
    "yemeni works": "أعمال يمنية",
    "yemeni organizations": "منظمات يمنية",
    "yemeni crimes": "جرائم يمنية",
    "yemeni islands": "جزر يمنية",
    "yemeni competitions": "منافسات يمنية",
    "yemeni novels": "روايات يمنية",
    "yemeni culture": "ثقافة يمنية",
    "yemeni media": "وسائل إعلام يمنية",
    "yemeni organisations": "منظمات يمنية",
    "yemeni architecture": "عمارة يمنية",
    "yemeni championships": "بطولات يمنية",
    "yemeni radio": "راديو يمنية",
    "yemeni awards": "جوائز يمنية",
    "yemeni comedy": "كوميديا يمنية",
    "yemeni festivals": "مهرجانات يمنية",
    "yemeni universities": "جامعات يمنية",
    "yemeni towns": "بلدات يمنية",
    "yemeni women's sport": "رياضة يمنية نسائية",
    "yemeni parks": "متنزهات يمنية",
    "yemeni musical groups": "فرق موسيقية يمنية",
    "yemeni video games": "ألعاب فيديو يمنية",
    "yemeni magazines": "مجلات يمنية",
    "yemeni plays": "مسرحيات يمنية",
    "yemeni sculptures": "منحوتات يمنية",
    "yemeni businesspeople": "شخصيات أعمال يمنية",
    "yemeni newspapers": "صحف يمنية",
    "yemeni compilation albums": "ألبومات تجميعية يمنية",
    "yemeni lakes": "بحيرات يمنية",
    "yemeni roads": "طرقات يمنية",
    "yemeni television-seasons": "مواسم تلفزيونية يمنية",
    "yemeni mountains": "جبال يمنية",
    "yemeni colonial": "مستعمرات يمنية",
    "yemeni sports competitions": "منافسات رياضية يمنية",
    "yemeni radio stations": "محطات إذاعية يمنية",
    "yemeni operas": "أوبيرات يمنية",
    "yemeni restaurants": "مطاعم يمنية",
    "yemeni temples": "معابد يمنية",
    "yemeni wars": "حروب يمنية",
    "yemeni drink": "مشروبات يمنية",
    "yemeni families": "عائلات يمنية",
    "yemeni titles": "ألقاب يمنية",
    "yemeni discoveries": "اكتشافات يمنية",
    "yemeni border": "حدود يمنية",
    "yemeni names": "أسماء يمنية",
    "yemeni fauna": "حيوانات يمنية",
    "yemeni publications": "منشورات يمنية",
    "yemeni websites": "مواقع ويب يمنية",
    "yemeni cathedrals": "كاتدرائيات يمنية",
    "yemeni tour": "بطولات يمنية",
    "yemeni introductions": "استحداثات يمنية",
    "yemeni short stories": "قصص قصيرة يمنية",
    "yemeni philosophy": "فلسفة يمنية",
    "yemeni television stations": "محطات تلفزيونية يمنية",
    "yemeni rock groups": "فرق روك يمنية",
    "yemeni issues": "قضايا يمنية",
    "yemeni poems": "قصائد يمنية",
    "yemeni societies": "جمعيات يمنية",
    "yemeni brands": "ماركات يمنية",
    "yemeni soundtracks": "موسيقى تصويرية يمنية",
    "yemeni mythology": "أساطير يمنية",
    "yemeni countries": "بلدان يمنية",
    "yemeni referendums": "استفتاءات يمنية",
    "yemeni parishes": "أبرشيات يمنية",
    "yemeni clothing": "ملابس يمنية",
    "yemeni metal musical groups": "فرق موسيقى ميتال يمنية",
    "yemeni peoples": "شعوب يمنية",
    "yemeni forests": "غابات يمنية",
    "yemeni riots": "أعمال شغب يمنية",
    "yemeni monarchy": "ملكية يمنية",
    "yemeni diplomatic missions": "بعثات دبلوماسية يمنية",
    "yemeni provinces": "مقاطعات يمنية",
    "yemeni volcanoes": "براكين يمنية",
    "yemeni popular culture": "ثقافة شعبية يمنية",
    "yemeni resorts": "منتجعات يمنية",
    "yemeni surnames": "ألقاب يمنية",
    "yemeni border crossings": "معابر حدودية يمنية",
    "yemeni rock music groups": "فرق موسيقى الروك يمنية",
    "yemeni executions": "إعدامات يمنية",
    "yemeni war crimes": "جرائم حرب يمنية",
    "yemeni explosions": "انفجارات يمنية",
    "yemeni given names": "أسماء شخصية يمنية",
    "yemeni heritage sites": "موقع تراث عالمي يمنية",
    "yemeni nationalism": "قومية يمنية",
    "yemeni musical instruments": "آلات موسيقية يمنية",
    "yemeni coats of arms": "شعارات نبالة يمنية",
    "yemeni tribes": "قبائل يمنية",
    "yemeni waterfalls": "شلالات يمنية",
    "yemeni military-equipment": "معدات عسكرية يمنية",
    "yemeni trials": "محاكمات يمنية",
    "yemeni terminology": "مصطلحات يمنية",
    "yemeni automotive": "سيارات يمنية",
    "yemeni literary awards": "جوائز أدبية يمنية",
    "yemeni mascots": "تمائم يمنية",
    "yemeni journalism": "صحافة يمنية",
    "yemeni trains": "قطارات يمنية",
    "yemeni television films": "أفلام تلفزيونية يمنية",
    "yemeni film series": "سلاسل أفلام يمنية",
    "yemeni television news": "أخبار تلفزيونية يمنية",
    "yemeni classical music": "موسيقى كلاسيكية يمنية",
    "yemeni football club seasons": "مواسم أندية كرة قدم يمنية",
    "yemeni gangs": "عصابات يمنية",
    "yemeni decorations": "أوسمة يمنية",
    "yemeni rebellions": "تمردات يمنية",
    "yemeni occupations": "مهن يمنية",
    "yemeni awards and decorations": "جوائز وأوسمة يمنية",
    "yemeni non-profit organizations": "منظمات غير ربحية يمنية",
    "yemeni cantons": "كانتونات يمنية",
    "yemeni encyclopedias": "موسوعات يمنية",
    "yemeni ballot measures": "إجراءات اقتراع يمنية",
    "yemeni telenovelas": "تيلينوفيلا يمنية",
    "yemeni inscriptions": "نقوش يمنية",
    "yemeni airstrikes": "ضربات جوية يمنية",
    "yemeni movies": "أفلام يمنية",
    "yemeni folk music": "موسيقى فلكلورية يمنية",
    "yemeni webcomics": "ويب كومكس يمنية",
    "yemeni casualties": "خسائر يمنية",
    "yemeni heavy metal musical groups": "فرق موسيقى هيفي ميتال يمنية",
    "yemeni heraldry": "نبالة يمنية",
    "yemeni television networks": "شبكات تلفزيونية يمنية",
    "yemeni miniseries": "مسلسلات قصيرة يمنية",
    "yemeni folk albums": "ألبومات فلكلورية يمنية",
    "yemeni rectors": "عمدات يمنية",
    "yemeni inventions": "اختراعات يمنية",
    "yemeni pop groups": "فرق بوب يمنية",
    "yemeni learned societies": "جمعيات علمية يمنية",
    "yemeni mixtape albums": "ألبومات ميكستايب يمنية",
    "yemeni masculine given names": "أسماء ذكور يمنية",
    "yemeni archipelagoes": "أرخبيلات يمنية",
    "yemeni webcomic": "ويب كومكس يمنية",
    "yemeni religions": "ديانات يمنية",
    "yemeni budgets": "موازنات يمنية",
    "yemeni classical albums": "ألبومات كلاسيكية يمنية",
    "yemeni musical duos": "فرق موسيقية ثنائية يمنية",
    "yemeni jewellery": "مجوهرات يمنية",
    "yemeni hip hop groups": "فرق هيب هوب يمنية",
    "yemeni pop music groups": "فرق موسيقى بوب يمنية",
    "yemeni civil awards and decorations": "جوائز وأوسمة مدنية يمنية",
    "yemeni revolutions": "ثورات يمنية",
    "yemeni media personalities": "شخصيات إعلامية يمنية",
    "yemeni indie rock groups": "فرق إيندي روك يمنية",
    "yemeni music people": "شخصيات موسيقية يمنية",
    "yemeni folk music groups": "فرق موسيقى تقليدية يمنية",
    "yemeni indie pop groups": "فرق إيندي بوب يمنية",
    "yemeni autobiographies": "ترجمة ذاتية يمنية",
    "yemeni blues musical groups": "فرق موسيقى بلوز يمنية",
    "yemeni memorials and cemeteries": "نصب تذكارية ومقابر يمنية",
    "yemeni memoirs": "مذكرات يمنية",
    "yemeni black metal musical groups": "فرق موسيقى بلاك ميتال يمنية",
    "yemeni folk rock groups": "فرق فولك روك يمنية",
    "yemeni political philosophy": "فلسفة سياسية يمنية",
    "yemeni reggae musical groups": "فرق موسيقى ريغيه يمنية",
    "yemeni swamps": "مستنقعات يمنية",
    "yemeni country music groups": "فرق كانتري يمنية",
    "yemeni world music groups": "فرق موسيقى العالم يمنية",
    "yemeni crimes against humanity": "جرائم ضد الإنسانية يمنية",
    "yemeni radio networks": "شبكات مذياع يمنية",
    "yemeni thrash metal musical groups": "فرق موسيقى ثراش ميتال يمنية",
    "yemeni ska groups": "فرق سكا يمنية",
    "yemeni royal families": "عائلات ملكية يمنية",
    "yemeni comedy albums": "ألبومات كوميدية يمنية",
    "yemeni funk musical groups": "فرق موسيقى فانك يمنية",
    "yemeni ballot propositions": "اقتراحات اقتراع يمنية",
    "yemeni television commercials": "إعلانات تجارية تلفزيونية يمنية",
    "yemeni christian rock groups": "فرق روك مسيحي يمنية",
    "yemeni learned and professional societies": "جمعيات علمية ومهنية يمنية",
    "yemeni professional societies": "جمعيات مهنية يمنية",
    "yemeni eurodance groups": "فرق يورودانس يمنية",
    "yemeni television programs": "برامج تلفزيونية يمنية",
    "yemeni schools and colleges": "مدارس وكليات يمنية",
    "yemeni doom metal musical groups": "فرق موسيقى دوم ميتال يمنية",
    "yemeni gothic metal musical groups": "فرق موسيقى غوثيك ميتال يمنية",
    "yemeni phonologies": "تصريفات صوتية يمنية",
    "yemeni phonology": "نطقيات يمنية",
    "yemeni football club matches": "مباريات أندية كرة قدم يمنية",
    "yemeni contemporary r&b musical groups": "فرق موسيقى آر أند بي معاصر يمنية",
    "yemeni television programmes": "برامج تلفزيونية يمنية",
    "yemeni youth sports competitions": "منافسات رياضية شبابية يمنية",
    "yemeni christian metal musical groups": "فرق موسيقى ميتال مسيحي يمنية",
    "yemeni verbs": "أفعال يمنية",
    "yemeni religious occupations": "مهن دينية يمنية",
    "yemeni electronic dance music groups": "فرق موسيقى الرقص الإلكترونية يمنية",
    "yemeni folklore characters": "شخصيات فلكلورية يمنية",
    "yemeni business culture": "ثقافة مالية يمنية",
    "yemeni military-terminology": "مصطلحات عسكرية يمنية",
    "yemeni online journalism": "صحافة إنترنت يمنية",
    "yemeni underground culture": "ثقافة باطنية يمنية",
    "yemeni comedy music": "موسيقى كوميدية يمنية",
    "yemeni rhythm and blues groups": "فرق ريذم أند بلوز يمنية",
    "yemeni sea temples": "معابد بحرية يمنية",
    "yemeni alternative metal groups": "فرق ميتال بديل يمنية",
    "yemeni contemporary r&b groups": "فرق آر أند بي معاصر يمنية",
    "yemeni entertainment industry businesspeople": "شخصيات أعمال يمنية في صناعة الترفيه",
    "yemeni youth music competitions": "منافسات موسيقية شبابية يمنية",
    "yemeni films": "أفلام يمنية",
    "yemeni events": "أحداث يمنية",
    "yemeni books": "كتب يمنية",
    "yemeni comics": "قصص مصورة يمنية",
    "yemeni paintings": "لوحات يمنية",
    "yemeni political parties": "أحزاب سياسية يمنية",
    "yemeni musicals": "مسرحيات غنائية يمنية",
    "yemeni children's books": "كتب أطفال يمنية",
    "yemeni international schools": "مدارس دولية يمنية",
    "yemeni conferences": "مؤتمرات يمنية",
    "yemeni non-fiction books": "كتب يمنية غير خيالية",
    "yemeni ethnic groups": "مجموعات عرقية يمنية",
    "yemeni fiction novels": "روايات خيالية يمنية",
    "yemeni fiction films": "أفلام خيالية يمنية",
    "yemeni comic": "قصص مصورة يمنية",
    "yemeni organized crime": "جريمة منظمة يمنية",
    "yemeni political organizations": "منظمات سياسية يمنية",
    "yemeni musical films": "أفلام موسيقية يمنية",
    "yemeni texts": "نصوص يمنية",
    "yemeni music awards": "جوائز موسيقى يمنية",
    "yemeni political movements": "حركات سياسية يمنية",
    "yemeni manuscripts": "مخطوطات يمنية",
    "yemeni political organisations": "منظمات سياسية يمنية",
    "yemeni biographical films": "أفلام سير ذاتية يمنية",
    "yemeni islamic organizations": "منظمات إسلامية يمنية",
    "yemeni children's films": "أفلام أطفال يمنية",
    "yemeni comic strips": "شرائط كومكس يمنية",
    "yemeni bibliographies": "ببليوجرافيات يمنية",
    "yemeni music organisations": "منظمات موسيقى يمنية",
    "yemeni historical films": "أفلام تاريخية يمنية",
    "yemeni music organizations": "منظمات موسيقى يمنية",
    "yemeni novellas": "روايات قصيرة يمنية",
    "yemeni documentaries": "وثائقيات يمنية",
    "yemeni experimental films": "أفلام تجريبية يمنية",
    "yemeni historical novels": "روايات تاريخية يمنية",
    "yemeni political films": "أفلام سياسية يمنية",
    "yemeni online encyclopedias": "موسوعات إنترنت يمنية",
    "yemeni children's novels": "روايات أطفال يمنية",
    "yemeni islamic organisations": "منظمات إسلامية يمنية",
    "yemeni illuminated manuscripts": "مخطوطات مذهبة يمنية",
    "yemeni cookbooks": "كتب طبخ يمنية",
    "yemeni children's magazines": "مجلات أطفال يمنية",
    "yemeni history organisations": "منظمات تاريخ يمنية",
    "yemeni history organizations": "منظمات تاريخ يمنية",
    "yemeni legal films": "أفلام قانونية يمنية",
    "yemeni biographical dictionaries": "قواميس سير ذاتية يمنية",
    "yemeni political novels": "روايات سياسية يمنية",
    "yemeni political websites": "مواقع ويب سياسية يمنية",
    "yemeni socialist organizations": "منظمات اشتراكية يمنية",
    "yemeni educational films": "أفلام تعليمية يمنية",
    "yemeni architecture awards": "جوائز عمارة يمنية",
    "yemeni socialist organisations": "منظمات اشتراكية يمنية",
    "yemeni political groups": "مجموعات سياسية يمنية",
    "yemeni non-fiction crime": "جريمة يمنية غير خيالية",
    "yemeni fiction novellas": "روايات قصيرة خيالية يمنية",
    "yemeni architecture organizations": "منظمات عمارة يمنية",
    "yemeni fiction comics": "قصص مصورة خيالية يمنية",
    "yemeni medical organizations": "منظمات طبية يمنية",
    "yemeni biographical novels": "روايات سير ذاتية يمنية",
    "yemeni non-fiction novels": "روايات يمنية غير خيالية",
    "yemeni architecture organisations": "منظمات عمارة يمنية",
    "yemeni fiction comic strips": "شرائط كومكس خيالية يمنية",
    "yemeni biographical comics": "قصص مصورة سير ذاتية يمنية",
    "yemeni children's novellas": "روايات قصيرة أطفال يمنية",
    "yemeni educational comics": "قصص مصورة تعليمية يمنية",
    "yemeni educational webcomics": "ويب كومكس تعليمية يمنية",
    "yemeni historical comics": "قصص مصورة تاريخية يمنية",
    "yemeni historical webcomics": "ويب كومكس تاريخية يمنية",
    "yemeni medical organisations": "منظمات طبية يمنية",
    "yemeni nautical comics": "قصص مصورة بحرية يمنية",
    "yemeni nautical novels": "روايات بحرية يمنية",
    "yemeni non-fiction comics": "قصص مصورة يمنية غير خيالية",
    "yemeni non-fiction comic": "قصص مصورة يمنية غير خيالية",
    "yemeni non-fiction comic strips": "شرائط كومكس يمنية غير خيالية",
    "yemeni non-fiction graphic novels": "روايات مصورة يمنية غير خيالية",
    "yemeni political webcomics": "ويب كومكس سياسية يمنية",
    "yemeni fiction soundtracks": "موسيقى تصويرية خيالية يمنية",
    "yemeni fiction webcomics": "ويب كومكس خيالية يمنية",
    "Members of Christian religious orders": "أعضاء أخويات دينية مسيحية",
    "Christian religious orders by century of establishment": "أخويات دينية مسيحية حسب قرن التأسيس",
    "Christian religious orders established in 11th century": "أخويات دينية مسيحية أسست في القرن 11",
    "Christian religious orders established in 12th century": "أخويات دينية مسيحية أسست في القرن 12",
    "Christian religious orders established in 13th century": "أخويات دينية مسيحية أسست في القرن 13",
    "Christian religious orders established in 14th century": "أخويات دينية مسيحية أسست في القرن 14",
    "Christian religious orders established in 15th century": "أخويات دينية مسيحية أسست في القرن 15",
    "Christian religious orders established in 16th century": "أخويات دينية مسيحية أسست في القرن 16",
    "Christian religious orders established in 17th century": "أخويات دينية مسيحية أسست في القرن 17",
    "Christian religious orders established in 18th century": "أخويات دينية مسيحية أسست في القرن 18",
    "Christian religious orders established in 19th century": "أخويات دينية مسيحية أسست في القرن 19",
    "Christian religious orders established in 20th century": "أخويات دينية مسيحية أسست في القرن 20",
    "Christian religious orders established in 21st century": "أخويات دينية مسيحية أسست في القرن 21",
    "Christian religious orders established in 5th century": "أخويات دينية مسيحية أسست في القرن 5",
    "Christian religious orders established in 6th century": "أخويات دينية مسيحية أسست في القرن 6",
    "Christian political parties by country": "أحزاب سياسية مسيحية حسب البلد",
    "Christian political parties in Australia": "أحزاب سياسية مسيحية في أستراليا",
    "Christian political parties in Canada": "أحزاب سياسية مسيحية في كندا",
    "Christian political parties in Germany": "أحزاب سياسية مسيحية في ألمانيا",
    "Christian political parties in Hungary": "أحزاب سياسية مسيحية في المجر",
    "Christian political parties in Lebanon": "أحزاب سياسية مسيحية في لبنان",
    "Christian political parties in Montenegro": "أحزاب سياسية مسيحية في الجبل الأسود",
    "Christian political parties in New Zealand": "أحزاب سياسية مسيحية في نيوزيلندا",
    "Christian political parties in Papua New Guinea": "أحزاب سياسية مسيحية في بابوا غينيا الجديدة",
    "Christian political parties in Poland": "أحزاب سياسية مسيحية في بولندا",
    "Christian political parties in Quebec": "أحزاب سياسية مسيحية في كيبك",
    "Christian political parties in South Africa": "أحزاب سياسية مسيحية في جنوب إفريقيا",
    "Christian political parties in Ukraine": "أحزاب سياسية مسيحية في أوكرانيا",
    "Christian political parties in United Kingdom": "أحزاب سياسية مسيحية في المملكة المتحدة",
    "Christian political parties in United States": "أحزاب سياسية مسيحية في الولايات المتحدة",
    "Politicians of Christian political parties": "سياسيون من أحزاب سياسية مسيحية",
    "Politicians of Jewish political parties": "سياسيون من أحزاب سياسية يهودية",
    "Christian texts by century": "نصوص مسيحية حسب القرن",
    "Christian texts by genre": "نصوص مسيحية حسب النوع الفني",
    "Christian texts by medium": "نصوص مسيحية حسب الوسط",
    "Christian texts by millennium": "نصوص مسيحية حسب الألفية",
    "Christian texts by period": "نصوص مسيحية حسب الحقبة",
    "christian texts": "نصوص مسيحية",
    "Jewish texts by century": "نصوص يهودية حسب القرن",
    "jewish texts": "نصوص يهودية",
    "jewish rock groups": "فرق روك يهودية",
    "christian events": "أحداث مسيحية",
    "christian political organizations": "منظمات سياسية مسيحية",
    "christian rock groups": "فرق روك مسيحية",
    "jewish history organizations": "منظمات تاريخ يهودية",
    "jewish political organizations": "منظمات سياسية يهودية",
    "jewish religious organizations": "منظمات دينية يهودية",
    "Kurdish Islamic organisations": "منظمات إسلامية كردية",
    "kurdish islamic organizations": "منظمات إسلامية كردية",
    "jewish sports organizations": "منظمات ألعاب رياضية يهودية",
    "christian sports organizations": "منظمات ألعاب رياضية مسيحية",
    "romanian motorsport people": "أعلام رياضة المحركات الرومانية",
    "american culture": "ثقافة أمريكية",
    "antigua and barbuda sport": "رياضة أنتيغوية وبربودية",
    "armenian television": "التلفزة الأرمينية",
    "asian restaurants": "مطاعم آسيوية",
    "asian-american people": "أمريكيون آسيويون",
    "austrian television series": "مسلسلات تلفزيونية نمساوية",
    "bangladeshi films": "أفلام بنغلاديشية",
    "bangladeshi politics": "السياسة البنغلاديشية",
    "belgian companies": "شركات بلجيكية",
    "bhutanese sport": "رياضة بوتانية",
    "brazilian football club seasons": "مواسم أندية كرة قدم برازيلية",
    "british women's sport": "رياضة بريطانية نسائية",
    "burmese names": "أسماء بورمية",
    "byzantine titles": "ألقاب بيزنطية",
    "canadian films": "أفلام كندية",
    "canadian music": "موسيقى كندية",
    "central american football": "كرة القدم الأمريكية الأوسطية",
    "chinese music": "موسيقى صينية",
    "christian educational organizations": "منظمات تعليمية مسيحية",
    "christian organizations": "منظمات مسيحية",
    "croatian music": "موسيقى كرواتية",
    "czech women's sport": "رياضة تشيكية نسائية",
    "danish books": "كتب دنماركية",
    "east german sport": "رياضة ألمانية شرقية",
    "emirati sport": "رياضة إماراتية",
    "english tennis": "كرة المضرب الإنجليزية",
    "eritrean war crimes": "جرائم حرب إريترية",
    "estonian music people": "شخصيات موسيقية إستونية",
    "ethiopian war crimes": "جرائم حرب إثيوبية",
    "european restaurants": "مطاعم أوروبية",
    "european-argentine culture": "ثقافة أرجنتينية أوروبية",
    "filipino-american culture": "ثقافة أمريكية فلبينية",
    "french restaurants": "مطاعم فرنسية",
    "french wars": "حروب فرنسية",
    "gothic architecture": "عمارة قوطية",
    "greek television series": "مسلسلات تلفزيونية يونانية",
    "hong kong sport": "رياضة هونغ كونغية",
    "hungarian sport": "رياضة مجرية",
    "hungarian websites": "مواقع ويب مجرية",
    "indian companies": "شركات هندية",
    "irish comedy": "كوميديا أيرلندية",
    "irish universities": "جامعات أيرلندية",
    "italian restaurants": "مطاعم إيطالية",
    "ivorian companies": "شركات إيفوارية",
    "japanese restaurants": "مطاعم يابانية",
    "japanese war crimes": "جرائم حرب يابانية",
    "jewish educational organizations": "منظمات تعليمية يهودية",
    "jewish music": "موسيقى يهودية",
    "jewish organizations": "منظمات يهودية",
    "kyrgyzstani sport": "رياضة قيرغيزستانية",
    "lebanese television series": "مسلسلات تلفزيونية لبنانية",
    "lithuanian films": "أفلام ليتوانية",
    "malawian websites": "مواقع ويب ملاوية",
    "mexican restaurants": "مطاعم مكسيكية",
    "mexican-american culture": "ثقافة أمريكية مكسيكية",
    "moroccan television series": "مسلسلات تلفزيونية مغربية",
    "nepali television": "التلفزة النيبالية",
    "nigerian football": "كرة القدم النيجيرية",
    "north american culture": "ثقافة أمريكية شمالية",
    "northern ireland sport": "رياضة أيرلندية شمالية",
    "ottoman classical music": "موسيقى كلاسيكية عثمانية",
    "pakistani football": "كرة القدم الباكستانية",
    "philippine football": "كرة القدم الفلبينية",
    "philippine presidential election": "انتخابات الرئاسة الفلبينية",
    "philippine television commercials": "إعلانات تجارية تلفزيونية فلبينية",
    "qatari football ": "كرة القدم القطرية",
    "romanian clothing": "ملابس رومانية",
    "romanian motorsport": "رياضة المحركات الرومانية",
    "romanian restaurants": "مطاعم رومانية",
    "romanian sport": "رياضة رومانية",
    "russian politics": "السياسة الروسية",
    "scottish islands": "جزر إسكتلندية",
    "scottish sports": "ألعاب رياضية إسكتلندية",
    "slovenian sport": "رياضة سلوفينية",
    "soviet navy": "البحرية السوفيتية",
    "soviet war crimes": "جرائم حرب سوفيتية",
    "spanish films": "أفلام إسبانية",
    "surinamese sport": "رياضة سورينامية",
    "swedish air force": "القوات الجوية السويدية",
    "swiss businesspeople": "شخصيات أعمال سويسرية",
    "syrian websites": "مواقع ويب سورية",
    "thai television": "التلفزة التايلندية",
    "trinidad and tobago football": "كرة القدم الترنيدادية",
    "vietnamese sport": "رياضة فيتنامية",
    "yemeni civil war": "الحرب الأهلية اليمنية",
    "yoruba names": "أسماء يوروبية",
    "asian games bronze medalists": "فائزون بميداليات برونزية في الألعاب الآسيوية",
    "azerbaijani encyclopedias": "موسوعات أذربيجانية",
    "azerbaijani football club seasons": "مواسم أندية كرة قدم أذربيجانية",
    "bahamian awards": "جوائز بهامية",
    "bangladesh cinema": "السينما البنغلاديشية",
    "bangladeshi awards": "جوائز بنغلاديشية",
    "bangladeshi companies": "شركات بنغلاديشية",
    "bangladeshi folk music": "موسيقى فلكلورية بنغلاديشية",
    "belarusian sport": "رياضة بيلاروسية",
    "belgian detention": "المعتقلات البلجيكية",
    "belgian novels": "روايات بلجيكية",
    "beninese sport": "رياضة بنينية",
    "bolivian television series": "مسلسلات تلفزيونية بوليفية",
    "brazilian television series": "مسلسلات تلفزيونية برازيلية",
    "british medical association": "الجمعية الطبية البريطانية",
    "british music": "موسيقى بريطانية",
    "british plays": "مسرحيات بريطانية",
    "british restaurants": "مطاعم بريطانية",
    "burmese sport": "رياضة بورمية",
    "cambodian sport": "رياضة كمبودية",
    "cameroonian football": "كرة القدم الكاميرونية",
    "canadian journalism": "صحافة كندية",
    "canadian magazines": "مجلات كندية",
    "cape verdean awards": "جوائز رأس أخضرية",
    "central american cinema": "السينما الأمريكية الأوسطية",
    "chilean football": "كرة القدم التشيلية",
    "chilean navy": "البحرية التشيلية",
    "chilean sport": "رياضة تشيلية",
    "chinese businesspeople": "شخصيات أعمال صينية",
    "chinese sport": "رياضة صينية",
    "christian radio stations": "محطات إذاعية مسيحية",
    "comorian football": "كرة القدم القمرية",
    "congolese movement": "الحركة الكونغوية",
    "croatian war crimes": "جرائم حرب كرواتية",
    "cypriot football": "كرة القدم القبرصية",
    "czech air force": "القوات الجوية التشيكية",
    "czech politics": "السياسة التشيكية",
    "czechoslovak television": "التلفزة التشيكوسلوفاكية",
    "danish football": "كرة القدم الدنماركية",
    "danish islands": "جزر دنماركية",
    "danish sport": "رياضة دنماركية",
    "danish television": "التلفزة الدنماركية",
    "dominican culture": "ثقافة دومينيكية",
    "dutch novels": "روايات هولندية",
    "english women's sport": "رياضة إنجليزية نسائية",
    "equatoguinean sport": "رياضة غينية استوائية",
    "estonian sport": "رياضة إستونية",
    "ethiopian sport": "رياضة إثيوبية",
    "european border": "حدود أوروبية",
    "european games silver medalists": "فائزون بميداليات فضية في الألعاب الأوروبية",
    "european music": "موسيقى أوروبية",
    "fijian football": "كرة القدم الفيجية",
    "finnish awards and decorations": "جوائز وأوسمة فنلندية",
    "finnish navy": "البحرية الفنلندية",
    "finnish novels": "روايات فنلندية",
    "finnish sport": "رياضة فنلندية",
    "finnish television series": "مسلسلات تلفزيونية فنلندية",
    "french cinema": "السينما الفرنسية",
    "french legal films": "أفلام قانونية فرنسية",
    "french mythology": "أساطير فرنسية",
    "french navy": "البحرية الفرنسية",
    "french sport": "رياضة فرنسية",
    "french war crimes": "جرائم حرب فرنسية",
    "german music": "موسيقى ألمانية",
    "german women's sport": "رياضة ألمانية نسائية",
    "greek companies": "شركات يونانية",
    "greek novels": "روايات يونانية",
    "greek poems": "قصائد يونانية",
    "greek women's sport": "رياضة يونانية نسائية",
    "greenlandic sport": "رياضة جرينلاندية",
    "guamanian football": "كرة القدم الغوامية",
    "guatemalan musical instruments": "آلات موسيقية غواتيمالية",
    "gujarati films": "أفلام غجراتية",
    "hungarian women's sport": "رياضة مجرية نسائية",
    "indian politics": "السياسة الهندية",
    "indonesian websites": "مواقع ويب إندونيسية",
    "iranian television series": "مسلسلات تلفزيونية إيرانية",
    "irish films": "أفلام أيرلندية",
    "irish general election": "الانتخابات العامة الأيرلندية",
    "israeli brands": "ماركات إسرائيلية",
    "israeli sport": "رياضة إسرائيلية",
    "israeli women's sport": "رياضة إسرائيلية نسائية",
    "jamaican brands": "ماركات جامايكية",
    "japanese companies": "شركات يابانية",
    "japanese music": "موسيقى يابانية",
    "japanese politics": "السياسة اليابانية",
    "japanese sport": "رياضة يابانية",
    "jewish american television series": "مسلسلات تلفزيونية أمريكية يهودية",
    "jewish american tennis": "كرة مضرب أمريكية يهودية",
    "jordanian football": "كرة القدم الأردنية",
    "kenyan novels": "روايات كينية",
    "kenyan television series": "مسلسلات تلفزيونية كينية",
    "korean businesspeople": "شخصيات أعمال كورية",
    "kyrgyzstani football": "كرة القدم القيرغيزستانية",
    "luxembourgian sport": "رياضة لوكسمبورغية",
    "luxembourgish inventions": "اختراعات لوكسمبورغية",
    "malaysian football": "كرة القدم الماليزية",
    "malaysian sport": "رياضة ماليزية",
    "mexican businesspeople": "شخصيات أعمال مكسيكية",
    "mexican novels": "روايات مكسيكية",
    "mexican politics": "السياسة المكسيكية",
    "mexican television series": "مسلسلات تلفزيونية مكسيكية",
    "monégasque sport": "رياضة موناكية",
    "native american films": "أفلام أمريكية أصلية",
    "nicaraguan football": "كرة القدم النيكاراغوية",
    "nigerian sport": "رياضة نيجيرية",
    "north american sport": "رياضة أمريكية شمالية",
    "norwegian military academy": "الأكاديمية العسكرية النرويجية",
    "norwegian music": "موسيقى نرويجية",
    "pakistani politics": "السياسة الباكستانية",
    "pakistani sport": "رياضة باكستانية",
    "pakistani television": "التلفزة الباكستانية",
    "palestinian organizations": "منظمات فلسطينية",
    "paraguayan films": "أفلام بارغوايانية",
    "peruvian sport": "رياضة بيروية",
    "peruvian television series": "مسلسلات تلفزيونية بيروية",
    "peruvian television": "التلفزة البيروية",
    "philippine revolution": "الثورة الفلبينية",
    "polish companies": "شركات بولندية",
    "polish football": "كرة القدم البولندية",
    "polish music": "موسيقى بولندية",
    "polish sport": "رياضة بولندية",
    "polish television": "التلفزة البولندية",
    "portuguese companies": "شركات برتغالية",
    "portuguese sport": "رياضة برتغالية",
    "puerto rican brands": "ماركات بورتوريكية",
    "qatari musical instruments": "آلات موسيقية قطرية",
    "russian journalism": "صحافة روسية",
    "russian revolution": "الثورة الروسية",
    "russian songs": "أغاني روسية",
    "samoan islands": "جزر ساموية",
    "scottish businesspeople": "شخصيات أعمال إسكتلندية",
    "scottish television": "التلفزة الإسكتلندية",
    "sierra leonean sport": "رياضة سيراليونية",
    "singaporean media personalities": "شخصيات إعلامية سنغافورية",
    "singaporean plays": "مسرحيات سنغافورية",
    "slovak music": "موسيقى سلوفاكية",
    "slovenian novels": "روايات سلوفينية",
    "south american sport": "رياضة أمريكية جنوبية",
    "south korean sport": "رياضة كورية جنوبية",
    "soviet football": "كرة القدم السوفيتية",
    "spanish companies": "شركات إسبانية",
    "sri lankan novels": "روايات سريلانكية",
    "sri lankan television": "التلفزة السريلانكية",
    "swedish inventions": "اختراعات سويدية",
    "swedish novels": "روايات سويدية",
    "swedish plays": "مسرحيات سويدية",
    "swedish war": "الحرب السويدية",
    "swiss books": "كتب سويسرية",
    "swiss detention": "المعتقلات السويسرية",
    "swiss websites": "مواقع ويب سويسرية",
    "syrian navy": "البحرية السورية",
    "syrian sport": "رياضة سورية",
    "tanzanian brands": "ماركات تنزانية",
    "tanzanian sport": "رياضة تنزانية",
    "thai families": "عائلات تايلندية",
    "thai films": "أفلام تايلندية",
    "turkish awards": "جوائز تركية",
    "tuvaluan football": "كرة القدم التوفالية",
    "ugandan television": "التلفزة الأوغندية",
    "ukrainian films": "أفلام أوكرانية",
    "ukrainian sport": "رياضة أوكرانية",
    "ukrainian television": "التلفزة الأوكرانية",
    "ukrainian works": "أعمال أوكرانية",
    "uruguayan war": "الحرب الأوروغويانية",
    "uzbekistani films": "أفلام أوزبكستانية",
    "venezuelan sport": "رياضة فنزويلية",
    "venezuelan television": "التلفزة الفنزويلية",
    "vietnamese companies": "شركات فيتنامية",
    "vietnamese women's sport": "رياضة فيتنامية نسائية",
    "welsh sport": "رياضة ويلزية",
    "yugoslav sport": "رياضة يوغسلافية",
    "zimbabwean companies": "شركات زيمبابوية",
    "zimbabwean general election": "الانتخابات العامة الزيمبابوية",
}

data1 = {
    "Lists of office-holders in 2014": "قوائم أصحاب المناصب في 2014",
    "Lists of office-holders in Armenia": "قوائم أصحاب المناصب في أرمينيا",
    "Lists of office-holders in Syria": "قوائم أصحاب المناصب في سوريا",
    "Christian Science in England": "علم مسيحي في إنجلترا",
    "Christian fiction": "خيال مسيحي",
    "Christian Science in California": "علم مسيحي في كاليفورنيا",
    "Christian Science in Canada": "علم مسيحي في كندا",
    "Christian Science in Colorado": "علم مسيحي في كولورادو",
    "Christian Science in Connecticut": "علم مسيحي في كونيتيكت",
    "Christian Science in Florida": "علم مسيحي في فلوريدا",
    "Christian Science in Germany": "علم مسيحي في ألمانيا",
    "Christian Science in Illinois": "علم مسيحي في إلينوي",
    "Christian Science in Massachusetts": "علم مسيحي في ماساتشوستس",
    "Christian Science in Missouri": "علم مسيحي في ميزوري",
    "Christian Science in New York (state)": "علم مسيحي في ولاية نيويورك",
    "Christian Science in New York City": "علم مسيحي في مدينة نيويورك",
    "Christian Science in United Kingdom": "علم مسيحي في المملكة المتحدة",
    "Christian Science in United States by state": "علم مسيحي في الولايات المتحدة حسب الولاية",
    "Christian Science in United States": "علم مسيحي في الولايات المتحدة",
    "Christian Science in Washington (state)": "علم مسيحي في ولاية واشنطن",
    "Christian Science in Wisconsin": "علم مسيحي في ويسكونسن",
    "Christian Science": "علم مسيحي",
    "Critics of Christian Science": "نقاد من علم مسيحي",
    "1888 in American sports": "ألعاب رياضية أمريكية في 1888",
    "1919 in American motorsport": "رياضة المحركات الأمريكية في 1919",
    "1919 in American tennis": "كرة المضرب الأمريكية في 1919",
    "1930 in Australian tennis": "كرة المضرب الأسترالية في 1930",
    "1931 in American motorsport": "رياضة المحركات الأمريكية في 1931",
    "1937 in Belgian motorsport": "رياضة المحركات البلجيكية في 1937",
    "1970s in Australian tennis": "كرة المضرب الأسترالية في عقد 1970",
    "1971 in American tennis": "كرة المضرب الأمريكية في 1971",
    "1974 in West German motorsport": "رياضة المحركات الألمانية الغربية في 1974",
    "1984 in American motorsport": "رياضة المحركات الأمريكية في 1984",
    "1987 in American sports by state": "ألعاب رياضية أمريكية في 1987 حسب الولاية",
    "1990s in Colombian tennis": "كرة المضرب الكولومبية في عقد 1990",
    "1991 in Australian tennis": "كرة المضرب الأسترالية في 1991",
    "1997 in British motorsport": "رياضة المحركات البريطانية في 1997",
    "1998 in Indian tennis": "كرة المضرب الهندية في 1998",
    "2000 in Canadian sports by province or territory": "ألعاب رياضية كندية في 2000 حسب المقاطعة أو الإقليم",
    "2004 in Chilean tennis": "كرة المضرب التشيلية في 2004",
    "2004 in French motorsport": "رياضة المحركات الفرنسية في 2004",
    "2005 in Australian tennis": "كرة المضرب الأسترالية في 2005",
    "2010s in Taiwanese tennis": "كرة المضرب التايوانية في عقد 2010",
    "Ancient Egyptian Jews": "مصريون قدماء يهود",
    "Canarian Jews": "كناريون يهود",
    "Ancient Christian saints": "قديسون قدماء",
    "works by gotthold ephraim lessing": "أعمال إفرايم ليسينغ",
    "works by leo tolstoy": "أعمال ليو تولستوي",
    "works by osamu tezuka": "أعمال أوسامو تزوكا",
    "2012 in Luxembourgian tennis": "كرة المضرب اللوكسمبورغية في 2012",
    "2013 in Hungarian motorsport": "رياضة المحركات المجرية في 2013",
    "2020 in French tennis": "كرة المضرب الفرنسية في 2020",
    "2020s in Thai motorsport": "رياضة المحركات التايلندية في عقد 2020",
    "2023 in Malaysian motorsport": "رياضة المحركات الماليزية في 2023",
    "Women's soccer players in United States by competition": "لاعبات كرة قدم في الولايات المتحدة حسب المنافسة",
    "1999–2000 in European rugby union leagues": "دوريات اتحاد الرجبي الأوروبي في 1999–2000",
    "2016–17 in European women's rugby union": "اتحاد رجبي أوروبية للسيدات في 2016–17",
    "Hong Kong motorsport people": "أعلام رياضة المحركات الهونغ الكونغية",
    "American football culture": "ثقافة كرة قدم أمريكية",
    "2012–13 in Spanish rugby union leagues": "دوريات اتحاد الرجبي الإسباني في 2012–13",
    "american football films": "أفلام كرة قدم أمريكية",
    "Men's footballers in Azerbaijan by competition": "لاعبو كرة قدم في أذربيجان حسب المنافسة",
    "Men's footballers in Guinea-Bissau by club": "لاعبو كرة قدم في غينيا بيساو حسب النادي",
    "Men's footballers in Portugal by competition": "لاعبو كرة قدم في البرتغال حسب المنافسة",
    "Men's footballers in Slovenia by club": "لاعبو كرة قدم في سلوفينيا حسب النادي",
    "Men's footballers in Solomon Islands by club": "لاعبو كرة قدم في جزر سليمان حسب النادي",
    "Men's footballers in Tajikistan by club": "لاعبو كرة قدم في طاجيكستان حسب النادي",
    "Founders of motor vehicle manufacturers by nationality": "مؤسسي مصانع السيارات حسب الجنسية",
    "Founders of motor vehicle manufacturers": "مؤسسي مصانع السيارات",
    "american football governing bodies": "هيئات تنظيم كرة قدم أمريكية",
    "1828 New Jersey elections": "انتخابات نيوجيرسي في 1828",
    "cuban football logos": "شعارات كرة القدم الكوبية",
    "thai league cup": "كأس الدوري التايلندي",
    "lao premier league seasons": "مواسم الدوري اللاوسي الممتاز",
    "american indoor soccer league seasons": "مواسم الدوري الأمريكي لكرة القدم داخل الصالات",
    "male actors from west midlands (county)": "ممثلون ذكور من مقاطعة ميدلاند الغربية",
    "Canadian football players in Edmonton": "لاعبو كرة قدم كندية في إدمونتون",
    "christian saints": "قديسون",
    "electro musicians": "موسيقيو موسيقى كهربائية",
    "film editors": "محررو أفلام",
    "gardeners": "مزارعو حدائق",
    "music journalists": "صحفيون موسيقيون",
    "olympic beach volleyball players": "لاعبو كرة طائرة شاطئية أولمبيون",
    "olympic divers": "غواصون أولمبيون",
    "olympic handball players": "لاعبو كرة يد أولمبيون",
    "olympic judoka": "لاعبو جودو أولمبيون",
    "olympic nordic combined skiers": "متزحلقو تزلج نوردي مزدوج أولمبيون",
    "polo players": "لاعبو بولو",
    "traditional pop music singers": "مغنو موسيقى بوب تقليدية",
    "voice actresses": "ممثلات أداء صوتي",
    "male models": "عارضو أزياء ذكور",
    "male sport shooters": "لاعبو رماية ذكور",
    "assassinated politicians": "سياسيون مغتالون",
    "18th-century Dutch explorers": "مستكشفون هولنديون في القرن 18",
    "1650s crimes": "جرائم عقد 1650",
    "20th century women musicians": "موسيقيات في القرن 20",
    "20th century canadian violinists": "عازفو كمان كنديون في القرن 20",
    "20th century russian dramatists": "دراميون روس في القرن 20",
    "20th century polish dramatists": "دراميون بولنديون في القرن 20",
    "20th century chinese dramatists": "دراميون صينيون في القرن 20",
    "20th century dramatists": "دراميون في القرن 20",
    "20th century english dramatists": "دراميون إنجليز في القرن 20",
    "20th century israeli dramatists": "دراميون إسرائيليون في القرن 20",
    "italian defectors to soviet union": "إيطاليون منشقون إلى الاتحاد السوفيتي",
    "zambian emigrants to sweden": "زامبيون مهاجرون إلى السويد",
    "sri lankan emigrants to india": "سريلانكيون مهاجرون إلى الهند",
    "taiwanese emigrants to argentina": "تايوانيون مهاجرون إلى الأرجنتين",
    "polish emigrants to brazil": "بولنديون مهاجرون إلى البرازيل",
    "italian emigrants to finland": "إيطاليون مهاجرون إلى فنلندا",
    "icelandic emigrants to new zealand": "آيسلنديون مهاجرون إلى نيوزيلندا",
    "german emigrants to scotland": "ألمان مهاجرون إلى إسكتلندا",
    "croatian emigrants to netherlands": "كروات مهاجرون إلى هولندا",
    "cypriot emigrants to israel": "قبرصيون مهاجرون إلى إسرائيل",
    "chinese emigrants to thailand": "صينيون مهاجرون إلى تايلاند",
    "british emigrants to switzerland": "بريطانيون مهاجرون إلى سويسرا",
    "british emigrants to zimbabwe": "بريطانيون مهاجرون إلى زيمبابوي",
    "American child classical musicians": "موسيقيون كلاسيكيون أمريكيون أطفال",
    "Canadian child singers": "مغنون كنديون أطفال",
    "Native American people in American Revolution": "أمريكيون أصليون في الثورة الأمريكية",
    "Yugoslav disabled sports-people": "رياضيون يوغسلافيون معاقون",
    "American women in politics by descent": "أمريكيات في السياسة حسب الأصل",
    "Native American people from Minnesota": "أمريكيون أصليون من منيسوتا",
    "Native American people from North Dakota": "أمريكيون أصليون من داكوتا الشمالية",
    "Native American people from South Dakota": "أمريكيون أصليون من داكوتا الجنوبية",
    "Native American people from Washington (state)": "أمريكيون أصليون من ولاية واشنطن",
    "Somalian disabled sports-people": "رياضيون صوماليون معاقون",
    "Ancient Jews by occupation": "يهود قدماء حسب المهنة",
    "Ancient Jews": "يهود قدماء",
    "Fictional American Jews in comics": "أمريكيون يهود خياليون في قصص مصورة",
    "Fictional American Jews": "أمريكيون يهود خياليون",
    "Fictional Argentine Jews": "أرجنتينيون يهود خياليون",
    "Fictional British Jews": "بريطانيون يهود خياليون",
    "Fictional Canadian Jews": "كنديون يهود خياليون",
    "Fictional English Jews": "إنجليز يهود خياليون",
    "Fictional German Jews": "ألمان يهود خياليون",
    "Fictional Israeli Jews": "إسرائيليون يهود خياليون",
    "Fictional Italian Jews": "إيطاليون يهود خياليون",
    "Fictional Polish Jews": "بولنديون يهود خياليون",
    "Fictional Russian Jews": "روس يهود خياليون",
    "Fictional Serbian Jews": "صرب يهود خياليون",
    "Political office-holders in Northern Ireland by county": "أصحاب مناصب سياسية في أيرلندا الشمالية حسب المقاطعة",
    "Lists of political office-holders in Northern Ireland": "قوائم أصحاب مناصب سياسية في أيرلندا الشمالية",
    "Lists of political office-holders in South Africa": "قوائم أصحاب مناصب سياسية في جنوب إفريقيا",
    "lists of political office-holders": "قوائم أصحاب مناصب سياسية",
    "1991 in Canadian sports by province or territory": "ألعاب رياضية كندية في 1991 حسب المقاطعة أو الإقليم",
    "Scottish sports trophies and awards": "جوائز وإنجازات ألعاب رياضية إسكتلندية",
    "2026 in American sports by month": "ألعاب رياضية أمريكية في 2026 حسب الشهر",
    "2026 in American sports by state": "ألعاب رياضية أمريكية في 2026 حسب الولاية",
    "2026 in American sports": "ألعاب رياضية أمريكية في 2026",
    "2026 in Canadian sports by month": "ألعاب رياضية كندية في 2026 حسب الشهر",
    "2026 in Canadian sports by province or territory": "ألعاب رياضية كندية في 2026 حسب المقاطعة أو الإقليم",
    "2026 in Canadian sports": "ألعاب رياضية كندية في 2026",
    "2026 in Mexican sports by month": "ألعاب رياضية مكسيكية في 2026 حسب الشهر",
    "2026 in Mexican sports": "ألعاب رياضية مكسيكية في 2026",
    "2025 in Qatari motorsport": "رياضة المحركات القطرية في 2025",
    "2026 in American motorsport": "رياضة المحركات الأمريكية في 2026",
    "2026 in Australian motorsport": "رياضة المحركات الأسترالية في 2026",
    "2026 in Emirati motorsport": "رياضة المحركات الإماراتية في 2026",
    "2026 in French motorsport": "رياضة المحركات الفرنسية في 2026",
    "2026 in German motorsport": "رياضة المحركات الألمانية في 2026",
    "2026 in Japanese motorsport": "رياضة المحركات اليابانية في 2026",
    # "American expatriate men's soccer players in Canada": "",
    "West German men sprinters": "عداؤون سريعون ألمانيون غربيون",
    "Emirati men's footballers": "لاعبو كرة قدم إماراتيون",
    "2015 American television": "التلفزة الأمريكية 2015",
    # "yemeni presidential elections": "انتخابات اليمن الرئاسية",
    "ambassadors of federated states of micronesia in yemen by year": "سفراء ولايات ميكرونيسيا المتحدة في اليمن حسب السنة",
    "Adaptations of works by Greek writers": "أعمال مقتبسة عن أعمال كتاب يونانيون",
    "Adaptations of works by Irish writers": "أعمال مقتبسة عن أعمال كتاب أيرلنديون",
    "Adaptations of works by Italian writers": "أعمال مقتبسة عن أعمال كتاب إيطاليون",
    "sieges of french invasion of egypt and syria": "حصارات الغزو الفرنسي لمصر وسوريا",
    "1330 in men's international football": "كرة قدم دولية للرجال في 1330",
    "2017 American television series": "مسلسلات تلفزيونية أمريكية في 2017",
    "Cross-country skiers at 1992 Winter Paralympics": "متزحلقون ريفيون في الألعاب البارالمبية الشتوية 1992",
    "2017 American television episodes": "حلقات تلفزيونية أمريكية في 2017",
    "2017 American television seasons": "مواسم تلفزيونية أمريكية في 2017",
    "Roller skaters at 2003 Pan American Games": "متزلجون بالعجلات في دورة الألعاب الأمريكية 2003",
    "Ski jumpers at 2007 Winter Universiade": "متزلجو قفز في الألعاب الجامعية الشتوية 2007",
    "Figure skaters at 2002 Winter Olympics": "متزلجون فنيون في الألعاب الأولمبية الشتوية 2002",
    "Figure skaters at 2003 Asian Winter Games": "متزلجون فنيون في الألعاب الآسيوية الشتوية 2003",
    "Figure skaters at 2007 Winter Universiade": "متزلجون فنيون في الألعاب الجامعية الشتوية 2007",
    "Nations at 2010 Summer Youth Olympics": "بلدان في الألعاب الأولمبية الشبابية الصيفية 2010",
    "military personnel of republic-of china": "أفراد عسكريون من جمهورية الصين",
    "children of prime ministers of ukraine": "أبناء رؤساء وزراء أوكرانيا",
    # "roman catholic bishops of fulda": "",
    "men of poseidon": "رجال من بوسيدون",
    "Olympic shooters of Egypt": "رماة أولمبيون من مصر",
    "Olympic short track speed skaters of Japan": "متزلجون على مسار قصير أولمبيون من اليابان",
    "Olympic figure skaters of Argentina": "متزلجون فنيون أولمبيون من الأرجنتين",
    "Olympic figure skaters of Armenia": "متزلجون فنيون أولمبيون من أرمينيا",
    "Olympic figure skaters of Australia": "متزلجون فنيون أولمبيون من أستراليا",
    # "communists of bosnia and herzegovina politicians": "أحداث أكتوبر 1550 الرياضية في أوقيانوسيا",
}

data_test2 = {
    "Schools for deaf in New York (state)": "مدارس للصم في ولاية نيويورك",
    "Cabinets involving Liberal Party (Norway)": "",
    "Television plays directed by William Sterling (director)": "",
    "Television plays filmed in Brisbane": "مسرحيات تلفزيونية صورت في بريزبان",
    "Television personalities from Yorkshire": "شخصيات تلفزيون من يوركشاير",
    "Cabinets involving Progress Party (Norway)": "مجالس وزراء تشمل حزب التقدم (النرويج)",
    "100 metres at African Championships in Athletics": "",
    "100 metres at IAAF World Youth Championships in Athletics": "",
    "100 metres at World Para Athletics Championships": "",
    "Documentary films about 2011 Tōhoku earthquake and tsunami": "",
    "People accused of lèse majesté in Thailand": "",
    "People accused of lèse majesté in Thailand since 2020": "",
    "People associated with former colleges of University of London": "",
    "People associated with Nazarene universities and colleges": "",
}


data_list_bad = {
    # "20th century roman catholic archbishops in colombia": "رؤساء أساقفة رومان كاثوليك في كولومبيا القرن 20",
    # "20th century disasters in afghanistan": "كوارث القرن 20 في أفغانستان",
    # "20th century churches in ethiopia": "كنائس في إثيوبيا القرن 20",
    # "20th century churches in nigeria": "كنائس في نيجيريا القرن 20",
    "Paralympic competitors for Cape Verde": "منافسون بارالمبيون من الرأس الأخضر",
    "20th century american people by occupation": "أمريكيون في القرن 20 حسب المهنة",
    "20th century people from al-andalus": "أشخاص من الأندلس في القرن 20",
    "1550s disestablishments in yugoslavia": "انحلالات عقد 1550 في يوغسلافيا",
    "20th century disestablishments in united kingdom": "انحلالات القرن 20 في المملكة المتحدة",
    "1550s establishments in wisconsin": "تأسيسات عقد 1550 في ويسكونسن",
    "20th century disestablishments in sri lanka": "انحلالات القرن 20 في سريلانكا",
    "3rd millennium disestablishments in england": "انحلالات الألفية 3 في إنجلترا",
    "1550s crimes in pakistan": "جرائم عقد 1550 في باكستان",
    "2nd millennium establishments in rhode island": "تأسيسات الألفية 2 في رود آيلاند",
    "1550s establishments in chile": "تأسيسات عقد 1550 في تشيلي",
    "1550s disestablishments in southeast asia": "انحلالات عقد 1550 في جنوب شرق آسيا",
    "1550s establishments in jamaica": "تأسيسات عقد 1550 في جامايكا",
    "1550s disestablishments in mississippi": "انحلالات عقد 1550 في مسيسيبي",
    "1550s establishments in maine": "تأسيسات عقد 1550 في مين",
    "1550s establishments in sweden": "تأسيسات عقد 1550 في السويد",
    "20th century disestablishments in newfoundland and labrador": "انحلالات القرن 20 في نيوفاوندلاند واللابرادور",
    "20th century disestablishments in danish colonial empire": "انحلالات القرن 20 في الإمبراطورية الاستعمارية الدنماركية",
    "20th century establishments in french guiana": "تأسيسات القرن 20 في غويانا الفرنسية",
    "20th century establishments in ireland": "تأسيسات القرن 20 في أيرلندا",
    "20th century monarchs by country": "ملكيون في القرن 20 حسب البلد",
    "july 1550 crimes by continent": "جرائم يوليو 1550 حسب القارة",
}


to_test = [
    ("test_2_test_1", data1),
    ("test_2_fast_data", fast_data),
    ("test_2_test_2", data_test2),
    ("test_2_new_bug_check", data_list_bad),
]


@pytest.mark.parametrize("category, expected", fast_data.items(), ids=fast_data.keys())
@pytest.mark.fast
def test_2_fast_data(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
@pytest.mark.fast
def test_1(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data_test2.items(), ids=data_test2.keys())
@pytest.mark.fast
def test_2(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", data_list_bad.items(), ids=data_list_bad.keys())
@pytest.mark.fast
def test_2_new_bug_check(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_peoples(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
