"""
Derived key mappings shared by the mixed key modules.
"""

from ...helps import len_print

POP_FINAL6_BASE: dict[str, str] = {
    "gulf war": "حرب الخليج الثانية",
    "robert award": "جائزة روبرت",
    "emmy award": "جائزة إيمي",
    "grammy award": "جائزة غرامي",
    "golden globe award": "جائزة غولدن غلوب",
    "independent spirit award": "جائزة الروح المستقلة",
    "national board of review award": "جائزة المجلس الوطني للمراجعة",
    "toronto international film festival award": "جائزة مهرجان تورونتو السينمائي الدولي",
    "hollywood film awards": "جوائز هوليوود للأفلام",
    "hong kong film awards": "جوائز مهرجان هونج كونج السينمائي",
    "empire awards": "جوائز إمباير",
    "ptc punjabi film awards": "جوائز المهرجان البنجابي السينمائي",
    "european film awards": "جوائز الفيلم الأوروبي",
    "environmental media awards": "جوائز الإعلام البيئي",
    "jussi awards": "جائزة جوسي",
    "bodil awards": "جائزة بوديل",
    "teen choice awards": "جائزة اختيار المراهقين",
    "claude jutra award": "جائزة كلود جوترا",
    "robert-bresson award": "جائزة روبرت بريسون",
    "robert award": "جائزة روبرت",
    "golden reel award": "جائزة الذهبية بكرة",
    "first steps award": "جائزة الخطوات الأولى",
    "herbert strate award": "جائزة إستراتيجيات هربرت",
    "nastro d'argento": "ناسترو دي أرجنتو",
    "crystal simorgh": "كريستال سيمرغ",
    "mussolini cup": "كأس موسوليني",
    "georg büchner prize winners": "فائزون بجائزة جورج بوشنر",
    "georg büchner prize": "جائزة جورج بوشنر",
    "grand prix": "سباق الجائزة الكبرى",
    "special jury prize": "جائزة لجنة التحكيم الخاصة",
    "fénix award of iberoamerican cinema": "جائزة فينيكس من الأيبيرية السينما الأميركية",
    "prix romy schneider": "جائزة رومي شنايدر",
    "human rights award (sarajevo film festival)": "جائزة حقوق الانسان (مهرجان سراييفو السينمائي)",
    "prix jean gabin": "جائزة جان غبن",
    "risto jarva prize": "جائزة جارفا ريستو",
    "for best canadian first feature film": "لأفضل وأول فيلم كندي مميز",
    "for best canadian film": "لأفضل فيلم كندي",
    "tp de oro": "تي بي دي أورو",
    "bayard d'or": "بايارد الذهبية",
    "golden bear": "الدب الذهبي",
    "for best male playback singer": "لأفضل مغني أفلام",
    "for best female playback singer": "لأفضل مغنية أفلام",
    "for best male singer": "لأفضل مغني",
    "for best female  singer": "لأفضل مغنية",
    "for best first feature": "لأفضل أول فيلم",
    "for best historical album": "لأفضل ألبوم تاريخي",
    "for best rock album": "لأفضل ألبوم روك",
    "for best album": "لأفضل ألبوم",
    "for best film": "لأفضل فيلم",
    "for best original song": "لأفضل أغنية أصلية",
    "for best album for children": "لأفضل ألبوم للأطفال",
    "for best spoken word album": "لأفضل ألبوم محكي",
    "for best alternative music album": "لأفضل ألبوم موسيقى بديلة",
    "for best screenplay": "لأفضل سيناريو",
    "for best motion picture – drama": "لأفضل فيلم - دراما",
    "for best motion picture – musical or comedy": "لأفضل فيلم - موسيقي أو كوميدي",
    "for best english-language foreign film": "لأفضل فيلم أجنبي ناطق بالإنجليزية",
    "for best foreign language film": "لأفضل فيلم بلغة أجنبية",
    "for best animated feature film": "لأفضل فيلم رسوم متحركة",
    "for best documentary film": "لأفضل فيلم وثائقي",
    "for best director": "لأفضل مخرج",
    "for best television series – drama": "لأفضل مسلسل - دراما",
    "for best television series – musical or comedy": "لأفضل مسلسل - موسيقي أو كوميدي",
    "for best miniseries or television film": "لأفضل مسلسل قصير أو فلم تلفزيوني",
    "for rhythm and blues": "لريذم أند بلوز",
    "for best actor": "لأفضل ممثل",
    "for best actor – motion picture drama": "لأفضل ممثل - فيلم دراما",
    "for best actor – television series drama": "لأفضل ممثل - مسلسل تلفزيوني دراما",
    "for best actor – miniseries or television film": "لأفضل ممثل - مسلسل قصير أو فيلم تلفزيوني",
    "for best actor – motion picture musical or comedy": "لأفضل ممثل في فيلم - موسيقي أو كوميدي",
    "for best actor – television series musical or comedy": "لأفضل ممثل في مسلسل موسيقي أو كوميدي",
    "for best supporting actor – motion picture": "لأفضل ممثل مساعد - فيلم",
    "for best supporting actor – series, miniseries or television film": "لأفضل ممثل مساعد - مسلسل، أو مسلسل قصير أو فيلم تلفزيوني",
    "for best actress – motion picture drama": "لأفضل ممثلة - فيلم دراما",
    "for best actress – motion picture musical or comedy": "لأفضل ممثلة - فيلم موسيقي أو كوميدي",
    "for best actress – television series musical or comedy": "لأفضل ممثلة - مسلسل تلفزيوني موسيقي أو كوميدي",
    "for best actress – television series drama": "لأفضل ممثلة - مسلسل دراما",
    "for best actress – miniseries or television film": "لأفضل ممثلة - مسلسل قصير أو فيلم تلفزيوني",
    "golden globe for an actress in a television series": "لأفضل ممثلة في مسلسل تلفزيوني",
    "for best supporting actress – motion picture": "لأفضل ممثلة مساعدة - فيلم",
    "for best supporting actress – series, miniseries or television film": "لأفضل ممثلة مساعدة - مسلسل، أو مسلسل قصير أو فيلم تلفزيوني",
    "for best original score": "لأفضل موسيقى تصويرية",
    "for album of the year": "لألبوم السنة",
    "for new star of the year – actor": "للنجم الصاعد",
    "for new star of the year – actress": "للنجمة الصاعدة",
}

MALE_TYPES: dict[str, str] = {
    "science": "علم",
    "literature": "أدب",
}

AWARDS: dict[str, str] = {
    "grammy": "غرامي",
    "golden globe": "غولدن غلوب",
    "filmfare": "فيلم فير",
    "robert": "روبرت",
    "emmy": "إيمي",
    "independent spirit": "الروح المستقلة",
    "national board of review": "المجلس الوطني للمراجعة",
    "toronto international film festival": "مهرجان تورونتو السينمائي الدولي",
    "hollywood film": "هوليوود للأفلام",
    "hong kong film": "مهرجان هونج كونج السينمائي",
    "empire": "إمباير",
    "ptc punjabi film": "المهرجان البنجابي السينمائي",
    "european film": "الفيلم الأوروبي",
    "environmental media": "الإعلام البيئي",
    "jussi": "جوسي",
    "bodil": "بوديل",
    "teen choice": "اختيار المراهقين",
    "claude jutra": "كلود جوترا",
    "robert-bresson": "روبرت بريسون",
    "golden reel": "الذهبية بكرة",
    "first steps": "الخطوات الأولى",
    "herbert strate": "إستراتيجيات هربرت",
}

AFTER_TYPE_FEMALE: dict[str, str] = {
    "universities and colleges": "جامعات وكليات",
    "schools": "مدارس",
    "awards": "جوائز",
    "buildings": "مبان",
    "centers": "مراكز",
    "museums": "متاحف",
    "organisations": "منظمات",
    "organizations": "منظمات",
    "non-profit organizations": "منظمات غير ربحية",
    "non-profit publishers": "ناشرون غير ربحيون",
    "groups": "مجموعات",
    "gangs": "عصابات",
    "associations": "جمعيات",
    "services": "خدمات",
    "consulting": "استشارات",
    "utilities": "مرافق",
    "parks": "متنزهات",
    "academies": "أكاديميات",
    "research": "أبحاث",
    "societies": "جمعيات",
    "learned societies": "جمعيات علمية",
    "professional societies": "جمعيات مهنية",
    "learned and professional societies": "جمعيات علمية ومهنية",
    "documents": "وثائق",
    "publishing": "منشورات",
    "companies": "شركات",
    "disciplines": "تخصصات",
    "terrorist incidents": "حوادث إرهابية",
    "parties": "أحزاب",
    "political parties": "أحزاب سياسية",
    "politics": "سياسة",
    "crises": "أزمات",
}


FIRST_TYPE_FEMALE: dict[str, str] = {
    "sports": "رياضية",
    "paleolibertarianism": "ليبرتارية أصلية",
    "libertarian": "ليبرتارية",
    "liberal": "ليبرالية",
    "classical conservative": "ليبرالية كلاسيكية",
    "liberal conservative": "ليبرالية محافظة",
    "structural": "هيكلية",
    "agricultural": "زراعية",
    "astronomical": "فلكية",
    "chemical": "كيميائية",
    "commercial": "تجارية",
    "economical": "اقتصادية",
    "educational": "تعليمية",
    "environmental": "بيئية",
    "experimental": "تجريبية",
    "historical": "تاريخية",
    "industrial": "صناعية",
    "internal": "داخلية",
    "international": "دولية",
    "legal": "قانونية",
    "magical": "سحرية",
    "medical": "طبية",
    "musical": "موسيقية",
    "nautical": "بحرية",
    "residential": "سكنية",
    "eurosceptic": "شكوكية أوروبية",
    "anti-revisionist": "مناهضة للتحريفية",
    "anti-capitalist": "مناهضة للرأسمالية",
    "socialist": "اشتراكية",
    "socialism": "اشتراكية",
    "ecosocialist": "اشتراكية بيئية",
    "biological": "بيولوجية",
    "cruise": "سياحية",
    "defunct": "سابقة",
    "military nuclear": "نووية عسكرية",
    "nuclear": "نووية",
    "military and war": "عسكرية وحربية",
    "military": "عسكرية",
    "training": "تدريبية",
    "consultative": "إستشارية",
    "legislative": "تشريعية",
    "constitutional": "دستورية",
    "political": "سياسية",
    "warfare": "حربية",
    "diplomatic": "دبلوماسية",
    "publicly traded": "تداول عام",
    "computer": "حوسبة",
    "multi-national": "متعددة الجنسيات",
    "multinational": "متعددة الجنسيات",
    "power": "طاقة",
    "office": "إدارية",
    "music": "موسيقى",
    "private": "خاصة",
    "independent": "مستقلة",
    "drama": "درامية",
    "law": "قانون",
    "bank": "بنوك",
    "academic": "أكاديمية",
    "academic and learned": "أكاديمية وعلمية",
    "horticultural": "بستنة",
    "islamic": "إسلامية",
    "fictional": "خيالية",
    "criminal": "إجرامية",
    "history": "تاريخ",
    "cycling": "ركوب الدراجات",
    "architecture": "عمارة",
    "transportation": "النقل",
    "science": "علمية",
    "ethnic": "عرقية",
    "professional": "تخصصية",
    "financial": "مالية",
    "public": "عمومية",
    "archaeological": "أثرية",
    "interventionist": "تدخلية",
    "non-interventionist": "غير تدخلية",
    "banned": "محظورة",
    "anti-islam": "معادية للإسلام",
    "zionist": "صهيونية",
    "anti-zionist": "معادية للصهيونية",
    "monarchist": "ملكية",
    "classical": "كلاسيكية",
    "far-left": "يسارية متطرفة",
    "far-right": "يمينية متطرفة",
    "social": "اجتماعية",
    "conservative": "محافظة",
    "republican": "جمهورية",
    "radical": "راديكالية",
    "nationalist": "قومية",
    "fascist": "فاشية",
    "secularist": "علمانية",
    "freemasonry": "ماسونية",
    "communist": "شيوعية",
    "centrist": "وسطية",
    "muslim": "إسلامية",
    "right-wing": "يمينية",
    "left-wing": "يسارية",
}


TA_CATEGORIES: dict[str, str] = {
    "arts": "فنية",
}


def build_pop_final6() -> dict[str, str]:
    """Return the fully expanded mapping used by ``all_keys2``."""

    data = dict(POP_FINAL6_BASE)

    for category, label in MALE_TYPES.items():
        data[f"fictional {category}"] = f"{label} خيالي"
        data[f"{category} themes"] = f"مواضيع {label}"

    for award, label in AWARDS.items():
        key = award.lower()
        data[f"{key} award"] = f"جائزة {label}"
        data[f"{key} awards"] = f"جوائز {label}"

    for first, first_label in FIRST_TYPE_FEMALE.items():
        data[f"{first} parties"] = f"أحزاب {first_label}"
        for second, second_label in AFTER_TYPE_FEMALE.items():
            data[f"{first.lower()} {second.lower()}"] = f"{second_label} {first_label}"

    for key, label in TA_CATEGORIES.items():
        data[f"{key} occupations"] = f"مهن {label}"

    return data


pop_final6: dict[str, str] = build_pop_final6()

len_print.data_len("newkey.py", {"pop_final6": pop_final6})

__all__ = ["pop_final6"]
