"""
Tests for bys_new bot
"""

from __future__ import annotations

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.new_resolvers.bys_new import resolve_by_labels

_by_and_fields = {
    "by bank and behavior": "حسب البنك والسلوك",
    "by bank and branch": "حسب البنك والفرع",
    "by bank and century": "حسب البنك والقرن",
    "by bank and city": "حسب البنك والمدينة",
    "by bank and class": "حسب البنك والصنف",
    "by bank and club": "حسب البنك والنادي",
    "by bank and company": "حسب البنك والشركة",
    "by bank and competition": "حسب البنك والمنافسة",
    "by bank and condition": "حسب البنك والحالة",
    "by bank and conflict": "حسب البنك والنزاع",
    "by bank and continent": "حسب البنك والقارة",
    "by bank and country": "حسب البنك والبلد",
    "by bank and country of residence": "حسب البنك وبلد الإقامة",
    "by bank and country subdivision": "حسب البنك وتقسيم البلد",
    "by bank and country subdivisions": "حسب البنك وتقسيمات البلد",
    "by bank and country-of-residence": "حسب البنك وبلد الإقامة",
    "by bank and county": "حسب البنك والمقاطعة",
    "by bank and date": "حسب البنك والتاريخ",
    "by bank and decade": "حسب البنك والعقد",
    "by bank and educational establishment": "حسب البنك والمؤسسة التعليمية",
    "by bank and educational institution": "حسب البنك والهيئة التعليمية",
    "by bank and era": "حسب البنك والعصر",
    "by bank and ethnicity": "حسب البنك والمجموعة العرقية",
    "by bank and event": "حسب البنك والحدث",
    "by bank and former religion": "حسب البنك والدين السابق",
    "by bank and genre": "حسب البنك والنوع الفني",
    "by bank and government agency": "حسب البنك والوكالة الحكومية",
    "by bank and history of colleges and universities": "حسب البنك وتاريخ الكليات والجامعات",
    "by bank and importance": "حسب البنك والأهمية",
    "by bank and industry": "حسب البنك والصناعة",
    "by bank and instrument": "حسب البنك والآلة",
    "by bank and issue": "حسب البنك والقضية",
    "by bank and league": "حسب البنك والدوري",
    "by bank and location": "حسب البنك والموقع",
    "by bank and magazine": "حسب البنك والمجلة",
    "by bank and medium": "حسب البنك والوسط",
    "by bank and millennium": "حسب البنك والألفية",
    "by bank and nation": "حسب البنك والموطن",
    "by bank and nationality": "حسب البنك والجنسية",
    "by bank and newspaper": "حسب البنك والصحيفة",
    "by bank and non-profit organizations": "حسب البنك والمنظمات غير الربحية",
    "by bank and non-profit publishers": "حسب البنك وناشرون غير ربحيون",
    "by bank and nonprofit organization": "حسب البنك والمنظمات غير الربحية",
    "by bank and occupation": "حسب البنك والمهنة",
    "by bank and organization": "حسب البنك والمنظمة",
    "by bank and organizer": "حسب البنك والمنظم",
    "by bank and orientation": "حسب البنك والتوجه",
    "by bank and party": "حسب البنك والحزب",
    "by bank and period": "حسب البنك والحقبة",
    "by bank and political orientation": "حسب البنك والتوجه السياسي",
    "by bank and prison": "حسب البنك والسجن",
    "by bank and professional association": "حسب البنك والجمعيات المهنية",
    "by bank and publication": "حسب البنك والمؤسسة",
    "by bank and quality": "حسب البنك والجودة",
    "by bank and rank": "حسب البنك والرتبة",
    "by bank and record label": "حسب البنك وشركة التسجيلات",
    "by bank and region": "حسب البنك والمنطقة",
    "by bank and religion": "حسب البنك والدين",
    "by bank and research organization": "حسب البنك ومنظمة البحوث",
    "by bank and role": "حسب البنك والدور",
    "by bank and sector": "حسب البنك والقطاع",
    "by bank and series": "حسب البنك والسلسلة",
    "by bank and setting location": "حسب البنك وموقع الأحداث",
    "by bank and shipbuilding company": "حسب البنك وشركة بناء السفن",
    "by bank and specialty": "حسب البنك والتخصص",
    "by bank and sport": "حسب البنك والرياضة",
    "by bank and state": "حسب البنك والولاية",
    "by bank and station": "حسب البنك والمحطة",
    "by bank and status": "حسب البنك والحالة",
    "by bank and subdivision": "حسب البنك والتقسيم",
    "by bank and team": "حسب البنك والفريق",
    "by bank and territory": "حسب البنك والإقليم",
    "by bank and time": "حسب البنك والوقت",
    "by bank and trade union": "حسب البنك والنقابات العمالية",
    "by bank and type": "حسب البنك والفئة",
    "by bank and writer": "حسب البنك والكاتب",
    "by bank and year": "حسب البنك والسنة",
    "by behavior and bank": "حسب السلوك والبنك",
    "by behavior and branch": "حسب السلوك والفرع",
    "by behavior and century": "حسب السلوك والقرن",
    "by behavior and city": "حسب السلوك والمدينة",
    "by behavior and class": "حسب السلوك والصنف",
    "by behavior and club": "حسب السلوك والنادي",
    "by behavior and company": "حسب السلوك والشركة",
    "by behavior and competition": "حسب السلوك والمنافسة",
    "by behavior and condition": "حسب السلوك والحالة",
    "by behavior and conflict": "حسب السلوك والنزاع",
    "by behavior and continent": "حسب السلوك والقارة",
    "by behavior and country": "حسب السلوك والبلد",
    "by behavior and country of residence": "حسب السلوك وبلد الإقامة",
    "by behavior and country subdivision": "حسب السلوك وتقسيم البلد",
    "by behavior and country subdivisions": "حسب السلوك وتقسيمات البلد",
    "by behavior and country-of-residence": "حسب السلوك وبلد الإقامة",
    "by behavior and county": "حسب السلوك والمقاطعة",
    "by behavior and date": "حسب السلوك والتاريخ",
    "by behavior and decade": "حسب السلوك والعقد",
    "by behavior and educational establishment": "حسب السلوك والمؤسسة التعليمية",
    "by behavior and educational institution": "حسب السلوك والهيئة التعليمية",
    "by behavior and era": "حسب السلوك والعصر",
    "by behavior and ethnicity": "حسب السلوك والمجموعة العرقية",
    "by behavior and event": "حسب السلوك والحدث",
    "by behavior and former religion": "حسب السلوك والدين السابق",
    "by behavior and genre": "حسب السلوك والنوع الفني",
    "by behavior and government agency": "حسب السلوك والوكالة الحكومية",
    "by behavior and history of colleges and universities": "حسب السلوك وتاريخ الكليات والجامعات",
    "by behavior and importance": "حسب السلوك والأهمية",
    "by behavior and industry": "حسب السلوك والصناعة",
    "by behavior and instrument": "حسب السلوك والآلة",
    "by behavior and issue": "حسب السلوك والقضية",
    "by behavior and league": "حسب السلوك والدوري",
    "by behavior and location": "حسب السلوك والموقع",
    "by behavior and magazine": "حسب السلوك والمجلة",
    "by behavior and medium": "حسب السلوك والوسط",
    "by behavior and millennium": "حسب السلوك والألفية",
    "by behavior and nation": "حسب السلوك والموطن",
    "by behavior and nationality": "حسب السلوك والجنسية",
    "by behavior and newspaper": "حسب السلوك والصحيفة",
    "by behavior and non-profit organizations": "حسب السلوك والمنظمات غير الربحية",
    "by behavior and non-profit publishers": "حسب السلوك وناشرون غير ربحيون",
    "by behavior and nonprofit organization": "حسب السلوك والمنظمات غير الربحية",
    "by behavior and occupation": "حسب السلوك والمهنة",
    "by behavior and organization": "حسب السلوك والمنظمة",
    "by behavior and organizer": "حسب السلوك والمنظم",
    "by behavior and orientation": "حسب السلوك والتوجه",
    "by behavior and party": "حسب السلوك والحزب",
    "by behavior and period": "حسب السلوك والحقبة",
    "by behavior and political orientation": "حسب السلوك والتوجه السياسي",
    "by behavior and prison": "حسب السلوك والسجن",
    "by behavior and professional association": "حسب السلوك والجمعيات المهنية",
    "by behavior and publication": "حسب السلوك والمؤسسة",
    "by behavior and quality": "حسب السلوك والجودة",
    "by behavior and rank": "حسب السلوك والرتبة",
    "by behavior and record label": "حسب السلوك وشركة التسجيلات",
    "by behavior and region": "حسب السلوك والمنطقة",
    "by behavior and religion": "حسب السلوك والدين",
    "by behavior and research organization": "حسب السلوك ومنظمة البحوث",
    "by behavior and role": "حسب السلوك والدور",
    "by behavior and sector": "حسب السلوك والقطاع",
    "by behavior and series": "حسب السلوك والسلسلة",
    "by behavior and setting location": "حسب السلوك وموقع الأحداث",
    "by behavior and shipbuilding company": "حسب السلوك وشركة بناء السفن",
    "by behavior and specialty": "حسب السلوك والتخصص",
    "by behavior and sport": "حسب السلوك والرياضة",
    "by behavior and state": "حسب السلوك والولاية",
    "by behavior and station": "حسب السلوك والمحطة",
    "by behavior and status": "حسب السلوك والحالة",
    "by behavior and subdivision": "حسب السلوك والتقسيم",
    "by behavior and team": "حسب السلوك والفريق",
    "by behavior and territory": "حسب السلوك والإقليم",
    "by behavior and time": "حسب السلوك والوقت",
    "by behavior and trade union": "حسب السلوك والنقابات العمالية",
    "by behavior and type": "حسب السلوك والفئة",
    "by behavior and writer": "حسب السلوك والكاتب",
    "by behavior and year": "حسب السلوك والسنة",
    "by branch and bank": "حسب الفرع والبنك",
    "by branch and behavior": "حسب الفرع والسلوك",
    "by branch and century": "حسب الفرع والقرن",
    "by branch and city": "حسب الفرع والمدينة",
    "by branch and class": "حسب الفرع والصنف",
    "by branch and club": "حسب الفرع والنادي",
    "by branch and company": "حسب الفرع والشركة",
    "by branch and competition": "حسب الفرع والمنافسة",
    "by branch and condition": "حسب الفرع والحالة",
    "by branch and conflict": "حسب الفرع والنزاع",
    "by branch and continent": "حسب الفرع والقارة",
    "by branch and country": "حسب الفرع والبلد",
    "by branch and country of residence": "حسب الفرع وبلد الإقامة",
    "by branch and country subdivision": "حسب الفرع وتقسيم البلد",
    "by branch and country subdivisions": "حسب الفرع وتقسيمات البلد",
    "by branch and country-of-residence": "حسب الفرع وبلد الإقامة",
    "by branch and county": "حسب الفرع والمقاطعة",
    "by branch and date": "حسب الفرع والتاريخ",
    "by branch and decade": "حسب الفرع والعقد",
    "by branch and educational establishment": "حسب الفرع والمؤسسة التعليمية",
    "by branch and educational institution": "حسب الفرع والهيئة التعليمية",
    "by branch and era": "حسب الفرع والعصر",
    "by branch and ethnicity": "حسب الفرع والمجموعة العرقية",
    "by branch and event": "حسب الفرع والحدث",
    "by branch and former religion": "حسب الفرع والدين السابق",
    "by branch and genre": "حسب الفرع والنوع الفني",
    "by branch and government agency": "حسب الفرع والوكالة الحكومية",
    "by branch and history of colleges and universities": "حسب الفرع وتاريخ الكليات والجامعات",
    "by branch and importance": "حسب الفرع والأهمية",
    "by branch and industry": "حسب الفرع والصناعة",
    "by branch and instrument": "حسب الفرع والآلة",
    "by branch and issue": "حسب الفرع والقضية",
    "by branch and league": "حسب الفرع والدوري",
    "by branch and location": "حسب الفرع والموقع",
    "by branch and magazine": "حسب الفرع والمجلة",
    "by branch and medium": "حسب الفرع والوسط",
    "by branch and millennium": "حسب الفرع والألفية",
    "by branch and nation": "حسب الفرع والموطن",
    "by branch and nationality": "حسب الفرع والجنسية",
    "by branch and newspaper": "حسب الفرع والصحيفة",
    "by branch and non-profit organizations": "حسب الفرع والمنظمات غير الربحية",
    "by branch and non-profit publishers": "حسب الفرع وناشرون غير ربحيون",
    "by branch and nonprofit organization": "حسب الفرع والمنظمات غير الربحية",
    "by branch and occupation": "حسب الفرع والمهنة",
    "by branch and organization": "حسب الفرع والمنظمة",
    "by branch and organizer": "حسب الفرع والمنظم",
    "by branch and orientation": "حسب الفرع والتوجه",
    "by branch and party": "حسب الفرع والحزب",
    "by branch and period": "حسب الفرع والحقبة",
    "by branch and political orientation": "حسب الفرع والتوجه السياسي",
    "by branch and prison": "حسب الفرع والسجن",
    "by branch and professional association": "حسب الفرع والجمعيات المهنية",
    "by branch and publication": "حسب الفرع والمؤسسة",
    "by branch and quality": "حسب الفرع والجودة",
    "by branch and rank": "حسب الفرع والرتبة",
    "by branch and record label": "حسب الفرع وشركة التسجيلات",
    "by branch and region": "حسب الفرع والمنطقة",
    "by branch and religion": "حسب الفرع والدين",
    "by branch and research organization": "حسب الفرع ومنظمة البحوث",
    "by branch and role": "حسب الفرع والدور",
    "by branch and sector": "حسب الفرع والقطاع",
    "by branch and series": "حسب الفرع والسلسلة",
    "by branch and setting location": "حسب الفرع وموقع الأحداث",
    "by branch and shipbuilding company": "حسب الفرع وشركة بناء السفن",
    "by branch and specialty": "حسب الفرع والتخصص",
    "by branch and sport": "حسب الفرع والرياضة",
    "by branch and state": "حسب الفرع والولاية",
    "by branch and station": "حسب الفرع والمحطة",
    "by branch and status": "حسب الفرع والحالة",
    "by branch and subdivision": "حسب الفرع والتقسيم",
    "by branch and team": "حسب الفرع والفريق",
    "by branch and territory": "حسب الفرع والإقليم",
    "by branch and time": "حسب الفرع والوقت",
    "by branch and trade union": "حسب الفرع والنقابات العمالية",
    "by branch and type": "حسب الفرع والفئة",
    "by branch and writer": "حسب الفرع والكاتب",
    "by branch and year": "حسب الفرع والسنة",
    "by century and bank": "حسب القرن والبنك",
    "by century and behavior": "حسب القرن والسلوك",
    "by century and branch": "حسب القرن والفرع",
    "by century and city": "حسب القرن والمدينة",
    "by century and class": "حسب القرن والصنف",
    "by century and club": "حسب القرن والنادي",
    "by century and company": "حسب القرن والشركة",
    "by century and competition": "حسب القرن والمنافسة",
    "by century and condition": "حسب القرن والحالة",
    "by century and conflict": "حسب القرن والنزاع",
    "by century and continent": "حسب القرن والقارة",
    "by century and country": "حسب القرن والبلد",
    "by century and country of residence": "حسب القرن وبلد الإقامة",
    "by century and country subdivision": "حسب القرن وتقسيم البلد",
    "by century and country subdivisions": "حسب القرن وتقسيمات البلد",
    "by century and country-of-residence": "حسب القرن وبلد الإقامة",
    "by century and county": "حسب القرن والمقاطعة",
    "by century and date": "حسب القرن والتاريخ",
    "by century and decade": "حسب القرن والعقد",
    "by century and educational establishment": "حسب القرن والمؤسسة التعليمية",
    "by century and educational institution": "حسب القرن والهيئة التعليمية",
    "by century and era": "حسب القرن والعصر",
    "by century and ethnicity": "حسب القرن والمجموعة العرقية",
    "by century and event": "حسب القرن والحدث",
    "by century and former religion": "حسب القرن والدين السابق",
    "by century and genre": "حسب القرن والنوع الفني",
    "by century and government agency": "حسب القرن والوكالة الحكومية",
    "by century and history of colleges and universities": "حسب القرن وتاريخ الكليات والجامعات",
    "by century and importance": "حسب القرن والأهمية",
    "by century and industry": "حسب القرن والصناعة",
    "by century and instrument": "حسب القرن والآلة",
    "by century and issue": "حسب القرن والقضية",
    "by century and league": "حسب القرن والدوري",
    "by century and location": "حسب القرن والموقع",
    "by century and magazine": "حسب القرن والمجلة",
    "by century and medium": "حسب القرن والوسط",
    "by century and millennium": "حسب القرن والألفية",
    "by century and nation": "حسب القرن والموطن",
    "by century and nationality": "حسب القرن والجنسية",
    "by century and newspaper": "حسب القرن والصحيفة",
    "by century and non-profit organizations": "حسب القرن والمنظمات غير الربحية",
    "by century and non-profit publishers": "حسب القرن وناشرون غير ربحيون",
    "by century and nonprofit organization": "حسب القرن والمنظمات غير الربحية",
    "by century and occupation": "حسب القرن والمهنة",
    "by century and organization": "حسب القرن والمنظمة",
    "by century and organizer": "حسب القرن والمنظم",
    "by century and orientation": "حسب القرن والتوجه",
    "by century and party": "حسب القرن والحزب",
    "by century and period": "حسب القرن والحقبة",
    "by century and political orientation": "حسب القرن والتوجه السياسي",
    "by century and prison": "حسب القرن والسجن",
    "by century and professional association": "حسب القرن والجمعيات المهنية",
    "by century and publication": "حسب القرن والمؤسسة",
    "by century and quality": "حسب القرن والجودة",
    "by century and rank": "حسب القرن والرتبة",
    "by century and record label": "حسب القرن وشركة التسجيلات",
    "by century and region": "حسب القرن والمنطقة",
    "by century and religion": "حسب القرن والدين",
    "by century and research organization": "حسب القرن ومنظمة البحوث",
    "by century and role": "حسب القرن والدور",
    "by century and sector": "حسب القرن والقطاع",
    "by century and series": "حسب القرن والسلسلة",
    "by century and setting location": "حسب القرن وموقع الأحداث",
    "by century and shipbuilding company": "حسب القرن وشركة بناء السفن",
    "by century and specialty": "حسب القرن والتخصص",
    "by century and sport": "حسب القرن والرياضة",
    "by century and state": "حسب القرن والولاية",
    "by century and station": "حسب القرن والمحطة",
    "by century and status": "حسب القرن والحالة",
    "by century and subdivision": "حسب القرن والتقسيم",
    "by century and team": "حسب القرن والفريق",
    "by century and territory": "حسب القرن والإقليم",
    "by century and time": "حسب القرن والوقت",
    "by century and trade union": "حسب القرن والنقابات العمالية",
}

_by_or_fields = {
    "by period or educational establishment": "حسب الحقبة أو المؤسسة التعليمية",
    "by period or educational institution": "حسب الحقبة أو الهيئة التعليمية",
    "by period or era": "حسب الحقبة أو العصر",
    "by period or ethnicity": "حسب الحقبة أو المجموعة العرقية",
    "by period or event": "حسب الحقبة أو الحدث",
    "by period or former religion": "حسب الحقبة أو الدين السابق",
    "by period or genre": "حسب الحقبة أو النوع الفني",
    "by period or government agency": "حسب الحقبة أو الوكالة الحكومية",
    "by period or history of colleges and universities": "حسب الحقبة أو تاريخ الكليات والجامعات",
    "by period or importance": "حسب الحقبة أو الأهمية",
    "by period or industry": "حسب الحقبة أو الصناعة",
    "by period or instrument": "حسب الحقبة أو الآلة",
    "by period or issue": "حسب الحقبة أو القضية",
    "by period or league": "حسب الحقبة أو الدوري",
    "by period or location": "حسب الحقبة أو الموقع",
    "by period or magazine": "حسب الحقبة أو المجلة",
    "by period or medium": "حسب الحقبة أو الوسط",
    "by period or millennium": "حسب الحقبة أو الألفية",
    "by period or nation": "حسب الحقبة أو الموطن",
    "by period or nationality": "حسب الحقبة أو الجنسية",
    "by period or newspaper": "حسب الحقبة أو الصحيفة",
    "by period or non-profit organizations": "حسب الحقبة أو المنظمات غير الربحية",
    "by period or non-profit publishers": "حسب الحقبة أو ناشرون غير ربحيون",
    "by period or nonprofit organization": "حسب الحقبة أو المنظمات غير الربحية",
    "by period or occupation": "حسب الحقبة أو المهنة",
    "by period or organization": "حسب الحقبة أو المنظمة",
    "by period or organizer": "حسب الحقبة أو المنظم",
    "by period or orientation": "حسب الحقبة أو التوجه",
    "by period or party": "حسب الحقبة أو الحزب",
    "by period or political orientation": "حسب الحقبة أو التوجه السياسي",
    "by period or prison": "حسب الحقبة أو السجن",
    "by period or professional association": "حسب الحقبة أو الجمعيات المهنية",
    "by period or publication": "حسب الحقبة أو المؤسسة",
    "by period or quality": "حسب الحقبة أو الجودة",
    "by period or rank": "حسب الحقبة أو الرتبة",
    "by period or record label": "حسب الحقبة أو شركة التسجيلات",
    "by period or region": "حسب الحقبة أو المنطقة",
    "by period or religion": "حسب الحقبة أو الدين",
    "by period or research organization": "حسب الحقبة أو منظمة البحوث",
    "by period or role": "حسب الحقبة أو الدور",
    "by period or sector": "حسب الحقبة أو القطاع",
    "by period or series": "حسب الحقبة أو السلسلة",
    "by period or setting location": "حسب الحقبة أو موقع الأحداث",
    "by period or shipbuilding company": "حسب الحقبة أو شركة بناء السفن",
    "by period or specialty": "حسب الحقبة أو التخصص",
    "by period or sport": "حسب الحقبة أو الرياضة",
    "by period or state": "حسب الحقبة أو الولاية",
    "by period or station": "حسب الحقبة أو المحطة",
    "by period or status": "حسب الحقبة أو الحالة",
    "by period or subdivision": "حسب الحقبة أو التقسيم",
    "by period or team": "حسب الحقبة أو الفريق",
    "by period or territory": "حسب الحقبة أو الإقليم",
    "by period or time": "حسب الحقبة أو الوقت",
    "by period or trade union": "حسب الحقبة أو النقابات العمالية",
    "by period or type": "حسب الحقبة أو الفئة",
    "by period or writer": "حسب الحقبة أو الكاتب",
    "by period or year": "حسب الحقبة أو السنة",
    "by political orientation or bank": "حسب التوجه السياسي أو البنك",
    "by political orientation or behavior": "حسب التوجه السياسي أو السلوك",
    "by political orientation or branch": "حسب التوجه السياسي أو الفرع",
    "by political orientation or century": "حسب التوجه السياسي أو القرن",
    "by political orientation or city": "حسب التوجه السياسي أو المدينة",
    "by political orientation or class": "حسب التوجه السياسي أو الصنف",
    "by political orientation or club": "حسب التوجه السياسي أو النادي",
    "by political orientation or company": "حسب التوجه السياسي أو الشركة",
    "by political orientation or competition": "حسب التوجه السياسي أو المنافسة",
    "by political orientation or condition": "حسب التوجه السياسي أو الحالة",
    "by political orientation or conflict": "حسب التوجه السياسي أو النزاع",
    "by political orientation or continent": "حسب التوجه السياسي أو القارة",
    "by political orientation or country": "حسب التوجه السياسي أو البلد",
    "by political orientation or country of residence": "حسب التوجه السياسي أو بلد الإقامة",
    "by political orientation or country subdivision": "حسب التوجه السياسي أو تقسيم البلد",
    "by political orientation or country subdivisions": "حسب التوجه السياسي أو تقسيمات البلد",
    "by political orientation or country-of-residence": "حسب التوجه السياسي أو بلد الإقامة",
    "by political orientation or county": "حسب التوجه السياسي أو المقاطعة",
    "by political orientation or date": "حسب التوجه السياسي أو التاريخ",
    "by political orientation or decade": "حسب التوجه السياسي أو العقد",
    "by political orientation or educational establishment": "حسب التوجه السياسي أو المؤسسة التعليمية",
    "by political orientation or educational institution": "حسب التوجه السياسي أو الهيئة التعليمية",
    "by political orientation or era": "حسب التوجه السياسي أو العصر",
    "by political orientation or ethnicity": "حسب التوجه السياسي أو المجموعة العرقية",
    "by political orientation or event": "حسب التوجه السياسي أو الحدث",
    "by political orientation or former religion": "حسب التوجه السياسي أو الدين السابق",
    "by political orientation or genre": "حسب التوجه السياسي أو النوع الفني",
    "by political orientation or government agency": "حسب التوجه السياسي أو الوكالة الحكومية",
    "by political orientation or history of colleges and universities": "حسب التوجه السياسي أو تاريخ الكليات والجامعات",
    "by political orientation or importance": "حسب التوجه السياسي أو الأهمية",
    "by political orientation or industry": "حسب التوجه السياسي أو الصناعة",
    "by political orientation or instrument": "حسب التوجه السياسي أو الآلة",
    "by political orientation or issue": "حسب التوجه السياسي أو القضية",
    "by political orientation or league": "حسب التوجه السياسي أو الدوري",
    "by political orientation or location": "حسب التوجه السياسي أو الموقع",
    "by political orientation or magazine": "حسب التوجه السياسي أو المجلة",
    "by political orientation or medium": "حسب التوجه السياسي أو الوسط",
    "by political orientation or millennium": "حسب التوجه السياسي أو الألفية",
    "by political orientation or nation": "حسب التوجه السياسي أو الموطن",
    "by political orientation or nationality": "حسب التوجه السياسي أو الجنسية",
    "by political orientation or newspaper": "حسب التوجه السياسي أو الصحيفة",
    "by political orientation or non-profit organizations": "حسب التوجه السياسي أو المنظمات غير الربحية",
    "by political orientation or non-profit publishers": "حسب التوجه السياسي أو ناشرون غير ربحيون",
    "by political orientation or nonprofit organization": "حسب التوجه السياسي أو المنظمات غير الربحية",
    "by political orientation or occupation": "حسب التوجه السياسي أو المهنة",
    "by political orientation or organization": "حسب التوجه السياسي أو المنظمة",
    "by political orientation or organizer": "حسب التوجه السياسي أو المنظم",
    "by political orientation or orientation": "حسب التوجه السياسي أو التوجه",
    "by political orientation or party": "حسب التوجه السياسي أو الحزب",
    "by political orientation or period": "حسب التوجه السياسي أو الحقبة",
    "by political orientation or prison": "حسب التوجه السياسي أو السجن",
    "by political orientation or professional association": "حسب التوجه السياسي أو الجمعيات المهنية",
    "by political orientation or publication": "حسب التوجه السياسي أو المؤسسة",
    "by political orientation or quality": "حسب التوجه السياسي أو الجودة",
    "by political orientation or rank": "حسب التوجه السياسي أو الرتبة",
    "by political orientation or record label": "حسب التوجه السياسي أو شركة التسجيلات",
    "by political orientation or region": "حسب التوجه السياسي أو المنطقة",
    "by political orientation or religion": "حسب التوجه السياسي أو الدين",
    "by political orientation or research organization": "حسب التوجه السياسي أو منظمة البحوث",
    "by political orientation or role": "حسب التوجه السياسي أو الدور",
    "by political orientation or sector": "حسب التوجه السياسي أو القطاع",
    "by political orientation or series": "حسب التوجه السياسي أو السلسلة",
    "by political orientation or setting location": "حسب التوجه السياسي أو موقع الأحداث",
    "by political orientation or shipbuilding company": "حسب التوجه السياسي أو شركة بناء السفن",
    "by political orientation or specialty": "حسب التوجه السياسي أو التخصص",
    "by political orientation or sport": "حسب التوجه السياسي أو الرياضة",
    "by political orientation or state": "حسب التوجه السياسي أو الولاية",
    "by political orientation or station": "حسب التوجه السياسي أو المحطة",
    "by political orientation or status": "حسب التوجه السياسي أو الحالة",
    "by political orientation or subdivision": "حسب التوجه السياسي أو التقسيم",
    "by political orientation or team": "حسب التوجه السياسي أو الفريق",
    "by political orientation or territory": "حسب التوجه السياسي أو الإقليم",
    "by political orientation or time": "حسب التوجه السياسي أو الوقت",
    "by political orientation or trade union": "حسب التوجه السياسي أو النقابات العمالية",
    "by political orientation or type": "حسب التوجه السياسي أو الفئة",
    "by political orientation or writer": "حسب التوجه السياسي أو الكاتب",
    "by political orientation or year": "حسب التوجه السياسي أو السنة",
    "by prison or bank": "حسب السجن أو البنك",
    "by prison or behavior": "حسب السجن أو السلوك",
    "by prison or branch": "حسب السجن أو الفرع",
    "by prison or century": "حسب السجن أو القرن",
    "by prison or city": "حسب السجن أو المدينة",
    "by prison or class": "حسب السجن أو الصنف",
    "by prison or club": "حسب السجن أو النادي",
    "by prison or company": "حسب السجن أو الشركة",
    "by prison or competition": "حسب السجن أو المنافسة",
    "by prison or condition": "حسب السجن أو الحالة",
    "by prison or conflict": "حسب السجن أو النزاع",
    "by prison or continent": "حسب السجن أو القارة",
    "by prison or country": "حسب السجن أو البلد",
    "by prison or country of residence": "حسب السجن أو بلد الإقامة",
    "by prison or country subdivision": "حسب السجن أو تقسيم البلد",
    "by prison or country subdivisions": "حسب السجن أو تقسيمات البلد",
    "by prison or country-of-residence": "حسب السجن أو بلد الإقامة",
    "by prison or county": "حسب السجن أو المقاطعة",
    "by prison or date": "حسب السجن أو التاريخ",
    "by prison or decade": "حسب السجن أو العقد",
    "by prison or educational establishment": "حسب السجن أو المؤسسة التعليمية",
    "by prison or educational institution": "حسب السجن أو الهيئة التعليمية",
    "by prison or era": "حسب السجن أو العصر",
    "by prison or ethnicity": "حسب السجن أو المجموعة العرقية",
    "by prison or event": "حسب السجن أو الحدث",
    "by prison or former religion": "حسب السجن أو الدين السابق",
    "by prison or genre": "حسب السجن أو النوع الفني",
    "by prison or government agency": "حسب السجن أو الوكالة الحكومية",
    "by prison or history of colleges and universities": "حسب السجن أو تاريخ الكليات والجامعات",
    "by prison or importance": "حسب السجن أو الأهمية",
    "by prison or industry": "حسب السجن أو الصناعة",
    "by prison or instrument": "حسب السجن أو الآلة",
    "by prison or issue": "حسب السجن أو القضية",
    "by prison or league": "حسب السجن أو الدوري",
    "by prison or location": "حسب السجن أو الموقع",
    "by prison or magazine": "حسب السجن أو المجلة",
    "by prison or medium": "حسب السجن أو الوسط",
    "by prison or millennium": "حسب السجن أو الألفية",
    "by prison or nation": "حسب السجن أو الموطن",
    "by prison or nationality": "حسب السجن أو الجنسية",
    "by prison or newspaper": "حسب السجن أو الصحيفة",
    "by prison or non-profit organizations": "حسب السجن أو المنظمات غير الربحية",
    "by prison or non-profit publishers": "حسب السجن أو ناشرون غير ربحيون",
    "by prison or nonprofit organization": "حسب السجن أو المنظمات غير الربحية",
    "by prison or occupation": "حسب السجن أو المهنة",
    "by prison or organization": "حسب السجن أو المنظمة",
    "by prison or organizer": "حسب السجن أو المنظم",
    "by prison or orientation": "حسب السجن أو التوجه",
    "by prison or party": "حسب السجن أو الحزب",
    "by prison or period": "حسب السجن أو الحقبة",
    "by prison or political orientation": "حسب السجن أو التوجه السياسي",
    "by prison or professional association": "حسب السجن أو الجمعيات المهنية",
    "by prison or publication": "حسب السجن أو المؤسسة",
    "by prison or quality": "حسب السجن أو الجودة",
    "by prison or rank": "حسب السجن أو الرتبة",
}
_by_by_fields = {
    "by bank by behavior": "حسب البنك حسب السلوك",
    "by bank by branch": "حسب البنك حسب الفرع",
    "by bank by century": "حسب البنك حسب القرن",
    "by bank by city": "حسب البنك حسب المدينة",
    "by bank by class": "حسب البنك حسب الصنف",
    "by bank by club": "حسب البنك حسب النادي",
    "by bank by company": "حسب البنك حسب الشركة",
    "by bank by competition": "حسب البنك حسب المنافسة",
    "by bank by condition": "حسب البنك حسب الحالة",
    "by bank by conflict": "حسب البنك حسب النزاع",
    "by bank by continent": "حسب البنك حسب القارة",
    "by bank by country": "حسب البنك حسب البلد",
    "by bank by country of residence": "حسب البنك حسب بلد الإقامة",
    "by bank by country subdivision": "حسب البنك حسب تقسيم البلد",
    "by bank by country subdivisions": "حسب البنك حسب تقسيمات البلد",
    "by bank by country-of-residence": "حسب البنك حسب بلد الإقامة",
    "by bank by county": "حسب البنك حسب المقاطعة",
    "by bank by date": "حسب البنك حسب التاريخ",
    "by bank by decade": "حسب البنك حسب العقد",
    "by bank by educational establishment": "حسب البنك حسب المؤسسة التعليمية",
    "by bank by educational institution": "حسب البنك حسب الهيئة التعليمية",
    "by bank by era": "حسب البنك حسب العصر",
    "by bank by ethnicity": "حسب البنك حسب المجموعة العرقية",
    "by bank by event": "حسب البنك حسب الحدث",
    "by bank by former religion": "حسب البنك حسب الدين السابق",
    "by bank by genre": "حسب البنك حسب النوع الفني",
    "by bank by government agency": "حسب البنك حسب الوكالة الحكومية",
    "by bank by history of colleges and universities": "حسب البنك حسب تاريخ الكليات والجامعات",
    "by bank by importance": "حسب البنك حسب الأهمية",
    "by bank by industry": "حسب البنك حسب الصناعة",
    "by bank by instrument": "حسب البنك حسب الآلة",
    "by bank by issue": "حسب البنك حسب القضية",
    "by bank by league": "حسب البنك حسب الدوري",
    "by bank by location": "حسب البنك حسب الموقع",
    "by bank by magazine": "حسب البنك حسب المجلة",
    "by bank by medium": "حسب البنك حسب الوسط",
    "by bank by millennium": "حسب البنك حسب الألفية",
    "by bank by nation": "حسب البنك حسب الموطن",
    "by bank by nationality": "حسب البنك حسب الجنسية",
    "by bank by newspaper": "حسب البنك حسب الصحيفة",
    "by bank by non-profit organizations": "حسب البنك حسب المنظمات غير الربحية",
    "by bank by non-profit publishers": "حسب البنك حسب ناشرون غير ربحيون",
    "by bank by nonprofit organization": "حسب البنك حسب المنظمات غير الربحية",
    "by bank by occupation": "حسب البنك حسب المهنة",
    "by bank by organization": "حسب البنك حسب المنظمة",
    "by bank by organizer": "حسب البنك حسب المنظم",
    "by bank by orientation": "حسب البنك حسب التوجه",
    "by bank by party": "حسب البنك حسب الحزب",
    "by bank by period": "حسب البنك حسب الحقبة",
    "by bank by political orientation": "حسب البنك حسب التوجه السياسي",
    "by bank by prison": "حسب البنك حسب السجن",
    "by bank by professional association": "حسب البنك حسب الجمعيات المهنية",
    "by bank by publication": "حسب البنك حسب المؤسسة",
    "by bank by quality": "حسب البنك حسب الجودة",
    "by bank by rank": "حسب البنك حسب الرتبة",
    "by bank by record label": "حسب البنك حسب شركة التسجيلات",
    "by bank by region": "حسب البنك حسب المنطقة",
    "by bank by religion": "حسب البنك حسب الدين",
    "by bank by research organization": "حسب البنك حسب منظمة البحوث",
    "by bank by role": "حسب البنك حسب الدور",
    "by bank by sector": "حسب البنك حسب القطاع",
    "by bank by series": "حسب البنك حسب السلسلة",
    "by bank by setting location": "حسب البنك حسب موقع الأحداث",
    "by bank by shipbuilding company": "حسب البنك حسب شركة بناء السفن",
    "by bank by specialty": "حسب البنك حسب التخصص",
    "by bank by sport": "حسب البنك حسب الرياضة",
    "by bank by state": "حسب البنك حسب الولاية",
    "by bank by station": "حسب البنك حسب المحطة",
    "by bank by status": "حسب البنك حسب الحالة",
    "by bank by subdivision": "حسب البنك حسب التقسيم",
    "by bank by team": "حسب البنك حسب الفريق",
    "by bank by territory": "حسب البنك حسب الإقليم",
    "by bank by time": "حسب البنك حسب الوقت",
    "by bank by trade union": "حسب البنك حسب النقابات العمالية",
    "by bank by type": "حسب البنك حسب الفئة",
    "by bank by writer": "حسب البنك حسب الكاتب",
    "by bank by year": "حسب البنك حسب السنة",
    "by behavior by bank": "حسب السلوك حسب البنك",
    "by behavior by branch": "حسب السلوك حسب الفرع",
    "by behavior by century": "حسب السلوك حسب القرن",
    "by behavior by city": "حسب السلوك حسب المدينة",
    "by behavior by class": "حسب السلوك حسب الصنف",
    "by behavior by club": "حسب السلوك حسب النادي",
    "by behavior by company": "حسب السلوك حسب الشركة",
    "by behavior by competition": "حسب السلوك حسب المنافسة",
    "by behavior by condition": "حسب السلوك حسب الحالة",
    "by behavior by conflict": "حسب السلوك حسب النزاع",
    "by behavior by continent": "حسب السلوك حسب القارة",
    "by behavior by country": "حسب السلوك حسب البلد",
    "by behavior by country of residence": "حسب السلوك حسب بلد الإقامة",
    "by behavior by country subdivision": "حسب السلوك حسب تقسيم البلد",
    "by behavior by country subdivisions": "حسب السلوك حسب تقسيمات البلد",
    "by behavior by country-of-residence": "حسب السلوك حسب بلد الإقامة",
    "by behavior by county": "حسب السلوك حسب المقاطعة",
    "by behavior by date": "حسب السلوك حسب التاريخ",
    "by behavior by decade": "حسب السلوك حسب العقد",
    "by behavior by educational establishment": "حسب السلوك حسب المؤسسة التعليمية",
    "by behavior by educational institution": "حسب السلوك حسب الهيئة التعليمية",
    "by behavior by era": "حسب السلوك حسب العصر",
    "by behavior by ethnicity": "حسب السلوك حسب المجموعة العرقية",
    "by behavior by event": "حسب السلوك حسب الحدث",
    "by behavior by former religion": "حسب السلوك حسب الدين السابق",
    "by behavior by genre": "حسب السلوك حسب النوع الفني",
    "by behavior by government agency": "حسب السلوك حسب الوكالة الحكومية",
    "by behavior by history of colleges and universities": "حسب السلوك حسب تاريخ الكليات والجامعات",
    "by behavior by importance": "حسب السلوك حسب الأهمية",
    "by behavior by industry": "حسب السلوك حسب الصناعة",
    "by behavior by instrument": "حسب السلوك حسب الآلة",
    "by behavior by issue": "حسب السلوك حسب القضية",
    "by behavior by league": "حسب السلوك حسب الدوري",
    "by behavior by location": "حسب السلوك حسب الموقع",
    "by behavior by magazine": "حسب السلوك حسب المجلة",
    "by behavior by medium": "حسب السلوك حسب الوسط",
    "by behavior by millennium": "حسب السلوك حسب الألفية",
    "by behavior by nation": "حسب السلوك حسب الموطن",
    "by behavior by nationality": "حسب السلوك حسب الجنسية",
    "by behavior by newspaper": "حسب السلوك حسب الصحيفة",
    "by behavior by non-profit organizations": "حسب السلوك حسب المنظمات غير الربحية",
    "by behavior by non-profit publishers": "حسب السلوك حسب ناشرون غير ربحيون",
    "by behavior by nonprofit organization": "حسب السلوك حسب المنظمات غير الربحية",
    "by behavior by occupation": "حسب السلوك حسب المهنة",
    "by behavior by organization": "حسب السلوك حسب المنظمة",
    "by behavior by organizer": "حسب السلوك حسب المنظم",
    "by behavior by orientation": "حسب السلوك حسب التوجه",
    "by behavior by party": "حسب السلوك حسب الحزب",
    "by behavior by period": "حسب السلوك حسب الحقبة",
    "by behavior by political orientation": "حسب السلوك حسب التوجه السياسي",
    "by behavior by prison": "حسب السلوك حسب السجن",
    "by behavior by professional association": "حسب السلوك حسب الجمعيات المهنية",
    "by behavior by publication": "حسب السلوك حسب المؤسسة",
    "by behavior by quality": "حسب السلوك حسب الجودة",
    "by behavior by rank": "حسب السلوك حسب الرتبة",
    "by behavior by record label": "حسب السلوك حسب شركة التسجيلات",
    "by behavior by region": "حسب السلوك حسب المنطقة",
    "by behavior by religion": "حسب السلوك حسب الدين",
    "by behavior by research organization": "حسب السلوك حسب منظمة البحوث",
    "by behavior by role": "حسب السلوك حسب الدور",
    "by behavior by sector": "حسب السلوك حسب القطاع",
    "by behavior by series": "حسب السلوك حسب السلسلة",
    "by behavior by setting location": "حسب السلوك حسب موقع الأحداث",
    "by behavior by shipbuilding company": "حسب السلوك حسب شركة بناء السفن",
    "by behavior by specialty": "حسب السلوك حسب التخصص",
    "by behavior by sport": "حسب السلوك حسب الرياضة",
    "by behavior by state": "حسب السلوك حسب الولاية",
    "by behavior by station": "حسب السلوك حسب المحطة",
    "by behavior by status": "حسب السلوك حسب الحالة",
    "by behavior by subdivision": "حسب السلوك حسب التقسيم",
    "by behavior by team": "حسب السلوك حسب الفريق",
    "by behavior by territory": "حسب السلوك حسب الإقليم",
    "by behavior by time": "حسب السلوك حسب الوقت",
    "by behavior by trade union": "حسب السلوك حسب النقابات العمالية",
    "by behavior by type": "حسب السلوك حسب الفئة",
    "by behavior by writer": "حسب السلوك حسب الكاتب",
    "by behavior by year": "حسب السلوك حسب السنة",
    "by branch by bank": "حسب الفرع حسب البنك",
    "by branch by behavior": "حسب الفرع حسب السلوك",
    "by branch by century": "حسب الفرع حسب القرن",
    "by branch by city": "حسب الفرع حسب المدينة",
    "by branch by class": "حسب الفرع حسب الصنف",
    "by branch by club": "حسب الفرع حسب النادي",
    "by branch by company": "حسب الفرع حسب الشركة",
    "by branch by competition": "حسب الفرع حسب المنافسة",
    "by branch by condition": "حسب الفرع حسب الحالة",
    "by branch by conflict": "حسب الفرع حسب النزاع",
    "by branch by continent": "حسب الفرع حسب القارة",
    "by branch by country": "حسب الفرع حسب البلد",
    "by branch by country of residence": "حسب الفرع حسب بلد الإقامة",
    "by branch by country subdivision": "حسب الفرع حسب تقسيم البلد",
    "by branch by country subdivisions": "حسب الفرع حسب تقسيمات البلد",
    "by branch by country-of-residence": "حسب الفرع حسب بلد الإقامة",
    "by branch by county": "حسب الفرع حسب المقاطعة",
    "by branch by date": "حسب الفرع حسب التاريخ",
    "by branch by decade": "حسب الفرع حسب العقد",
    "by branch by educational establishment": "حسب الفرع حسب المؤسسة التعليمية",
    "by branch by educational institution": "حسب الفرع حسب الهيئة التعليمية",
    "by branch by era": "حسب الفرع حسب العصر",
    "by branch by ethnicity": "حسب الفرع حسب المجموعة العرقية",
    "by branch by event": "حسب الفرع حسب الحدث",
    "by branch by former religion": "حسب الفرع حسب الدين السابق",
    "by branch by genre": "حسب الفرع حسب النوع الفني",
    "by branch by government agency": "حسب الفرع حسب الوكالة الحكومية",
    "by branch by history of colleges and universities": "حسب الفرع حسب تاريخ الكليات والجامعات",
    "by branch by importance": "حسب الفرع حسب الأهمية",
    "by branch by industry": "حسب الفرع حسب الصناعة",
    "by branch by instrument": "حسب الفرع حسب الآلة",
    "by branch by issue": "حسب الفرع حسب القضية",
    "by branch by league": "حسب الفرع حسب الدوري",
    "by branch by location": "حسب الفرع حسب الموقع",
    "by branch by magazine": "حسب الفرع حسب المجلة",
    "by branch by medium": "حسب الفرع حسب الوسط",
    "by branch by millennium": "حسب الفرع حسب الألفية",
    "by branch by nation": "حسب الفرع حسب الموطن",
    "by branch by nationality": "حسب الفرع حسب الجنسية",
    "by branch by newspaper": "حسب الفرع حسب الصحيفة",
    "by branch by non-profit organizations": "حسب الفرع حسب المنظمات غير الربحية",
    "by branch by non-profit publishers": "حسب الفرع حسب ناشرون غير ربحيون",
    "by branch by nonprofit organization": "حسب الفرع حسب المنظمات غير الربحية",
    "by branch by occupation": "حسب الفرع حسب المهنة",
    "by branch by organization": "حسب الفرع حسب المنظمة",
    "by branch by organizer": "حسب الفرع حسب المنظم",
    "by branch by orientation": "حسب الفرع حسب التوجه",
    "by branch by party": "حسب الفرع حسب الحزب",
    "by branch by period": "حسب الفرع حسب الحقبة",
    "by branch by political orientation": "حسب الفرع حسب التوجه السياسي",
    "by branch by prison": "حسب الفرع حسب السجن",
    "by branch by professional association": "حسب الفرع حسب الجمعيات المهنية",
    "by branch by publication": "حسب الفرع حسب المؤسسة",
    "by branch by quality": "حسب الفرع حسب الجودة",
    "by branch by rank": "حسب الفرع حسب الرتبة",
    "by branch by record label": "حسب الفرع حسب شركة التسجيلات",
    "by branch by region": "حسب الفرع حسب المنطقة",
    "by branch by religion": "حسب الفرع حسب الدين",
    "by branch by research organization": "حسب الفرع حسب منظمة البحوث",
    "by branch by role": "حسب الفرع حسب الدور",
    "by branch by sector": "حسب الفرع حسب القطاع",
    "by branch by series": "حسب الفرع حسب السلسلة",
    "by branch by setting location": "حسب الفرع حسب موقع الأحداث",
    "by branch by shipbuilding company": "حسب الفرع حسب شركة بناء السفن",
    "by branch by specialty": "حسب الفرع حسب التخصص",
    "by branch by sport": "حسب الفرع حسب الرياضة",
    "by branch by state": "حسب الفرع حسب الولاية",
    "by branch by station": "حسب الفرع حسب المحطة",
    "by branch by status": "حسب الفرع حسب الحالة",
    "by branch by subdivision": "حسب الفرع حسب التقسيم",
    "by branch by team": "حسب الفرع حسب الفريق",
    "by branch by territory": "حسب الفرع حسب الإقليم",
    "by branch by time": "حسب الفرع حسب الوقت",
    "by branch by trade union": "حسب الفرع حسب النقابات العمالية",
    "by branch by type": "حسب الفرع حسب الفئة",
    "by branch by writer": "حسب الفرع حسب الكاتب",
    "by branch by year": "حسب الفرع حسب السنة",
    "by century by bank": "حسب القرن حسب البنك",
    "by century by behavior": "حسب القرن حسب السلوك",
    "by century by branch": "حسب القرن حسب الفرع",
    "by century by city": "حسب القرن حسب المدينة",
    "by century by class": "حسب القرن حسب الصنف",
    "by century by club": "حسب القرن حسب النادي",
    "by century by company": "حسب القرن حسب الشركة",
    "by century by competition": "حسب القرن حسب المنافسة",
    "by century by condition": "حسب القرن حسب الحالة",
    "by century by conflict": "حسب القرن حسب النزاع",
    "by century by continent": "حسب القرن حسب القارة",
    "by century by country": "حسب القرن حسب البلد",
    "by century by country of residence": "حسب القرن حسب بلد الإقامة",
    "by century by country subdivision": "حسب القرن حسب تقسيم البلد",
    "by century by country subdivisions": "حسب القرن حسب تقسيمات البلد",
    "by century by country-of-residence": "حسب القرن حسب بلد الإقامة",
    "by century by county": "حسب القرن حسب المقاطعة",
    "by century by date": "حسب القرن حسب التاريخ",
    "by century by decade": "حسب القرن حسب العقد",
    "by century by educational establishment": "حسب القرن حسب المؤسسة التعليمية",
    "by century by educational institution": "حسب القرن حسب الهيئة التعليمية",
    "by century by era": "حسب القرن حسب العصر",
    "by century by ethnicity": "حسب القرن حسب المجموعة العرقية",
    "by century by event": "حسب القرن حسب الحدث",
    "by century by former religion": "حسب القرن حسب الدين السابق",
    "by century by genre": "حسب القرن حسب النوع الفني",
    "by century by government agency": "حسب القرن حسب الوكالة الحكومية",
    "by century by history of colleges and universities": "حسب القرن حسب تاريخ الكليات والجامعات",
    "by century by importance": "حسب القرن حسب الأهمية",
    "by century by industry": "حسب القرن حسب الصناعة",
    "by century by instrument": "حسب القرن حسب الآلة",
    "by century by issue": "حسب القرن حسب القضية",
    "by century by league": "حسب القرن حسب الدوري",
    "by century by location": "حسب القرن حسب الموقع",
    "by century by magazine": "حسب القرن حسب المجلة",
    "by century by medium": "حسب القرن حسب الوسط",
    "by century by millennium": "حسب القرن حسب الألفية",
    "by century by nation": "حسب القرن حسب الموطن",
    "by century by nationality": "حسب القرن حسب الجنسية",
    "by century by newspaper": "حسب القرن حسب الصحيفة",
    "by century by non-profit organizations": "حسب القرن حسب المنظمات غير الربحية",
    "by century by non-profit publishers": "حسب القرن حسب ناشرون غير ربحيون",
    "by century by nonprofit organization": "حسب القرن حسب المنظمات غير الربحية",
    "by century by occupation": "حسب القرن حسب المهنة",
    "by century by organization": "حسب القرن حسب المنظمة",
    "by century by organizer": "حسب القرن حسب المنظم",
    "by century by orientation": "حسب القرن حسب التوجه",
    "by century by party": "حسب القرن حسب الحزب",
    "by century by period": "حسب القرن حسب الحقبة",
    "by century by political orientation": "حسب القرن حسب التوجه السياسي",
    "by century by prison": "حسب القرن حسب السجن",
    "by century by professional association": "حسب القرن حسب الجمعيات المهنية",
    "by century by publication": "حسب القرن حسب المؤسسة",
    "by century by quality": "حسب القرن حسب الجودة",
    "by century by rank": "حسب القرن حسب الرتبة",
    "by century by record label": "حسب القرن حسب شركة التسجيلات",
    "by century by region": "حسب القرن حسب المنطقة",
    "by century by religion": "حسب القرن حسب الدين",
    "by century by research organization": "حسب القرن حسب منظمة البحوث",
    "by century by role": "حسب القرن حسب الدور",
    "by century by sector": "حسب القرن حسب القطاع",
    "by century by series": "حسب القرن حسب السلسلة",
    "by century by setting location": "حسب القرن حسب موقع الأحداث",
    "by century by shipbuilding company": "حسب القرن حسب شركة بناء السفن",
    "by century by specialty": "حسب القرن حسب التخصص",
    "by century by sport": "حسب القرن حسب الرياضة",
    "by century by state": "حسب القرن حسب الولاية",
    "by century by station": "حسب القرن حسب المحطة",
    "by century by status": "حسب القرن حسب الحالة",
    "by century by subdivision": "حسب القرن حسب التقسيم",
    "by century by team": "حسب القرن حسب الفريق",
    "by century by territory": "حسب القرن حسب الإقليم",
    "by century by time": "حسب القرن حسب الوقت",
    "by century by trade union": "حسب القرن حسب النقابات العمالية",
    "by century by type": "حسب القرن حسب الفئة",
    "by century by writer": "حسب القرن حسب الكاتب",
    "by century by year": "حسب القرن حسب السنة",
    "by city by bank": "حسب المدينة حسب البنك",
    "by city by behavior": "حسب المدينة حسب السلوك",
    "by city by branch": "حسب المدينة حسب الفرع",
    "by city by century": "حسب المدينة حسب القرن",
    "by city by class": "حسب المدينة حسب الصنف",
    "by city by club": "حسب المدينة حسب النادي",
    "by city by company": "حسب المدينة حسب الشركة",
    "by city by competition": "حسب المدينة حسب المنافسة",
    "by city by condition": "حسب المدينة حسب الحالة",
    "by city by conflict": "حسب المدينة حسب النزاع",
    "by city by continent": "حسب المدينة حسب القارة",
    "by city by country": "حسب المدينة حسب البلد",
    "by city by country of residence": "حسب المدينة حسب بلد الإقامة",
    "by city by country subdivision": "حسب المدينة حسب تقسيم البلد",
    "by city by country subdivisions": "حسب المدينة حسب تقسيمات البلد",
    "by city by country-of-residence": "حسب المدينة حسب بلد الإقامة",
    "by city by county": "حسب المدينة حسب المقاطعة",
    "by city by date": "حسب المدينة حسب التاريخ",
    "by city by decade": "حسب المدينة حسب العقد",
    "by city by educational establishment": "حسب المدينة حسب المؤسسة التعليمية",
    "by city by educational institution": "حسب المدينة حسب الهيئة التعليمية",
    "by city by era": "حسب المدينة حسب العصر",
    "by city by ethnicity": "حسب المدينة حسب المجموعة العرقية",
    "by city by event": "حسب المدينة حسب الحدث",
    "by city by former religion": "حسب المدينة حسب الدين السابق",
    "by city by genre": "حسب المدينة حسب النوع الفني",
    "by city by government agency": "حسب المدينة حسب الوكالة الحكومية",
    "by city by history of colleges and universities": "حسب المدينة حسب تاريخ الكليات والجامعات",
    "by city by importance": "حسب المدينة حسب الأهمية",
    "by city by industry": "حسب المدينة حسب الصناعة",
    "by city by instrument": "حسب المدينة حسب الآلة",
    "by city by issue": "حسب المدينة حسب القضية",
    "by city by league": "حسب المدينة حسب الدوري",
    "by city by location": "حسب المدينة حسب الموقع",
    "by city by magazine": "حسب المدينة حسب المجلة",
    "by city by medium": "حسب المدينة حسب الوسط",
    "by city by millennium": "حسب المدينة حسب الألفية",
    "by city by nation": "حسب المدينة حسب الموطن",
    "by city by nationality": "حسب المدينة حسب الجنسية",
    "by city by newspaper": "حسب المدينة حسب الصحيفة",
    "by city by non-profit organizations": "حسب المدينة حسب المنظمات غير الربحية",
    "by city by non-profit publishers": "حسب المدينة حسب ناشرون غير ربحيون",
    "by city by nonprofit organization": "حسب المدينة حسب المنظمات غير الربحية",
    "by city by occupation": "حسب المدينة حسب المهنة",
    "by city by organization": "حسب المدينة حسب المنظمة",
    "by city by organizer": "حسب المدينة حسب المنظم",
    "by city by orientation": "حسب المدينة حسب التوجه",
    "by city by party": "حسب المدينة حسب الحزب",
    "by city by period": "حسب المدينة حسب الحقبة",
    "by city by political orientation": "حسب المدينة حسب التوجه السياسي",
    "by city by prison": "حسب المدينة حسب السجن",
    "by city by professional association": "حسب المدينة حسب الجمعيات المهنية",
    "by city by publication": "حسب المدينة حسب المؤسسة",
    "by city by quality": "حسب المدينة حسب الجودة",
    "by city by rank": "حسب المدينة حسب الرتبة",
    "by city by record label": "حسب المدينة حسب شركة التسجيلات",
    "by city by region": "حسب المدينة حسب المنطقة",
    "by city by religion": "حسب المدينة حسب الدين",
    "by city by research organization": "حسب المدينة حسب منظمة البحوث",
    "by city by role": "حسب المدينة حسب الدور",
    "by city by sector": "حسب المدينة حسب القطاع",
    "by city by series": "حسب المدينة حسب السلسلة",
    "by city by setting location": "حسب المدينة حسب موقع الأحداث",
    "by city by shipbuilding company": "حسب المدينة حسب شركة بناء السفن",
    "by city by specialty": "حسب المدينة حسب التخصص",
    "by city by sport": "حسب المدينة حسب الرياضة",
    "by city by state": "حسب المدينة حسب الولاية",
    "by city by station": "حسب المدينة حسب المحطة",
    "by city by status": "حسب المدينة حسب الحالة",
    "by city by subdivision": "حسب المدينة حسب التقسيم",
    "by city by team": "حسب المدينة حسب الفريق",
    "by city by territory": "حسب المدينة حسب الإقليم",
    "by city by time": "حسب المدينة حسب الوقت",
    "by city by trade union": "حسب المدينة حسب النقابات العمالية",
    "by city by type": "حسب المدينة حسب الفئة",
    "by city by writer": "حسب المدينة حسب الكاتب",
    "by city by year": "حسب المدينة حسب السنة",
    "by class by bank": "حسب الصنف حسب البنك",
    "by class by behavior": "حسب الصنف حسب السلوك",
    "by class by branch": "حسب الصنف حسب الفرع",
    "by class by century": "حسب الصنف حسب القرن",
    "by class by city": "حسب الصنف حسب المدينة",
    "by class by club": "حسب الصنف حسب النادي",
    "by class by company": "حسب الصنف حسب الشركة",
    "by class by competition": "حسب الصنف حسب المنافسة",
    "by class by condition": "حسب الصنف حسب الحالة",
    "by class by conflict": "حسب الصنف حسب النزاع",
    "by class by continent": "حسب الصنف حسب القارة",
    "by class by country": "حسب الصنف حسب البلد",
    "by class by country of residence": "حسب الصنف حسب بلد الإقامة",
    "by class by country subdivision": "حسب الصنف حسب تقسيم البلد",
    "by class by country subdivisions": "حسب الصنف حسب تقسيمات البلد",
    "by class by country-of-residence": "حسب الصنف حسب بلد الإقامة",
    "by class by county": "حسب الصنف حسب المقاطعة",
    "by class by date": "حسب الصنف حسب التاريخ",
    "by class by decade": "حسب الصنف حسب العقد",
    "by class by educational establishment": "حسب الصنف حسب المؤسسة التعليمية",
    "by class by educational institution": "حسب الصنف حسب الهيئة التعليمية",
    "by class by era": "حسب الصنف حسب العصر",
    "by class by ethnicity": "حسب الصنف حسب المجموعة العرقية",
    "by class by event": "حسب الصنف حسب الحدث",
    "by class by former religion": "حسب الصنف حسب الدين السابق",
    "by class by genre": "حسب الصنف حسب النوع الفني",
    "by class by government agency": "حسب الصنف حسب الوكالة الحكومية",
    "by class by history of colleges and universities": "حسب الصنف حسب تاريخ الكليات والجامعات",
    "by class by importance": "حسب الصنف حسب الأهمية",
    "by class by industry": "حسب الصنف حسب الصناعة",
    "by class by instrument": "حسب الصنف حسب الآلة",
    "by class by issue": "حسب الصنف حسب القضية",
    "by class by league": "حسب الصنف حسب الدوري",
    "by class by location": "حسب الصنف حسب الموقع",
    "by class by magazine": "حسب الصنف حسب المجلة",
    "by class by medium": "حسب الصنف حسب الوسط",
    "by class by millennium": "حسب الصنف حسب الألفية",
    "by class by nation": "حسب الصنف حسب الموطن",
    "by class by nationality": "حسب الصنف حسب الجنسية",
    "by class by newspaper": "حسب الصنف حسب الصحيفة",
    "by class by non-profit organizations": "حسب الصنف حسب المنظمات غير الربحية",
    "by class by non-profit publishers": "حسب الصنف حسب ناشرون غير ربحيون",
    "by class by nonprofit organization": "حسب الصنف حسب المنظمات غير الربحية",
    "by class by occupation": "حسب الصنف حسب المهنة",
    "by class by organization": "حسب الصنف حسب المنظمة",
    "by class by organizer": "حسب الصنف حسب المنظم",
    "by class by orientation": "حسب الصنف حسب التوجه",
    "by class by party": "حسب الصنف حسب الحزب",
    "by class by period": "حسب الصنف حسب الحقبة",
    "by class by political orientation": "حسب الصنف حسب التوجه السياسي",
    "by class by prison": "حسب الصنف حسب السجن",
    "by class by professional association": "حسب الصنف حسب الجمعيات المهنية",
    "by class by publication": "حسب الصنف حسب المؤسسة",
    "by class by quality": "حسب الصنف حسب الجودة",
    "by class by rank": "حسب الصنف حسب الرتبة",
    "by class by record label": "حسب الصنف حسب شركة التسجيلات",
    "by class by region": "حسب الصنف حسب المنطقة",
    "by class by religion": "حسب الصنف حسب الدين",
    "by class by research organization": "حسب الصنف حسب منظمة البحوث",
    "by class by role": "حسب الصنف حسب الدور",
    "by class by sector": "حسب الصنف حسب القطاع",
    "by class by series": "حسب الصنف حسب السلسلة",
    "by class by setting location": "حسب الصنف حسب موقع الأحداث",
    "by class by shipbuilding company": "حسب الصنف حسب شركة بناء السفن",
    "by class by specialty": "حسب الصنف حسب التخصص",
    "by class by sport": "حسب الصنف حسب الرياضة",
    "by class by state": "حسب الصنف حسب الولاية",
    "by class by station": "حسب الصنف حسب المحطة",
    "by class by status": "حسب الصنف حسب الحالة",
    "by class by subdivision": "حسب الصنف حسب التقسيم",
    "by class by team": "حسب الصنف حسب الفريق",
    "by class by territory": "حسب الصنف حسب الإقليم",
    "by class by time": "حسب الصنف حسب الوقت",
    "by class by trade union": "حسب الصنف حسب النقابات العمالية",
    "by class by type": "حسب الصنف حسب الفئة",
    "by class by writer": "حسب الصنف حسب الكاتب",
    "by class by year": "حسب الصنف حسب السنة",
    "by club by bank": "حسب النادي حسب البنك",
    "by club by behavior": "حسب النادي حسب السلوك",
    "by club by branch": "حسب النادي حسب الفرع",
    "by club by century": "حسب النادي حسب القرن",
    "by club by city": "حسب النادي حسب المدينة",
    "by club by class": "حسب النادي حسب الصنف",
    "by club by company": "حسب النادي حسب الشركة",
    "by club by competition": "حسب النادي حسب المنافسة",
    "by club by condition": "حسب النادي حسب الحالة",
    "by club by conflict": "حسب النادي حسب النزاع",
    "by club by continent": "حسب النادي حسب القارة",
    "by club by country": "حسب النادي حسب البلد",
    "by club by country of residence": "حسب النادي حسب بلد الإقامة",
    "by club by country subdivision": "حسب النادي حسب تقسيم البلد",
    "by club by country subdivisions": "حسب النادي حسب تقسيمات البلد",
    "by club by country-of-residence": "حسب النادي حسب بلد الإقامة",
    "by club by county": "حسب النادي حسب المقاطعة",
    "by club by date": "حسب النادي حسب التاريخ",
    "by club by decade": "حسب النادي حسب العقد",
    "by club by educational establishment": "حسب النادي حسب المؤسسة التعليمية",
    "by club by educational institution": "حسب النادي حسب الهيئة التعليمية",
    "by club by era": "حسب النادي حسب العصر",
    "by club by ethnicity": "حسب النادي حسب المجموعة العرقية",
    "by club by event": "حسب النادي حسب الحدث",
    "by club by former religion": "حسب النادي حسب الدين السابق",
    "by club by genre": "حسب النادي حسب النوع الفني",
    "by club by government agency": "حسب النادي حسب الوكالة الحكومية",
    "by club by history of colleges and universities": "حسب النادي حسب تاريخ الكليات والجامعات",
    "by club by importance": "حسب النادي حسب الأهمية",
    "by club by industry": "حسب النادي حسب الصناعة",
    "by club by instrument": "حسب النادي حسب الآلة",
    "by club by issue": "حسب النادي حسب القضية",
    "by club by league": "حسب النادي حسب الدوري",
    "by club by location": "حسب النادي حسب الموقع",
    "by club by magazine": "حسب النادي حسب المجلة",
    "by club by medium": "حسب النادي حسب الوسط",
    "by club by millennium": "حسب النادي حسب الألفية",
    "by club by nation": "حسب النادي حسب الموطن",
    "by club by nationality": "حسب النادي حسب الجنسية",
    "by club by newspaper": "حسب النادي حسب الصحيفة",
    "by club by non-profit organizations": "حسب النادي حسب المنظمات غير الربحية",
    "by club by non-profit publishers": "حسب النادي حسب ناشرون غير ربحيون",
    "by club by nonprofit organization": "حسب النادي حسب المنظمات غير الربحية",
    "by club by occupation": "حسب النادي حسب المهنة",
    "by club by organization": "حسب النادي حسب المنظمة",
    "by club by organizer": "حسب النادي حسب المنظم",
    "by club by orientation": "حسب النادي حسب التوجه",
    "by club by party": "حسب النادي حسب الحزب",
    "by club by period": "حسب النادي حسب الحقبة",
    "by club by political orientation": "حسب النادي حسب التوجه السياسي",
    "by club by prison": "حسب النادي حسب السجن",
    "by club by professional association": "حسب النادي حسب الجمعيات المهنية",
    "by club by publication": "حسب النادي حسب المؤسسة",
    "by club by quality": "حسب النادي حسب الجودة",
    "by club by rank": "حسب النادي حسب الرتبة",
    "by club by record label": "حسب النادي حسب شركة التسجيلات",
    "by club by region": "حسب النادي حسب المنطقة",
    "by club by religion": "حسب النادي حسب الدين",
    "by club by research organization": "حسب النادي حسب منظمة البحوث",
    "by club by role": "حسب النادي حسب الدور",
    "by club by sector": "حسب النادي حسب القطاع",
    "by club by series": "حسب النادي حسب السلسلة",
    "by club by setting location": "حسب النادي حسب موقع الأحداث",
    "by club by shipbuilding company": "حسب النادي حسب شركة بناء السفن",
    "by club by specialty": "حسب النادي حسب التخصص",
    "by club by sport": "حسب النادي حسب الرياضة",
    "by club by state": "حسب النادي حسب الولاية",
    "by club by station": "حسب النادي حسب المحطة",
    "by club by status": "حسب النادي حسب الحالة",
    "by club by subdivision": "حسب النادي حسب التقسيم",
    "by club by team": "حسب النادي حسب الفريق",
    "by club by territory": "حسب النادي حسب الإقليم",
    "by club by time": "حسب النادي حسب الوقت",
    "by club by trade union": "حسب النادي حسب النقابات العمالية",
    "by club by type": "حسب النادي حسب الفئة",
    "by club by writer": "حسب النادي حسب الكاتب",
    "by club by year": "حسب النادي حسب السنة",
    "by company by bank": "حسب الشركة حسب البنك",
    "by company by behavior": "حسب الشركة حسب السلوك",
    "by company by branch": "حسب الشركة حسب الفرع",
    "by company by century": "حسب الشركة حسب القرن",
    "by company by city": "حسب الشركة حسب المدينة",
    "by company by class": "حسب الشركة حسب الصنف",
    "by company by club": "حسب الشركة حسب النادي",
    "by company by competition": "حسب الشركة حسب المنافسة",
    "by company by condition": "حسب الشركة حسب الحالة",
    "by company by conflict": "حسب الشركة حسب النزاع",
    "by company by continent": "حسب الشركة حسب القارة",
    "by company by country": "حسب الشركة حسب البلد",
    "by company by country of residence": "حسب الشركة حسب بلد الإقامة",
    "by company by country subdivision": "حسب الشركة حسب تقسيم البلد",
    "by company by country subdivisions": "حسب الشركة حسب تقسيمات البلد",
    "by company by country-of-residence": "حسب الشركة حسب بلد الإقامة",
    "by company by county": "حسب الشركة حسب المقاطعة",
    "by company by date": "حسب الشركة حسب التاريخ",
    "by company by decade": "حسب الشركة حسب العقد",
    "by company by educational establishment": "حسب الشركة حسب المؤسسة التعليمية",
    "by company by educational institution": "حسب الشركة حسب الهيئة التعليمية",
    "by company by era": "حسب الشركة حسب العصر",
    "by company by ethnicity": "حسب الشركة حسب المجموعة العرقية",
    "by company by event": "حسب الشركة حسب الحدث",
    "by company by former religion": "حسب الشركة حسب الدين السابق",
    "by company by genre": "حسب الشركة حسب النوع الفني",
    "by company by government agency": "حسب الشركة حسب الوكالة الحكومية",
    "by company by history of colleges and universities": "حسب الشركة حسب تاريخ الكليات والجامعات",
    "by company by importance": "حسب الشركة حسب الأهمية",
    "by company by industry": "حسب الشركة حسب الصناعة",
    "by company by instrument": "حسب الشركة حسب الآلة",
    "by company by issue": "حسب الشركة حسب القضية",
    "by company by league": "حسب الشركة حسب الدوري",
    "by company by location": "حسب الشركة حسب الموقع",
    "by company by magazine": "حسب الشركة حسب المجلة",
    "by company by medium": "حسب الشركة حسب الوسط",
    "by company by millennium": "حسب الشركة حسب الألفية",
    "by company by nation": "حسب الشركة حسب الموطن",
    "by company by nationality": "حسب الشركة حسب الجنسية",
    "by company by newspaper": "حسب الشركة حسب الصحيفة",
    "by company by non-profit organizations": "حسب الشركة حسب المنظمات غير الربحية",
    "by company by non-profit publishers": "حسب الشركة حسب ناشرون غير ربحيون",
    "by company by nonprofit organization": "حسب الشركة حسب المنظمات غير الربحية",
    "by company by occupation": "حسب الشركة حسب المهنة",
    "by company by organization": "حسب الشركة حسب المنظمة",
    "by company by organizer": "حسب الشركة حسب المنظم",
    "by company by orientation": "حسب الشركة حسب التوجه",
    "by company by party": "حسب الشركة حسب الحزب",
    "by company by period": "حسب الشركة حسب الحقبة",
    "by company by political orientation": "حسب الشركة حسب التوجه السياسي",
    "by company by prison": "حسب الشركة حسب السجن",
    "by company by professional association": "حسب الشركة حسب الجمعيات المهنية",
    "by company by publication": "حسب الشركة حسب المؤسسة",
    "by company by quality": "حسب الشركة حسب الجودة",
    "by company by rank": "حسب الشركة حسب الرتبة",
    "by company by record label": "حسب الشركة حسب شركة التسجيلات",
    "by company by region": "حسب الشركة حسب المنطقة",
    "by company by religion": "حسب الشركة حسب الدين",
    "by company by research organization": "حسب الشركة حسب منظمة البحوث",
    "by company by role": "حسب الشركة حسب الدور",
    "by company by sector": "حسب الشركة حسب القطاع",
    "by company by series": "حسب الشركة حسب السلسلة",
    "by company by setting location": "حسب الشركة حسب موقع الأحداث",
    "by company by shipbuilding company": "حسب الشركة حسب شركة بناء السفن",
    "by company by specialty": "حسب الشركة حسب التخصص",
    "by company by sport": "حسب الشركة حسب الرياضة",
    "by company by state": "حسب الشركة حسب الولاية",
    "by company by station": "حسب الشركة حسب المحطة",
    "by company by status": "حسب الشركة حسب الحالة",
    "by company by subdivision": "حسب الشركة حسب التقسيم",
    "by company by team": "حسب الشركة حسب الفريق",
    "by company by territory": "حسب الشركة حسب الإقليم",
    "by company by time": "حسب الشركة حسب الوقت",
    "by company by trade union": "حسب الشركة حسب النقابات العمالية",
    "by company by type": "حسب الشركة حسب الفئة",
    "by company by writer": "حسب الشركة حسب الكاتب",
    "by company by year": "حسب الشركة حسب السنة",
    "by competition by bank": "حسب المنافسة حسب البنك",
    "by competition by behavior": "حسب المنافسة حسب السلوك",
    "by competition by branch": "حسب المنافسة حسب الفرع",
    "by competition by century": "حسب المنافسة حسب القرن",
    "by competition by city": "حسب المنافسة حسب المدينة",
    "by competition by class": "حسب المنافسة حسب الصنف",
    "by competition by club": "حسب المنافسة حسب النادي",
    "by competition by company": "حسب المنافسة حسب الشركة",
    "by competition by condition": "حسب المنافسة حسب الحالة",
    "by competition by conflict": "حسب المنافسة حسب النزاع",
    "by competition by continent": "حسب المنافسة حسب القارة",
    "by competition by country": "حسب المنافسة حسب البلد",
    "by competition by country of residence": "حسب المنافسة حسب بلد الإقامة",
    "by competition by country subdivision": "حسب المنافسة حسب تقسيم البلد",
    "by competition by country subdivisions": "حسب المنافسة حسب تقسيمات البلد",
    "by competition by country-of-residence": "حسب المنافسة حسب بلد الإقامة",
    "by competition by county": "حسب المنافسة حسب المقاطعة",
    "by competition by date": "حسب المنافسة حسب التاريخ",
    "by competition by decade": "حسب المنافسة حسب العقد",
    "by competition by educational establishment": "حسب المنافسة حسب المؤسسة التعليمية",
    "by competition by educational institution": "حسب المنافسة حسب الهيئة التعليمية",
    "by competition by era": "حسب المنافسة حسب العصر",
    "by competition by ethnicity": "حسب المنافسة حسب المجموعة العرقية",
    "by competition by event": "حسب المنافسة حسب الحدث",
    "by competition by former religion": "حسب المنافسة حسب الدين السابق",
    "by competition by genre": "حسب المنافسة حسب النوع الفني",
    "by competition by government agency": "حسب المنافسة حسب الوكالة الحكومية",
    "by competition by history of colleges and universities": "حسب المنافسة حسب تاريخ الكليات والجامعات",
    "by competition by importance": "حسب المنافسة حسب الأهمية",
    "by competition by industry": "حسب المنافسة حسب الصناعة",
    "by competition by instrument": "حسب المنافسة حسب الآلة",
    "by competition by issue": "حسب المنافسة حسب القضية",
    "by competition by league": "حسب المنافسة حسب الدوري",
    "by competition by location": "حسب المنافسة حسب الموقع",
    "by competition by magazine": "حسب المنافسة حسب المجلة",
    "by competition by medium": "حسب المنافسة حسب الوسط",
    "by competition by millennium": "حسب المنافسة حسب الألفية",
    "by competition by nation": "حسب المنافسة حسب الموطن",
    "by competition by nationality": "حسب المنافسة حسب الجنسية",
    "by competition by newspaper": "حسب المنافسة حسب الصحيفة",
    "by competition by non-profit organizations": "حسب المنافسة حسب المنظمات غير الربحية",
    "by competition by non-profit publishers": "حسب المنافسة حسب ناشرون غير ربحيون",
    "by competition by nonprofit organization": "حسب المنافسة حسب المنظمات غير الربحية",
    "by competition by occupation": "حسب المنافسة حسب المهنة",
    "by competition by organization": "حسب المنافسة حسب المنظمة",
    "by competition by organizer": "حسب المنافسة حسب المنظم",
    "by competition by orientation": "حسب المنافسة حسب التوجه",
    "by competition by party": "حسب المنافسة حسب الحزب",
    "by competition by period": "حسب المنافسة حسب الحقبة",
    "by competition by political orientation": "حسب المنافسة حسب التوجه السياسي",
    "by competition by prison": "حسب المنافسة حسب السجن",
    "by competition by professional association": "حسب المنافسة حسب الجمعيات المهنية",
    "by competition by publication": "حسب المنافسة حسب المؤسسة",
    "by competition by quality": "حسب المنافسة حسب الجودة",
    "by competition by rank": "حسب المنافسة حسب الرتبة",
    "by competition by record label": "حسب المنافسة حسب شركة التسجيلات",
    "by competition by region": "حسب المنافسة حسب المنطقة",
    "by competition by religion": "حسب المنافسة حسب الدين",
    "by competition by research organization": "حسب المنافسة حسب منظمة البحوث",
    "by competition by role": "حسب المنافسة حسب الدور",
    "by competition by sector": "حسب المنافسة حسب القطاع",
    "by competition by series": "حسب المنافسة حسب السلسلة",
    "by competition by setting location": "حسب المنافسة حسب موقع الأحداث",
    "by competition by shipbuilding company": "حسب المنافسة حسب شركة بناء السفن",
    "by competition by specialty": "حسب المنافسة حسب التخصص",
    "by competition by sport": "حسب المنافسة حسب الرياضة",
    "by competition by state": "حسب المنافسة حسب الولاية",
    "by competition by station": "حسب المنافسة حسب المحطة",
    "by competition by status": "حسب المنافسة حسب الحالة",
    "by competition by subdivision": "حسب المنافسة حسب التقسيم",
    "by competition by team": "حسب المنافسة حسب الفريق",
    "by competition by territory": "حسب المنافسة حسب الإقليم",
    "by competition by time": "حسب المنافسة حسب الوقت",
    "by competition by trade union": "حسب المنافسة حسب النقابات العمالية",
    "by competition by type": "حسب المنافسة حسب الفئة",
    "by competition by writer": "حسب المنافسة حسب الكاتب",
    "by competition by year": "حسب المنافسة حسب السنة",
    "by condition by bank": "حسب الحالة حسب البنك",
    "by condition by behavior": "حسب الحالة حسب السلوك",
    "by condition by branch": "حسب الحالة حسب الفرع",
    "by condition by century": "حسب الحالة حسب القرن",
    "by condition by city": "حسب الحالة حسب المدينة",
    "by condition by class": "حسب الحالة حسب الصنف",
    "by condition by club": "حسب الحالة حسب النادي",
    "by condition by company": "حسب الحالة حسب الشركة",
    "by condition by competition": "حسب الحالة حسب المنافسة",
    "by condition by conflict": "حسب الحالة حسب النزاع",
    "by condition by continent": "حسب الحالة حسب القارة",
    "by condition by country": "حسب الحالة حسب البلد",
    "by condition by country of residence": "حسب الحالة حسب بلد الإقامة",
    "by condition by country subdivision": "حسب الحالة حسب تقسيم البلد",
    "by condition by country subdivisions": "حسب الحالة حسب تقسيمات البلد",
    "by condition by country-of-residence": "حسب الحالة حسب بلد الإقامة",
    "by condition by county": "حسب الحالة حسب المقاطعة",
    "by condition by date": "حسب الحالة حسب التاريخ",
    "by condition by decade": "حسب الحالة حسب العقد",
    "by condition by educational establishment": "حسب الحالة حسب المؤسسة التعليمية",
    "by condition by educational institution": "حسب الحالة حسب الهيئة التعليمية",
    "by condition by era": "حسب الحالة حسب العصر",
    "by condition by ethnicity": "حسب الحالة حسب المجموعة العرقية",
    "by condition by event": "حسب الحالة حسب الحدث",
    "by condition by former religion": "حسب الحالة حسب الدين السابق",
    "by condition by genre": "حسب الحالة حسب النوع الفني",
    "by condition by government agency": "حسب الحالة حسب الوكالة الحكومية",
    "by condition by history of colleges and universities": "حسب الحالة حسب تاريخ الكليات والجامعات",
    "by condition by importance": "حسب الحالة حسب الأهمية",
    "by condition by industry": "حسب الحالة حسب الصناعة",
    "by condition by instrument": "حسب الحالة حسب الآلة",
    "by condition by issue": "حسب الحالة حسب القضية",
    "by condition by league": "حسب الحالة حسب الدوري",
    "by condition by location": "حسب الحالة حسب الموقع",
    "by condition by magazine": "حسب الحالة حسب المجلة",
    "by condition by medium": "حسب الحالة حسب الوسط",
    "by condition by millennium": "حسب الحالة حسب الألفية",
    "by condition by nation": "حسب الحالة حسب الموطن",
    "by condition by nationality": "حسب الحالة حسب الجنسية",
    "by condition by newspaper": "حسب الحالة حسب الصحيفة",
    "by condition by non-profit organizations": "حسب الحالة حسب المنظمات غير الربحية",
    "by condition by non-profit publishers": "حسب الحالة حسب ناشرون غير ربحيون",
    "by condition by nonprofit organization": "حسب الحالة حسب المنظمات غير الربحية",
    "by condition by occupation": "حسب الحالة حسب المهنة",
    "by condition by organization": "حسب الحالة حسب المنظمة",
    "by condition by organizer": "حسب الحالة حسب المنظم",
    "by condition by orientation": "حسب الحالة حسب التوجه",
    "by condition by party": "حسب الحالة حسب الحزب",
    "by condition by period": "حسب الحالة حسب الحقبة",
    "by condition by political orientation": "حسب الحالة حسب التوجه السياسي",
    "by condition by prison": "حسب الحالة حسب السجن",
    "by condition by professional association": "حسب الحالة حسب الجمعيات المهنية",
    "by condition by publication": "حسب الحالة حسب المؤسسة",
    "by condition by quality": "حسب الحالة حسب الجودة",
    "by condition by rank": "حسب الحالة حسب الرتبة",
    "by condition by record label": "حسب الحالة حسب شركة التسجيلات",
    "by condition by region": "حسب الحالة حسب المنطقة",
    "by condition by religion": "حسب الحالة حسب الدين",
    "by condition by research organization": "حسب الحالة حسب منظمة البحوث",
    "by condition by role": "حسب الحالة حسب الدور",
    "by condition by sector": "حسب الحالة حسب القطاع",
    "by condition by series": "حسب الحالة حسب السلسلة",
    "by condition by setting location": "حسب الحالة حسب موقع الأحداث",
}

_by_music_labels = {
    "by artist": "حسب الفنان",
    "by artist nationality": "حسب جنسية الفنان",
    "by composer": "حسب الملحن",
    "by composer nationality": "حسب جنسية الملحن",
    "by genre and artist": "حسب النوع الفني والفنان",
    "by genre and artist nationality": "حسب النوع الفني وجنسية الفنان",
    "by genre and composer": "حسب النوع الفني والملحن",
    "by genre and composer nationality": "حسب النوع الفني وجنسية الملحن",
    "by genre and manufacturer": "حسب النوع الفني والصانع",
    "by genre and manufacturer nationality": "حسب النوع الفني وجنسية الصانع",
    "by manufacturer": "حسب الصانع",
    "by manufacturer nationality": "حسب جنسية الصانع",
}
_by_music_table_base = {
    "by city": "حسب المدينة",
    "by seniority": "حسب الأقدمية",
    "by producer": "حسب المنتج",
    "by software": "حسب البرمجيات",
    "by band": "حسب الفرقة",
    "by medium by nationality": "حسب الوسط حسب الجنسية",
    "by instrument": "حسب الآلة",
    "by instrument, genre and nationality": "حسب الآلة والنوع الفني والجنسية",
    "by genre, nationality and instrument": "حسب النوع الفني والجنسية والآلة",
    "by nationality, genre and instrument": "حسب الجنسية والنوع والآلة",
    "by instrument and nationality": "حسب الآلة والجنسية",
    "by instrument and genre": "حسب الآلة والنوع الفني",
    "by genre and instrument": "حسب النوع الفني والآلة",
    "by nationality and instrument ": "حسب الجنسية والآلة",
    "by century and instrument": "حسب القرن والآلة",
    "by medium": "حسب الوسط",
    "by name": "حسب الإسم",
    "by voice type": "حسب نوع الصوت",
    "by language": "حسب اللغة",
    "by nationality": "حسب الجنسية",
}

to_test = [
    ("test_by_and_fields", _by_and_fields),
    ("test_by_or_fields", _by_or_fields),
    ("test_by_by_fields", _by_by_fields),
    ("test_by_musics", _by_music_labels),
    ("test_music_by_table", _by_music_table_base),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_by_labels)
    dump_diff(diff_result, name)

    expected2 = {x: v for x, v in expected.items() if v and x in diff_result}
    dump_diff(expected2, f"{name}_expected")

    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
