#
import pytest
from load_one_data import dump_diff, dump_diff_text, one_dump_test

from ArWikiCats import resolve_label_ar

data0 = {
    "permanent representatives of bahrain": "مندوبو البحرين الدائمون",
    "permanent representatives of kazakhstan": "مندوبو كازاخستان الدائمون",
    "permanent representatives of kyrgyzstan": "مندوبو قيرغيزستان الدائمون",
    "permanent representatives of luxembourg": "مندوبو لوكسمبورغ الدائمون",
    "bilateral relations of united kingdom": "علاقات المملكة المتحدة الثنائية",
    "permanent representatives of barbados": "مندوبو بربادوس الدائمون",
    "Military units and formations of Islamic Emirate of Afghanistan": "وحدات وتشكيلات عسكرية في إمارة أفغانستان الإسلامية",
    "Military units and formations of World War I": "وحدات وتشكيلات عسكرية في الحرب العالمية الأولى",
    # "1697 meteorology": "الأرصاد الجوية في 1697",
    # "1680s meteorology": "الأرصاد الجوية في عقد 1680",
    # "1684 meteorology": "الأرصاد الجوية في 1684",
    # "1683 meteorology": "الأرصاد الجوية في 1683",
    "Eastern European Hockey League": "الدوري الأوروبي الشرقي للهوكي",
    "Eastern European Hockey League seasons": "مواسم الدوري الأوروبي الشرقي للهوكي",
    "Eastern European Hockey League teams": "فرق الدوري الأوروبي الشرقي للهوكي",
    "people from santa fe province": "أشخاص من محافظة سانتا في",
    "Italy political leader navigational boxes": "صناديق تصفح قادة سياسيون إيطاليون",
    "Bosnia and Herzegovina political leader navigational boxes": "صناديق تصفح قادة سياسيون بوسنيون",
    "non-profit organizations by continent": "منظمات غير ربحية حسب القارة",
    "non-profit organizations by country": "منظمات غير ربحية حسب البلد",
    "non-profit organizations by dependent territory": "منظمات غير ربحية حسب الأقاليم التابعة",
    "non-profit organizations by subject": "منظمات غير ربحية حسب الموضوع",
    "non-profit organizations by type": "منظمات غير ربحية حسب الفئة",
    "academic journals published by non-profit organizations by country": "نشرات دورية أكاديمية نشرتها منظمات غير ربحية حسب البلد",
    "German military personnel by branch": "أفراد عسكريون ألمان حسب الفرع",
    "Dutch military personnel by branch": "أفراد عسكريون هولنديون حسب الفرع",
    "1650s soviet": "سوفيت في عقد 1650",
    "14th century people by nationality and occupation": "أشخاص في القرن 14 حسب الجنسية والمهنة",
    "Taekwondo at 2021 Islamic Solidarity Games": "التايكوندو في ألعاب التضامن الإسلامي 2021",
    "Taekwondo at Islamic Solidarity Games": "التايكوندو في ألعاب التضامن الإسلامي",
    "Works about Islamic State of Iraq and Levant": "أعمال عن تنظيم الدولة الإسلامية (داعش)",
    "Islamic Solidarity Games medalists in taekwondo": "فائزون بميداليات ألعاب التضامن الإسلامي في التايكوندو",
    "Academic staff of World Islamic Sciences and Education University": "أعضاء هيئة تدريس جامعة العلوم الإسلامية العالمية",
    "World Islamic Sciences and Education University alumni": "خريجو جامعة العلوم الإسلامية العالمية",
    "World Islamic Sciences and Education University": "جامعة العلوم الإسلامية العالمية",
    "Mine warfare vessels of Islamic Republic of Iran Navy": "سفن حرب ألغام في القوة البحرية لجيش الجمهورية الإسلامية الإيرانية",
    "Missile boats of Islamic Republic of Iran Navy": "قوارب صواريخ في القوة البحرية لجيش الجمهورية الإسلامية الإيرانية",
    "Amphibious warfare vessels of Islamic Republic of Iran Navy": "سفن حربية برمائية في القوة البحرية لجيش الجمهورية الإسلامية الإيرانية",
    "Ship classes of Islamic Republic of Iran Navy": "فئات سفن في القوة البحرية لجيش الجمهورية الإسلامية الإيرانية",
    "Ships of Islamic Republic of Iran Navy": "سفن القوة البحرية لجيش الجمهورية الإسلامية الإيرانية",
    "Submarines of Islamic Republic of Iran Navy": "غواصات القوة البحرية لجيش الجمهورية الإسلامية الإيرانية",
    "Auxiliary ships of Islamic Republic of Iran Navy": "سفن مساعدة في القوة البحرية لجيش الجمهورية الإسلامية الإيرانية",
    "Destroyers of Islamic Republic of Iran Navy": "مدمرات في القوة البحرية لجيش الجمهورية الإسلامية الإيرانية",
    "Frigates of Islamic Republic of Iran Navy": "فرقاطات في القوة البحرية لجيش الجمهورية الإسلامية الإيرانية",
}

data1 = {
    "samoan rugby league players": "لاعبو دوري رجبي سامويون",
    "Sunni Muslim scholars of Islam by ethnicity": "مسلمون سنة باحثون عن الإسلام حسب المجموعة العرقية",
    "Sunni Muslim scholars of Islam by nationality": "مسلمون سنة باحثون عن الإسلام حسب الجنسية",
    "american women's wheelchair basketball players": "لاعبات كرة سلة على كراسي متحركة أمريكيات",
    "turkish women's wheelchair basketball players": "لاعبات كرة سلة على كراسي متحركة تركيات",
    "israeli women's wheelchair basketball players": "لاعبات كرة سلة على كراسي متحركة إسرائيليات",
    "german women's wheelchair basketball players": "لاعبات كرة سلة على كراسي متحركة ألمانيات",
    "dutch women's wheelchair basketball players": "لاعبات كرة سلة على كراسي متحركة هولنديات",
    "australian women's wheelchair basketball players": "لاعبات كرة سلة على كراسي متحركة أستراليات",
    "british women's wheelchair basketball players": "لاعبات كرة سلة على كراسي متحركة بريطانيات",
    "french women's wheelchair basketball players": "لاعبات كرة سلة على كراسي متحركة فرنسيات",
    "canadian women's wheelchair basketball players": "لاعبات كرة سلة على كراسي متحركة كنديات",
    "19th-century women from Ottoman Arabia": "نساء من الدولة العثمانية في شبه الجزيرة العربية في القرن 19",
    "19th-century poets from Ottoman Arabia": "شعراء من الدولة العثمانية في شبه الجزيرة العربية في القرن 19",
    "19th-century people from Ottoman Arabia": "أشخاص من الدولة العثمانية في شبه الجزيرة العربية في القرن 19",
    "2002 commonwealth games": "ألعاب الكومنولث 2002",
    "2006 commonwealth games": "ألعاب الكومنولث 2006",
    "2014 commonwealth games": "ألعاب الكومنولث 2014",
    "afghan premier league": "الدوري الأفغاني الممتاز",
    "africa cup of nations": "كأس الأمم الإفريقية",
    "albanian second division": "الدوري الألباني الدرجة الثانية",
    "algerian basketball championship": "بطولة الجزائر لكرة السلة",
    "algerian league cup": "كأس الدوري الجزائري",
    "algerian women's volleyball league": "الدوري الجزائري لكرة الطائرة للسيدات",
    "all-africa games": "ألعاب عموم إفريقيا",
    "american hockey league": "الدوري الأمريكي للهوكي",
    "anguillan league": "الدوري الأنغويلاني",
    "armenian independence cup": "كأس الاستقلال الأرميني",
    "armenian premier league": "الدوري الأرميني الممتاز",
    "asian games": "الألعاب الآسيوية",
    "australian baseball league": "الدوري الأسترالي لكرة القاعدة",
    "australian football league": "الدوري الأسترالي لكرة القدم",
    "bandy world cup": "كأس العالم للباندي",
    "bangladesh football premier leagues": "دوريات كرة قدم بنغلاديشية من الدرجة الممتازة",
    "barbados fa cup": "كأس الاتحاد البربادوسي",
    "barbados premier division": "الدوري البربادوسي الممتاز",
    "bermudian premier division": "الدوري البرمودي الممتاز",
    "bosnia and herzegovina football cup": "كأس البوسنة والهرسك لكرة القدم",
    "botswana premier league": "الدوري البوتسواني الممتاز",
    "burkinabé premier league": "الدوري البوركينابي الممتاز",
    "cambodian league": "الدوري الكمبودي",
    "costa rican cup": "كأس كوستاريكا",
    "cricket world cup": "كأس العالم للكريكت",
    "croatian premier handball league": "الدوري الكرواتي الممتاز لكرة اليد",
    "cyprus cup": "كأس قبرص",
    "east asian games": "الألعاب الآسيوية الشرقية",
    "french women's handball championship": "بطولة فرنسا لكرة اليد للسيدات",
    "gerry weber open": "بطولة هالي المفتوحة",
    "grand prix": "سباق الجائزة الكبرى",
    "greek men's handball championship": "بطولة اليونان لكرة اليد للرجال",
    "greek women's handball championship": "بطولة اليونان لكرة اليد للسيدات",
    "gulf cup of nations": "كأس الخليج العربي",
    "handball league of serbia": "دوري كرة اليد في صربيا",
    "hockey world cup": "كأس العالم للهوكي",
    "hong kong first division league": "الدوري الهونغ الكونغي الدرجة الأولى",
    "hong kong premier league": "الدوري الهونغ الكونغي الممتاز",
    "iraqi super cup": "كأس السوبر العراقي",
    "japan football league": "دوري اليابان لكرة القدم",
    "japan professional basketball league": "دوري اليابان لكرة السلة للمحترفين",
    "kenyan premier league": "الدوري الكيني الممتاز",
    "kuwaiti premier league": "الدوري الكويتي الممتاز",
    "lao league": "الدوري اللاوسي",
    "latvian football cup": "كأس لاتفيا لكرة القدم",
    "lebanese football league": "الدوري اللبناني لكرة القدم",
    "lega basket serie a": "ليغا باسكيت الدرجة الأولى",
    "lesotho premier league": "الدوري الليسوتي الممتاز",
    "libyan premier league": "الدوري الليبي الممتاز",
    "lithuanian football cup": "كأس ليتوانيا لكرة القدم",
    "maccabiah games": "الألعاب المكابيه",
    "macedonian cup": "كأس مقدونيا",
    "macedonian handball super league": "دوري السوبر كرة اليد المقدوني",
    "malawi premier division": "الدوري الملاوي الممتاز",
    "maldives fa cup": "كأس الاتحاد المالديفي",
    "maltese second division": "الدوري المالطي الدرجة الثانية",
    "mauritian league": "الدوري الموريشيوسي",
    "men's african volleyball championship": "بطولة إفريقيا لكرة الطائرة رجالية",
    "moldovan cup": "كأس مولدوفا",
    "national basketball league of canada": "دوريات كرة سلة وطنية في كندا",
    "national basketball league": "دوريات كرة سلة وطنية",
    "national hockey league": "دوريات هوكي وطنية",
    "national soccer league": "دوريات كرة قدم وطنية",
    "nigerian professional football league": "دوري كرة القدم النيجيري للمحترفين",
    "north african super cup": "كأس السوبر الإفريقي الشمالي",
    "norwegian football cup": "كأس النرويج لكرة القدم",
    "omani league": "الدوري العماني",
    "palestine cup": "كأس فلسطين",
    "premier soccer league": "دوريات كرة قدم من الدرجة الممتازة",
    "russian basketball super league": "دوري السوبر كرة السلة الروسي",
    "russian handball super league": "دوري السوبر كرة اليد الروسي",
    "samoa cup": "كأس ساموا",
    "saudi second division": "الدوري السعودي الدرجة الثانية",
    "scottish cup": "كأس إسكتلندا",
    "scottish football league second division": "الدوري الإسكتلندي لكرة القدم الدرجة الثانية",
    "scottish football league": "الدوري الإسكتلندي لكرة القدم",
    "slovenian football cup": "كأس سلوفينيا لكرة القدم",
    "south american volleyball championship": "بطولة أمريكا الجنوبية لكرة الطائرة",
    "south american women's football championship": "بطولة أمريكا الجنوبية لكرة القدم للسيدات",
    "soviet cup": "كأس الاتحاد السوفيتي",
    "sumo": "السومو",
    "syrian premier league": "الدوري السوري الممتاز",
    "table tennis world cup": "كأس العالم لكرة الطاولة",
    "taekwondo": "التايكوندو",
    "thai fa cup": "كأس الاتحاد التايلندي",
    "thai premier league": "الدوري التايلندي الممتاز",
    "tour de france": "طواف فرنسا",
    "turkish basketball super league": "دوري السوبر كرة السلة التركي",
    "irish super league": "دوري السوبر الأيرلندي",
    "turkish handball super league": "دوري السوبر كرة اليد التركي",
    "vietnamese second division": "الدوري الفيتنامي الدرجة الثانية",
    "women's chinese basketball association": "الرابطة الصينية لكرة السلة للسيدات",
    "women's korean basketball league": "الدوري الكوري لكرة السلة للسيدات",
    "world games": "دورة الألعاب العالمية",
    "yemeni unity cup": "كأس الوحدة اليمنية",
    "College sports coaches in the United States by sport by state": "مدربو رياضات الكليات في الولايات المتحدة حسب الرياضة حسب الولاية",
    "national university of singapore": "جامعة سنغافورة الوطنية",
    "sri lankan civil war by decade": "الحرب الأهلية السريلانكية حسب العقد",
    "church of jesus christ of latter-day saints": "كنيسة يسوع المسيح لقديسي الأيام الأخيرة",
    "senate of pakistan": "مجلس شيوخ باكستان",
    "parliament of india": "برلمان الهند",
    "political people": "ساسة",
}

data_2 = {
    "puerto princesa international airport": "مطار بويرتو برينسيسا الدولي",
    "united states military academy": "الأكاديمية العسكرية الأمريكية",
    "west end theatre": "مسارح وست اند",
    "xin dynasty": "سلالة شين الحاكمة",
    "tokyo metropolitan police department": "قسم شرطة العاصمة طوكيو",
    "supreme court of israel": "المحكمة العليا (إسرائيل)",
    "sydney opera house": "دار أوبرا سيدني",
    "sovereign military order of malta": "فرسان مالطة",
    "second congo war": "حرب الكونغو الثانية",
    "san quentin state prison": "سجن سان كوينتن",
    "royal canadian mounted police": "شرطة الخيالة الكندية الملكية",
    "royal danish army": "القوات البرية الدانماركية",
    "russian academy of arts": "الأكاديمية الروسية للفنون",
    "lgbtq people": "أعلام إل جي بي تي كيو",
    "black people": "أعلام سوداء",
}

data_3 = {
    # "second italo-ethiopian war": "الحرب الإيطالية الإثيوبية الثانية",
    "Afghanistan Football Federation": "الاتحاد الأفغاني لكرة القدم",
    "Aruba Football Federation": "الاتحاد الأروبي لكرة القدم",
    "Bhutan Football Federation": "الاتحاد البوتاني لكرة القدم",
    "Bodies of water of Germany by state": "مسطحات مائية في ألمانيا حسب الولاية",
    "Bodies of water of Carmarthenshire": "مسطحات مائية في كرمرثنشير",
    "2023 in dependent territories of United Kingdom": "أقاليم ما وراء البحار البريطانية في 2023",
    "Battles involving al-Qaeda in Arabian Peninsula": "معارك تشمل تنظيم القاعدة في جزيرة العرب",
    "Film set at Metropolitan Museum of Art": "أفلام تقع أحداثها في متحف المتروبوليتان للفنون",
    "Halo (franchise) players": "لاعبو هيلو (سلسلة)",
    "Lists of members of Parliament of Syria": "قوائم أعضاء برلمان سوريا",
    "National Library of Israel": "مكتبة إسرائيل الوطنية",
    "Paintings of Judas Iscariot": "لوحات عن يهوذا الإسخريوطي",
    "People of Third Punic War": "أشخاص في الحرب البونيقية الثالثة",
    "Rectors of Stellenbosch University": "عمدات جامعة ستيلينبوش",
    "Violence against LGBTQ people in Oceania": "عنف ضد أعلام إل جي بي تي كيو في أوقيانوسيا",
}

data_4 = {
    "2020–21 in North Macedonia football": "كرة القدم المقدونية الشمالية في 2020–21",
    "2021–22 in North Macedonia football": "كرة القدم المقدونية الشمالية في 2021–22",
    "2024–25 in North Macedonia football": "كرة القدم المقدونية الشمالية في 2024–25",
    "2025–26 in North Macedonia football": "كرة القدم المقدونية الشمالية في 2025–26",
    "Albania–North Macedonia border": "الحدود الألبانية المقدونية الشمالية",
    "Bangladesh–North Macedonia relations": "العلاقات البنغلاديشية المقدونية الشمالية",
    "Belgium–North Macedonia relations": "العلاقات البلجيكية المقدونية الشمالية",
    "Bulgaria–North Macedonia border": "الحدود البلغارية المقدونية الشمالية",
    "Bulgaria–North Macedonia border crossings": "معابر الحدود البلغارية المقدونية الشمالية",
    "Bulgaria–North Macedonia sports relations": "العلاقات البلغارية المقدونية الشمالية الرياضية",
    "Cameroon–North Macedonia relations": "العلاقات الكاميرونية المقدونية الشمالية",
    "Colombia–North Macedonia relations": "العلاقات الكولومبية المقدونية الشمالية",
    "Cyprus–North Macedonia relations": "العلاقات القبرصية المقدونية الشمالية",
    "Dominican Republic–North Macedonia relations": "العلاقات الدومينيكانية المقدونية الشمالية",
    "El Salvador–North Macedonia relations": "العلاقات السلفادورية المقدونية الشمالية",
    "Equatorial Guinea–North Macedonia relations": "العلاقات الغينية الاستوائية المقدونية الشمالية",
    "Georgia (country)–North Macedonia relations": "العلاقات الجورجية المقدونية الشمالية",
    "Ghana–North Macedonia relations": "العلاقات الغانية المقدونية الشمالية",
    "Greece–North Macedonia border": "الحدود المقدونية الشمالية اليونانية",
    "Greece–North Macedonia border crossings": "معابر الحدود المقدونية الشمالية اليونانية",
    "Honduras–North Macedonia relations": "العلاقات المقدونية الشمالية الهندوراسية",
    "Italy–North Macedonia sports relations": "العلاقات الإيطالية المقدونية الشمالية الرياضية",
    "Jordan–North Macedonia relations": "العلاقات الأردنية المقدونية الشمالية",
    "Kosovo–North Macedonia border": "الحدود الكوسوفية المقدونية الشمالية",
    "Kosovo–North Macedonia border crossings": "معابر الحدود الكوسوفية المقدونية الشمالية",
    "Kosovo–North Macedonia relations": "العلاقات الكوسوفية المقدونية الشمالية",
    "Liechtenstein–North Macedonia relations": "العلاقات الليختنشتانية المقدونية الشمالية",
    "Lithuania–North Macedonia relations": "العلاقات الليتوانية المقدونية الشمالية",
    "Moldova–North Macedonia relations": "العلاقات المقدونية الشمالية المولدوفية",
    "Montenegro–North Macedonia relations": "العلاقات المقدونية الشمالية المونتينيغرية",
    "Montenegro–North Macedonia sports relations": "العلاقات المقدونية الشمالية المونتينيغرية الرياضية",
    "Morocco–North Macedonia relations": "العلاقات المغربية المقدونية الشمالية",
    "Netherlands–North Macedonia relations": "العلاقات المقدونية الشمالية الهولندية",
    "North Macedonia diplomacy-related lists": "قوائم متعلقة بالدبلوماسية المقدونية الشمالية",
    "North Macedonia football manager history navigational boxes": "صناديق تصفح تاريخ مدربو كرة قدم مقدونيا الشمالية",
    "North Macedonia football navigational boxes": "صناديق تصفح كرة القدم المقدونية الشمالية",
    "North Macedonia–Qatar relations": "العلاقات القطرية المقدونية الشمالية",
    "North Macedonia–Saudi Arabia relations": "العلاقات السعودية المقدونية الشمالية",
    "North Macedonia–Senegal relations": "العلاقات السنغالية المقدونية الشمالية",
    "North Macedonia–Serbia border": "الحدود الصربية المقدونية الشمالية",
    "North Macedonia–Serbia border crossings": "معابر الحدود الصربية المقدونية الشمالية",
    "North Macedonia–Slovakia relations": "العلاقات السلوفاكية المقدونية الشمالية",
    "North Macedonia–Slovenia sports relations": "العلاقات السلوفينية المقدونية الشمالية الرياضية",
    "North Macedonia–Thailand relations": "العلاقات التايلندية المقدونية الشمالية",
    "Albania–North Macedonia relations": "العلاقات الألبانية المقدونية الشمالية",
    "Algeria–North Macedonia relations": "العلاقات الجزائرية المقدونية الشمالية",
    "Argentina–North Macedonia relations": "العلاقات الأرجنتينية المقدونية الشمالية",
    "Armenia–North Macedonia relations": "العلاقات الأرمينية المقدونية الشمالية",
    "Australia–North Macedonia relations": "العلاقات الأسترالية المقدونية الشمالية",
    "Austria–North Macedonia relations": "العلاقات المقدونية الشمالية النمساوية",
    "Azerbaijan–North Macedonia relations": "العلاقات الأذربيجانية المقدونية الشمالية",
    "Bahamas–North Macedonia relations": "العلاقات البهامية المقدونية الشمالية",
    "Belarus–North Macedonia relations": "العلاقات البيلاروسية المقدونية الشمالية",
    "Bosnia and Herzegovina–North Macedonia relations": "العلاقات البوسنية المقدونية الشمالية",
    "Brazil–North Macedonia relations": "العلاقات البرازيلية المقدونية الشمالية",
    "Bulgaria–North Macedonia relations": "العلاقات البلغارية المقدونية الشمالية",
    "Canada–North Macedonia relations": "العلاقات الكندية المقدونية الشمالية",
    "China–North Macedonia relations": "العلاقات الصينية المقدونية الشمالية",
    "Croatia–North Macedonia relations": "العلاقات الكرواتية المقدونية الشمالية",
    "Czech Republic–North Macedonia relations": "العلاقات التشيكية المقدونية الشمالية",
    "Denmark–North Macedonia relations": "العلاقات الدنماركية المقدونية الشمالية",
    "Egypt–North Macedonia relations": "العلاقات المصرية المقدونية الشمالية",
    "Estonia–North Macedonia relations": "العلاقات الإستونية المقدونية الشمالية",
    "Finland–North Macedonia relations": "العلاقات الفنلندية المقدونية الشمالية",
    "France–North Macedonia relations": "العلاقات الفرنسية المقدونية الشمالية",
    "Germany–North Macedonia relations": "العلاقات الألمانية المقدونية الشمالية",
    "Greece–North Macedonia relations": "العلاقات المقدونية الشمالية اليونانية",
    "Guinea–North Macedonia relations": "العلاقات الغينية المقدونية الشمالية",
    "Hungary–North Macedonia relations": "العلاقات المجرية المقدونية الشمالية",
    "Iceland–North Macedonia relations": "العلاقات الآيسلندية المقدونية الشمالية",
    "India–North Macedonia relations": "العلاقات المقدونية الشمالية الهندية",
    "Indonesia–North Macedonia relations": "العلاقات الإندونيسية المقدونية الشمالية",
    "Iran–North Macedonia relations": "العلاقات الإيرانية المقدونية الشمالية",
    "Israel–North Macedonia relations": "العلاقات الإسرائيلية المقدونية الشمالية",
    "Italy–North Macedonia relations": "العلاقات الإيطالية المقدونية الشمالية",
    "Jamaica–North Macedonia relations": "العلاقات الجامايكية المقدونية الشمالية",
    "Japan–North Macedonia relations": "العلاقات المقدونية الشمالية اليابانية",
    "Kazakhstan–North Macedonia relations": "العلاقات الكازاخستانية المقدونية الشمالية",
    "Latvia–North Macedonia relations": "العلاقات اللاتفية المقدونية الشمالية",
    "Luxembourg–North Macedonia relations": "العلاقات اللوكسمبورغية المقدونية الشمالية",
    "Malaysia–North Macedonia relations": "العلاقات الماليزية المقدونية الشمالية",
    "Maldives–North Macedonia relations": "العلاقات المالديفية المقدونية الشمالية",
    "Mexico–North Macedonia relations": "العلاقات المقدونية الشمالية المكسيكية",
    "Myanmar–North Macedonia relations": "العلاقات المقدونية الشمالية الميانمارية",
    "Nigeria–North Macedonia relations": "العلاقات المقدونية الشمالية النيجيرية",
    "North Macedonia political leader navigational boxes": "صناديق تصفح قادة سياسيون مقدونيون شماليون",
    "North Macedonia sports templates": "قوالب مقدونيا الشمالية الرياضية",
    "North Macedonia–Norway relations": "العلاقات المقدونية الشمالية النرويجية",
    "North Macedonia–Poland relations": "العلاقات البولندية المقدونية الشمالية",
    "North Macedonia–Portugal relations": "العلاقات البرتغالية المقدونية الشمالية",
    "North Macedonia–Romania relations": "العلاقات الرومانية المقدونية الشمالية",
    "North Macedonia–Russia relations": "العلاقات الروسية المقدونية الشمالية",
    "North Macedonia–Rwanda relations": "العلاقات الرواندية المقدونية الشمالية",
    "North Macedonia–Serbia relations": "العلاقات الصربية المقدونية الشمالية",
    "North Macedonia–Slovenia relations": "العلاقات السلوفينية المقدونية الشمالية",
    "North Macedonia–South Korea relations": "العلاقات الكورية الجنوبية المقدونية الشمالية",
    "North Macedonia–Spain relations": "العلاقات الإسبانية المقدونية الشمالية",
    "North Macedonia–Sudan relations": "العلاقات السودانية المقدونية الشمالية",
    "North Macedonia–Sweden relations": "العلاقات السويدية المقدونية الشمالية",
    "North Macedonia–Switzerland relations": "العلاقات السويسرية المقدونية الشمالية",
    "North Macedonia–Togo relations": "العلاقات التوغوية المقدونية الشمالية",
    "North Macedonia–Tunisia relations": "العلاقات التونسية المقدونية الشمالية",
    "North Macedonia–Turkey relations": "العلاقات التركية المقدونية الشمالية",
    "North Macedonia–Ukraine relations": "العلاقات الأوكرانية المقدونية الشمالية",
    "North Macedonia–United Arab Emirates relations": "العلاقات الإماراتية المقدونية الشمالية",
    "North Macedonia–United Kingdom relations": "العلاقات البريطانية المقدونية الشمالية",
    "North Macedonia–United States relations": "العلاقات الأمريكية المقدونية الشمالية",
    "North Macedonia–Uzbekistan relations": "العلاقات الأوزبكستانية المقدونية الشمالية",
}

to_test = [
    ("test_4_data_0", data0),
    ("test_4_data_1", data1),
    ("test_4_data_3", data_3),
    ("test_4_data_4", data_4),
]


@pytest.mark.parametrize("category, expected", data0.items(), ids=data0.keys())
def test_4_data_0(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data1.items(), ids=data1.keys())
def test_4_data_1(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("category, expected", data_3.items(), ids=data_3.keys())
def test_4_data_3(category: str, expected: str) -> None:
    assert resolve_label_ar(category) == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_label_ar)
    dump_diff(diff_result, name)

    # dump_diff_text (expected, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
