#!/usr/bin/python3
"""
"""

add_in_to_country = [
    "solar eclipses",
]
# ---
Keep_it_last = [
    "remakes of",
]
# ---
Keep_it_frist = [
    "spaceflight",
    "lists of",
    # "people associated with" ,
    "actors in",
    "male actors in",
    "centuries in",
    "centuries",
    "qualification for",
    "participants",
    "seasons in",
    "seasons",
    "works by",
    "deaths by",
]

Add_in_table = [
    "historical documents",
    "road incidents",
    "racehorse deaths",
    "animal deaths",
    "documents",
    "sports awards",
    "military alliances",
    "illuminated manuscripts",
    "biblical manuscripts",
    "censuses",  # تعداد السكان
]

__all__ = [
    "add_in_to_country",
    "Keep_it_last",
    "Keep_it_frist",
    "Add_in_table",
]
