"""Additional key-label mappings for companies, media and professions."""

from __future__ import annotations

from ...helps import len_print
from ..sports.games_labs import SUMMER_WINTER_TABS
from ..utils.json_dir import open_json_file

companies_keys3 = {
    "railway": "السكك الحديدية",
    "transport": "النقل",
    "railway stations": "محطات السكك الحديدية",
    "road": "الطرق",
    "road transport": "النقل البري",
    "entertainment": "ترفيه",
    "aviation": "الطيران",
    "airlines": "طيران",
    "bus": "الباصات",
    "design": "تصميم",
    "aviation accidents": "حوادث طيران",
    "vehicle": "المركبات",
    "transport companies": "شركات النقل",
    "railway companies": "شركات السكك الحديدية",
    "entertainment companies": "شركات ترفيه",
    "transport disasters": "كوارث نقل",
    "railway accidents": "حوادث سكك حديد",
    "design companies": "شركات تصميم",
    "vehicle manufacturing": "تصنيع المركبات",
    "vehicle manufacturing companies": "شركات تصنيع المركبات",
    "water transport": "النقل المائي",
    "holding": "قابضة",
    "motor vehicle": "السيارات",
    "vehicle manufacturers": "مصانع المركبات",
    "holding companies": "شركات قابضة",
    "truck": "الشاحنات",
    "rolling stock": "القطارات",
    "defunct airlines": "طيران سابقة",
    "shipping": "النقل البحري",
    "government-owned": "مملوكة للحكومة",
    "defunct airlines of": "طيران سابقة في",
    "bus stations": "محطات الباصات",
    "motor vehicle manufacturers": "مصانع السيارات",
    "government-owned companies": "شركات مملوكة للحكومة",
    "privately held": "خاصة",
    "privately held companies": "شركات خاصة",
    "shipping companies": "شركات النقل البحري",
    "ferry transport": "النقل بالعبارات",
    "airline": "الخطوط الجوية",
    "locomotive": "القاطرات",
    "defunct railway": "سكك حديد سابقة",
    "airlines accidents": "حوادث طيران",
    "bus companies": "شركات الباصات",
    "bus manufacturers": "مصانع الباصات",
    "truck manufacturers": "مصانع الشاحنات",
    "distance education": "التعليم عن بعد",
    "defunct transport": "نقل سابقة",
    "rolling stock manufacturers": "مصانع القطارات",
    "locomotive manufacturers": "مصانع القاطرات",
    "defunct motor vehicle": "سيارات سابقة",
    "distance education institutions": "مؤسسات تعليم عن بعد",
    "cargo airlines": "الشحن الجوي",
    "railway accident": "حوادث سكك حديد",
    "aviation accident": "حوادث طيران",
    "transport stations": "محطات النقل",
    "defunct shipping": "نقل بحري سابقة",
    "defunct rolling stock": "قطارات سابقة",
    "defunct locomotive": "قاطرات سابقة",
    "road stations": "محطات الطرق",
    "transport accidents": "حوادث نقل",
    "rail industry": "السكك الحديدية",
    "aviation companies": "شركات الطيران",
    "entertainment franchises": "امتيازات ترفيه",
    "defunct bus": "باصات سابقة",
    "defunct entertainment": "الترفيه سابقة",
    "road accidents": "حوادث طرق",
    "defunct aviation": "طيران سابقة",
    "defunct government-owned": "مملوكة للحكومة سابقة",
    "transport policy": "سياسات النقل",
    "airline companies": "شركات الخطوط الجوية",
    "defunct airline": "خطوط جوية سابقة",
    "rail industry companies": "شركات السكك الحديدية",
    "defunct truck": "شاحنات سابقة",
    "defunct cargo airlines": "شحن جوي سابقة",
    "defunct privately held": "خاصة سابقة",
    "defunct rail industry": "سكك حديد سابقة",
    "rail industry manufacturing": "تصنيع السكك الحديدية",
    "rail industry manufacturing companies": "شركات تصنيع السكك الحديدية",
    "transport accident": "حوادث نقل",
    "airline tickets": "تذاكر الخطوط الجوية",
    "defunct cargo airlines of": "شحن جوي سابقة في",
    "defunct design": "تصميم سابقة",
    "design institutions": "مؤسسات تصميم",
    "motor vehicle companies": "شركات السيارات",
    "vehicle companies": "شركات المركبات",
    "motor vehicle manufacturing": "تصنيع السيارات",
    "transport tickets": "تذاكر النقل",
    "railway franchises": "امتيازات السكك الحديدية",
    "road transport companies": "شركات النقل البري",
    "water transport companies": "شركات النقل المائي",
}

tab2 = {
    "colleges": "كليات",
    "distance education": "التعليم عن بعد",
    "education controversies": "خلافات متعلقة بالتعليم",
    "federal colleges": "كليات فيدرالية",
    "federal libraries": "مكتبات فيدرالية",
    "federal schools": "مدارس فيدرالية",
    "federal universities": "جامعات فيدرالية",
    "federal universities and colleges": "جامعات وكليات فيدرالية",
    "government colleges": "كليات حكومية",
    "government libraries": "مكتبات حكومية",
    "government schools": "مدارس حكومية",
    "government universities": "جامعات حكومية",
    "government universities and colleges": "جامعات وكليات حكومية",
    "islamic colleges": "كليات إسلامية",
    "islamic libraries": "مكتبات إسلامية",
    "islamic schools": "مدارس إسلامية",
    "islamic universities": "جامعات إسلامية",
    "islamic universities and colleges": "جامعات وكليات إسلامية",
    "libraries": "مكتبات",
    "national colleges": "كليات وطنية",
    "national libraries": "مكتبات وطنية",
    "national schools": "مدارس وطنية",
    "national universities": "جامعات وطنية",
    "national universities and colleges": "جامعات وكليات وطنية",
    "public colleges": "كليات حكومية",
    "public libraries": "مكتبات حكومية",
    "public schools": "مدارس حكومية",
    "public universities": "جامعات حكومية",
    "public universities and colleges": "جامعات وكليات حكومية",
    "schools": "مدارس",
    "Standardized tests": "اختبارات قياسية",
    "universities": "جامعات",
    "universities and colleges": "جامعات وكليات",
}

pop_final_3_update = {
    "Agricultural buildings and structures on the-national-register-of-historic-places in": "مبان ومنشآت زراعية  في السجل الوطني للأماكن التاريخية في ",
    "agricultural buildings and structures": "مبان ومنشآت زراعية",
    "architecture museums": "متاحف معمارية",
    "astronomical observatories": "مراصد فلكية",
    "bank buildings on the-national-register-of-historic-places in": "مباني بنوك  في السجل الوطني للأماكن التاريخية في ",
    "bank buildings": "مباني بنوك",
    "bridge disasters": "كوارث جسور",
    "bridge": "جسور",
    "bridges on the-national-register-of-historic-places in": "جسور  في السجل الوطني للأماكن التاريخية في ",
    "bridges": "جسور",
    "buildings and structures on the-national-register-of-historic-places in": "مبان ومنشآت  في السجل الوطني للأماكن التاريخية في ",
    "buildings and structures": "مبان ومنشآت",
    "buildings on the-national-register-of-historic-places in": "مباني  في السجل الوطني للأماكن التاريخية في ",
    "buildings": "مباني",
    "burial monuments and structures": "معالم ومنشآت أماكن الدفن",
    "burials": "مدفونون",
    "canals on the-national-register-of-historic-places in": "ممرات مائية  في السجل الوطني للأماكن التاريخية في ",
    "canals": "ممرات مائية",
    "Cemeteries on the-national-register-of-historic-places in": "مقابر  في السجل الوطني للأماكن التاريخية في ",
    "cemeteries": "مقابر",
    "christian buildings and structures": "مبان ومنشآت مسيحية",
    "christian buildings": "مباني مسيحية",
    "christian Cemeteries": "مقابر مسيحية",
    "christian colleges": "كليات مسيحية",
    "christian Hospitals": "مستشفيات مسيحية",
    "christian libraries": "مكتبات مسيحية",
    "christian Museums": "متاحف مسيحية",
    "christian schools": "مدارس مسيحية",
    "christian universities and colleges": "جامعات وكليات مسيحية",
    "christian universities": "جامعات مسيحية",
    "clock towers": "أبراج ساعة",
    "Clubhouses on the-national-register-of-historic-places in": "نوادي  في السجل الوطني للأماكن التاريخية في ",
    "clubhouses": "نوادي",
    "colleges": "كليات",
    "commercial buildings on the-national-register-of-historic-places in": "مباني تجارية  في السجل الوطني للأماكن التاريخية في ",
    "commercial buildings": "مباني تجارية",
    "defunct Astronomical observatories": "مراصد فلكية سابقة",
    "defunct Hospitals": "مستشفيات سابقة",
    "defunct Hotels": "فنادق سابقة",
    "defunct islamic schools": "مدارس إسلامية سابقة",
    "defunct libraries": "مكتبات سابقة",
    "defunct Museums": "متاحف سابقة",
    "defunct private universities and colleges": "جامعات وكليات خاصة سابقة",
    "defunct public schools": "مدارس حكومية سابقة",
    "defunct public universities and colleges": "جامعات وكليات حكومية سابقة",
    "defunct public universities": "جامعات حكومية سابقة",
    "defunct restaurants": "مطاعم سابقة",
    "defunct schools": "مدارس سابقة",
    "defunct sports venues": "ملاعب رياضية سابقة",
    "defunct supermarkets": "محلات سوبر ماركت سابقة",
    "defunct transportation": "وسائل نقل سابقة",
    "defunct universities and colleges": "جامعات وكليات سابقة",
    "defunct universities": "جامعات سابقة",
    "distance education": "التعليم عن بعد",
    "education controversies": "خلافات متعلقة بالتعليم",
    "facilities on the-national-register-of-historic-places in": "مرافق  في السجل الوطني للأماكن التاريخية في ",
    "facilities": "مرافق",
    "federal colleges": "كليات فيدرالية",
    "federal universities and colleges": "جامعات وكليات فيدرالية",
    "federal universities": "جامعات فيدرالية",
    "ferries": "عبارات",
    "fountains on the-national-register-of-historic-places in": "نوافير  في السجل الوطني للأماكن التاريخية في ",
    "fountains": "نوافير",
    "government colleges": "كليات حكومية",
    "government schools": "مدارس حكومية",
    "government universities and colleges": "جامعات وكليات حكومية",
    "government universities": "جامعات حكومية",
    "history museums": "متاحف تاريخية",
    "hospitals": "مستشفيات",
    "hotels": "فنادق",
    "Industrial buildings and structures on the-national-register-of-historic-places in": "مبان ومنشآت صناعية  في السجل الوطني للأماكن التاريخية في ",
    "industrial buildings and structures": "مبان ومنشآت صناعية",
    "islamic education": "تعليم إسلامي",
    "islamic libraries": "مكتبات إسلامية",
    "islamic schools": "مدارس إسلامية",
    "islamic universities and colleges": "جامعات وكليات إسلامية",
    "islamic universities": "جامعات إسلامية",
    "laboratories": "مختبرات",
    "libraries on the-national-register-of-historic-places in": "مكتبات  في السجل الوطني للأماكن التاريخية في ",
    "libraries": "مكتبات",
    "lighthouses on the-national-register-of-historic-places in": "منارات  في السجل الوطني للأماكن التاريخية في ",
    "lighthouses": "منارات",
    "medical education": "تعليم طبي",
    "memorials and cemeteries": "نصب تذكارية ومقابر",
    "memorials on the-national-register-of-historic-places in": "نصب تذكارية  في السجل الوطني للأماكن التاريخية في ",
    "memorials": "نصب تذكارية",
    "military and war museums": "متاحف عسكرية وحربية",
    "mines": "مناجم",
    "monuments and memorials on the-national-register-of-historic-places in": "معالم أثرية ونصب تذكارية  في السجل الوطني للأماكن التاريخية في ",
    "monuments and memorials": "معالم أثرية ونصب تذكارية",
    "monuments and structures": "معالم أثرية ومنشآت",
    "monuments": "معالم أثرية",
    "Museums on the-national-register-of-historic-places in": "متاحف  في السجل الوطني للأماكن التاريخية في ",
    "museums": "متاحف",
    "national colleges": "كليات وطنية",
    "national libraries": "مكتبات وطنية",
    "national schools": "مدارس وطنية",
    "national universities and colleges": "جامعات وكليات وطنية",
    "national universities": "جامعات وطنية",
    "nature centers": "مراكز طبيعية",
    "outdoor sculptures": "منحوتات خارجية",
    "palaces": "قصور",
    "places of worship": "أماكن عبادة",
    "private universities and colleges": "جامعات وكليات خاصة",
    "public colleges": "كليات حكومية",
    "public libraries": "مكتبات حكومية",
    "public schools": "مدارس حكومية",
    "public universities and colleges": "جامعات وكليات حكومية",
    "public universities": "جامعات حكومية",
    "recording studios": "استديوهات تسجيل",
    "restaurants on the-national-register-of-historic-places in": "مطاعم  في السجل الوطني للأماكن التاريخية في ",
    "restaurants": "مطاعم",
    "Road bridges on the-national-register-of-historic-places in": "جسور طرق  في السجل الوطني للأماكن التاريخية في ",
    "road bridges": "جسور طرق",
    "road incidents": "حوادث طرق",
    "roads on the-national-register-of-historic-places in": "طرق  في السجل الوطني للأماكن التاريخية في ",
    "roads": "طرق",
    "schools": "مدارس",
    "science museums": "متاحف علمية",
    "sculpture": "منحوتات",
    "skyscraper hotels": "فنادق ناطحات سحاب",
    "skyscrapers": "ناطحات سحاب",
    "sports museums": "متاحف رياضية",
    "sports venues on the-national-register-of-historic-places in": "ملاعب رياضية  في السجل الوطني للأماكن التاريخية في ",
    "sports venues": "ملاعب رياضية",
    "standardized tests": "اختبارات قياسية",
    "state universities and colleges": "جامعات وكليات ولايات",
    "structures on the-national-register-of-historic-places in": "منشآت  في السجل الوطني للأماكن التاريخية في ",
    "structures": "منشآت",
    "studios": "استديوهات",
    "supermarkets": "محلات سوبر ماركت",
    "synagogues on the-national-register-of-historic-places in": "كنس  في السجل الوطني للأماكن التاريخية في ",
    "synagogues": "كنس",
    "theatres on the-national-register-of-historic-places in": "مسارح  في السجل الوطني للأماكن التاريخية في ",
    "theatres": "مسارح",
    "towers on the-national-register-of-historic-places in": "أبراج  في السجل الوطني للأماكن التاريخية في ",
    "towers": "أبراج",
    "transport buildings and structures": "مبان ومنشآت نقل",
    "transportation disasters": "كوارث وسائل نقل",
    "transportation museums": "متاحف النقل",
    "transportation on the-national-register-of-historic-places in": "وسائل نقل  في السجل الوطني للأماكن التاريخية في ",
    "transportation": "وسائل نقل",
    "universities and colleges": "جامعات وكليات",
    "universities": "جامعات",
}

ALBUMS_TYPE: dict[str, str] = {
    "folktronica": "فولكترونيكا",
    "concept": "مفاهيمية",
    "surprise": "مفاجئة",
    "comedy": "كوميدية",
    "mixtape": "ميكستايب",
    "remix": "ريمكس",
    "animation": "رسوم متحركة",
    "video": "فيديو",
    "compilation": "تجميعية",
    "live": "مباشرة",
    "jazz": "جاز",
    "eps": "أسطوانة مطولة",
    "folk": "فولك",
}

BUSINESSPEOPLE_INDUSTRIES: dict[str, str] = {
    "video game": "ألعاب الفيديو",
    "real estate": "العقارات",
    "financial": "المالية",
    "metals": "المعادن",
    "entertainment": "الترفيه",
    "fashion": "الأزياء",
    "computer": "كمبيوتر",
    "cosmetics": "مستحضرات التجميل",
}

FILM_PRODUCTION_COMPANY: dict[str, str] = {
    "Yash Raj": "ياش راج",
    "Illumination Entertainment": "إليمونيشن للترفيه",
    "Walt Disney Animation Studios": "استديوهات والت ديزني للرسوم المتحركة",
    "Carolco Pictures": "كارلوكو بيكشرز",
    "Aardman Animations": "آردمان انيمشنز",
    "Soyuzmultfilm": "سويز مولتفيلم",
    "Weinstein Company": "شركة وينشتاين",
    "Castle Rock Entertainment": "كاسل روك للترفيه",
    "United Artists": "يونايتد آرتيست",
    "Mosfilm": "موسفيلم",
    "National Geographic Society": "منظمة ناشيونال جيوغرافيك",
    "Showtime (TV network)": "شوتايم",
    "Touchstone Pictures": "توتشستون بيكشرز",
    "Rooster Teeth": "أسنان الديك",
    "Blue Sky Studios": "استديوهات بلو سكاي",
    "Bad Robot Productions": "باد روبوت للإنتاج",
    "TMS Entertainment": "تي أم أس إنترتنيمنت",
    "Sony Pictures Entertainment": "سوني بيكشرز إنترتنمنت",
    "sony pictures animation": "سوني بيكشرز أنيماشين",
    "Toei Company": "شركة توي",
    "Toho": "توهو",
    "Universal Studios": "يونيفرسل ستوديوز",
    "Walt Disney Company": "ديزني",
    "Paramount Pictures": "باراماونت بيكتشرز",
    "20th Century Fox": "تونتيث سينتشوري فوكس",
    "DreamWorks Animation": "دريمووركس أنيماشين",
    "Pixar": "بيكسار",
    "Metro-Goldwyn-Mayer": "مترو غولدوين ماير",
    "Lucasfilm": "لوكاس فيلم",
    "Amblin Entertainment": "أمبلين للترفيه",
    "DreamWorks": "دريم ووركس",
    "Funimation": "شركة فنميشن للترفيه",
    "Columbia Pictures": "كولومبيا بيكتشرز",
    "Marvel Studios": "استوديوهات مارفل",
    "HBO": "هوم بوكس أوفيس",
    "Warner Bros.": "وارنر برذرز",
}


def build_pop_final_3() -> dict[str, str]:
    """Build the main mapping used for pop culture categories."""

    registry = open_json_file("population/pop_final_3.json") or {}

    for industry, label in BUSINESSPEOPLE_INDUSTRIES.items():
        registry[f"{industry} businesspeople"] = f"شخصيات أعمال في {label}"
        registry[f"{industry} industry businesspeople"] = f"شخصيات أعمال في صناعة {label}"

    for company, label in FILM_PRODUCTION_COMPANY.items():
        registry[company] = label
        registry[f"{company} films"] = f"أفلام {label}"

    registry.update(SUMMER_WINTER_TABS)
    registry.update(companies_keys3)
    registry.update(tab2)
    registry.update(pop_final_3_update)

    return registry


pop_final_3: dict[str, str] = build_pop_final_3()

Ambassadors_tab: dict[str, str] = {}

len_print.data_len(
    "all_keys3.py",
    {
        "pop_final_3": pop_final_3,
        "ALBUMS_TYPE": ALBUMS_TYPE,
        "FILM_PRODUCTION_COMPANY": FILM_PRODUCTION_COMPANY,
        "Ambassadors_tab": Ambassadors_tab,
        "BUSINESSPEOPLE_INDUSTRIES": BUSINESSPEOPLE_INDUSTRIES,
    },
)

__all__ = [
    "pop_final_3",
    "ALBUMS_TYPE",
    "FILM_PRODUCTION_COMPANY",
    "Ambassadors_tab",
    "BUSINESSPEOPLE_INDUSTRIES",
]
