#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {
    "animation directors": "x",
    "anti-corruption activists": "x",
    "antiquarians": "x",
    "arts administrators": "x",
    "astrological writers": "x",
    "auctioneers": "x",
    "bacteriologists": "x",
    "ballerinas": "x",
    "ballet masters": "x",
    "balloonists": "x",
    "bank robbers": "x",
    "baritones": "x",
    "barristers": "x",
    "bass-baritones": "x",
    "biomechanists": "x",
    "blacksmiths": "x",
    "booksellers": "x",
    "border guards": "x",
    "botanical writers": "x",
    "bricklayers": "x",
    "brothel owners": "x",
    "bryologists": "x",
    "business theorists": "x",
    "cabinetmakers": "x",
    "candlepin bowling players": "x",
    "car collectors": "x",
    "carpenters": "x",
    "chairmeof corporations": "x",
    "chaplains": "x",
    "chess writers": "x",
    "chief technologists": "x",
    "chief technology officers": "x",
    "children's book illustrators": "x",
    "chiropractors": "x",
    "chroniclers": "x",
    "city founders": "x",
    "civil engineering contractors": "x",
    "clarinetists": "x",
    "classical clarinetists": "x",
    "classical organists": "x",
    "classical viola d'amore players": "x",
    "classical violists": "x",
    "comedy duos": "x",
    "congregationalist ministers": "x",
    "contract bridge players": "x",
    "cosmonauts": "x",
    "courtesans": "x",
    "craftspeople": "x",
    "duckpin bowling players": "x",
    "ecclesiastical architects": "x",
    "electricians": "x",
    "engineering academics": "x",
    "erotic dancers": "x",
    "erotic photographers": "x",
    "eskrimadors": "x",
    "exercise instructors": "x",
    "financial analysts": "x",
    "five-pin bowling players": "x",
    "folk harpists": "x",
    "folk-song collectors": "x",
    "foreign policy writers": "x",
    "foresters": "x",
    "game show hosts": "x",
    "gangsters": "x",
    "garden writers": "x",
    "genealogists": "x",
    "general practitioners": "x",
    "geochemists": "x",
    "geomorphologists": "x",
    "hammered dulcimer players": "x",
    "harmonicists": "x",
    "harpists": "x",
    "harpsichordists": "x",
    "hedge fund managers": "x",
    "hokkien pop singers": "x",
    "ian dissidents": "x",
    "indologists": "x",
    "infotainers": "x",
    "innovators": "x",
    "investment bankers": "x",
    "jazz accordionists": "x",
    "jazz clarinetists": "x",
    "jazz double-bassists": "x",
    "jazz horn players": "x",
    "jazz tubists": "x",
    "jazz upright-bassists": "x",
    "jazz vibraphonists": "x",
    "jewellers": "x",
    "labor unionists": "x",
    "ladies-in-waiting": "x",
    "latinists": "x",
    "latter day saint writers": "x",
    "letter writers": "x",
    "lichenologists": "x",
    "limnologists": "x",
    "lobbyists": "x",
    "magazine people": "x",
    "magistrates": "x",
    "mandolin players": "x",
    "materials scientists": "x",
    "media personalities": "x",
    "media scholars": "x",
    "medical administrators": "x",
    "mesoamerican": "x",
    "metallurgists": "x",
    "mezzo-sopranos": "x",
    "military chaplains": "x",
    "missionarys": "x",
    "mobsters": "x",
    "museologists": "x",
    "musical instrument makers": "x",
    "musical theatre lyricists": "x",
    "musical theatre": "x",
    "mycologists": "x",
    "naïve painters": "x",
    "netballers": "x",
    "nine-pin bowling players": "x",
    "numismatists": "x",
    "nurserymen": "x",
    "nursing administrators": "x",
    "occult writers": "x",
    "operatic basses": "x",
    "operatic mezzo-sopranos": "x",
    "operatic sopranos": "x",
    "optometrists": "x",
    "orchardists": "x",
    "orienteers": "x",
    "orthodox rabbis": "x",
    "oud players": "x",
    "outlaws": "x",
    "palaeographers": "x",
    "palaeontologists": "x",
    "paleoanthropologists": "x",
    "paleogeographers": "x",
    "papyrologists": "x",
    "paraglider pilots": "x",
    "pastoralists": "x",
    "people irail transport": "x",
    "philatelists": "x",
    "phytopathologists": "x",
    "pipe organ builders": "x",
    "planktologists": "x",
    "plumbers": "x",
    "podcasters": "x",
    "police chiefs": "x",
    "pool players": "x",
    "prosecutors": "x",
    "psychologists": "x",
    "public relations people": "x",
    "public servants": "x",
    "punk rock groups": "x",
    "ranchers": "x",
    "rapists": "x",
    "reporters and correspondents": "x",
    "roboticists": "x",
    "roman catholic clergy": "x",
    "self-help writers": "x",
    "semioticians": "x",
    "sex offenders": "x",
    "sex workers": "x",
    "shamans": "x",
    "silent actors": "x",
    "silversmiths": "x",
    "social commentators": "x",
    "song collectors": "x",
    "speleologists": "x",
    "spiritual mediums": "x",
    "spree killers": "x",
    "stained glass artists and manufacturers": "x",
    "stockbrokers": "x",
    "stonemasons": "x",
    "storytellers": "x",
    "stunt performers": "x",
    "suffragists": "x",
    "talent agents": "x",
    "telenovela actors": "x",
    "television evangelists": "x",
    "temperance activists": "x",
    "ten-pibowling players": "x",
    "ten-pin bowling players": "x",
    "tenors": "x",
    "textbook writers": "x",
    "theatre architects": "x",
    "theatre critics": "x",
    "tin whistle players": "x",
    "topographers": "x",
    "uilleann pipers": "x",
    "vedettes": "x",
    "veterinary scientists": "x",
    "vibraphonists": "x",
    "viola d'amore players": "x",
    "violists": "x",
    "watchmakers (people)": "x",
    "web series actresses": "x",
    "wicket-keeper": "x",
    "wicket-keepers": "x",
    "writers on paranormal topics": "x",
}


TEMPORAL_CASES = [
    ("test_Jobs_22_empty", data1),
]


@pytest.mark.parametrize("name,data", TEMPORAL_CASES)
@pytest.mark.skip2
def test_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
