#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {
    "Category:Persecution of LGBT people": "تصنيف:اضطهاد الأشخاص المثليين",
    "Category:Persecution of LGBTQ people": "تصنيف:اضطهاد الأشخاص المثليين",
    "Category:1990s LGBTQ-related sitcoms": "تصنيف:مسلسلات تلفزيونية كوميدية أمريكية متعلقة بإل جي بي تي كيو في عقد 1990",
    "Category:Icelandic LGBTQ-related films": "تصنيف:أفلام آيسلندية متعلقة بإلمثليين والمثليات ومزدوجي التوجه الجنسي والمتحولين جنسيا",
    "Category:Irish LGBTQ-related films": "تصنيف:أفلام أيرلندية متعلقة بإل جي بي تي كيو",
    "Category:LGBTQ-related buddy films": "تصنيف:أفلام متعلقة بإل جي بي تي كيو رفقاء",
    "Category:LGBTQ-related films by genre": "تصنيف:أفلام متعلقة بإل جي بي تي كيو حسب النوع الفني",
    "Category:LGBTQ-related horror films": "تصنيف:أفلام متعلقة بإل جي بي تي كيو رعب",
    "Category:LGBTQ-related mass media by country": "تصنيف:وسائل إعلام حسب البلد مرتبطة بإل جي بي تي كيو",
    "Category:LGBTQ-related mass media in Denmark": "تصنيف:وسائل إعلام في الدنمارك مرتبطة بإل جي بي تي كيو",
    "Category:LGBTQ-related mass media in Europe": "تصنيف:وسائل إعلام في أوروبا مرتبطة بإل جي بي تي كيو",
    "Category:LGBTQ-related mass media in Ireland": "تصنيف:وسائل إعلام في أيرلندا مرتبطة بإل جي بي تي كيو",
    "Category:LGBTQ-related radio stations": "تصنيف:محطات إذاعية مرتبطة بإل جي بي تي كيو",
    "Category:LGBTQ-related sitcoms by decade": "تصنيف:مسلسلات تلفزيونية كوميدية أمريكية متعلقة بإل جي بي تي كيو حسب العقد",
    "Category:LGBTQ-related sitcoms": "تصنيف:مسلسلات تلفزيونية كوميدية متعلقة بإل جي بي تي كيو",
    "Category:LGBTQ-related sports films": "تصنيف:أفلام متعلقة بإل جي بي تي كيو رياضية",
    "Category:Luxembourgian LGBTQ-related films": "تصنيف:أفلام لوكسمبورغية متعلقة بإل جي بي تي كيو",
    "Category:1988 executions of Iranian political prisoners": "تصنيف:إعدامات مسجونون سياسيون إيرانيون 1988",
    "Category:10th century in East Francia": "تصنيف:مملكة الفرنجة الشرقيين في القرن 10",
    "Category:10th century in West Francia": "تصنيف:مملكة الفرنجة الغربيين في القرن 10",
    "Category:10th-century kings of West Francia": "تصنيف:ملوك مملكة الفرنجة الغربيين القرن 10",
    "Category:10th-century people from West Francia": "تصنيف:أشخاص من مملكة الفرنجة الغربيين في القرن 10",
    "Category:13th-century wives of Ottoman sultans": "تصنيف:زوجات سلاطين عثمانيين في القرن 13",
    "Category:14th-century consorts of Ottoman sultans": "تصنيف:زوجات سلاطين عثمانيين في القرن 14",
    "Category:17th-century wives of Ottoman sultans": "تصنيف:زوجات سلاطين عثمانيين في القرن 17",
    "Category:18th-century Native American people": "تصنيف:السكان الأصليين في الولايات المتحدة في القرن 18",
    "Category:18th-century Native Americans": "تصنيف:القرن 18 السكان الأصليين في الولايات المتحدة",
    "Category:18th-century wives of Ottoman sultans": "تصنيف:زوجات سلاطين عثمانيين في القرن 18",
    "Category:1948 Palestinian exodus": "تصنيف:تهجير الفلسطينيين 1948",
    "Category:1948 Palestinian expulsion and flight": "تصنيف:تهجير الفلسطينيين 1948",
    "Category:19th-century wives of Ottoman sultans": "تصنيف:زوجات سلاطين عثمانيين في القرن 19",
    "Category:2009 African Nations Championship": "تصنيف:بطولة أمم إفريقيا للمحليين 2009",
    "Category:2009 African Nations Championship players": "تصنيف:لاعبو بطولة أمم إفريقيا للمحليين 2009",
    "Category:2011 African Nations Championship": "تصنيف:بطولة أمم إفريقيا للمحليين 2011",
    "Category:2011 African Nations Championship players": "تصنيف:لاعبو بطولة أمم إفريقيا للمحليين 2011",
    "Category:2014 African Nations Championship players": "تصنيف:لاعبو كأس الأمم الإفريقية للمحليين 2014",
    "Category:2016 African Nations Championship": "تصنيف:بطولة أمم إفريقيا للمحليين 2016",
    "Category:2016 African Nations Championship players": "تصنيف:لاعبو بطولة أمم إفريقيا للمحليين 2016",
    "Category:2018 African Nations Championship": "تصنيف:بطولة أمم إفريقيا للمحليين 2018",
    "Category:2018 African Nations Championship players": "تصنيف:لاعبو بطولة أمم إفريقيا للمحليين 2018",
    "Category:2020 African Nations Championship": "تصنيف:بطولة أمم إفريقيا للمحليين 2020",
    "Category:2020 African Nations Championship players": "تصنيف:لاعبو بطولة أمم إفريقيا للمحليين 2020",
    "Category:2022 African Nations Championship": "تصنيف:بطولة أمم إفريقيا للمحليين 2022",
    "Category:2022 African Nations Championship players": "تصنيف:لاعبو بطولة أمم إفريقيا للمحليين 2022",
    "Category:2024 African Nations Championship": "تصنيف:بطولة أمم إفريقيا للمحليين 2024",
    "Category:2024 pro-Palestinian protests on university campuses": "تصنيف:احتجاجات مؤيدة للفلسطينيين في الجامعات 2024",
    "Category:20th-century Asian male musicians": "تصنيف:موسيقيون ذكور آسيويين في القرن 20",
    "Category:20th-century assassinated Asian politicians": "تصنيف:سياسيون آسيويين مغتالون في القرن 20",
    "Category:20th-century venerated Christians": "تصنيف:تبجيل المسيحيين في القرن العشرين",
    "Category:20th-century wives of Ottoman sultans": "تصنيف:زوجات سلاطين عثمانيين في القرن 20",
    "Category:2nd millennium assassinated Asian politicians": "تصنيف:سياسيون آسيويين مغتالون في الألفية 2",
    "Category:9th century in East Francia": "تصنيف:مملكة الفرنجة الشرقيين في القرن 9",
    "Category:9th century in West Francia": "تصنيف:مملكة الفرنجة الغربيين في القرن 9",
    "Category:9th-century kings of West Francia": "تصنيف:ملوك مملكة الفرنجة الغربيين القرن 9",
    "Category:9th-century people from East Francia": "تصنيف:أشخاص من مملكة الفرنجة الشرقيين في القرن 9",
    "Category:9th-century people from West Francia": "تصنيف:أشخاص من مملكة الفرنجة الغربيين في القرن 9",
    "Category:Abbasid qahramana": "تصنيف:قهرمانات الخلفاء العباسيين",
    "Category:Aboriginal title": "تصنيف:أراضي السكان الأصليين",
    "Category:Aboriginal title in Canada": "تصنيف:أراضي السكان الأصليين في كندا",
    "Category:Academic staff of the University of al-Qarawiyyin": "تصنيف:أعضاء هيئة تدريس جامعة القرويين",
    "Category:Academy of Canadian Cinema & Television": "تصنيف:أكاديمية السينما والتلفاز الكنديين",
    "Category:Action films about Asian Americans": "تصنيف:أفلام حركة عن أمريكيون آسيويين",
    "Category:Active politicians": "تصنيف:سياسيين نشطين",
    "Category:Activists for Hispanic and Latino American civil rights": "تصنيف:ناشطو حقوق الأمريكيين اللاتينيين والهسبانيين",
    "Category:Advanced Placement": "تصنيف:برنامج التعيين المتقدم",
    "Category:African American-related lists": "تصنيف:قوائم متعلقة بالأمريكيين الأفارقة",
    "Category:African Americans' rights organizations": "تصنيف:منظمات حقوق الأمركيين الأفارقة",
    "Category:African Nations Championship": "تصنيف:كأس الأمم الإفريقية للمحليين",
    "Category:African Nations Championship finals": "تصنيف:نهائيات بطولة أمم إفريقيا للمحليين",
    "Category:African Nations Championship navigational boxes": "تصنيف:صناديق تصفح بطولة أمم إفريقيا للمحليين",
    "Category:African Nations Championship players": "تصنيف:لاعبو كأس الأمم الإفريقية للمحليين",
    "Category:African Nations Championship qualification": "تصنيف:تصفيات بطولة أمم إفريقيا للمحليين",
    "Category:African-American films": "تصنيف:أفلام عن الأمريكيين الأفارقة",
    "Category:African-American history by city": "تصنيف:تاريخ الأمريكيين الأفارقة حسب المدينة",
    "Category:African-American history by location": "تصنيف:تاريخ الأمريكيين الأفارقة حسب الموقع",
    "Category:African-American history by state": "تصنيف:تاريخ الأمريكيين الأفارقة حسب الولاية",
    "Category:African-American history by state or territory": "تصنيف:تاريخ الأمريكيين الأفارقة حسب الولاية",
    "Category:African-American history in Baltimore": "تصنيف:تاريخ الأمريكيين الأفارقة في بالتيمور (ماريلند)",
    "Category:African-American history of Maryland": "تصنيف:تاريخ الأمريكيين الأفارقة في ماريلند",
    "Category:Agronomists": "تصنيف:مهندسين زراعيين",
    "Category:Albanian football biography stubs": "تصنيف:بذرة أعلام كرة قدم ألبانيين",
    "Category:Albums by Kuwaiti artists by genre": "تصنيف:ألبومات فنانين كويتيين حسب النوع الفني",
    "Category:Albums by South Korean artists by genre": "تصنيف:ألبومات فنانين كوريين جنوبيين حسب النوع الفني",
    "Category:Algeria men's A' international footballers": "تصنيف:لاعبو منتخب الجزائر لكرة القدم للمحليين",
    "Category:Algerian football biography stubs": "تصنيف:بذرة أعلام كرة قدم جزائريين",
    "Category:All Progressives Congress": "تصنيف:مؤتمر الجميع التقدميين النيجيري",
    "Category:Alliance of European Conservatives and Reformists": "تصنيف:تحالف المصلحين والمحافظين الأوروبيين",
    "Category:Alliance of Independent Social Democrats politicians": "تصنيف:تحالف السياسيين الاشتراكيين الديمقراطيين المستقلين",
    "Category:Alternative rock albums by Canadian artists": "تصنيف:ألبومات روك بديل لفنانين كنديين",
    "Category:Ambient albums by French artists": "تصنيف:ألبومات أمبينت لفنانين فرنسيين",
    "Category:American Indian reservations": "تصنيف:محميات السكان الأصليين الأمريكية",
    "Category:American Indian reservations by state": "تصنيف:محميات السكان الأصليين الأمريكية حسب الولاية",
    "Category:American Indian reservations in Alaska": "تصنيف:محميات السكان الأصليين الأمريكية في ألاسكا",
    "Category:American Indian reservations in Arizona": "تصنيف:محميات السكان الأصليين الأمريكية في أريزونا",
    "Category:American Indian reservations in Colorado": "تصنيف:محميات السكان الأصليين الأمريكية في كولورادو",
    "Category:American Indian reservations in Massachusetts": "تصنيف:محميات السكان الأصليين الأمريكية في ماساتشوستس",
    "Category:American Indian reservations in Michigan": "تصنيف:محميات السكان الأصليين الأمريكية في ميشيغان",
    "Category:American Indian reservations in Minnesota": "تصنيف:محميات السكان الأصليين الأمريكية في منيسوتا",
    "Category:American Indian reservations in Montana": "تصنيف:محميات السكان الأصليين الأمريكية في مونتانا",
    "Category:American Indian reservations in New Mexico": "تصنيف:محميات السكان الأصليين الأمريكية في نيومكسيكو",
    "Category:American Indian reservations in New York (state)": "تصنيف:محميات السكان الأصليين الأمريكية في ولاية نيويورك",
    "Category:American Indian reservations in North Dakota": "تصنيف:محميات السكان الأصليين الأمريكية في داكوتا الشمالية",
    "Category:American Indian reservations in Oklahoma": "تصنيف:محميات السكان الأصليين الأمريكية في أوكلاهوما",
    "Category:American Indian reservations in South Dakota": "تصنيف:محميات السكان الأصليين الأمريكية في داكوتا الجنوبية",
    "Category:American Indian reservations in Utah": "تصنيف:محميات السكان الأصليين الأمريكية في يوتا",
    "Category:American Indian reservations in Washington (state)": "تصنيف:محميات السكان الأصليين الأمريكية في ولاية واشنطن",
    "Category:American Indian reservations in Wisconsin": "تصنيف:محميات السكان الأصليين الأمريكية في ويسكونسن",
    "Category:American Indian reservations in Wyoming": "تصنيف:محميات السكان الأصليين الأمريكية في وايومنغ",
    "Category:American Institute of Architects": "تصنيف:الجمعية الأمريكية للمعماريين",
    "Category:American Institute of Chemical Engineers": "تصنيف:المعهد الأمريكي للمهندسين الكيميائيين",
    "Category:American Psychiatric Association": "تصنيف:الجمعية الأمريكية للأطباء النفسيين",
    "Category:American Society of Cinematographers": "تصنيف:الجمعية الأمريكية للمصورين السينمائيين",
    "Category:American Society of Civil Engineers": "تصنيف:الجمعية الأمريكية للمهندسين المدنيين",
    "Category:American artist groups and collectives": "تصنيف:مجموعات الفنانين الأمريكيين",
    "Category:American aviators of Asian descent": "تصنيف:طيارون أمريكيون آسيويين",
    "Category:American confidence tricksters": "تصنيف:أكبر المحتالين الأمريكيين",
    "Category:American feminists of Asian descent": "تصنيف:نسويون أمريكيون آسيويين",
    "Category:American film directors of Asian descent": "تصنيف:مخرجو أفلام أمريكيون آسيويين",
    "Category:American players of American football of Asian descent": "تصنيف:لاعبو أمريكيون آسيويين في كرة القدم الأمريكية",
    "Category:American soccer biography stubs": "تصنيف:بذرة أعلام كرة قدم أمريكيين",
    "Category:American tennis players of Asian descent": "تصنيف:لاعبو كرة مضرب أمريكيون آسيويين",
    "Category:American trade unionists of Asian descent": "تصنيف:نقابيون أمريكيون آسيويين",
    "Category:American victims of anti-LGBT hate crimes": "تصنيف:ضحايا جرائم أمريكيون بسبب الكراهية ضد المثليين",
    "Category:American victims of anti-LGBTQ hate crimes": "تصنيف:ضحايا جرائم أمريكيون بسبب الكراهية ضد المثليين",
    "Category:American writer navigational boxes": "تصنيف:صناديق تصفح كتاب أمريكيين",
    "Category:Amiens SC": "تصنيف:نادي أميين",
    "Category:Amiens SC managers": "تصنيف:مدربو نادي أميين",
    "Category:Amiens SC non-playing staff": "تصنيف:طاقم نادي أميين غير اللاعبين",
    "Category:Amiens SC players": "تصنيف:لاعبو أميين",
    "Category:Ancient Asian people": "تصنيف:آسيويين قدماء",
    "Category:Ancient Asian people by country": "تصنيف:آسيويين قدماء حسب البلد",
    "Category:Ancient Egyptians": "تصنيف:قدماء المصريين",
    "Category:Ancient Greek plays by writer": "تصنيف:مسرحيات يونانيين قدماء حسب الكاتب",
    "Category:Angola men's A' international footballers": "تصنيف:لاعبو منتخب أنغولا لكرة القدم للرجال للمحليين",
    "Category:Angolan football biography stubs": "تصنيف:بذرة أعلام كرة قدم أنجوليين",
    "Category:Animated films about music and musicians": "تصنيف:أفلام رسوم متحركة عن الموسيقى والموسيقيين",
    "Category:Anti-American sentiment by country": "تصنيف:مشاعر معادية للأمريكيين حسب البلد",
    "Category:Anti-American sentiment in Africa": "تصنيف:مشاعر معادية للأمريكيين في إفريقيا",
    "Category:Anti-American sentiment in Asia": "تصنيف:مشاعر معادية للأمريكيين في آسيا",
    "Category:Anti-American sentiment in China": "تصنيف:مشاعر معادية للأمريكيين في الصين",
    "Category:Anti-American sentiment in Europe": "تصنيف:مشاعر معادية للأمريكيين في أوروبا",
    "Category:Anti-American sentiment in Germany": "تصنيف:مشاعر معادية للأمريكيين في ألمانيا",
    "Category:Anti-American sentiment in Iran": "تصنيف:مشاعر معادية للأمريكيين في إيران",
    "Category:Anti-American sentiment in Japan": "تصنيف:مشاعر معادية للأمريكيين في اليابان",
    "Category:Anti-American sentiment in Korea": "تصنيف:مشاعر معادية للأمريكيين في كوريا",
    "Category:Anti-American sentiment in North America": "تصنيف:مشاعر معادية للأمريكيين في أمريكا الشمالية",
    "Category:Anti-American sentiment in North Korea": "تصنيف:مشاعر معادية للأمريكيين في كوريا الشمالية",
    "Category:Anti-American sentiment in Russia": "تصنيف:مشاعر معادية للأمريكيين في روسيا",
    "Category:Anti-American sentiment in South America": "تصنيف:مشاعر معادية للأمريكيين في أمريكا الجنوبية",
    "Category:Anti-American sentiment in South Korea": "تصنيف:مشاعر معادية للأمريكيين في كوريا الجنوبية",
    "Category:Anti-American sentiment in Turkey": "تصنيف:مشاعر معادية للأمريكيين في تركيا",
    "Category:Anti-American sentiment in the Middle East": "تصنيف:مشاعر معادية للأمريكيين في الشرق الأوسط",
    "Category:Anti-American sentiment in the United States": "تصنيف:مشاعر معادية للأمريكيين في الولايات المتحدة",
    "Category:Anti-Americanism": "تصنيف:معاداة الأمريكيين",
    "Category:Anti-Asian sentiment": "تصنيف:مشاعر معادية لآسيويين",
    "Category:Anti-Asian sentiment by continent": "تصنيف:مشاعر معادية للآسيويين حسب القارة",
    "Category:Anti-Asian sentiment in Australia": "تصنيف:مشاعر معادية للآسيويين في أستراليا",
    "Category:Anti-Asian sentiment in Canada": "تصنيف:مشاعر معادية للآسيويين في كندا",
    "Category:Anti-Asian sentiment in Europe": "تصنيف:مشاعر معادية للآسيويين في أوروبا",
    "Category:Anti-Asian sentiment in North America": "تصنيف:مشاعر معادية للآسيويين في أمريكا الشمالية",
    "Category:Anti-Asian sentiment in Oceania": "تصنيف:مشاعر معادية للآسيويين في أوقيانوسيا",
    "Category:Anti-Asian sentiment in Russia": "تصنيف:مشاعر معادية للآسيويين في روسيا",
    "Category:Anti-Asian sentiment in the United States": "تصنيف:مشاعر معادية للآسيويين في الولايات المتحدة",
    "Category:Anti-Australian sentiment": "تصنيف:مشاعر معادية للأستراليين",
    "Category:Anti-Azerbaijanism": "تصنيف:معاداة الأذربيجانيين",
    "Category:Anti-Belarusian sentiment": "تصنيف:مشاعر معادية للبيلاروسيين",
    "Category:Anti-Bulgarian sentiment": "تصنيف:مشاعر معادية للبلغاريين",
    "Category:Anti-Canadian sentiment": "تصنيف:مشاعر معادية للكنديين",
    "Category:Anti-Caucasus sentiment": "تصنيف:مشاعر معادية للقوقازيين",
    "Category:Anti-Caucasus sentiment in Russia": "تصنيف:مشاعر معادية للقوقازيين في روسيا",
    "Category:Anti-Chechen sentiment": "تصنيف:مشاعر معادية للشيشانيين",
    "Category:Anti-Chilean sentiment": "تصنيف:مشاعر معادية للتشيليين",
    "Category:Anti-Chinese sentiment by continent": "تصنيف:مشاعر معادية للصينيين حسب القارة",
    "Category:Anti-Chinese sentiment by country": "تصنيف:مشاعر معادية للصينيين حسب البلد",
    "Category:Anti-Chinese sentiment in Asia": "تصنيف:مشاعر معادية للصينيين في آسيا",
    "Category:Anti-Chinese sentiment in Australia": "تصنيف:مشاعر معادية للصينيين في أستراليا",
    "Category:Anti-Chinese sentiment in Canada": "تصنيف:مشاعر معادية للصينيين في كندا",
    "Category:Anti-Chinese sentiment in China": "تصنيف:مشاعر معادية للصينيين في الصين",
    "Category:Anti-Chinese sentiment in Indonesia": "تصنيف:مشاعر معادية للصينيين في إندونيسيا",
    "Category:Anti-Chinese sentiment in Japan": "تصنيف:مشاعر معادية للصينيين في اليابان",
    "Category:Anti-Chinese sentiment in Korea": "تصنيف:مشاعر معادية للصينيين في كوريا",
    "Category:Anti-Chinese sentiment in Mexico": "تصنيف:مشاعر معادية للصينيين في المكسيك",
    "Category:Anti-Chinese sentiment in North America": "تصنيف:مشاعر معادية للصينيين في أمريكا الشمالية",
    "Category:Anti-Chinese sentiment in Oceania": "تصنيف:مشاعر معادية للصينيين في أوقيانوسيا",
    "Category:Anti-Chinese sentiment in Pakistan": "تصنيف:مشاعر معادية للصينيين في باكستان",
    "Category:Anti-Chinese sentiment in South Korea": "تصنيف:مشاعر معادية للصينيين في كوريا الجنوبية",
    "Category:Anti-Chinese sentiment in the United States": "تصنيف:مشاعر معادية للصينيين في الولايات المتحدة",
    "Category:Anti-Christian sentiment by continent": "تصنيف:مشاعر معادية للمسيحيين حسب القارة",
    "Category:Anti-Christian sentiment in Afghanistan": "تصنيف:مشاعر معادية للمسيحيين في أفغانستان",
    "Category:Anti-Christian sentiment in Africa": "تصنيف:مشاعر معادية للمسيحيين في إفريقيا",
    "Category:Anti-Christian sentiment in Albania": "تصنيف:مشاعر معادية للمسيحيين في ألبانيا",
    "Category:Anti-Christian sentiment in Bulgaria": "تصنيف:مشاعر معادية للمسيحيين في بلغاريا",
    "Category:Anti-Christian sentiment in Cambodia": "تصنيف:مشاعر معادية للمسيحيين في كمبوديا",
    "Category:Anti-Christian sentiment in Canada": "تصنيف:مشاعر معادية للمسيحيين في كندا",
    "Category:Anti-Christian sentiment in China": "تصنيف:مشاعر معادية للمسيحيين في الصين",
    "Category:Anti-Christian sentiment in France": "تصنيف:مشاعر معادية للمسيحيين في فرنسا",
    "Category:Anti-Christian sentiment in Germany": "تصنيف:مشاعر معادية للمسيحيين في ألمانيا",
    "Category:Anti-Christian sentiment in Greece": "تصنيف:مشاعر معادية للمسيحيين في اليونان",
    "Category:Anti-Christian sentiment in India": "تصنيف:مشاعر معادية للمسيحيين في الهند",
    "Category:Anti-Christian sentiment in Indonesia": "تصنيف:مشاعر معادية للمسيحيين في إندونيسيا",
    "Category:Anti-Christian sentiment in Iran": "تصنيف:مشاعر معادية للمسيحيين في إيران",
    "Category:Anti-Christian sentiment in Iraq": "تصنيف:مشاعر معادية للمسيحيين في العراق",
    "Category:Anti-Christian sentiment in Israel": "تصنيف:مشاعر معادية للمسيحيين في إسرائيل",
    "Category:Anti-Christian sentiment in Italy": "تصنيف:مشاعر معادية للمسيحيين في إيطاليا",
    "Category:Anti-Christian sentiment in Japan": "تصنيف:مشاعر معادية للمسيحيين في اليابان",
    "Category:Anti-Christian sentiment in Lebanon": "تصنيف:مشاعر معادية للمسيحيين في لبنان",
    "Category:Anti-Christian sentiment in Malaysia": "تصنيف:مشاعر معادية للمسيحيين في ماليزيا",
    "Category:Anti-Christian sentiment in North America": "تصنيف:مشاعر معادية للمسيحيين في أمريكا الشمالية",
    "Category:Anti-Christian sentiment in Norway": "تصنيف:مشاعر معادية للمسيحيين في النرويج",
    "Category:Anti-Christian sentiment in Oceania": "تصنيف:مشاعر معادية للمسيحيين في أوقيانوسيا",
    "Category:Anti-Christian sentiment in Pakistan": "تصنيف:مشاعر معادية للمسيحيين في باكستان",
    "Category:Anti-Christian sentiment in Poland": "تصنيف:مشاعر معادية للمسيحيين في بولندا",
    "Category:Anti-Christian sentiment in Russia": "تصنيف:مشاعر معادية للمسيحيين في روسيا",
    "Category:Anti-Christian sentiment in Saudi Arabia": "تصنيف:مشاعر معادية للمسيحيين في السعودية",
    "Category:Anti-Christian sentiment in Spain": "تصنيف:مشاعر معادية للمسيحيين في إسبانيا",
    "Category:Anti-Christian sentiment in Sri Lanka": "تصنيف:مشاعر معادية للمسيحيين في سريلانكا",
    "Category:Anti-Christian sentiment in Sweden": "تصنيف:مشاعر معادية للمسيحيين في السويد",
    "Category:Anti-Christian sentiment in Syria": "تصنيف:مشاعر معادية للمسيحيين في سوريا",
    "Category:Anti-Christian sentiment in Turkey": "تصنيف:مشاعر معادية للمسيحيين في تركيا",
    "Category:Anti-Christian sentiment in Ukraine": "تصنيف:مشاعر معادية للمسيحيين في أوكرانيا",
    "Category:Anti-Christian sentiment in the Philippines": "تصنيف:مشاعر معادية للمسيحيين في الفلبين",
    "Category:Anti-Christian sentiment in the United Kingdom": "تصنيف:مشاعر معادية للمسيحيين في المملكة المتحدة",
    "Category:Anti-Czech sentiment": "تصنيف:مشاعر معادية للتشيكيين",
    "Category:Anti-Danish sentiment": "تصنيف:مشاعر معادية للدنماركيين",
    "Category:Anti-Dutch sentiment": "تصنيف:مشاعر معادية للهولنديين",
    "Category:Anti-Estonian sentiment": "تصنيف:مشاعر معادية للإستونيين",
    "Category:Anti-Ethiopian sentiment": "تصنيف:مشاعر معادية للإثيوبيين",
    "Category:Anti-European sentiment": "تصنيف:مشاعر معادية للأوروبيين",
    "Category:Anti-Filipino sentiment": "تصنيف:مشاعر معادية للفلبينيين",
    "Category:Anti-Finnish sentiment": "تصنيف:مشاعر معادية للفنلنديين",
    "Category:Anti-Georgian sentiment": "تصنيف:مشاعر معادية للجورجيين",
    "Category:Anti-Greek sentiment": "تصنيف:مشاعر معادية لليونانيين",
    "Category:Anti-Haitian sentiment": "تصنيف:مشاعر معادية للهايتيين",
    "Category:Anti-Iranian sentiments": "تصنيف:مشاعر معادية للإيرانيين",
    "Category:Anti-Irish sentiment": "تصنيف:مشاعر معادية للأيرلنديين",
    "Category:Anti-Israeli sentiment": "تصنيف:مشاعر معادية للإسرائيليين",
    "Category:Anti-Israeli sentiment by country": "تصنيف:مشاعر معادية للإسرائيليين حسب البلد",
    "Category:Anti-Israeli sentiment in Afghanistan": "تصنيف:مشاعر معادية للإسرائيليين في أفغانستان",
    "Category:Anti-Israeli sentiment in Africa": "تصنيف:مشاعر معادية للإسرائيليين في إفريقيا",
    "Category:Anti-Israeli sentiment in Asia": "تصنيف:مشاعر معادية للإسرائيليين في آسيا",
    "Category:Anti-Israeli sentiment in Egypt": "تصنيف:مشاعر معادية للإسرائيليين في مصر",
    "Category:Anti-Israeli sentiment in Europe": "تصنيف:مشاعر معادية للإسرائيليين في أوروبا",
    "Category:Anti-Israeli sentiment in Iran": "تصنيف:مشاعر معادية للإسرائيليين في إيران",
    "Category:Anti-Israeli sentiment in Iraq": "تصنيف:مشاعر معادية للإسرائيليين في العراق",
    "Category:Anti-Israeli sentiment in Israel": "تصنيف:مشاعر معادية للإسرائيليين في إسرائيل",
    "Category:Anti-Israeli sentiment in Lebanon": "تصنيف:مشاعر معادية للإسرائيليين في لبنان",
    "Category:Anti-Israeli sentiment in Libya": "تصنيف:مشاعر معادية للإسرائيليين في ليبيا",
    "Category:Anti-Israeli sentiment in North America": "تصنيف:مشاعر معادية للإسرائيليين في أمريكا الشمالية",
    "Category:Anti-Israeli sentiment in Palestine": "تصنيف:مشاعر معادية للإسرائيليين في فلسطين",
    "Category:Anti-Israeli sentiment in South America": "تصنيف:مشاعر معادية للإسرائيليين في أمريكا الجنوبية",
    "Category:Anti-Israeli sentiment in Syria": "تصنيف:مشاعر معادية للإسرائيليين في سوريا",
    "Category:Anti-Israeli sentiment in Yemen": "تصنيف:مشاعر معادية للإسرائيليين في اليمن",
    "Category:Anti-Israeli sentiment in the United States": "تصنيف:مشاعر معادية للإسرائيليين في الولايات المتحدة",
    "Category:Anti-Italian sentiment": "تصنيف:مشاعر معادية للإيطاليين",
    "Category:Anti-Japanese sentiment in Korea": "تصنيف:تمييز ضد اليابانيين في كوريا",
    "Category:Anti-Japanese sentiment in North Korea": "تصنيف:مشاعر معادية لليابانيين في كوريا الشمالية",
    "Category:Anti-Japanese sentiment in South Korea": "تصنيف:مشاعر معادية لليابانيين في كوريا الجنوبية",
    "Category:Anti-Japanese sentiment in Taiwan": "تصنيف:مشاعر معادية لليابانيين في تايوان",
    "Category:Anti-Japanese sentiment in the United States": "تصنيف:مشاعر معادية لليابانيين في الولايات المتحدة",
    "Category:Anti-Korean sentiment in Japan": "تصنيف:تمييز ضد الكوريين في اليابان",
    "Category:Anti-Korean sentiment in the United States": "تصنيف:مشاعر معادية للكوريين في الولايات المتحدة",
    "Category:Anti-Latvian sentiment": "تصنيف:مشاعر معادية لللاتفيين",
    "Category:Anti-Mexican sentiment": "تصنيف:مشاعر معادية للمكسيكيين",
    "Category:Anti-Mongolian sentiment": "تصنيف:مشاعر معادية للمنغوليين",
    "Category:Anti-Palestinian sentiment": "تصنيف:مشاعر معادية للفلسطينيين",
    "Category:Anti-Palestinian sentiment by country": "تصنيف:مشاعر معادية للفلسطينيين حسب البلد",
    "Category:Anti-Palestinian sentiment in Asia": "تصنيف:مشاعر معادية للفلسطينيين في آسيا",
    "Category:Anti-Palestinian sentiment in Germany": "تصنيف:مشاعر معادية للفلسطينيين في ألمانيا",
    "Category:Anti-Palestinian sentiment in Israel": "تصنيف:مشاعر معادية للفلسطينيين في إسرائيل",
    "Category:Anti-Palestinian sentiment in the Middle East": "تصنيف:مشاعر معادية للفلسطينيين في الشرق الأوسط",
    "Category:Anti-Palestinian sentiment in the United States": "تصنيف:مشاعر معادية للفلسطينيين في الولايات المتحدة",
    "Category:Anti-Polish sentiment in Europe": "تصنيف:مشاعر معادية للبولنديين في أوروبا",
    "Category:Anti-Portuguese sentiment": "تصنيف:مشاعر معادية للبرتغاليين",
    "Category:Anti-Scottish sentiment": "تصنيف:مشاعر معادية للإسكتلنديين",
    "Category:Anti-Slovene sentiment": "تصنيف:مشاعر معادية للسلوفينيين",
    "Category:Anti-Somali sentiment": "تصنيف:مشاعر معادية للصوماليين",
    "Category:Anti-Swedish sentiment": "تصنيف:مشاعر معادية للسويديين",
    "Category:Anti-Syrian sentiment": "تصنيف:مشاعر معادية للسوريين",
    "Category:Anti-Taiwanese sentiment": "تصنيف:مشاعر معادية للتايوانيين",
    "Category:Anti-Thai sentiment": "تصنيف:مشاعر معادية للتايلنديين",
    "Category:Anti-Ukrainian sentiment": "تصنيف:مشاعر معادية للأوكرانيين",
    "Category:Anti-Ukrainian sentiment in Europe": "تصنيف:مشاعر معادية للأوكرانيين في أوروبا",
    "Category:Anti-Ukrainian sentiment in Russia": "تصنيف:مشاعر معادية للأوكرانيين في روسيا",
    "Category:Anti-Ukrainian sentiment in Ukraine": "تصنيف:مشاعر معادية للأوكرانيين في أوكرانيا",
    "Category:Anti-Vietnamese sentiment": "تصنيف:مشاعر معادية للفيتناميين",
    "Category:Anti-indigenous racism": "تصنيف:تمييز عنصري ضد السكان الأصليين",
    "Category:Anti-same-sex-marriage activists": "تصنيف:ناشطون ضد زواج المثليين",
    "Category:Arab Nationalist Movement breakaway groups": "تصنيف:مجموعات حركة قوميين عرب انفصالية",
    "Category:Archbishops of Vienne": "تصنيف:رؤساء أساقفة من فيين (إقليم فرنسي)",
    "Category:Argentine football biography stubs": "تصنيف:بذرة أعلام كرة قدم أرجنتينيين",
    "Category:Arteries": "تصنيف:شرايين",
    "Category:Arteries of the abdomen": "تصنيف:شرايين البطن",
    "Category:Arteries of the head and neck": "تصنيف:شرايين الرأس والعنق",
    "Category:Arteries of the lower limb": "تصنيف:شرايين الطرف السفلي",
    "Category:Arteries of the thorax": "تصنيف:شرايين الصدر",
    "Category:Arteries of the torso": "تصنيف:شرايين الجذع",
    "Category:Arteries of the upper limb": "تصنيف:شرايين الطرف العلوي",
    "Category:Asian Australian": "تصنيف:أستراليون آسيويين",
    "Category:Asian Caribbean": "تصنيف:كاريبيون آسيويين",
    "Category:Asian Catholics": "تصنيف:كاثوليك آسيويين",
    "Category:Asian Central American": "تصنيف:أمريكيون أوسطيون آسيويين",
    "Category:Asian Go players": "تصنيف:لاعبو غو آسيويين",
    "Category:Asian Irish": "تصنيف:أيرلنديون آسيويين",
    "Category:Asian New Zealander": "تصنيف:نيوزيلنديون آسيويين",
    "Category:Asian Nigerian": "تصنيف:نيجيريون آسيويين",
    "Category:Asian anti-communists": "تصنيف:آسيويين مناهضون للشيوعية",
    "Category:Asian aviators": "تصنيف:طيارون آسيويين",
    "Category:Asian baseball coaches": "تصنيف:مدربو كرة قاعدة آسيويين",
    "Category:Asian biblical scholars": "تصنيف:علماء الكتاب المقدس آسيويين",
    "Category:Asian child actors": "تصنيف:ممثلون أطفال آسيويين",
    "Category:Asian cricket biography stubs": "تصنيف:بذرة عن سيرة لاعبي الكريكت الآسيويين",
    "Category:Asian diaspora in Ireland": "تصنيف:أيرلنديون آسيويين",
    "Category:Asian diaspora in New Zealand": "تصنيف:نيوزيلنديون آسيويين",
    "Category:Asian diaspora in Nigeria": "تصنيف:نيجيريون آسيويين",
    "Category:Asian diaspora in the Caribbean": "تصنيف:كاريبيون آسيويين",
    "Category:Asian diaspora in the United Kingdom": "تصنيف:آسيويين بريطانيون",
    "Category:Asian fascists": "تصنيف:فاشيون آسيويين",
    "Category:Asian film director navigational boxes": "تصنيف:صناديق تصفح مخرجي أفلام آسيويين",
    "Category:Asian football biography stubs": "تصنيف:بذرة أعلام كرة قدم آسيويين",
    "Category:Asian football champions": "تصنيف:أبطال كرة القدم آسيويين",
    "Category:Asian liberal politicians": "تصنيف:ليبراليون كلاسيكيون آسيويين",
    "Category:Asian musician navigational boxes": "تصنيف:قوالب موسيقيون آسيويين",
    "Category:Asian musicians templates": "تصنيف:قوالب موسيقيون آسيويين",
    "Category:Asian newspaper editors": "تصنيف:محررو صحف آسيويين",
    "Category:Asian pacifists": "تصنيف:دعاة سلام آسيويين",
    "Category:Asian people by ethnicity": "تصنيف:أعلام آسيويين حسب المجموعة العرقية",
    "Category:Asian people by nationality and occupation": "تصنيف:أعلام آسيويين حسب الجنسية والمهنة",
    "Category:Asian people of African-American descent": "تصنيف:آسيويين من أصل إفريقي أمريكي",
    "Category:Asian people of Albanian descent": "تصنيف:آسيويين من أصل ألباني",
    "Category:Asian people of American descent": "تصنيف:آسيويين من أصل أمريكي",
    "Category:Asian people of Angolan descent": "تصنيف:آسيويين من أصل أنغولي",
    "Category:Asian people of Argentine descent": "تصنيف:آسيويين من أصل أرجنتيني",
    "Category:Asian people of Austrian descent": "تصنيف:آسيويين من أصل نمساوي",
    "Category:Asian people of Barbadian descent": "تصنيف:آسيويين من أصل بربادوسي",
    "Category:Asian people of Belarusian descent": "تصنيف:آسيويين من أصل بيلاروسي",
    "Category:Asian people of Belgian descent": "تصنيف:آسيويين من أصل بلجيكي",
    "Category:Asian people of Beninese descent": "تصنيف:آسيويين من أصل بنيني",
    "Category:Asian people of Bolivian descent": "تصنيف:آسيويين من أصل بوليفي",
    "Category:Asian people of Bosnia and Herzegovina descent": "تصنيف:آسيويين من أصل بوسني",
    "Category:Asian people of Brazilian descent": "تصنيف:آسيويين من أصل برازيلي",
    "Category:Asian people of Cameroonian descent": "تصنيف:آسيويين من أصل كاميروني",
    "Category:Asian people of Canadian descent": "تصنيف:آسيويين من أصل كندي",
    "Category:Asian people of Chilean descent": "تصنيف:آسيويين من أصل تشيلي",
    "Category:Asian people of Colombian descent": "تصنيف:آسيويين من أصل كولومبي",
    "Category:Asian people of Croatian descent": "تصنيف:آسيويين من أصل كرواتي",
    "Category:Asian people of Danish descent": "تصنيف:آسيويين من أصل دنماركي",
    "Category:Asian people of Ecuadorian descent": "تصنيف:أعلام آسيويين من أصل إكوادوري",
    "Category:Asian people of English descent": "تصنيف:آسيويين من أصل إنجليزي",
    "Category:Asian people of Estonian descent": "تصنيف:آسيويين من أصل إستوني",
    "Category:Asian people of Ethiopian descent": "تصنيف:آسيويين من أصل إثيوبي",
    "Category:Asian people of European-Jewish descent": "تصنيف:آسيويين من أصل يهودي أوروبي",
    "Category:Asian people of Finnish descent": "تصنيف:آسيويين من أصل فنلندي",
    "Category:Asian people of Ghanaian descent": "تصنيف:آسيويين من أصل غاني",
    "Category:Asian people of Greek descent": "تصنيف:آسيويين من أصل يوناني",
    "Category:Asian people of Guinean descent": "تصنيف:آسيويين من أصل غيني",
    "Category:Asian people of Hungarian descent": "تصنيف:آسيويين من أصل مجري",
    "Category:Asian people of Icelandic descent": "تصنيف:آسيويين من أصل آيسلندي",
    "Category:Asian people of Kazakhstani descent": "تصنيف:آسيويين من أصل كازاخستاني",
    "Category:Asian people of Kenyan descent": "تصنيف:آسيويين من أصل كيني",
    "Category:Asian people of Liberian descent": "تصنيف:آسيويين من أصل ليبيري",
    "Category:Asian people of Lithuanian descent": "تصنيف:آسيويين من أصل ليتواني",
    "Category:Asian people of Macedonian descent": "تصنيف:أعلام آسيويين من أصل مقدوني",
    "Category:Asian people of Malian descent": "تصنيف:آسيويين من أصل مالي",
    "Category:Asian people of Moldovan descent": "تصنيف:أعلام آسيويين من أصل مولدوفي",
    "Category:Asian people of Montenegrin descent": "تصنيف:آسيويين من أصل مونتينيغري",
    "Category:Asian people of Nigerian descent": "تصنيف:آسيويين من أصل نيجيري",
    "Category:Asian people of Norwegian descent": "تصنيف:آسيويين من أصل نرويجي",
    "Category:Asian people of Peruvian descent": "تصنيف:أعلام آسيويين من أصل بيروي",
    "Category:Asian people of Polish descent": "تصنيف:آسيويين من أصل بولندي",
    "Category:Asian people of Romanian descent": "تصنيف:آسيويين من أصل روماني",
    "Category:Asian people of Scottish descent": "تصنيف:آسيويين من أصل إسكتلندي",
    "Category:Asian people of Slovenian descent": "تصنيف:آسيويين من أصل سلوفيني",
    "Category:Asian people of Sri Lankan descent": "تصنيف:آسيويين من أصل سريلانكي",
    "Category:Asian people of Surinamese descent": "تصنيف:آسيويين من أصل سورينامي",
    "Category:Asian people of Swedish descent": "تصنيف:آسيويين من أصل سويدي",
    "Category:Asian people of Swiss descent": "تصنيف:آسيويين من أصل سويسري",
    "Category:Asian people of Tanzanian descent": "تصنيف:آسيويين من أصل تنزاني",
    "Category:Asian people of Tongan descent": "تصنيف:آسيويين من أصل تونغاني",
    "Category:Asian people of Ukrainian descent": "تصنيف:آسيويين من أصل أوكراني",
    "Category:Asian people of Uruguayan descent": "تصنيف:آسيويين من أصل أوروغوياني",
    "Category:Asian people of Venezuelan descent": "تصنيف:أعلام آسيويين من أصل فنزويلي",
    "Category:Asian people of Welsh descent": "تصنيف:آسيويين من أصل ويلزي",
    "Category:Asian people of Yugoslav descent": "تصنيف:آسيويين من أصل يوغسلافي",
    "Category:Asian physicists": "تصنيف:فيزيائيون آسيويين",
    "Category:Asian political people": "تصنيف:ساسة آسيويين",
    "Category:Asian pop singer navigational boxes": "تصنيف:قوالب مغنو بوب آسيويين",
    "Category:Asian pop singers templates": "تصنيف:قوالب مغنو بوب آسيويين",
    "Category:Asian revolutionaries": "تصنيف:ثوار آسيويين",
    "Category:Asian rugby union players": "تصنيف:لاعبو اتحاد رجبي آسيويين",
    "Category:Asian scientists": "تصنيف:علماء آسيويين",
    "Category:Asian scientists by nationality": "تصنيف:علماء آسيويين حسب الجنسية",
    "Category:Asian sociologists": "تصنيف:علماء اجتماع آسيويين",
    "Category:Asian sports coaches": "تصنيف:مدربو رياضة آسيويين",
    "Category:Asian swimmers": "تصنيف:سباحون آسيويين",
    "Category:Asian tennis players": "تصنيف:لاعبو كرة مضرب آسيويين",
    "Category:Asian-American feminists": "تصنيف:نسويون أمريكيون آسيويين",
    "Category:Asian-American films by genre": "تصنيف:أفلام أمريكيون آسيويين حسب النوع الفني",
    "Category:Asian-American members of the Cabinet of the United States": "تصنيف:أمريكيون آسيويين أعضاء في مجلس وزراء الولايات المتحدة",
    "Category:Asian-American members of the United States House of Representatives": "تصنيف:أمريكيون آسيويين أعضاء في مجلس النواب الأمريكي",
    "Category:Asian-American people in Alaska politics": "تصنيف:أمريكيون آسيويين في سياسة ألاسكا",
    "Category:Asian-American people in California politics": "تصنيف:أمريكيون آسيويين في سياسة كاليفورنيا",
    "Category:Asian-American people in Connecticut politics": "تصنيف:أمريكيون آسيويين في سياسة كونيتيكت",
    "Category:Asian-American people in Florida politics": "تصنيف:أمريكيون آسيويين في سياسة فلوريدا",
    "Category:Asian-American people in Georgia (U.S. state) politics": "تصنيف:أمريكيون آسيويين في سياسة ولاية جورجيا",
    "Category:Asian-American people in Hawaii politics": "تصنيف:أمريكيون آسيويين في سياسة هاواي",
    "Category:Asian-American people in Illinois politics": "تصنيف:أمريكيون آسيويين في سياسة إلينوي",
    "Category:Asian-American people in Louisiana politics": "تصنيف:أمريكيون آسيويين في سياسة لويزيانا",
    "Category:Asian-American people in Massachusetts politics": "تصنيف:أمريكيون آسيويين في سياسة ماساتشوستس",
    "Category:Asian-American people in Michigan politics": "تصنيف:أمريكيون آسيويين في سياسة ميشيغان",
    "Category:Asian-American people in Missouri politics": "تصنيف:أمريكيون آسيويين في سياسة ميزوري",
    "Category:Asian-American people in Nebraska politics": "تصنيف:أمريكيون آسيويين في سياسة نبراسكا",
    "Category:Asian-American people in New Jersey politics": "تصنيف:أمريكيون آسيويين في سياسة نيوجيرسي",
    "Category:Asian-American people in New York (state) politics": "تصنيف:أمريكيون آسيويين في سياسة ولاية نيويورك",
    "Category:Asian-American people in Ohio politics": "تصنيف:أمريكيون آسيويين في سياسة أوهايو",
    "Category:Asian-American people in Oklahoma politics": "تصنيف:أمريكيون آسيويين في سياسة أوكلاهوما",
    "Category:Asian-American people in Oregon politics": "تصنيف:أمريكيون آسيويين في سياسة أوريغن",
    "Category:Asian-American people in Pennsylvania politics": "تصنيف:أمريكيون آسيويين في سياسة بنسلفانيا",
    "Category:Asian-American people in South Carolina politics": "تصنيف:أمريكيون آسيويين في سياسة كارولاينا الجنوبية",
    "Category:Asian-American people in Texas politics": "تصنيف:أمريكيون آسيويين في سياسة تكساس",
    "Category:Asian-American people in Utah politics": "تصنيف:أمريكيون آسيويين في سياسة يوتا",
    "Category:Asian-American people in Virginia politics": "تصنيف:أمريكيون آسيويين في سياسة فرجينيا",
    "Category:Asian-American people in Washington (state) politics": "تصنيف:أمريكيون آسيويين في سياسة ولاية واشنطن",
    "Category:Asian-American tennis players": "تصنيف:لاعبو كرة مضرب أمريكيون آسيويين",
    "Category:Asian-American trade unionists": "تصنيف:نقابيون أمريكيون آسيويين",
    "Category:Asian-Jewish culture in Israel": "تصنيف:ثقافة يهود آسيويين في إسرائيل",
    "Category:Assassinated Asian politicians": "تصنيف:سياسيون آسيويين مغتالون",
    "Category:Assassinated Turkish Kurdish politicians": "تصنيف:سياسيين أكراد أتراك مغتالون",
    "Category:Assassinated politicians in Asia": "تصنيف:سياسيون آسيويين مغتالون",
    "Category:Association football players by men's A' national team": "تصنيف:لاعبو كرة قدم حسب منتخب المحليين",
    "Category:Australian Aboriginal culture": "تصنيف:ثقافة السكان الأصليين في أستراليا",
    "Category:Australian Aboriginal mythology": "تصنيف:أساطير سكان أستراليا الأصليين",
    "Category:Australian film director navigational boxes": "تصنيف:صناديق تصفح مخرجي أفلام أستراليين",
    "Category:Australian military memorials": "تصنيف:نصب تذكارية ومقابر عسكريين أستراليين",
    "Category:Austrian automotive pioneers": "تصنيف:رواد السيارات النمساويين",
    "Category:Austrian football biography stubs": "تصنيف:بذرة أعلام كرة قدم نمساويين",
    "Category:Awards of the American Society of Civil Engineers": "تصنيف:جوائز في الجمعية الأمريكية للمهندسين المدنيين",
    "Category:Ayyubid emirs": "تصنيف:أمراء أيوبيين",
    "Category:Ayyubid emirs of Yemen": "تصنيف:أمراء أيوبيين في اليمن",
    "Category:Bahraini football biography stubs": "تصنيف:بذرة أعلام كرة قدم بحرينيين",
    "Category:Bahraini religious leaders": "تصنيف:زعماء دينيين بحرينيين",
    "Category:Bahá'í gardens": "تصنيف:حدائق البهائيين",
    "Category:Baiyin": "تصنيف:بايين",
    "Category:Battles involving Babylonia": "تصنيف:معارك البابليين",
    "Category:Battles involving East Francia": "تصنيف:معارك تشمل مملكة الفرنجة الشرقيين",
    "Category:Battles involving Native American people": "تصنيف:معارك تشمل السكان الأصليين في الولايات المتحدة",
    "Category:Battles involving Native Americans": "تصنيف:معارك تشمل السكان الأصليين في الولايات المتحدة",
    "Category:Battles involving Phoenicia": "تصنيف:معارك تشمل فينيقيين",
    "Category:Battles involving Safavid Iran": "تصنيف:معارك الصفويين",
    "Category:Battles involving the Anglo-Saxons": "تصنيف:معارك الأنجلوساكسونيين",
    "Category:Battles involving the Ayyubids": "تصنيف:معارك الأيوبيين",
    "Category:Battles involving the Canaanites": "تصنيف:معارك الكنعانيين",
    "Category:Battles involving the Ghurid dynasty": "تصنيف:معارك الغوريين",
    "Category:Battles involving the Ghurids": "تصنيف:معارك الغوريين",
    "Category:Battles involving the Hittite Empire": "تصنيف:معارك الحيثيين",
    "Category:Battles involving the Medes": "تصنيف:معارك الميديين",
    "Category:Battles involving the Median kingdom": "تصنيف:معارك الميديين",
    "Category:Battles involving the Visigoths": "تصنيف:معارك القوط الغربيين",
    "Category:Belarusian collaborators with Nazi Germany": "تصنيف:تعاون البيلاروسيين مع ألمانيا النازية",
    "Category:Belarusian partisans": "تصنيف:الثوار البيلاروسيين",
    "Category:Bengali Muslim scholars of Islam": "تصنيف:علماء المسلمين البنغاليين في الإسلام",
    "Category:Biographical films about journalists": "تصنيف:أفلام سير ذاتية عن صحفيين",
    "Category:Biographical films about mass media people": "تصنيف:أفلام سير ذاتية عن الإعلاميين",
    "Category:Biographical films about mathematicians": "تصنيف:أفلام سير ذاتية عن رياضياتيين",
    "Category:Biographical films about military leaders": "تصنيف:أفلام سير ذاتية عن قادة عسكريين",
    "Category:Biographical films about military personnel": "تصنيف:أفلام سير ذاتية عن عسكريين",
    "Category:Biographical films about musicians": "تصنيف:أفلام سير ذاتية عن موسيقيين",
    "Category:Biographical films about politicians": "تصنيف:أفلام سير ذاتية عن سياسيين",
    "Category:Biographical films about religious leaders": "تصنيف:أفلام سير ذاتية عن قادة دينيين",
    "Category:Biographical films about revolutionaries": "تصنيف:أفلام سير ذاتية عن ثوريين",
    "Category:Biographical films about sports-people": "تصنيف:أفلام سير ذاتية عن رياضيين",
    "Category:Biographical films about war correspondents": "تصنيف:أفلام سير ذاتية عن مراسلين حربيين",
    "Category:Biographical plays about politicians": "تصنيف:مسرحيات سير ذاتية عن سياسيين",
    "Category:Biographies about African-American people": "تصنيف:سير ذاتية عن أمريكيين أفارقة",
    "Category:Biographies about American Jews": "تصنيف:سير عن يهود أمريكيين",
    "Category:Biographies about musicians": "تصنيف:سير عن موسيقيين",
    "Category:Biographies about politicians": "تصنيف:سير عن سياسيين",
    "Category:Bishops of Vienne": "تصنيف:أساقفة من فيين (إقليم فرنسي)",
    "Category:Black metal albums by Swedish artists": "تصنيف:ألبومات بلاك ميتال لفنانين سويديين",
    "Category:Blues albums by British artists": "تصنيف:ألبومات بلوز لفنانين بريطانيين",
    "Category:Blues albums by Egyptian artists": "تصنيف:ألبومات بلوز لفنانين مصريين",
    "Category:Book of Leviticus": "تصنيف:سفر اللاويين",
    "Category:Books about American politicians": "تصنيف:كتب عن سياسيين أمريكيين",
    "Category:Books about British politicians": "تصنيف:كتب عن سياسيين بريطانيين",
    "Category:Books about Native American history": "تصنيف:كتب عن تاريخ الأمريكيين الأصليين",
    "Category:Books about Palestinians": "تصنيف:كتب عن فلسطينيين",
    "Category:Books about Russian politicians": "تصنيف:كتب عن سياسيين روس",
    "Category:Books about entertainers": "تصنيف:كتب عن فنانين ترفيهيين",
    "Category:Books about musicians": "تصنيف:كتب عن موسيقيين",
    "Category:Books about politicians": "تصنيف:كتب عن سياسيين",
    "Category:Books about sports-people": "تصنيف:كتب عن رياضيين",
    "Category:Bosnia and Herzegovina football biography stubs": "تصنيف:بذرة أعلام كرة قدم بوسنيين",
    "Category:Boucles de la Mayenne": "تصنيف:بوكل دو لا مايين",
    "Category:Boxing Olympic champions navigational boxes": "تصنيف:قوالب تصفح الأبطال الأولمبيين في الملاكمة",
    "Category:Brazilian football biography stubs": "تصنيف:بذرة أعلام كرة قدم برازيليين",
    "Category:British Asian footballers": "تصنيف:لاعبو آسيويين بريطانيون",
    "Category:British Indian history": "تصنيف:تاريخ الهنود البريطانيين",
    "Category:British forensic pathologists": "تصنيف:أطباء شرعيين بريطانيون",
    "Category:British geophysicists": "تصنيف:جيوفيزيائيين بريطانيون",
    "Category:British military memorials and cemeteries": "تصنيف:نصب تذكارية ومقابر عسكريين بريطانيين",
    "Category:British writer navigational boxes": "تصنيف:قوالب تصفح كتاب بريطانيين",
    "Category:Buddhist terrorism": "تصنيف:إرهاب منسوب للبوذيين",
    "Category:Buildings and structures by British architects": "تصنيف:مبان ومنشآت حسب معماريين بريطانيين",
    "Category:Buildings and structures by English architects": "تصنيف:مبان ومنشآت حسب معماريين إنجليز",
    "Category:Buildings and structures in Haute-Vienne": "تصنيف:مبان ومنشآت في فيين العليا (إقليم فرنسي)",
    "Category:Buildings and structures in Payne County, Oklahoma": "تصنيف:مبان ومنشآت في مقاطعة بايين (أوكلاهوما)",
    "Category:Buildings and structures in Vienne": "تصنيف:مبان ومنشآت في فيين (إقليم فرنسي)",
    "Category:Buildings and structures in Vienne (department)": "تصنيف:مبان ومنشآت في فيين (إقليم فرنسي)",
    "Category:Bulgarian football biography stubs": "تصنيف:بذرة أعلام كرة قدم بلغاريين",
    "Category:Burkina Faso men's A' international footballers": "تصنيف:لاعبو منتخب بوركينا فاسو لكرة القدم للرجال للمحليين",
    "Category:Burkinabe football biography stubs": "تصنيف:بذرة أعلام كرة قدم بوركينابيين",
    "Category:Burkinabé football biography stubs": "تصنيف:بذرة أعلام كرة قدم بوركينابيين",
    "Category:Burundi men's A' international footballers": "تصنيف:لاعبو منتخب بوروندي لكرة القدم للرجال للمحليين",
    "Category:Caffeine": "تصنيف:كافيين",
    "Category:Cameroon men's A' international footballers": "تصنيف:لاعبو منتخب الكاميرون لكرة القدم للرجال للمحليين",
    "Category:Cameroonian football biography stubs": "تصنيف:بذرة أعلام كرة قدم كاميرونيين",
    "Category:Camiguin": "تصنيف:كاميغويين",
    "Category:Canadian filmographies": "تصنيف:قوائم أعمال لممثلين كنديين",
    "Category:Canadian geophysicists": "تصنيف:جيوفيزيائيين كنديون",
    "Category:Canadian military memorials and cemeteries": "تصنيف:نصب تذكارية ومقابر عسكريين كنديين",
    "Category:Canadian rock musician navigational boxes": "تصنيف:قوالب مغنو روك كنديين",
    "Category:Canadian rock musician templates": "تصنيف:قوالب مغنو روك كنديين",
    "Category:Career achievements of sports-people": "تصنيف:إنجازات الرياضيين المهنية",
    "Category:Castles of the Nizari Ismaili state": "تصنيف:قلاع إسماعيليين",
    "Category:Cayenne": "تصنيف:كايين",
    "Category:Censorship of LGBT issues": "تصنيف:الرقابة في قضايا المثليين",
    "Category:Censorship of LGBTQ issues": "تصنيف:الرقابة في قضايا المثليين",
    "Category:Central Asian American": "تصنيف:أمريكيون آسيويين أوسطيون",
    "Category:Central Asian Jews": "تصنيف:يهود آسيويين أوسطيون",
    "Category:Central Asian Muslims": "تصنيف:مسلمون آسيويين أوسطيون",
    "Category:Central Asian diaspora in the United States": "تصنيف:أمريكيون آسيويين أوسطيون",
    "Category:Central Asian football biography stubs": "تصنيف:بذرة أعلام كرة قدم آسيويين أوسطيون",
    "Category:Central Asian people by religion": "تصنيف:أعلام آسيويين أوسطيون حسب الدين",
    "Category:Centre of Social Democrats politicians": "تصنيف:سياسيو وسط الديمقراطيين الاشتراكيين",
    "Category:Ceremonial officers in the United Kingdom": "تصنيف:ضباط مقلدين بريطانيين",
    "Category:Chaldean kings": "تصنيف:ملوك كلدانيين",
    "Category:Chennaiyin FC": "تصنيف:نادي تشينايين",
    "Category:Chennaiyin FC managers": "تصنيف:مدربو نادي تشينايين",
    "Category:Chennaiyin FC players": "تصنيف:لاعبو نادي تشينايين",
    "Category:Chennaiyin FC templates": "تصنيف:قوالب نادي تشينايين",
    "Category:Child murder in Asia": "تصنيف:أطفال آسيويين قتلوا",
    "Category:Children of presidents of France": "تصنيف:أبناء قادة وطنيين في فرنسا",
    "Category:Chinese diaspora in Thailand": "تصنيف:تايلانديين صينيين",
    "Category:Chinese football biography stubs": "تصنيف:بذرة أعلام كرة قدم صينيين",
    "Category:Christian holy places": "تصنيف:أماكن مقدسة للمسيحيين",
    "Category:Christian music albums by American artists": "تصنيف:ألبومات موسيقى مسيحية لفنانين أمريكيين",
    "Category:Christian music albums by South Korean artists": "تصنيف:ألبومات موسيقى مسيحية لفنانين كوريين جنوبيين",
    "Category:Christian socialist theologians": "تصنيف:اللاهوتيين الاشتراكيين المسيحيين",
    "Category:Christian terrorism": "تصنيف:إرهاب منسوب للمسيحيين",
    "Category:Christian terrorism by continent": "تصنيف:إرهاب منسوب للمسيحيين حسب القارة",
    "Category:Christian terrorism in Africa": "تصنيف:إرهاب منسوب للمسيحيين في إفريقيا",
    "Category:Christian terrorism in Asia": "تصنيف:إرهاب منسوب للمسيحيين في آسيا",
    "Category:Christian terrorism in Europe": "تصنيف:إرهاب منسوب للمسيحيين في أوروبا",
    "Category:Christian terrorism in North America": "تصنيف:إرهاب منسوب للمسيحيين في أمريكا الشمالية",
    "Category:Christian terrorism in the United States": "تصنيف:إرهاب منسوب للمسيحيين في الولايات المتحدة",
    "Category:Christmas albums by South Korean artists": "تصنيف:ألبومات عيد الميلاد لفنانين كوريين جنوبيين",
    "Category:Cities in Payne County, Oklahoma": "تصنيف:مدن في مقاطعة بايين (أوكلاهوما)",
    "Category:Cocaine": "تصنيف:كوكايين",
    "Category:Cocaine in the United States": "تصنيف:كوكايين في الولايات المتحدة",
    "Category:Colombian football biography stubs": "تصنيف:بذرة أعلام كرة قدم كولومبيين",
    "Category:Colombian serial killers": "تصنيف:قتلة متسلسلون كولومبيين",
    "Category:Colombian victims of crime": "تصنيف:ضحايا جرائم كولومبيين",
    "Category:Comedy-drama films about Asian Americans": "تصنيف:أفلام كوميدية درامية عن أمريكيون آسيويين",
    "Category:Commanders in chief": "تصنيف:القادة العسكريين",
    "Category:Communes of Haute-Vienne": "تصنيف:بلديات فيين العليا",
    "Category:Communes of Vienne": "تصنيف:بلديات فيين (إقليم فرنسي)",
    "Category:Communes of Vienne (department)": "تصنيف:بلديات فيين (إقليم فرنسي)",
    "Category:Compiègne": "تصنيف:كومبيين",
    "Category:Concubines of the Abbasid caliphs": "تصنيف:محظيات الخلفاء العباسيين",
    "Category:Constituencies for French residents overseas": "تصنيف:النواب الممثلون للفرنسيين المقيمين في الخارج",
    "Category:Contemporary R&B albums by American artists": "تصنيف:ألبومات آر إن بي لفنانين أمريكيين",
    "Category:Contemporary R&B albums by British artists": "تصنيف:ألبومات آر إن بي لفنانين بريطانيين",
    "Category:Contemporary R&B albums by Canadian artists": "تصنيف:ألبومات آر أند بي معاصر لفنانين كنديين",
    "Category:Coronations of British monarchs": "تصنيف:تتويج الملوك البريطانيين",
    "Category:Countries at the African Nations Championship": "تصنيف:بلدان في بطولة أمم إفريقيا للمحليين",
    "Category:Crimean Karaites": "تصنيف:قريميين",
    "Category:Crimes of the communist regime in Ukraine against Ukrainians": "تصنيف:جرائم النظام الشيوعي في أوكرانيا ضد الأوكرانيين",
    "Category:Croatian football biography stubs": "تصنيف:بذرة أعلام كرة قدم كرواتيين",
    "Category:Croatian geophysicists": "تصنيف:جيوفيزيائيين كروات",
    "Category:Culture of Camiguin": "تصنيف:ثقافة كاميغويين",
    "Category:Czech football biography stubs": "تصنيف:بذرة أعلام كرة قدم تشيكيين",
    "Category:Dance music albums by American artists": "تصنيف:ألبومات موسيقى الرقص لفنانين أمريكيين",
    "Category:Dance music albums by Australian artists": "تصنيف:ألبومات موسيقى الرقص لفنانين أستراليين",
    "Category:Dance music albums by British artists": "تصنيف:ألبومات موسيقى الرقص لفنانين بريطانيين",
    "Category:Dance music albums by Canadian artists": "تصنيف:ألبومات موسيقى الرقص لفنانين كنديين",
    "Category:Dance music albums by Mexican artists": "تصنيف:ألبومات موسيقى الرقص لفنانين مكسيكيين",
    "Category:Dance music albums by Romanian artists": "تصنيف:ألبومات موسيقى الرقص لفنانين رومانيين",
    "Category:Dance music albums by Swedish artists": "تصنيف:ألبومات موسيقى الرقص لفنانين سويديين",
    "Category:Dance-pop albums by American artists": "تصنيف:ألبومات بوب الرقص لفنانين أمريكيين",
    "Category:Dance-pop albums by Australian artists": "تصنيف:ألبومات بوب الرقص لفنانين أستراليين",
    "Category:Dance-pop albums by British artists": "تصنيف:ألبومات بوب الرقص لفنانين بريطانيين",
    "Category:Dance-pop albums by Canadian artists": "تصنيف:ألبومات بوب الرقص لفنانين كنديين",
    "Category:Dance-pop albums by Mexican artists": "تصنيف:ألبومات بوب الرقص لفنانين مكسيكيين",
    "Category:Danish football biography stubs": "تصنيف:بذرة أعلام كرة قدم دنماركيين",
    "Category:Danish geophysicists": "تصنيف:جيوفيزيائيين دنماركيون",
    "Category:Deaths from arteriosclerosis": "تصنيف:وفيات بسبب تصلب الشرايين",
    "Category:Democratic republic of congo men's A' international footballers": "تصنيف:لاعبو منتخب جمهورية الكونغو الديمقراطية لكرة القدم للرجال للمحليين",
    "Category:Directors Guild of America": "تصنيف:نقابة المخرجين الأمريكيين",
    "Category:Discalced Carmelite Order": "تصنيف:رهبنة الكرمليين الحفاة",
    "Category:Disco albums by American artists": "تصنيف:ألبومات ديسكو لفنانين أمريكيين",
    "Category:Disco albums by Australian artists": "تصنيف:ألبومات ديسكو لفنانين أستراليين",
    "Category:Disco albums by British artists": "تصنيف:ألبومات ديسكو فنانين بريطانيين",
    "Category:Discographies of American artists": "تصنيف:ديسكوغرافيات الفنانين الأمريكيين",
    "Category:Discographies of Japanese artists": "تصنيف:ديسكوغرافيا فنانين يابانيين",
    "Category:Discoveries by astronomer": "تصنيف:اكتشافات فلكيين",
    "Category:Diseases of arteries, arterioles and capillaries": "تصنيف:أمراض الشرايين والشرينات والشعيرات الدموية",
    "Category:Documentary films about African Americans": "تصنيف:أفلام وثائقية عن أمريكيين أفارقة",
    "Category:Documentary films about American politicians": "تصنيف:أفلام وثائقية عن سياسيين أمريكيين",
    "Category:Documentary films about classical music and musicians": "تصنيف:أفلام وثائقية عن الموسيقيين والموسيقى الكلاسيكية",
    "Category:Documentary films about comedy and comedians": "تصنيف:أفلام وثائقية عن كوميدية وكوميديين",
    "Category:Documentary films about indigenous rights": "تصنيف:أفلام وثائقية عن حقوق السكان الأصليين",
    "Category:Documentary films about journalists": "تصنيف:أفلام وثائقية عن صحفيين",
    "Category:Documentary films about mass media people": "تصنيف:أفلام وثائقية عن الإعلاميين",
    "Category:Documentary films about music and musicians": "تصنيف:أفلام وثائقية عن الموسيقى والموسيقيين",
    "Category:Documentary films about playwrights": "تصنيف:أفلام وثائقية عن كتاب مسرحيين",
    "Category:Documentary films about politicians": "تصنيف:أفلام وثائقية عن سياسيين",
    "Category:Documentary films about sports-people": "تصنيف:أفلام وثائقية عن رياضيين",
    "Category:Documentary films about visual artists": "تصنيف:أفلام وثائقية عن فنانين بصريين",
    "Category:Documentary films about war correspondents": "تصنيف:أفلام وثائقية عن مراسلين حربيين",
    "Category:Domestic workers in films": "تصنيف:أفلام عن عمال منزليين",
    "Category:Dong Phaya Yen Mountains": "تصنيف:مجمع دونغ فايايين كاو ياي الحرجي",
    "Category:Dutch child singers": "تصنيف:مطربين هولنديين أطفال",
    "Category:Dutch football biography stubs": "تصنيف:بذرة أعلام كرة قدم هولنديين",
    "Category:East Francia": "تصنيف:مملكة الفرنجة الشرقيين",
    "Category:Education in Payne County, Oklahoma": "تصنيف:التعليم في مقاطعة بايين (أوكلاهوما)",
    "Category:Egyptian football biography stubs": "تصنيف:بذرة أعلام كرة قدم مصريين",
    "Category:Egyptian writer navigational boxes": "تصنيف:قوالب تصفح كتاب مصريين",
    "Category:Electronic albums by American artists": "تصنيف:ألبومات إليكترونيك لفنانين أمريكيين",
    "Category:Electronic albums by Australian artists": "تصنيف:ألبومات إليكترونيك لفنانين أستراليين",
    "Category:Electronic albums by British artists": "تصنيف:ألبومات إليكترونيك لفنانين بريطانيين",
    "Category:Electronic albums by French artists": "تصنيف:ألبومات إليكترونيك لفنانين فرنسيين",
    "Category:Electronic albums by Greek artists": "تصنيف:ألبومات إليكترونيك لفنانين يونانيين",
    "Category:Electronic albums by Swedish artists": "تصنيف:ألبومات إليكترونيك لفنانين سويديين",
    "Category:Electronic dance music albums by American artists": "تصنيف:ألبومات موسيقى الرقص الإلكترونية لفنانين أمريكيين",
    "Category:Electronic dance music albums by Swedish artists": "تصنيف:ألبومات موسيقى الرقص الإلكترونية لفنانين سويديين",
    "Category:Emirati football biography stubs": "تصنيف:بذرة أعلام كرة قدم إماراتيين",
    "Category:English agronomists": "تصنيف:مهندسون زراعيين إنجليز",
    "Category:Epistle to the Hebrews": "تصنيف:الرسالة إلى العبرانيين",
    "Category:Equatorial Guinea men's A' international footballers": "تصنيف:لاعبو منتخب غينيا الاستوائية لكرة القدم للرجال للمحليين",
    "Category:Establishments in East Francia": "تصنيف:تأسيسات في مملكة الفرنجة الشرقيين",
    "Category:Ethiopia men's A' international footballers": "تصنيف:لاعبو منتخب إثيوبيا لكرة القدم للرجال للمحليين",
    "Category:European Commissioners by country navigational boxes": "تصنيف:صناديق تصفح مفوضين أوروبيين حسب البلد",
    "Category:European Conservatives and Reformists Party": "تصنيف:تحالف المصلحين والمحافظين الأوروبيين",
    "Category:European artist groups and collectives": "تصنيف:مجموعات وجماعيات فنانين أوروبيين",
    "Category:European commissioners by country navigational boxes": "تصنيف:صناديق تصفح مفوضين أوروبيين حسب البلد",
    "Category:European water polo biography stubs": "تصنيف:بذرة عن السيرة الشخصية لأوروبيين في كرة الماء",
    "Category:Experimental music albums by American artists": "تصنيف:ألبومات موسيقى تجريبية لفنانين أمريكيين",
    "Category:FBI Most Wanted Terrorists": "تصنيف:أكثر الإرهابيين مطلوبية لمكتب التحقيقات الفيدرالي",
    "Category:FC Biel-Bienne": "تصنيف:نادي بيل-بيين",
    "Category:FC Biel-Bienne managers": "تصنيف:مدربو نادي بيل-بيين",
    "Category:FC Biel-Bienne players": "تصنيف:لاعبو نادي بيل-بيين",
    "Category:Fallschirmjäger divisions": "تصنيف:فرق المظليين",
    "Category:Fellows of the American Institute of Architects": "تصنيف:زملاء الجمعية الأمريكية للمعماريين",
    "Category:Fellows of the American Institute of Chemical Engineers": "تصنيف:زملاء المعهد الأمريكي للمهندسين الكيميائيين",
    "Category:Fellows of the American Society of Civil Engineers": "تصنيف:زملاء الجمعية الأمريكية للمهندسين المدنيين",
    "Category:Fellows of the American Society of Mechanical Engineers": "تصنيف:زملاء الجمعية الأمريكية للمهندسين الميكانيكيين",
    "Category:Fellows of the Biomedical Engineering Society": "تصنيف:زملاء مجتمع المهندسين الطبيين",
    "Category:Fellows of the Institution of Civil Engineers": "تصنيف:زملاء معهد المهندسين المدنيين",
    "Category:Fellows of the Royal College of Psychiatrists": "تصنيف:زملاء الكلية الملكية للأطباء النفسيين",
    "Category:Fellows of the Royal Institute of British Architects": "تصنيف:زملاء المعهد الملكي للمعماريين البريطانيين",
    "Category:Fiction about same-sex marriage": "تصنيف:زواج المثليين في الأعمال الخيالية",
    "Category:Films about American military personnel": "تصنيف:أفلام عن عسكريين أمريكيين",
    "Category:Films about American politicians": "تصنيف:أفلام عن سياسيين أمريكيين",
    "Category:Films about Native Americans": "تصنيف:أفلام عن السكان الأصليين في الولايات المتحدة",
    "Category:Films about Nazi hunters": "تصنيف:أفلام عن صيادي النازيين",
    "Category:Films about Nazis": "تصنيف:أفلام عن نازيين",
    "Category:Films about North Korean defectors": "تصنيف:أفلام عن كوريين شماليين منشقين",
    "Category:Films about bodyguards": "تصنيف:أفلام عن حراس شخصيين",
    "Category:Films about classical music and musicians": "تصنيف:أفلام عن الموسيقيين والموسيقى الكلاسيكية",
    "Category:Films about cocaine": "تصنيف:أفلام عن كوكايين",
    "Category:Films about comedians": "تصنيف:أفلام عن كوميديين",
    "Category:Films about fictional painters": "تصنيف:أفلام عن رسامين خياليين",
    "Category:Films about journalists": "تصنيف:أفلام عن صحفيين",
    "Category:Films about mass media people": "تصنيف:أفلام عن الإعلاميين",
    "Category:Films about military personnel": "تصنيف:أفلام عن عسكريين",
    "Category:Films about music and musicians": "تصنيف:أفلام عن الموسيقى والموسيقيين",
    "Category:Films about playwrights": "تصنيف:أفلام عن كتاب مسرحيين",
    "Category:Films about politicians": "تصنيف:أفلام عن سياسيين",
    "Category:Films about psychopaths and sociopaths": "تصنيف:أفلام عن السيكوباثيين",
    "Category:Films about revolutionaries": "تصنيف:أفلام عن ثوريين",
    "Category:Films about socialites": "تصنيف:أفلام عن اجتماعيين",
    "Category:Films about sports-people": "تصنيف:أفلام عن رياضيين",
    "Category:Films about the 1948 Palestinian exodus": "تصنيف:أفلام عن تهجير الفلسطينيين عام 1948",
    "Category:Films about war correspondents": "تصنيف:أفلام عن مراسلين حربيين",
    "Category:Films based on Brewster's Millions": "تصنيف:أفلام مبنية على ملايين بروستر",
    "Category:Films by African-American directors": "تصنيف:أفلام مخرجين أفارقة أمريكيين",
    "Category:Films by Algerian directors": "تصنيف:أفلام حسب المخرجين الجزائريين",
    "Category:Films by American directors": "تصنيف:أفلام حسب المخرجين الأمريكيين",
    "Category:Films by Argentine directors": "تصنيف:أفلام مخرجين أرجنتينيين",
    "Category:Films by Australian directors": "تصنيف:أفلام حسب المخرجين الأستراليين",
    "Category:Films by Australian producers": "تصنيف:أفلام منتجين أستراليين",
    "Category:Films by Austrian directors": "تصنيف:أفلام حسب المخرجين النمساويين",
    "Category:Films by Belgian directors": "تصنيف:أفلام مخرجين بلجيكيين",
    "Category:Films by Bosnia and Herzegovina directors": "تصنيف:أفلام مخرجين بوسنيين",
    "Category:Films by Brazilian directors": "تصنيف:أفلام مخرجين برازيليين",
    "Category:Films by British directors": "تصنيف:أفلام مخرجين بريطانيين",
    "Category:Films by British producers": "تصنيف:أفلام منتجين بريطانيين",
    "Category:Films by Burkinabe directors": "تصنيف:أفلام مخرجين بوركينابيين",
    "Category:Films by Cambodian directors": "تصنيف:أفلام مخرجين كمبوديين",
    "Category:Films by Canadian directors": "تصنيف:أفلام حسب المخرجين الكنديين",
    "Category:Films by Chadian directors": "تصنيف:أفلام مخرجين تشاديين",
    "Category:Films by Chilean directors": "تصنيف:أفلام مخرجين تشيليين",
    "Category:Films by Chinese directors": "تصنيف:أفلام مخرجين صينيين",
    "Category:Films by Colombian directors": "تصنيف:أفلام مخرجين كولومبيين",
    "Category:Films by Cuban directors": "تصنيف:أفلام لمخرجين كوبيين",
    "Category:Films by Czech directors": "تصنيف:أفلام حسب المخرجين التشيكيين",
    "Category:Films by Czechoslovak directors": "تصنيف:أفلام مخرجين تشيكوسلوفاكيين",
    "Category:Films by Danish directors": "تصنيف:أفلام لمخرجين دنماركيين",
    "Category:Films by Dutch directors": "تصنيف:أفلام مخرجين هولنديين",
    "Category:Films by Egyptian directors": "تصنيف:أفلام حسب المخرجين المصريين",
    "Category:Films by English directors": "تصنيف:أفلام حسب المخرجين الإنجليزيين",
    "Category:Films by Filipino directors": "تصنيف:أفلام مخرجين فلبينيين",
    "Category:Films by French directors": "تصنيف:أفلام حسب المخرجين الفرنسيين",
    "Category:Films by French producers": "تصنيف:أفلام منتجين فرنسيين",
    "Category:Films by Greek directors": "تصنيف:أفلام مخرجين يونانيين",
    "Category:Films by Haitian directors": "تصنيف:أفلام مخرجين هايتيين",
    "Category:Films by Hong Kong producers": "تصنيف:أفلام منتجين هونغ كونغيين",
    "Category:Films by Hungarian directors": "تصنيف:أفلام مخرجين مجريين",
    "Category:Films by Hungarian producers": "تصنيف:أفلام منتجين مجريين",
    "Category:Films by Icelandic directors": "تصنيف:أفلام مخرجين آيسلنديين",
    "Category:Films by Indonesian directors": "تصنيف:أفلام مخرجين إندونيسيين",
    "Category:Films by Iranian directors": "تصنيف:أفلام من إخراج مخرجين إيرانيين",
    "Category:Films by Iraqi directors": "تصنيف:أفلام مخرجين عراقيين",
    "Category:Films by Irish directors": "تصنيف:أفلام مخرجين أيرلنديين",
    "Category:Films by Israeli directors": "تصنيف:أفلام مخرجين إسرائيليين",
    "Category:Films by Israeli producers": "تصنيف:أفلام منتجين إسرائيليين",
    "Category:Films by Italian directors": "تصنيف:أفلام المخرجين الإيطاليين",
    "Category:Films by Italian producers": "تصنيف:أفلام منتجين إيطاليين",
    "Category:Films by Japanese directors": "تصنيف:أفلام حسب المخرجين اليابانيين",
    "Category:Films by Japanese producers": "تصنيف:أفلام منتجين يابانيين",
    "Category:Films by Kazakhstani directors": "تصنيف:أفلام مخرجين كازاخستانيين",
    "Category:Films by Korean directors": "تصنيف:أفلام مخرجين كوريين",
    "Category:Films by Lebanese directors": "تصنيف:أفلام مخرجين لبنانيين",
    "Category:Films by Lebanese producers": "تصنيف:أفلام منتجين لبنانيين",
    "Category:Films by Malaysian directors": "تصنيف:أفلام مخرجين ماليزيين",
    "Category:Films by Malian directors": "تصنيف:أفلام مخرجين ماليين",
    "Category:Films by Mauritanian directors": "تصنيف:أفلام مخرجين موريتانيين",
    "Category:Films by Mexican directors": "تصنيف:أفلام حسب المخرجين المكسيكيين",
    "Category:Films by Mexican producers": "تصنيف:أفلام منتجين مكسيكيين",
    "Category:Films by New Zealand directors": "تصنيف:أفلام حسب المخرجين النيوزيلنديين",
    "Category:Films by New Zealand producers": "تصنيف:أفلام منتجين نيوزيلنديين",
    "Category:Films by Nigerian directors": "تصنيف:أفلام مخرجين نيجيريين",
    "Category:Films by Nigerian producers": "تصنيف:أفلام منتجين نيجيريين",
    "Category:Films by Norwegian directors": "تصنيف:أفلام مخرجين نرويجيين",
    "Category:Films by Pakistani directors": "تصنيف:أفلام مخرجين باكستانيين",
    "Category:Films by Palestinian directors": "تصنيف:أفلام مخرجين فلسطينيين",
    "Category:Films by Peruvian directors": "تصنيف:أفلام مخرجين بيرويين",
    "Category:Films by Polish directors": "تصنيف:أفلام مخرجين بولنديين",
    "Category:Films by Polish producers": "تصنيف:أفلام منتجين بولنديين",
    "Category:Films by Portuguese directors": "تصنيف:أفلام مخرجين برتغاليين",
    "Category:Films by Portuguese producers": "تصنيف:أفلام منتجين برتغاليين",
    "Category:Films by Puerto Rican directors": "تصنيف:أفلام مخرجين بورتوريكيين",
    "Category:Films by Romanian directors": "تصنيف:أفلام مخرجين رومانيين",
    "Category:Films by Scottish directors": "تصنيف:أفلام مخرجين إسكتلنديين",
    "Category:Films by Senegalese directors": "تصنيف:أفلام لمخرجين سنغاليين",
    "Category:Films by Slovak directors": "تصنيف:أفلام مخرجين سلوفاكيين",
    "Category:Films by Slovak producers": "تصنيف:أفلام منتجين سلوفاكيين",
    "Category:Films by South Korean directors": "تصنيف:أفلام مخرجين كوريين جنوبيين",
    "Category:Films by South Korean producers": "تصنيف:أفلام منتجين كوريين جنوبيين",
    "Category:Films by Swedish directors": "تصنيف:أفلام مخرجين سويديين",
    "Category:Films by Swiss directors": "تصنيف:أفلام مخرجين سويسريين",
    "Category:Films by Swiss producers": "تصنيف:أفلام منتجين سويسريين",
    "Category:Films by Syrian directors": "تصنيف:أفلام مخرجين سوريين",
    "Category:Films by Taiwanese directors": "تصنيف:أفلام مخرجين تايوانيين",
    "Category:Films by Taiwanese producers": "تصنيف:أفلام منتجين تايوانيين",
    "Category:Films by Tunisian directors": "تصنيف:أفلام مخرجين تونسيين",
    "Category:Films by Ukrainian directors": "تصنيف:أفلام مخرجين أوكرانيين",
    "Category:Films by Welsh directors": "تصنيف:أفلام مخرجين ويلزيين",
    "Category:Films by Yugoslav directors": "تصنيف:أفلام مخرجين يوغسلافيين",
    "Category:Floristry": "تصنيف:تزيين بالزهور",
    "Category:Folk albums by American artists": "تصنيف:ألبومات تراث شعبي لفنانين أمريكيين",
    "Category:Folk albums by British artists": "تصنيف:ألبومات تراث شعبي لفنانين بريطانيين",
    "Category:Folk albums by Canadian artists": "تصنيف:ألبومات تراث شعبي لفنانين كنديين",
    "Category:Folk albums by Egyptian artists": "تصنيف:ألبومات تراث شعبي لفنانين مصريين",
    "Category:Folk albums by Emirati artists": "تصنيف:ألبومات تراث شعبي لفنانين إماراتيين",
    "Category:Folk albums by Iranian artists": "تصنيف:ألبومات تراث شعبي لفنانين إيرانيين",
    "Category:Folk albums by Irish artists": "تصنيف:ألبومات تراث شعبي لفنانين أيرلنديين",
    "Category:Folk albums by Lebanese artists": "تصنيف:ألبومات تراث شعبي لفنانين لبنانيين",
    "Category:Folk albums by Tunisian artists": "تصنيف:ألبومات تراث شعبي لفنانين تونسيين",
    "Category:Folk rock albums by American artists": "تصنيف:ألبومات روك شعبي لفنانين أمريكيين",
    "Category:Folk rock albums by British artists": "تصنيف:ألبومات روك شعبي لفنانين بريطانيين",
    "Category:Folk rock albums by Canadian artists": "تصنيف:ألبومات روك شعبي لفنانين كنديين",
    "Category:Footballers from Cayenne": "تصنيف:لاعبو كرة قدم من كايين",
    "Category:Forced migrations of Native Americans in the United States": "تصنيف:ترحيل قسري للسكان الأصليين في الولايات المتحدة",
    "Category:Forensic pathologists": "تصنيف:أطباء شرعيين",
    "Category:Free Egyptians Party politicians": "تصنيف:سياسيو حزب المصريين الأحرار",
    "Category:French film director navigational boxes": "تصنيف:صناديق تصفح مخرجي أفلام فرنسيين",
    "Category:French football biography stubs": "تصنيف:بذرة أعلام كرة قدم فرنسيين",
    "Category:Funk albums by American artists": "تصنيف:ألبومات فانك لفنانين أمريكيين",
    "Category:Gabon men's A' international footballers": "تصنيف:لاعبو منتخب الغابون لكرة القدم للرجال للمحليين",
    "Category:Gabonese football biography stubs": "تصنيف:بذرة أعلام كرة قدم غابونيين",
    "Category:Gangsta rap albums by American artists": "تصنيف:ألبومات راب عصابات لفنانين أمريكيين",
    "Category:Gay male literature": "تصنيف:أدب المثليين جنسياً",
    "Category:Gay villages": "تصنيف:قرى مثليين",
    "Category:Gay villages in Brazil": "تصنيف:قرى مثليين في البرازيل",
    "Category:Gay villages in California": "تصنيف:قرى مثليين في كاليفورنيا",
    "Category:Gay villages in New York (state)": "تصنيف:قرى مثليين في ولاية نيويورك",
    "Category:Gay villages in the United States": "تصنيف:قرى مثليين في الولايات المتحدة",
    "Category:Geography of Camiguin": "تصنيف:جغرافيا كاميغويين",
    "Category:Geography of Haute-Vienne": "تصنيف:جغرافيا فيين العليا",
    "Category:Geography of Payne County, Oklahoma": "تصنيف:جغرافيا مقاطعة بايين (أوكلاهوما)",
    "Category:Geography of Vienne": "تصنيف:جغرافيا فيين (إقليم فرنسي)",
    "Category:Geography of Vienne (department)": "تصنيف:جغرافيا فيين (إقليم فرنسي)",
    "Category:German military governors of Paris": "تصنيف:الحكام العسكريين الألمان لباريس",
    "Category:German naval architects": "تصنيف:المهندسين المعماريين البحريين الألمان",
    "Category:Gesta Hungarorum": "تصنيف:أعمال المجريين (مخطوطة)",
    "Category:Ghana men's A' international footballers": "تصنيف:لاعبو منتخب غانا لكرة القدم للرجال للمحليين",
    "Category:Ghanaian football biography stubs": "تصنيف:بذرة أعلام كرة قدم غانيين",
    "Category:Glider pilots": "تصنيف:مزلق الطياريين",
    "Category:Governors of Camiguin": "تصنيف:حكام من كاميغويين",
    "Category:Grand Duchy of Tuscany people": "تصنيف:الدوقية العظمى للتوسكانيين",
    "Category:Great Officers of State": "تصنيف:أكابر موظفي الدولة البريطانيين",
    "Category:Greek football biography stubs": "تصنيف:بذرة أعلام كرة قدم يونانيين",
    "Category:Greek genocide": "تصنيف:مذابح اليونانيين البونتيك",
    "Category:Guinea men's A' international footballers": "تصنيف:لاعبو منتخب غينيا لكرة القدم للرجال للمحليين",
    "Category:Guinean football biography stubs": "تصنيف:بذرة أعلام كرة قدم غينيين",
    "Category:Gutian dynasty of Sumer": "تصنيف:سلالة الجوتيين في سومر",
    "Category:Halloween food": "تصنيف:مأكولات ترتبط بالهالويين",
    "Category:Hard rock albums by American artists": "تصنيف:ألبومات هارد روك لفنانين أمريكيين",
    "Category:Hard rock albums by British artists": "تصنيف:ألبومات هارد روك لفنانين بريطانيين",
    "Category:Haute-Vienne": "تصنيف:فيين العليا (إقليم فرنسي)",
    "Category:Heavy metal albums by American artists": "تصنيف:ألبومات هيفي ميتال لفنانين أمريكيين",
    "Category:Hetmans of the Zaporozhian Cossacks": "تصنيف:هيتمان القوزاق الزاباروجيين",
    "Category:Hinduism-motivated violence in India": "تصنيف:إرهاب منسوب للهندوسيين",
    "Category:Hip hop albums by American artists": "تصنيف:ألبومات هيب هوب من قبل فنانين أميركيين",
    "Category:Hip-hop albums by American artists": "تصنيف:ألبومات هيب هوب من قبل فنانين أميركيين",
    "Category:Hip-hop albums by British artists": "تصنيف:ألبومات هيب هوب لفنانين بريطانيين",
    "Category:Hip-hop albums by Canadian artists": "تصنيف:ألبومات هيب هوب لفنانين كنديين",
    "Category:Hispanic and Latino American sitcoms": "تصنيف:لاتينيين كوميدية الموقف",
    "Category:Historians of African Americans": "تصنيف:مؤرخو الأمريكيين الأفارقة",
    "Category:Historians of Native Americans": "تصنيف:مؤرخو السكان الأصليين في الولايات المتحدة",
    "Category:Historians of the Hazaraspids": "تصنيف:مؤرخو الهزارسبيين",
    "Category:Historians under the Buyid dynasty": "تصنيف:مؤرخون عاصروا البويهيين",
    "Category:History of Assyria": "تصنيف:تاريخ الآشوريين",
    "Category:History of Haute-Vienne": "تصنيف:تاريخ فيين العليا",
    "Category:History of Indigenous Australians": "تصنيف:تاريخ سكان أستراليا الأصليين",
    "Category:History of Indigenous peoples of North America": "تصنيف:تاريخ السكان الأمريكيين الأصليين الشماليين",
    "Category:History of Vienne": "تصنيف:تاريخ فيين (إقليم فرنسي)",
    "Category:History of Vienne (department)": "تصنيف:تاريخ فيين (إقليم فرنسي)",
    "Category:History of indigenous peoples of North America": "تصنيف:تاريخ السكان الأمريكيين الأصليين الشماليين",
    "Category:History of the Palestinian refugees": "تصنيف:تاريخ اللاجئين الفلسطينيين",
    "Category:Hittite kings": "تصنيف:ملوك الحيثيين",
    "Category:House of Brienne": "تصنيف:أسرة بريين",
    "Category:Houthi insurgency in Yemen": "تصنيف:تمرد الحوثيين في اليمن",
    "Category:Huayin": "تصنيف:هوايين",
    "Category:Huguenot history in France": "تصنيف:تاريخ الهوغونوتيين في فرنسا",
    "Category:Hungarian football biography stubs": "تصنيف:بذرة أعلام كرة قدم مجريين",
    "Category:Hurrian kings": "تصنيف:ملوك الحوريين",
    "Category:Hussite Wars": "تصنيف:حروب الهوسيين",
    "Category:Illegitimate children of Portuguese monarchs": "تصنيف:أطفال غير شرعيين من ملوك البرتغال",
    "Category:Illegitimate children of monarchs": "تصنيف:أبناء شخصيات ملكية غير شرعيين",
    "Category:Immigration and LGBT topics": "تصنيف:الهجرة ومواضيع المثليين",
    "Category:Immigration and LGBTQ topics": "تصنيف:الهجرة ومواضيع المثليين",
    "Category:Independent Republicans politicians": "تصنيف:سياسيو حزب الجمهوريين المستقلين",
    "Category:Indian military memorials and cemeteries": "تصنيف:نصب تذكارية ومقابر عسكريين هنود",
    "Category:Indian reserves": "تصنيف:محميات سكان أصليين",
    "Category:Indian reserves by province or territory": "تصنيف:محميات سكان أصليين حسب المحافظة أو الإقليم",
    "Category:Indian reserves in Saskatchewan": "تصنيف:محميات سكان أصليين في ساسكاتشوان",
    "Category:Indian sports-people stubs": "تصنيف:بذرة عن رياضيين هنود",
    "Category:Indie folk albums by American artists": "تصنيف:ألبومات إندي فولك لفنانين أمريكيين",
    "Category:Indie rock albums by American artists": "تصنيف:ألبومات إيندي روك لفنانين أمريكيين",
    "Category:Indigenous Christianity": "تصنيف:مسيحية السكان الأصليين",
    "Category:Indigenous affairs ministries": "تصنيف:وزارات شؤون سكان أصليين",
    "Category:Indigenous cinema": "تصنيف:سينما تتعلق بالسكان الأصليين",
    "Category:Indigenous culture in Canada": "تصنيف:حضارة السكان الأصليين في كندا",
    "Category:Indigenous culture of Asia": "تصنيف:ثقافة السكان الأصليين في آسيا",
    "Category:Indigenous land rights": "تصنيف:حقوق أراضي السكان الأصليين",
    "Category:Indigenous law": "تصنيف:قوانين السكان الأصليين",
    "Category:Indigenous literature": "تصنيف:أدب السكان الأصليين",
    "Category:Indigenous mass media": "تصنيف:وسائل إعلام السكان الأصليين",
    "Category:Indigenous nationalism": "تصنيف:قومية السكان الأصليين",
    "Category:Indigenous peoples of the Caribbean": "تصنيف:سكان الكاريبي الأصليين",
    "Category:Indigenous politics": "تصنيف:سياسة السكان الأصليين",
    "Category:Indigenous politics in Brazil": "تصنيف:سياسة السكان الأصليين في البرازيل",
    "Category:Indigenous politics in Canada": "تصنيف:سياسة السكان الأصليين في كندا",
    "Category:Indigenous politics in Europe": "تصنيف:سياسة السكان الأصليين في أوروبا",
    "Category:Indigenous politics in Mexico": "تصنيف:سياسة السكان الأصليين في المكسيك",
    "Category:Indigenous politics in North America": "تصنيف:سياسة السكان الأصليين في أمريكا الشمالية",
    "Category:Indigenous politics in Oceania": "تصنيف:سياسة السكان الأصليين في أوقيانوسيا",
    "Category:Indigenous politics in South America": "تصنيف:سياسة السكان الأصليين في أمريكا الجنوبية",
    "Category:Indigenous politics in the Americas": "تصنيف:سياسة السكان الأصليين في الأمريكتين",
    "Category:Indigenous rights": "تصنيف:حقوق السكان الأصليين",
    "Category:Indigenous rights in Canada": "تصنيف:حقوق السكان الأصليين في كندا",
    "Category:Individuals designated as terrorists by the United States government": "تصنيف:أفراد وصفتهم حكومة الولايات المتحدة بالإرهابيين",
    "Category:Indonesian football biography stubs": "تصنيف:بذرة أعلام كرة قدم إندونيسيين",
    "Category:Industrial Workers of the World": "تصنيف:العمال الصناعيين في العالم",
    "Category:Institution of Chemical Engineers": "تصنيف:معهد المهندسين الكيميائيين",
    "Category:Institution of Civil Engineers": "تصنيف:معهد المهندسين المدنيين",
    "Category:Institution of Mechanical Engineers": "تصنيف:معهد المهندسين الميكانيكيين",
    "Category:Institution of Structural Engineers": "تصنيف:معهد المهندسين الإنشائيين",
    "Category:International Federation of Journalists": "تصنيف:الاتحاد الدولي للصحفيين",
    "Category:Internment camps for Japanese Americans": "تصنيف:معسكرات اعتقال الأمريكيين اليابانيين",
    "Category:Internment of Japanese Americans": "تصنيف:اعتقال الأمريكيين اليابانيين",
    "Category:Intra-Palestinian peace efforts": "تصنيف:جهود السلام بين الفلسطينيين",
    "Category:Invasions by the Umayyad Caliphate": "تصنيف:غزوات الأمويين",
    "Category:Iranian football biography stubs": "تصنيف:بذرة أعلام كرة قدم إيرانيين",
    "Category:Iranian writer navigational boxes": "تصنيف:صناديق تصفح كتاب إيرانيين",
    "Category:Iranian writer templates": "تصنيف:قوالب كتاب إيرانيين",
    "Category:Iraqi football biography stubs": "تصنيف:بذرة أعلام كرة قدم عراقيين",
    "Category:Irish sports-people stubs": "تصنيف:بذرة عن رياضيين آيرلنديين",
    "Category:Israeli casualties in the Second Intifada": "تصنيف:ضحايا إسرائيليين في الانتفاضة الفلسطينية الثانية",
    "Category:Israeli colonels": "تصنيف:عقداء إسرائيليين",
    "Category:Israeli settler violence": "تصنيف:عنف المستوطنين الإسرائيليين",
    "Category:Italian expatriates in Austria": "تصنيف:مغتربين إيطاليين في النمسا",
    "Category:Italian football biography stubs": "تصنيف:بذرة أعلام كرة قدم إيطاليين",
    "Category:Ivorian football biography stubs": "تصنيف:بذرة أعلام كرة قدم إيفواريين",
    "Category:Ivory Coast men's A' international footballers": "تصنيف:لاعبو منتخب ساحل العاج لكرة القدم للرجال للمحليين",
    "Category:Japanese film director navigational boxes": "تصنيف:صناديق تصفح مخرجي أفلام يابانيين",
    "Category:Japanese football biography stubs": "تصنيف:بذرة أعلام كرة قدم يابانيين",
    "Category:Japanese writer navigational boxes": "تصنيف:قوالب تصفح كتاب يابانيين",
    "Category:Jazz albums by American artists": "تصنيف:ألبومات جاز لفنانين أمريكيين",
    "Category:Jazz albums by British artists": "تصنيف:ألبومات جاز لفنانين بريطانيين",
    "Category:Jazz albums by Canadian artists": "تصنيف:ألبومات جاز لفنانين كنديين",
    "Category:Jazz albums by Egyptian artists": "تصنيف:ألبومات جاز لفنانين مصريين",
    "Category:Jazz fusion albums by American artists": "تصنيف:ألبومات جاز فيوشن لفنانين أمريكيين",
    "Category:Jesuit publications": "تصنيف:إصدارات يسوعيين",
    "Category:Joint suicides by Nazis": "تصنيف:حالات انتحار مشتركة بين النازيين",
    "Category:Jordanian football biography stubs": "تصنيف:بذرة أعلام كرة قدم أردنيين",
    "Category:Karaite Jews": "تصنيف:قريميين",
    "Category:Kassite kings": "تصنيف:ملوك كاشيين",
    "Category:Kayin State": "تصنيف:ولاية كايين",
    "Category:Kingdom of the Suebi": "تصنيف:مملكة السويبيين",
    "Category:Kings of East Francia": "تصنيف:ملوك مملكة الفرنجة الشرقيين",
    "Category:Kinin–kallikrein system": "تصنيف:نظام كاينين-كاليكريين",
    "Category:Korean Catholics": "تصنيف:كاثوليكيون كوريين",
    "Category:Kuwaiti football biography stubs": "تصنيف:بذرة أعلام كرة قدم كويتيين",
    "Category:LGBT adoption": "تصنيف:تبني المثليين للأطفال",
    "Category:LGBT adoption in Europe": "تصنيف:تبني المثليين للأطفال في أوروبا",
    "Category:LGBT adoption in the United States": "تصنيف:تبني المثليين للأطفال في الولايات المتحدة",
    "Category:LGBT beauty pageants": "تصنيف:مسابقات الجمال للمثليين",
    "Category:LGBT culture": "تصنيف:ثقافة المثليين",
    "Category:LGBT culture by city": "تصنيف:ثقافة المثليين حسب المدينة",
    "Category:LGBT culture by continent": "تصنيف:ثقافة المثليين حسب القارة",
    "Category:LGBT culture by country": "تصنيف:ثقافة المثليين حسب البلد",
    "Category:LGBT culture by location": "تصنيف:ثقافة المثليين حسب الموقع",
    "Category:LGBT culture by region": "تصنيف:ثقافة المثليين حسب المنطفة",
    "Category:LGBT culture in Asia": "تصنيف:ثقافة المثليين في آسيا",
    "Category:LGBT culture in Australia": "تصنيف:ثقافة المثليين في أستراليا",
    "Category:LGBT culture in Australia by city": "تصنيف:ثقافة المثليين في أستراليا حسب المدينة",
    "Category:LGBT culture in Brazil": "تصنيف:ثقافة المثليين في البرازيل",
    "Category:LGBT culture in Canada": "تصنيف:ثقافة المثليين في كندا",
    "Category:LGBT culture in Denmark": "تصنيف:ثقافة المثليين في الدنمارك",
    "Category:LGBT culture in England": "تصنيف:ثقافة المثليين في إنجلترا",
    "Category:LGBT culture in Europe": "تصنيف:ثقافة المثليين في أوروبا",
    "Category:LGBT culture in Europe by country": "تصنيف:ثقافة المثليين في أوروبا حسب البلد",
    "Category:LGBT culture in France": "تصنيف:ثقافة المثليين في فرنسا",
    "Category:LGBT culture in Germany": "تصنيف:ثقافة المثليين في ألمانيا",
    "Category:LGBT culture in Greenland": "تصنيف:ثقافة المثليين في جرينلاند",
    "Category:LGBT culture in India": "تصنيف:ثقافة المثليين في الهند",
    "Category:LGBT culture in Ireland": "تصنيف:ثقافة المثليين في أيرلندا",
    "Category:LGBT culture in Italy": "تصنيف:ثقافة المثليين في إيطاليا",
    "Category:LGBT culture in Japan": "تصنيف:ثقافة المثليين في اليابان",
    "Category:LGBT culture in Liverpool": "تصنيف:ثقافة المثليين في ليفربول",
    "Category:LGBT culture in London": "تصنيف:ثقافة المثليين في لندن",
    "Category:LGBT culture in Mexico": "تصنيف:ثقافة المثليين في المكسيك",
    "Category:LGBT culture in North America": "تصنيف:ثقافة المثليين في أمريكا الشمالية",
    "Category:LGBT culture in Norway": "تصنيف:ثقافة المثليين في النرويج",
    "Category:LGBT culture in Scotland": "تصنيف:ثقافة المثليين في إسكتلندا",
    "Category:LGBT culture in South America": "تصنيف:ثقافة المثليين في أمريكا الجنوبية",
    "Category:LGBT culture in Spain": "تصنيف:ثقافة المثليين في إسبانيا",
    "Category:LGBT culture in Sydney": "تصنيف:ثقافة المثليين في سيدني",
    "Category:LGBT culture in the Netherlands": "تصنيف:ثقافة المثليين في هولندا",
    "Category:LGBT culture in the United Kingdom": "تصنيف:ثقافة المثليين في المملكة المتحدة",
    "Category:LGBT culture in the United Kingdom by city": "تصنيف:ثقافة المثليين في المملكة المتحدة حسب المدينة",
    "Category:LGBT culture in the United States by region": "تصنيف:ثقافة المثليين في الولايات المتحدة حسب المنطقة",
    "Category:LGBT drinking establishments": "تصنيف:مؤسسات الشرب للمثليين",
    "Category:LGBT events": "تصنيف:أحداث المثليين",
    "Category:LGBT events by country": "تصنيف:أحداث متعلقة بالمثليين حسب البلد",
    "Category:LGBT events in Brazil": "تصنيف:أحداث المثليين في البرازيل",
    "Category:LGBT events in Denmark": "تصنيف:أحداث متعلقة بالمثليين في الدنمارك",
    "Category:LGBT events in Ireland": "تصنيف:أحداث متعلقة بالمثليين في أيرلندا",
    "Category:LGBT festivals": "تصنيف:مهرجانات المثليين",
    "Category:LGBT film festivals": "تصنيف:مهرجانات أفلام المثليين",
    "Category:LGBT health organizations": "تصنيف:منظمات الصحة المعنية بالمثليين",
    "Category:LGBT health organizations in the United States": "تصنيف:منظمات الصحة المعنية بالمثليين في الولايات المتحدة",
    "Category:LGBT history by country": "تصنيف:تاريخ المثليين حسب البلد",
    "Category:LGBT history in Denmark": "تصنيف:تاريخ المثليين في الدنمارك",
    "Category:LGBT history in Germany": "تصنيف:تاريخ المثليين في ألمانيا",
    "Category:LGBT history in Ireland": "تصنيف:تاريخ المثليين في أيرلندا",
    "Category:LGBT history in Italy": "تصنيف:تاريخ المثليين في إيطاليا",
    "Category:LGBT history in Peru": "تصنيف:تاريخ المثليين في بيرو",
    "Category:LGBT history in the United Kingdom": "تصنيف:تاريخ المثليين في المملكة المتحدة",
    "Category:LGBT in the Arab world": "تصنيف:حقوق المثليين في الوطن العربي",
    "Category:LGBT in the Middle East": "تصنيف:حقوق المثليين في الشرق الأوسط",
    "Category:LGBT in the People's Republic of China": "تصنيف:معاملة المثليين في جمهورية الصين الشعبية",
    "Category:LGBT nightclubs": "تصنيف:نوادي ليلية للمثليين",
    "Category:LGBT organizations in Iceland": "تصنيف:منظمات المثليين في آيسلندا",
    "Category:LGBT parenting": "تصنيف:الأبوة والأمومة عند المثليين",
    "Category:LGBT parenting in North America": "تصنيف:الأبوة والأمومة عند المثليين في أمريكا الشمالية",
    "Category:LGBT parenting in the United States": "تصنيف:الأبوة والأمومة عند المثليين في الولايات المتحدة",
    "Category:LGBT poetry": "تصنيف:شعر المثليين",
    "Category:LGBT political advocacy groups by country": "تصنيف:جمعيات تأييد سياسي للمثليين حسب البلد",
    "Category:LGBT political advocacy groups in Brazil": "تصنيف:جمعيات تأييد سياسي للمثليين في البرازيل",
    "Category:LGBT political advocacy groups in Denmark": "تصنيف:جمعيات تأييد سياسي للمثليين في الدنمارك",
    "Category:LGBT political advocacy groups in Iceland": "تصنيف:جمعيات تأييد سياسي للمثليين في آيسلندا",
    "Category:LGBT political advocacy groups in Morocco": "تصنيف:جمعيات تأييد سياسي للمثليين في المغرب",
    "Category:LGBT political advocacy groups in the Netherlands": "تصنيف:جمعيات تأييد سياسي للمثليين في هولندا",
    "Category:LGBT political advocacy groups in republic of Ireland": "تصنيف:جمعيات تأييد سياسي للمثليين في جمهورية أيرلندا",
    "Category:LGBT politics": "تصنيف:سياسة المثليين جنسيا",
    "Category:LGBT rights": "تصنيف:حقوق المثليين جنسيا",
    "Category:LGBT rights by continent": "تصنيف:حقوق المثليين حسب القارة",
    "Category:LGBT rights by country": "تصنيف:حقوق المثليين حسب البلد",
    "Category:LGBT rights by country subdivision": "تصنيف:حقوق المثليين حسب المستوى دون الوطني للبلد",
    "Category:LGBT rights by former country": "تصنيف:حقوق المثليين حسب البلد السابق",
    "Category:LGBT rights by issue": "تصنيف:حقوق المثليين حسب القضية",
    "Category:LGBT rights by region": "تصنيف:حقوق المثليين حسب المنطقة",
    "Category:LGBT rights case law": "تصنيف:قضايا محاكم حول حقوق المثليين",
    "Category:LGBT rights in Africa": "تصنيف:حقوق المثليين في إفريقيا",
    "Category:LGBT rights in Africa by country": "تصنيف:حقوق المثليين في إفريقيا حسب البلد",
    "Category:LGBT rights in Akrotiri and Dhekelia": "تصنيف:حقوق المثليين في أكروتيري ودكليا",
    "Category:LGBT rights in Albania": "تصنيف:حقوق المثليين في ألبانيا",
    "Category:LGBT rights in Andorra": "تصنيف:حقوق المثليين في أندورا",
    "Category:LGBT rights in Argentina": "تصنيف:حقوق المثليين في الأرجنتين",
    "Category:LGBT rights in Armenia": "تصنيف:حقوق المثليين في أرمينيا",
    "Category:LGBT rights in Aruba": "تصنيف:حقوق المثليين في أروبا",
    "Category:LGBT rights in Asia": "تصنيف:حقوق المثليين في آسيا",
    "Category:LGBT rights in Asia by country": "تصنيف:حقوق المثليين في آسيا حسب البلد",
    "Category:LGBT rights in Australia": "تصنيف:حقوق المثليين في أستراليا",
    "Category:LGBT rights in Australia by state or territory": "تصنيف:حقوق المثليين في أستراليا حسب الولاية أو الإقليم",
    "Category:LGBT rights in Austria": "تصنيف:حقوق المثليين في النمسا",
    "Category:LGBT rights in Azerbaijan": "تصنيف:حقوق المثليين في أذربيجان",
    "Category:LGBT rights in Azerbaijan by region": "تصنيف:حقوق المثليين في أذربيجان حسب المنطقة",
    "Category:LGBT rights in Barbados": "تصنيف:حقوق المثليين في باربادوس",
    "Category:LGBT rights in Belarus": "تصنيف:حقوق المثليين في روسيا البيضاء",
    "Category:LGBT rights in Belgium": "تصنيف:حقوق المثليين في بلجيكا",
    "Category:LGBT rights in Belize": "تصنيف:حقوق المثليين في بليز",
    "Category:LGBT rights in Bermuda": "تصنيف:حقوق المثليين في برمودا",
    "Category:LGBT rights in Bolivia": "تصنيف:حقوق المثليين في بوليفيا",
    "Category:LGBT rights in Bonaire": "تصنيف:حقوق المثليين في بونير",
    "Category:LGBT rights in Bosnia and Herzegovina by region": "تصنيف:حقوق المثليين في البوسنة والهرسك حسب المنطقة",
    "Category:LGBT rights in Brazil": "تصنيف:حقوق المثليين في البرازيل",
    "Category:LGBT rights in British Overseas Territories": "تصنيف:حقوق المثليين في أقاليم ما وراء البحار البريطانية",
    "Category:LGBT rights in Bulgaria": "تصنيف:حقوق المثليين في بلغاريا",
    "Category:LGBT rights in Cambodia": "تصنيف:حقوق المثليين في كمبوديا",
    "Category:LGBT rights in Cameroon": "تصنيف:حقوق المثليين في الكاميرون",
    "Category:LGBT rights in Canada": "تصنيف:حقوق المثليين في كندا",
    "Category:LGBT rights in Central America": "تصنيف:حقوق المثليين في أمريكا الوسطى",
    "Category:LGBT rights in Chile": "تصنيف:حقوق المثليين في تشيلي",
    "Category:LGBT rights in China": "تصنيف:حقوق المثليين في الصين",
    "Category:LGBT rights in Colombia": "تصنيف:حقوق المثليين في كولومبيا",
    "Category:LGBT rights in Costa Rica": "تصنيف:حقوق المثليين في كوستاريكا",
    "Category:LGBT rights in Croatia": "تصنيف:حقوق المثليين في كرواتيا",
    "Category:LGBT rights in Cuba": "تصنيف:حقوق المثليين في كوبا",
    "Category:LGBT rights in Curaçao": "تصنيف:حقوق المثليين في كوراساو",
    "Category:LGBT rights in Cyprus": "تصنيف:حقوق المثليين في قبرص",
    "Category:LGBT rights in Denmark": "تصنيف:حقوق المثليين في الدنمارك",
    "Category:LGBT rights in Ecuador": "تصنيف:حقوق المثليين في الإكوادور",
    "Category:LGBT rights in Egypt": "تصنيف:حقوق المثليين في مصر",
    "Category:LGBT rights in El Salvador": "تصنيف:حقوق المثليين في السلفادور",
    "Category:LGBT rights in England": "تصنيف:حقوق المثليين في إنجلترا",
    "Category:LGBT rights in Estonia": "تصنيف:حقوق المثليين في إستونيا",
    "Category:LGBT rights in Eswatini": "تصنيف:حقوق المثليين في إسواتيني",
    "Category:LGBT rights in Europe": "تصنيف:حقوق المثليين في أوروبا",
    "Category:LGBT rights in Europe by country": "تصنيف:حقوق المثليين في أوروبا حسب البلد",
    "Category:LGBT rights in Fiji by region": "تصنيف:حقوق المثليين في فيجي حسب المنطقة",
    "Category:LGBT rights in Finland": "تصنيف:حقوق المثليين في فنلندا",
    "Category:LGBT rights in France": "تصنيف:حقوق المثليين في فرنسا",
    "Category:LGBT rights in France by region": "تصنيف:حقوق المثليين في فرنسا حسب المنطقة",
    "Category:LGBT rights in Germany": "تصنيف:حقوق المثليين في ألمانيا",
    "Category:LGBT rights in Gibraltar": "تصنيف:حقوق المثليين في جبل طارق",
    "Category:LGBT rights in Greece": "تصنيف:حقوق المثليين في اليونان",
    "Category:LGBT rights in Greenland": "تصنيف:حقوق المثليين في جرينلاند",
    "Category:LGBT rights in Guatemala": "تصنيف:حقوق المثليين في غواتيمالا",
    "Category:LGBT rights in Guernsey": "تصنيف:حقوق المثليين في غيرنزي",
    "Category:LGBT rights in Guyana": "تصنيف:حقوق المثليين في غيانا",
    "Category:LGBT rights in Hawaii": "تصنيف:حقوق المثليين في هاواي",
    "Category:LGBT rights in Honduras": "تصنيف:حقوق المثليين في هندوراس",
    "Category:LGBT rights in Hong Kong": "تصنيف:حقوق المثليين في هونغ كونغ",
    "Category:LGBT rights in Hungary": "تصنيف:حقوق المثليين في المجر",
    "Category:LGBT rights in Iceland": "تصنيف:حقوق المثليين في آيسلندا",
    "Category:LGBT rights in India": "تصنيف:حقوق المثليين في الهند",
    "Category:LGBT rights in India by state": "تصنيف:حقوق المثليين في الهند حسب الولاية",
    "Category:LGBT rights in Indiana": "تصنيف:حقوق المثليين في إنديانا",
    "Category:LGBT rights in Indonesia": "تصنيف:حقوق المثليين في إندونيسيا",
    "Category:LGBT rights in Indonesia by province": "تصنيف:حقوق المثليين في إندونيسيا حسب المقاطعة",
    "Category:LGBT rights in Iran": "تصنيف:حقوق المثليين في إيران",
    "Category:LGBT rights in Iraq": "تصنيف:حقوق المثليين في العراق",
    "Category:LGBT rights in Iraq by region": "تصنيف:حقوق المثليين في العراق حسب المنطقة",
    "Category:LGBT rights in Israel": "تصنيف:حقوق المثليين في إسرائيل",
    "Category:LGBT rights in Italy": "تصنيف:حقوق المثليين في إيطاليا",
    "Category:LGBT rights in Ivory Coast": "تصنيف:حقوق المثليين في ساحل العاج",
    "Category:LGBT rights in Jamaica": "تصنيف:حقوق المثليين في جامايكا",
    "Category:LGBT rights in Japan": "تصنيف:حقوق المثليين في اليابان",
    "Category:LGBT rights in Jersey": "تصنيف:حقوق المثليين في جيرزي",
    "Category:LGBT rights in Kurdistan": "تصنيف:حقوق المثليين في كردستان",
    "Category:LGBT rights in Kyrgyzstan": "تصنيف:حقوق المثليين في قيرغيزستان",
    "Category:LGBT rights in Latvia": "تصنيف:حقوق المثليين في لاتفيا",
    "Category:LGBT rights in Lebanon": "تصنيف:حقوق المثليين في لبنان",
    "Category:LGBT rights in Liechtenstein": "تصنيف:حقوق المثليين في ليختنشتاين",
    "Category:LGBT rights in Lithuania": "تصنيف:حقوق المثليين في ليتوانيا",
    "Category:LGBT rights in Luxembourg": "تصنيف:حقوق المثليين في لوكسمبورغ",
    "Category:LGBT rights in Maine": "تصنيف:حقوق المثليين في مين",
    "Category:LGBT rights in Malaysia": "تصنيف:حقوق المثليين في ماليزيا",
    "Category:LGBT rights in Malta": "تصنيف:حقوق المثليين في مالطا",
    "Category:LGBT rights in Massachusetts": "تصنيف:حقوق المثليين في ماساتشوستس",
    "Category:LGBT rights in Mexico": "تصنيف:حقوق المثليين في المكسيك",
    "Category:LGBT rights in Moldova": "تصنيف:حقوق المثليين في مولدوفا",
    "Category:LGBT rights in Monaco": "تصنيف:حقوق المثليين في موناكو",
    "Category:LGBT rights in Montenegro": "تصنيف:حقوق المثليين في الجبل الأسود",
    "Category:LGBT rights in Morocco": "تصنيف:حقوق المثليين في المغرب",
    "Category:LGBT rights in Myanmar": "تصنيف:حقوق المثليين في ميانمار",
    "Category:LGBT rights in Nepal": "تصنيف:حقوق المثليين في نيبال",
    "Category:LGBT rights in New Zealand": "تصنيف:حقوق المثليين في نيوزيلندا",
    "Category:LGBT rights in Nicaragua": "تصنيف:حقوق المثليين في نيكاراغوا",
    "Category:LGBT rights in Nigeria": "تصنيف:حقوق المثليين في نيجيريا",
    "Category:LGBT rights in Niue": "تصنيف:حقوق المثليين في نييوي",
    "Category:LGBT rights in North America": "تصنيف:حقوق المثليين في أمريكا الشمالية",
    "Category:LGBT rights in North America by country": "تصنيف:حقوق المثليين في أمريكا الشمالية حسب البلد",
    "Category:LGBT rights in North Macedonia": "تصنيف:حقوق المثليين في مقدونيا الشمالية",
    "Category:LGBT rights in Northern Ireland": "تصنيف:حقوق المثليين في أيرلندا الشمالية",
    "Category:LGBT rights in Norway": "تصنيف:حقوق المثليين في النرويج",
    "Category:LGBT rights in Norway by region": "تصنيف:حقوق المثليين في النرويج حسب المنطقة",
    "Category:LGBT rights in Oceania": "تصنيف:حقوق المثليين في أوقيانوسيا",
    "Category:LGBT rights in Oceania by country": "تصنيف:حقوق المثليين في أوقيانوسيا حسب البلد",
    "Category:LGBT rights in Pakistan": "تصنيف:حقوق المثليين في باكستان",
    "Category:LGBT rights in Panama": "تصنيف:حقوق المثليين في بنما",
    "Category:LGBT rights in Papua New Guinea": "تصنيف:حقوق المثليين في بابوا غينيا الجديدة",
    "Category:LGBT rights in Paraguay": "تصنيف:حقوق المثليين في باراغواي",
    "Category:LGBT rights in Peru": "تصنيف:حقوق المثليين في بيرو",
    "Category:LGBT rights in Poland": "تصنيف:حقوق المثليين في بولندا",
    "Category:LGBT rights in Portugal": "تصنيف:حقوق المثليين في البرتغال",
    "Category:LGBT rights in Portugal by region": "تصنيف:حقوق المثليين في البرتغال حسب المنطقة",
    "Category:LGBT rights in Puerto Rico": "تصنيف:حقوق المثليين في بورتوريكو",
    "Category:LGBT rights in Romania": "تصنيف:حقوق المثليين في رومانيا",
    "Category:LGBT rights in Russia": "تصنيف:حقوق المثليين في روسيا",
    "Category:LGBT rights in Russia by region": "تصنيف:حقوق المثليين في روسيا حسب المنطقة",
    "Category:LGBT rights in Saba": "تصنيف:حقوق المثليين في سابا",
    "Category:LGBT rights in Saint Helena, Ascension and Tristan da Cunha": "تصنيف:حقوق المثليين في سانت هيلينا وأسينشين وتريستان دا كونا",
    "Category:LGBT rights in Saint Lucia": "تصنيف:حقوق المثليين في سانت لوسيا",
    "Category:LGBT rights in San Marino": "تصنيف:حقوق المثليين في سان مارينو",
    "Category:LGBT rights in Scotland": "تصنيف:حقوق المثليين في إسكتلندا",
    "Category:LGBT rights in Serbia": "تصنيف:حقوق المثليين في صربيا",
    "Category:LGBT rights in Serbia by region": "تصنيف:حقوق المثليين في صربيا حسب المنطقة",
    "Category:LGBT rights in Sierra Leone": "تصنيف:حقوق المثليين في سيراليون",
    "Category:LGBT rights in Singapore": "تصنيف:حقوق المثليين في سنغافورة",
    "Category:LGBT rights in Sint Eustatius": "تصنيف:حقوق المثليين في سينت أوستاتيوس",
    "Category:LGBT rights in Sint Maarten": "تصنيف:حقوق المثليين في سينت مارتن",
    "Category:LGBT rights in Slovakia": "تصنيف:حقوق المثليين في سلوفاكيا",
    "Category:LGBT rights in Slovenia": "تصنيف:حقوق المثليين في سلوفينيا",
    "Category:LGBT rights in South America": "تصنيف:حقوق المثليين في أمريكا الجنوبية",
    "Category:LGBT rights in South America by country": "تصنيف:حقوق المثليين في أمريكا الجنوبية حسب البلد",
    "Category:LGBT rights in South Korea": "تصنيف:حقوق المثليين في كوريا الجنوبية",
    "Category:LGBT rights in Spain": "تصنيف:حقوق المثليين في إسبانيا",
    "Category:LGBT rights in Sri Lanka": "تصنيف:حقوق المثليين في سريلانكا",
    "Category:LGBT rights in Suriname": "تصنيف:حقوق المثليين في سورينام",
    "Category:LGBT rights in Sweden": "تصنيف:حقوق المثليين في السويد",
    "Category:LGBT rights in Switzerland": "تصنيف:حقوق المثليين في سويسرا",
    "Category:LGBT rights in Syria": "تصنيف:حقوق المثليين في سوريا",
    "Category:LGBT rights in Taiwan": "تصنيف:حقوق المثليين في تايوان",
    "Category:LGBT rights in Thailand": "تصنيف:حقوق المثليين في تايلاند",
    "Category:LGBT rights in Tonga": "تصنيف:حقوق المثليين في تونغا",
    "Category:LGBT rights in Transnistria": "تصنيف:حقوق المثليين في ترانسنيستريا",
    "Category:LGBT rights in Trinidad and Tobago": "تصنيف:حقوق المثليين في ترينيداد وتوباغو",
    "Category:LGBT rights in Turkey": "تصنيف:حقوق المثليين في تركيا",
    "Category:LGBT rights in Uganda": "تصنيف:حقوق المثليين في أوغندا",
    "Category:LGBT rights in Ukraine": "تصنيف:حقوق المثليين في أوكرانيا",
    "Category:LGBT rights in Uruguay": "تصنيف:حقوق المثليين في أوروغواي",
    "Category:LGBT rights in Uzbekistan": "تصنيف:حقوق المثليين في أوزبكستان",
    "Category:LGBT rights in Venezuela": "تصنيف:حقوق المثليين في فنزويلا",
    "Category:LGBT rights in Vietnam": "تصنيف:حقوق المثليين في فيتنام",
    "Category:LGBT rights in Wales": "تصنيف:حقوق المثليين في ويلز",
    "Category:LGBT rights in insular areas of the United States": "تصنيف:حقوق المثليين في المناطق المعزولة في الولايات المتحدة",
    "Category:LGBT rights in the Americas": "تصنيف:حقوق المثليين في الأمريكتين",
    "Category:LGBT rights in the Bahamas": "تصنيف:حقوق المثليين في باهاماس",
    "Category:LGBT rights in the Caribbean": "تصنيف:حقوق المثليين في الكاريبي",
    "Category:LGBT rights in the Cayman Islands": "تصنيف:حقوق المثليين في جزر كايمان",
    "Category:LGBT rights in the Comoros": "تصنيف:حقوق المثليين في جزر القمر",
    "Category:LGBT rights in the Cook Islands": "تصنيف:حقوق المثليين في جزر كوك",
    "Category:LGBT rights in the Crown Dependencies": "تصنيف:حقوق المثليين في تبعيات التاج البريطاني",
    "Category:LGBT rights in the Czech Republic": "تصنيف:حقوق المثليين في جمهورية التشيك",
    "Category:LGBT rights in the Falkland Islands": "تصنيف:حقوق المثليين في جزر فوكلاند",
    "Category:LGBT rights in the Faroe Islands": "تصنيف:حقوق المثليين في جزر فارو",
    "Category:LGBT rights in the Isle of Man": "تصنيف:حقوق المثليين في جزيرة مان",
    "Category:LGBT rights in the Netherlands": "تصنيف:حقوق المثليين في هولندا",
    "Category:LGBT rights in the Nordic countries": "تصنيف:حقوق المثليين في بلدان نوردية",
    "Category:LGBT rights in the People's Republic of China": "تصنيف:حقوق المثليين في جمهورية الصين الشعبية",
    "Category:LGBT rights in the Philippines": "تصنيف:حقوق المثليين في الفلبين",
    "Category:LGBT rights in republic of Ireland": "تصنيف:حقوق المثليين في جمهورية أيرلندا",
    "Category:LGBT rights in republic of congo": "تصنيف:حقوق المثليين في جمهورية الكونغو",
    "Category:LGBT rights in the Solomon Islands": "تصنيف:حقوق المثليين في جزر سليمان",
    "Category:LGBT rights in the Soviet Union": "تصنيف:حقوق المثليين في الاتحاد السوفيتي",
    "Category:LGBT rights in the United Arab Emirates": "تصنيف:حقوق المثليين في الإمارات العربية المتحدة",
    "Category:LGBT rights in the United Kingdom": "تصنيف:حقوق المثليين في المملكة المتحدة",
    "Category:LGBT rights in the United Kingdom by country": "تصنيف:حقوق المثليين في المملكة المتحدة حسب البلد",
    "Category:LGBT rights in the United States": "تصنيف:حقوق المثليين في الولايات المتحدة",
    "Category:LGBT rights in the United States Virgin Islands": "تصنيف:حقوق المثليين في جزر العذراء الأمريكية",
    "Category:LGBT rights in the United States by region": "تصنيف:حقوق المثليين في الولايات المتحدة حسب المنطقة",
    "Category:LGBT rights in the United States by state": "تصنيف:حقوق المثليين في الولايات المتحدة حسب الولاية",
    "Category:LGBT rights movement": "تصنيف:حركة حقوق المثليين",
    "Category:LGBT rights organizations": "تصنيف:منظمات حقوق المثليين",
    "Category:LGBT rights table templates": "تصنيف:قوالب جدول حقوق المثليين",
    "Category:LGBT rights templates": "تصنيف:قوالب حقوق المثليين",
    "Category:LGBT terminology": "تصنيف:مصطلحات المثليين",
    "Category:LGBT theatre": "تصنيف:مسرح المثليين",
    "Category:LGBT timelines": "تصنيف:التسلسلات الزمنية للمثليين",
    "Category:LGBT tourism": "تصنيف:سياحة المثليين",
    "Category:LGBTQ beauty pageants": "تصنيف:مسابقات الجمال للمثليين",
    "Category:LGBTQ culture": "تصنيف:ثقافة المثليين",
    "Category:LGBTQ culture by city": "تصنيف:ثقافة المثليين حسب المدينة",
    "Category:LGBTQ culture by continent": "تصنيف:ثقافة المثليين حسب القارة",
    "Category:LGBTQ culture by country": "تصنيف:ثقافة المثليين حسب البلد",
    "Category:LGBTQ culture by location": "تصنيف:ثقافة المثليين حسب الموقع",
    "Category:LGBTQ culture in Asia": "تصنيف:ثقافة المثليين في آسيا",
    "Category:LGBTQ culture in Australia": "تصنيف:ثقافة المثليين في أستراليا",
    "Category:LGBTQ culture in Australia by city": "تصنيف:ثقافة المثليين في أستراليا حسب المدينة",
    "Category:LGBTQ culture in Brazil": "تصنيف:ثقافة المثليين في البرازيل",
    "Category:LGBTQ culture in Canada": "تصنيف:ثقافة المثليين في كندا",
    "Category:LGBTQ culture in Denmark": "تصنيف:ثقافة المثليين في الدنمارك",
    "Category:LGBTQ culture in England": "تصنيف:ثقافة المثليين في إنجلترا",
    "Category:LGBTQ culture in Europe": "تصنيف:ثقافة المثليين في أوروبا",
    "Category:LGBTQ culture in France": "تصنيف:ثقافة المثليين في فرنسا",
    "Category:LGBTQ culture in Germany": "تصنيف:ثقافة المثليين في ألمانيا",
    "Category:LGBTQ culture in Greenland": "تصنيف:ثقافة المثليين في جرينلاند",
    "Category:LGBTQ culture in India": "تصنيف:ثقافة المثليين في الهند",
    "Category:LGBTQ culture in Ireland": "تصنيف:ثقافة المثليين في أيرلندا",
    "Category:LGBTQ culture in Italy": "تصنيف:ثقافة المثليين في إيطاليا",
    "Category:LGBTQ culture in Japan": "تصنيف:ثقافة المثليين في اليابان",
    "Category:LGBTQ culture in Liverpool": "تصنيف:ثقافة المثليين في ليفربول",
    "Category:LGBTQ culture in London": "تصنيف:ثقافة المثليين في لندن",
    "Category:LGBTQ culture in Mexico": "تصنيف:ثقافة المثليين في المكسيك",
    "Category:LGBTQ culture in North America": "تصنيف:ثقافة المثليين في أمريكا الشمالية",
    "Category:LGBTQ culture in Norway": "تصنيف:ثقافة المثليين في النرويج",
    "Category:LGBTQ culture in Scotland": "تصنيف:ثقافة المثليين في إسكتلندا",
    "Category:LGBTQ culture in South America": "تصنيف:ثقافة المثليين في أمريكا الجنوبية",
    "Category:LGBTQ culture in Spain": "تصنيف:ثقافة المثليين في إسبانيا",
    "Category:LGBTQ culture in Sydney": "تصنيف:ثقافة المثليين في سيدني",
    "Category:LGBTQ culture in the Netherlands": "تصنيف:ثقافة المثليين في هولندا",
    "Category:LGBTQ culture in the United Kingdom": "تصنيف:ثقافة المثليين في المملكة المتحدة",
    "Category:LGBTQ culture in the United Kingdom by city": "تصنيف:ثقافة المثليين في المملكة المتحدة حسب المدينة",
    "Category:LGBTQ drinking establishments": "تصنيف:مؤسسات الشرب للمثليين",
    "Category:LGBTQ events": "تصنيف:أحداث المثليين",
    "Category:LGBTQ events by country": "تصنيف:أحداث متعلقة بالمثليين حسب البلد",
    "Category:LGBTQ events in Brazil": "تصنيف:أحداث المثليين في البرازيل",
    "Category:LGBTQ events in Denmark": "تصنيف:أحداث متعلقة بالمثليين في الدنمارك",
    "Category:LGBTQ events in Ireland": "تصنيف:أحداث متعلقة بالمثليين في أيرلندا",
    "Category:LGBTQ festivals": "تصنيف:مهرجانات المثليين",
    "Category:LGBTQ film festivals": "تصنيف:مهرجانات أفلام المثليين",
    "Category:LGBTQ health organizations": "تصنيف:منظمات الصحة المعنية بالمثليين",
    "Category:LGBTQ health organizations in the United States": "تصنيف:منظمات الصحة المعنية بالمثليين في الولايات المتحدة",
    "Category:LGBTQ history by country": "تصنيف:تاريخ المثليين حسب البلد",
    "Category:LGBTQ history in Denmark": "تصنيف:تاريخ المثليين في الدنمارك",
    "Category:LGBTQ history in Germany": "تصنيف:تاريخ المثليين في ألمانيا",
    "Category:LGBTQ history in Ireland": "تصنيف:تاريخ المثليين في أيرلندا",
    "Category:LGBTQ history in Italy": "تصنيف:تاريخ المثليين في إيطاليا",
    "Category:LGBTQ history in Peru": "تصنيف:تاريخ المثليين في بيرو",
    "Category:LGBTQ history in the United Kingdom": "تصنيف:تاريخ المثليين في المملكة المتحدة",
    "Category:LGBTQ in the Arab world": "تصنيف:معاملة المثليين في الوطن العربي",
    "Category:LGBTQ in the Middle East": "تصنيف:معاملة المثليين في الشرق الأوسط",
    "Category:LGBTQ monuments and memorials": "تصنيف:معالم أثرية ونصب تذكارية متعلقة بمثليين",
    "Category:LGBTQ monuments and memorials in the United States": "تصنيف:معالم ونصب تذكارية لمثليين في الولايات المتحدة",
    "Category:LGBTQ nightclubs": "تصنيف:نوادي ليلية للمثليين",
    "Category:LGBTQ organizations based in Iceland": "تصنيف:منظمات المثليين في آيسلندا",
    "Category:LGBTQ parenting": "تصنيف:الأبوة والأمومة عند المثليين",
    "Category:LGBTQ parenting in North America": "تصنيف:الأبوة والأمومة عند المثليين في أمريكا الشمالية",
    "Category:LGBTQ parenting in the United States": "تصنيف:الأبوة والأمومة عند المثليين في الولايات المتحدة",
    "Category:LGBTQ poetry": "تصنيف:شعر المثليين",
    "Category:LGBTQ political advocacy groups by country": "تصنيف:جمعيات تأييد سياسي للمثليين حسب البلد",
    "Category:LGBTQ political advocacy groups in Brazil": "تصنيف:جمعيات تأييد سياسي للمثليين في البرازيل",
    "Category:LGBTQ political advocacy groups in Denmark": "تصنيف:جمعيات تأييد سياسي للمثليين في الدنمارك",
    "Category:LGBTQ political advocacy groups in Iceland": "تصنيف:جمعيات تأييد سياسي للمثليين في آيسلندا",
    "Category:LGBTQ political advocacy groups in Morocco": "تصنيف:جمعيات تأييد سياسي للمثليين في المغرب",
    "Category:LGBTQ political advocacy groups in Russia": "تصنيف:جمعيات تأييد سياسي للمثليين في روسيا",
    "Category:LGBTQ political advocacy groups in the Netherlands": "تصنيف:جمعيات تأييد سياسي للمثليين في هولندا",
    "Category:LGBTQ political advocacy groups in republic of Ireland": "تصنيف:جمعيات تأييد سياسي للمثليين في جمهورية أيرلندا",
    "Category:LGBTQ politics": "تصنيف:سياسة المثليين جنسيا",
    "Category:LGBTQ rights": "تصنيف:معاملة المثليين جنسيا",
    "Category:LGBTQ rights by continent": "تصنيف:معاملة المثليين حسب القارة",
    "Category:LGBTQ rights by country": "تصنيف:معاملة المثليين حسب البلد",
    "Category:LGBTQ rights by country subdivision": "تصنيف:معاملة المثليين حسب المستوى دون الوطني للبلد",
    "Category:LGBTQ rights by former country": "تصنيف:معاملة المثليين حسب البلد السابق",
    "Category:LGBTQ rights by issue": "تصنيف:معاملة المثليين حسب القضية",
    "Category:LGBTQ rights by location": "تصنيف:معاملة المثليين حسب المنطقة",
    "Category:LGBTQ rights case law": "تصنيف:قضايا محاكم حول معاملة المثليين",
    "Category:LGBTQ rights in Africa": "تصنيف:معاملة المثليين في إفريقيا",
    "Category:LGBTQ rights in Akrotiri and Dhekelia": "تصنيف:معاملة المثليين في أكروتيري ودكليا",
    "Category:LGBTQ rights in Albania": "تصنيف:معاملة المثليين في ألبانيا",
    "Category:LGBTQ rights in Andorra": "تصنيف:معاملة المثليين في أندورا",
    "Category:LGBTQ rights in Argentina": "تصنيف:معاملة المثليين في الأرجنتين",
    "Category:LGBTQ rights in Armenia": "تصنيف:معاملة المثليين في أرمينيا",
    "Category:LGBTQ rights in Aruba": "تصنيف:معاملة المثليين في أروبا",
    "Category:LGBTQ rights in Asia": "تصنيف:معاملة المثليين في آسيا",
    "Category:LGBTQ rights in Australia": "تصنيف:معاملة المثليين في أستراليا",
    "Category:LGBTQ rights in Australia by state or territory": "تصنيف:معاملة المثليين في أستراليا حسب الولاية أو الإقليم",
    "Category:LGBTQ rights in Austria": "تصنيف:معاملة المثليين في النمسا",
    "Category:LGBTQ rights in Azerbaijan": "تصنيف:معاملة المثليين في أذربيجان",
    "Category:LGBTQ rights in Barbados": "تصنيف:معاملة المثليين في بربادوس",
    "Category:LGBTQ rights in Belarus": "تصنيف:معاملة المثليين في روسيا البيضاء",
    "Category:LGBTQ rights in Belgium": "تصنيف:معاملة المثليين في بلجيكا",
    "Category:LGBTQ rights in Belize": "تصنيف:معاملة المثليين في بليز",
    "Category:LGBTQ rights in Bermuda": "تصنيف:معاملة المثليين في برمودا",
    "Category:LGBTQ rights in Bolivia": "تصنيف:معاملة المثليين في بوليفيا",
    "Category:LGBTQ rights in Bonaire": "تصنيف:معاملة المثليين في بونير",
    "Category:LGBTQ rights in Bosnia and Herzegovina by region": "تصنيف:معاملة المثليين في البوسنة والهرسك حسب المنطقة",
    "Category:LGBTQ rights in Brazil": "تصنيف:معاملة المثليين في البرازيل",
    "Category:LGBTQ rights in Bulgaria": "تصنيف:معاملة المثليين في بلغاريا",
    "Category:LGBTQ rights in Cambodia": "تصنيف:معاملة المثليين في كمبوديا",
    "Category:LGBTQ rights in Cameroon": "تصنيف:معاملة المثليين في الكاميرون",
    "Category:LGBTQ rights in Canada": "تصنيف:معاملة المثليين في كندا",
    "Category:LGBTQ rights in Central America": "تصنيف:معاملة المثليين في أمريكا الوسطى",
    "Category:LGBTQ rights in Chile": "تصنيف:معاملة المثليين في تشيلي",
    "Category:LGBTQ rights in China": "تصنيف:معاملة المثليين في الصين",
    "Category:LGBTQ rights in Colombia": "تصنيف:معاملة المثليين في كولومبيا",
    "Category:LGBTQ rights in Costa Rica": "تصنيف:معاملة المثليين في كوستاريكا",
    "Category:LGBTQ rights in Croatia": "تصنيف:معاملة المثليين في كرواتيا",
    "Category:LGBTQ rights in Cuba": "تصنيف:معاملة المثليين في كوبا",
    "Category:LGBTQ rights in Curaçao": "تصنيف:معاملة المثليين في كوراساو",
    "Category:LGBTQ rights in Cyprus": "تصنيف:معاملة المثليين في قبرص",
    "Category:LGBTQ rights in Denmark": "تصنيف:معاملة المثليين في الدنمارك",
    "Category:LGBTQ rights in Ecuador": "تصنيف:معاملة المثليين في الإكوادور",
    "Category:LGBTQ rights in Egypt": "تصنيف:معاملة المثليين في مصر",
    "Category:LGBTQ rights in El Salvador": "تصنيف:معاملة المثليين في السلفادور",
    "Category:LGBTQ rights in England": "تصنيف:معاملة المثليين في إنجلترا",
    "Category:LGBTQ rights in Estonia": "تصنيف:معاملة المثليين في إستونيا",
    "Category:LGBTQ rights in Eswatini": "تصنيف:معاملة المثليين في إسواتيني",
    "Category:LGBTQ rights in Ethiopia": "تصنيف:معاملة المثليين في إثيوبيا",
    "Category:LGBTQ rights in Europe": "تصنيف:معاملة المثليين في أوروبا",
    "Category:LGBTQ rights in Finland": "تصنيف:معاملة المثليين في فنلندا",
    "Category:LGBTQ rights in France": "تصنيف:معاملة المثليين في فرنسا",
    "Category:LGBTQ rights in France by region": "تصنيف:معاملة المثليين في فرنسا حسب المنطقة",
    "Category:LGBTQ rights in Germany": "تصنيف:معاملة المثليين في ألمانيا",
    "Category:LGBTQ rights in Gibraltar": "تصنيف:معاملة المثليين في جبل طارق",
    "Category:LGBTQ rights in Greece": "تصنيف:معاملة المثليين في اليونان",
    "Category:LGBTQ rights in Greenland": "تصنيف:معاملة المثليين في جرينلاند",
    "Category:LGBTQ rights in Guatemala": "تصنيف:معاملة المثليين في غواتيمالا",
    "Category:LGBTQ rights in Guernsey": "تصنيف:معاملة المثليين في غيرنزي",
    "Category:LGBTQ rights in Guyana": "تصنيف:معاملة المثليين في غيانا",
    "Category:LGBTQ rights in Hawaii": "تصنيف:معاملة المثليين في هاواي",
    "Category:LGBTQ rights in Honduras": "تصنيف:معاملة المثليين في هندوراس",
    "Category:LGBTQ rights in Hong Kong": "تصنيف:معاملة المثليين في هونغ كونغ",
    "Category:LGBTQ rights in Hungary": "تصنيف:معاملة المثليين في المجر",
    "Category:LGBTQ rights in Iceland": "تصنيف:معاملة المثليين في آيسلندا",
    "Category:LGBTQ rights in India": "تصنيف:معاملة المثليين في الهند",
    "Category:LGBTQ rights in India by state": "تصنيف:معاملة المثليين في الهند حسب الولاية",
    "Category:LGBTQ rights in Indiana": "تصنيف:معاملة المثليين في إنديانا",
    "Category:LGBTQ rights in Indonesia": "تصنيف:معاملة المثليين في إندونيسيا",
    "Category:LGBTQ rights in Indonesia by province": "تصنيف:معاملة المثليين في إندونيسيا حسب المقاطعة",
    "Category:LGBTQ rights in Iran": "تصنيف:معاملة المثليين في إيران",
    "Category:LGBTQ rights in Iraq": "تصنيف:معاملة المثليين في العراق",
    "Category:LGBTQ rights in Iraq by region": "تصنيف:معاملة المثليين في العراق حسب المنطقة",
    "Category:LGBTQ rights in Israel": "تصنيف:معاملة المثليين في إسرائيل",
    "Category:LGBTQ rights in Italy": "تصنيف:معاملة المثليين في إيطاليا",
    "Category:LGBTQ rights in Ivory Coast": "تصنيف:معاملة المثليين في ساحل العاج",
    "Category:LGBTQ rights in Jamaica": "تصنيف:معاملة المثليين في جامايكا",
    "Category:LGBTQ rights in Japan": "تصنيف:معاملة المثليين في اليابان",
    "Category:LGBTQ rights in Jersey": "تصنيف:معاملة المثليين في جيرزي",
    "Category:LGBTQ rights in Kyrgyzstan": "تصنيف:معاملة المثليين في قيرغيزستان",
    "Category:LGBTQ rights in Latin America": "تصنيف:معاملة المثليين في أمريكا اللاتينية",
    "Category:LGBTQ rights in Latvia": "تصنيف:معاملة المثليين في لاتفيا",
    "Category:LGBTQ rights in Lebanon": "تصنيف:معاملة المثليين في لبنان",
    "Category:LGBTQ rights in Liechtenstein": "تصنيف:معاملة المثليين في ليختنشتاين",
    "Category:LGBTQ rights in Lithuania": "تصنيف:معاملة المثليين في ليتوانيا",
    "Category:LGBTQ rights in Luxembourg": "تصنيف:معاملة المثليين في لوكسمبورغ",
    "Category:LGBTQ rights in Maine": "تصنيف:معاملة المثليين في مين",
    "Category:LGBTQ rights in Malaysia": "تصنيف:معاملة المثليين في ماليزيا",
    "Category:LGBTQ rights in Malta": "تصنيف:معاملة المثليين في مالطا",
    "Category:LGBTQ rights in Massachusetts": "تصنيف:معاملة المثليين في ماساتشوستس",
    "Category:LGBTQ rights in Mexico": "تصنيف:معاملة المثليين في المكسيك",
    "Category:LGBTQ rights in Moldova": "تصنيف:معاملة المثليين في مولدوفا",
    "Category:LGBTQ rights in Monaco": "تصنيف:معاملة المثليين في موناكو",
    "Category:LGBTQ rights in Montenegro": "تصنيف:معاملة المثليين في الجبل الأسود",
    "Category:LGBTQ rights in Morocco": "تصنيف:معاملة المثليين في المغرب",
    "Category:LGBTQ rights in Myanmar": "تصنيف:معاملة المثليين في ميانمار",
    "Category:LGBTQ rights in Nepal": "تصنيف:معاملة المثليين في نيبال",
    "Category:LGBTQ rights in New Zealand": "تصنيف:معاملة المثليين في نيوزيلندا",
    "Category:LGBTQ rights in Nicaragua": "تصنيف:معاملة المثليين في نيكاراغوا",
    "Category:LGBTQ rights in Nigeria": "تصنيف:معاملة المثليين في نيجيريا",
    "Category:LGBTQ rights in Niue": "تصنيف:معاملة المثليين في نييوي",
    "Category:LGBTQ rights in North America": "تصنيف:معاملة المثليين في أمريكا الشمالية",
    "Category:LGBTQ rights in North Macedonia": "تصنيف:معاملة المثليين في مقدونيا الشمالية",
    "Category:LGBTQ rights in Northern Ireland": "تصنيف:معاملة المثليين في أيرلندا الشمالية",
    "Category:LGBTQ rights in Norway": "تصنيف:معاملة المثليين في النرويج",
    "Category:LGBTQ rights in Norway by region": "تصنيف:معاملة المثليين في النرويج حسب المنطقة",
    "Category:LGBTQ rights in Oceania": "تصنيف:معاملة المثليين في أوقيانوسيا",
    "Category:LGBTQ rights in Pakistan": "تصنيف:معاملة المثليين في باكستان",
    "Category:LGBTQ rights in Panama": "تصنيف:معاملة المثليين في بنما",
    "Category:LGBTQ rights in Papua New Guinea": "تصنيف:معاملة المثليين في بابوا غينيا الجديدة",
    "Category:LGBTQ rights in Paraguay": "تصنيف:معاملة المثليين في باراغواي",
    "Category:LGBTQ rights in Peru": "تصنيف:معاملة المثليين في بيرو",
    "Category:LGBTQ rights in Poland": "تصنيف:معاملة المثليين في بولندا",
    "Category:LGBTQ rights in Portugal": "تصنيف:معاملة المثليين في البرتغال",
    "Category:LGBTQ rights in Puerto Rico": "تصنيف:معاملة المثليين في بورتوريكو",
    "Category:LGBTQ rights in Romania": "تصنيف:معاملة المثليين في رومانيا",
    "Category:LGBTQ rights in Russia": "تصنيف:معاملة المثليين في روسيا",
    "Category:LGBTQ rights in Russia by region": "تصنيف:معاملة المثليين في روسيا حسب المنطقة",
    "Category:LGBTQ rights in Saba": "تصنيف:معاملة المثليين في سابا",
    "Category:LGBTQ rights in Saint Helena, Ascension and Tristan da Cunha": "تصنيف:معاملة المثليين في سانت هيلينا وأسينشين وتريستان دا كونا",
    "Category:LGBTQ rights in Saint Lucia": "تصنيف:معاملة المثليين في سانت لوسيا",
    "Category:LGBTQ rights in San Marino": "تصنيف:معاملة المثليين في سان مارينو",
    "Category:LGBTQ rights in Scotland": "تصنيف:معاملة المثليين في إسكتلندا",
    "Category:LGBTQ rights in Serbia": "تصنيف:معاملة المثليين في صربيا",
    "Category:LGBTQ rights in Sierra Leone": "تصنيف:معاملة المثليين في سيراليون",
    "Category:LGBTQ rights in Singapore": "تصنيف:معاملة المثليين في سنغافورة",
    "Category:LGBTQ rights in Sint Eustatius": "تصنيف:معاملة المثليين في سينت أوستاتيوس",
    "Category:LGBTQ rights in Sint Maarten": "تصنيف:معاملة المثليين في سينت مارتن",
    "Category:LGBTQ rights in Slovakia": "تصنيف:معاملة المثليين في سلوفاكيا",
    "Category:LGBTQ rights in Slovenia": "تصنيف:معاملة المثليين في سلوفينيا",
    "Category:LGBTQ rights in South America": "تصنيف:معاملة المثليين في أمريكا الجنوبية",
    "Category:LGBTQ rights in South Korea": "تصنيف:معاملة المثليين في كوريا الجنوبية",
    "Category:LGBTQ rights in Spain": "تصنيف:معاملة المثليين في إسبانيا",
    "Category:LGBTQ rights in Sri Lanka": "تصنيف:معاملة المثليين في سريلانكا",
    "Category:LGBTQ rights in Suriname": "تصنيف:معاملة المثليين في سورينام",
    "Category:LGBTQ rights in Sweden": "تصنيف:معاملة المثليين في السويد",
    "Category:LGBTQ rights in Switzerland": "تصنيف:معاملة المثليين في سويسرا",
    "Category:LGBTQ rights in Syria": "تصنيف:معاملة المثليين في سوريا",
    "Category:LGBTQ rights in Taiwan": "تصنيف:معاملة المثليين في تايوان",
    "Category:LGBTQ rights in Thailand": "تصنيف:معاملة المثليين في تايلاند",
    "Category:LGBTQ rights in Tonga": "تصنيف:معاملة المثليين في تونغا",
    "Category:LGBTQ rights in Transnistria": "تصنيف:معاملة المثليين في ترانسنيستريا",
    "Category:LGBTQ rights in Trinidad and Tobago": "تصنيف:معاملة المثليين في ترينيداد وتوباغو",
    "Category:LGBTQ rights in Turkey": "تصنيف:معاملة المثليين في تركيا",
    "Category:LGBTQ rights in Uganda": "تصنيف:معاملة المثليين في أوغندا",
    "Category:LGBTQ rights in Ukraine": "تصنيف:معاملة المثليين في أوكرانيا",
    "Category:LGBTQ rights in Uruguay": "تصنيف:معاملة المثليين في أوروغواي",
    "Category:LGBTQ rights in Uzbekistan": "تصنيف:معاملة المثليين في أوزبكستان",
    "Category:LGBTQ rights in Venezuela": "تصنيف:معاملة المثليين في فنزويلا",
    "Category:LGBTQ rights in Vietnam": "تصنيف:معاملة المثليين في فيتنام",
    "Category:LGBTQ rights in Wales": "تصنيف:معاملة المثليين في ويلز",
    "Category:LGBTQ rights in dependent territories of the United Kingdom": "تصنيف:معاملة المثليين في تبعيات التاج البريطاني",
    "Category:LGBTQ rights in insular areas of the United States": "تصنيف:معاملة المثليين في المناطق المعزولة في الولايات المتحدة",
    "Category:LGBTQ rights in the Americas": "تصنيف:معاملة المثليين في الأمريكتين",
    "Category:LGBTQ rights in the Arab world": "تصنيف:حقوق المثليين في الوطن العربي",
    "Category:LGBTQ rights in the Bahamas": "تصنيف:معاملة المثليين في باهاماس",
    "Category:LGBTQ rights in the Caribbean": "تصنيف:معاملة المثليين في الكاريبي",
    "Category:LGBTQ rights in the Cayman Islands": "تصنيف:معاملة المثليين في جزر كايمان",
    "Category:LGBTQ rights in the Comoros": "تصنيف:معاملة المثليين في جزر القمر",
    "Category:LGBTQ rights in the Cook Islands": "تصنيف:معاملة المثليين في جزر كوك",
    "Category:LGBTQ rights in the Czech Republic": "تصنيف:معاملة المثليين في جمهورية التشيك",
    "Category:LGBTQ rights in the Falkland Islands": "تصنيف:معاملة المثليين في جزر فوكلاند",
    "Category:LGBTQ rights in the Faroe Islands": "تصنيف:معاملة المثليين في جزر فارو",
    "Category:LGBTQ rights in the Isle of Man": "تصنيف:معاملة المثليين في جزيرة مان",
    "Category:LGBTQ rights in the Middle East": "تصنيف:حقوق المثليين في الشرق الأوسط",
    "Category:LGBTQ rights in the Netherlands": "تصنيف:معاملة المثليين في هولندا",
    "Category:LGBTQ rights in the Philippines": "تصنيف:معاملة المثليين في الفلبين",
    "Category:LGBTQ rights in republic of Ireland": "تصنيف:معاملة المثليين في جمهورية أيرلندا",
    "Category:LGBTQ rights in republic of congo": "تصنيف:معاملة المثليين في جمهورية الكونغو",
    "Category:LGBTQ rights in the Solomon Islands": "تصنيف:معاملة المثليين في جزر سليمان",
    "Category:LGBTQ rights in the United Arab Emirates": "تصنيف:معاملة المثليين في الإمارات العربية المتحدة",
    "Category:LGBTQ rights in the United Kingdom": "تصنيف:معاملة المثليين في المملكة المتحدة",
    "Category:LGBTQ rights in the United Kingdom by country": "تصنيف:معاملة المثليين في المملكة المتحدة حسب البلد",
    "Category:LGBTQ rights in the United States": "تصنيف:معاملة المثليين في الولايات المتحدة",
    "Category:LGBTQ rights in the United States Virgin Islands": "تصنيف:معاملة المثليين في جزر العذراء الأمريكية",
    "Category:LGBTQ rights in the United States by location": "تصنيف:معاملة المثليين في الولايات المتحدة حسب المنطقة",
    "Category:LGBTQ rights in the United States by state": "تصنيف:معاملة المثليين في الولايات المتحدة حسب الولاية",
    "Category:LGBTQ rights movement": "تصنيف:حركات داعمة للمثليين",
    "Category:LGBTQ rights organizations": "تصنيف:منظمات داعمة للمثليين",
    "Category:LGBTQ rights table templates": "تصنيف:قوالب جدول معاملة المثليين",
    "Category:LGBTQ rights templates": "تصنيف:قوالب معاملة المثليين",
    "Category:LGBTQ terminology": "تصنيف:مصطلحات المثليين",
    "Category:LGBTQ theatre": "تصنيف:مسرح المثليين",
    "Category:LGBTQ timelines": "تصنيف:التسلسلات الزمنية للمثليين",
    "Category:LGBTQ tourism": "تصنيف:سياحة المثليين",
    "Category:Labour Friends of Israel": "تصنيف:أصدقاء إسرائيل العماليين",
    "Category:Landforms of Camiguin": "تصنيف:تضاريس كاميغويين",
    "Category:Landforms of Haute-Vienne": "تصنيف:تضاريس فيين العليا (إقليم فرنسي)",
    "Category:Landforms of Vienne": "تصنيف:تضاريس فيين (إقليم فرنسي)",
    "Category:Landforms of Vienne (department)": "تصنيف:تضاريس فيين (إقليم فرنسي)",
    "Category:Languages of Camiguin": "تصنيف:لغات كاميغويين",
    "Category:Latin music albums by American artists": "تصنيف:ألبومات موسيقى لاتينية لفنانين أمريكيين",
    "Category:Latino sitcoms": "تصنيف:لاتينيين كوميديا الموقف",
    "Category:Latvian football biography stubs": "تصنيف:بذرة أعلام كرة قدم لاتفيين",
    "Category:Law enforcement operations against Islamist groups": "تصنيف:غارات الشرطة على الإسلاميين",
    "Category:Leaders of Progressive Democrats": "تصنيف:قادة حزب الديمقراطيين التقدميين",
    "Category:Lebanese football biography stubs": "تصنيف:بذرة أعلام كرة قدم لبنانيين",
    "Category:Levitical cities": "تصنيف:مدن اللاويين",
    "Category:Liberal Democrats (UK) MPs": "تصنيف:أعضاء برلمان الديمقراطيين الليبراليين (المملكة المتحدة)",
    "Category:Libya men's A' international footballers": "تصنيف:لاعبو منتخب ليبيا لكرة القدم للرجال للمحليين",
    "Category:Libyan football biography stubs": "تصنيف:بذرة أعلام كرة قدم ليبيين",
    "Category:Life peers": "تصنيف:نبلاء عمريين",
    "Category:Linguists by language group of study": "تصنيف:لغويين حسب مجموعة لغة الدراسة",
    "Category:Lists of African politicians": "تصنيف:قوائم سياسيين أفارقة",
    "Category:Lists of African-American people": "تصنيف:قوائم الأمريكيين الأفارقة",
    "Category:Lists of Albanian politicians": "تصنيف:قوائم سياسيين ألبان",
    "Category:Lists of Algerian people": "تصنيف:قوائم جزائريين",
    "Category:Lists of Algerian people by occupation": "تصنيف:قوائم جزائريين حسب المهنة",
    "Category:Lists of Algerian politicians": "تصنيف:قوائم سياسيين جزائريين",
    "Category:Lists of Algerian sports-people": "تصنيف:قوائم رياضيين جزائريين",
    "Category:Lists of American people": "تصنيف:قوائم أمريكيين",
    "Category:Lists of American people by educational affiliation": "تصنيف:قوائم أمريكيين حسب الانتماء التعليمي",
    "Category:Lists of American people by educational affiliation by state": "تصنيف:قوائم أمريكيين حسب الانتماء التعليمي حسب الولاية",
    "Category:Lists of American people by ethnic or national origin": "تصنيف:قوائم أمريكيين حسب الأصل العرقي أو الوطني",
    "Category:Lists of American people by ethnicity": "تصنيف:قوائم أمريكيين حسب الأصل العرقي أو الوطني",
    "Category:Lists of American people by occupation": "تصنيف:قوائم أمريكيين حسب المهنة",
    "Category:Lists of American politicians": "تصنيف:قوائم سياسيين أمريكيين",
    "Category:Lists of American politicians by state": "تصنيف:قوائم سياسيين أمريكيين حسب الولاية",
    "Category:Lists of Argentine people": "تصنيف:قوائم أرجنتينيين",
    "Category:Lists of Argentine people by occupation": "تصنيف:قوائم أرجنتينيين حسب المهنة",
    "Category:Lists of Argentine politicians": "تصنيف:قوائم سياسيين أرجنتينيين",
    "Category:Lists of Armenian politicians": "تصنيف:قوائم سياسيين أرمن",
    "Category:Lists of Asian people": "تصنيف:قوائم آسيويين",
    "Category:Lists of Asian politicians": "تصنيف:قوائم سياسيين آسيويين",
    "Category:Lists of Australian award winners": "تصنيف:قوائم حائزي جوائز أستراليين",
    "Category:Lists of Australian people": "تصنيف:قوائم أستراليين",
    "Category:Lists of Australian people by occupation": "تصنيف:قوائم أستراليين حسب المهنة",
    "Category:Lists of Australian politicians": "تصنيف:قوائم سياسيين أستراليين",
    "Category:Lists of Austrian people": "تصنيف:قوائم نمساويين",
    "Category:Lists of Austrian people by occupation": "تصنيف:قوائم نمساويين حسب المهنة",
    "Category:Lists of Austrian politicians": "تصنيف:قوائم سياسيين نمساويين",
    "Category:Lists of Azerbaijani people": "تصنيف:قوائم أذربيجانيين",
    "Category:Lists of Azerbaijani people by occupation": "تصنيف:قوائم أذربيجانيين حسب المهنة",
    "Category:Lists of Azerbaijani politicians": "تصنيف:قوائم سياسيين أذربيجانيين",
    "Category:Lists of Azerbaijani sports-people": "تصنيف:قوائم رياضيين أذربيجانيين",
    "Category:Lists of Bahraini people by occupation": "تصنيف:قوائم بحرينيين حسب المهنة",
    "Category:Lists of Bahraini sports-people": "تصنيف:قوائم رياضيين بحرينيين",
    "Category:Lists of Bangladeshi people": "تصنيف:قوائم بنجلاديشيين",
    "Category:Lists of Bangladeshi people by occupation": "تصنيف:قوائم بنجلاديشيين حسب المهنة",
    "Category:Lists of Bangladeshi politicians": "تصنيف:قوائم سياسيين بنجلاديشيين",
    "Category:Lists of Belgian people": "تصنيف:قوائم بلجيكيين",
    "Category:Lists of Belgian people by occupation": "تصنيف:قوائم بلجيكيين حسب المهنة",
    "Category:Lists of Belgian politicians": "تصنيف:قوائم سياسيين بلجيكيين",
    "Category:Lists of Beninese people": "تصنيف:قوائم بنينيين",
    "Category:Lists of Brazilian people": "تصنيف:قوائم برازيليين",
    "Category:Lists of Brazilian people by occupation": "تصنيف:قوائم برازيليين حسب المهنة",
    "Category:Lists of Brazilian politicians": "تصنيف:قوائم سياسيين برازيليين",
    "Category:Lists of British award winners": "تصنيف:قوائم حائزي جوائز بريطانيين",
    "Category:Lists of British people": "تصنيف:قوائم بريطانيين",
    "Category:Lists of British people by occupation": "تصنيف:قوائم بريطانيين حسب المهنة",
    "Category:Lists of British politicians": "تصنيف:قوائم سياسيين بريطانيين",
    "Category:Lists of British sports-people": "تصنيف:قوائم رياضيين بريطانيين",
    "Category:Lists of Bruneian people": "تصنيف:قوائم برونيين",
    "Category:Lists of Bulgarian people": "تصنيف:قوائم بلغاريين",
    "Category:Lists of Bulgarian people by occupation": "تصنيف:قوائم بلغاريين حسب المهنة",
    "Category:Lists of Bulgarian politicians": "تصنيف:قوائم سياسيين بلغاريين",
    "Category:Lists of Burkinabe people": "تصنيف:قوائم بوركينابيين",
    "Category:Lists of Burkinabé people": "تصنيف:قوائم بوركينابيين",
    "Category:Lists of Burundian people": "تصنيف:قوائم بورونديين",
    "Category:Lists of Burundian people by occupation": "تصنيف:قوائم بورونديين حسب المهنة",
    "Category:Lists of Cameroonian people": "تصنيف:قوائم كاميرونيين",
    "Category:Lists of Cameroonian people by occupation": "تصنيف:قوائم كاميرونيين حسب المهنة",
    "Category:Lists of Canadian people": "تصنيف:قوائم كنديين",
    "Category:Lists of Canadian people by descent": "تصنيف:قوائم كنديين حسب الأصل العرقي أو الوطني",
    "Category:Lists of Canadian people by ethnic or national origin": "تصنيف:قوائم كنديين حسب الأصل العرقي أو الوطني",
    "Category:Lists of Canadian people by occupation": "تصنيف:قوائم كنديين حسب المهنة",
    "Category:Lists of Canadian politicians": "تصنيف:قوائم سياسيين كنديين",
    "Category:Lists of Cape Verdean people": "تصنيف:قوائم أخضريين",
    "Category:Lists of Central American people": "تصنيف:قوائم أمريكيين أوسطيين",
    "Category:Lists of Central American politicians": "تصنيف:قوائم سياسيين أمريكيين أوسطيين",
    "Category:Lists of Chilean people": "تصنيف:قوائم تشيليين",
    "Category:Lists of Chinese people": "تصنيف:قوائم صينيين",
    "Category:Lists of Chinese people by occupation": "تصنيف:قوائم صينيين حسب المهنة",
    "Category:Lists of Chinese politicians": "تصنيف:قوائم سياسيين صينيين",
    "Category:Lists of Christians": "تصنيف:قوائم مسيحيين",
    "Category:Lists of Colombian people": "تصنيف:قوائم كولومبيين",
    "Category:Lists of Colombian people by occupation": "تصنيف:قوائم كولومبيين حسب المهنة",
    "Category:Lists of Colombian politicians": "تصنيف:قوائم السياسيين الكولومبيين",
    "Category:Lists of Costa Rican people": "تصنيف:قوائم كوستاريكيين",
    "Category:Lists of Costa Rican politicians": "تصنيف:قوائم سياسيين كوستاريكيين",
    "Category:Lists of Croatian people": "تصنيف:قوائم كرواتيين",
    "Category:Lists of Croatian people by occupation": "تصنيف:قوائم كرواتيين حسب المهنة",
    "Category:Lists of Croatian politicians": "تصنيف:قوائم سياسيين كرواتيين",
    "Category:Lists of Croatian sports-people": "تصنيف:قوائم رياضيين كرواتيين",
    "Category:Lists of Cypriot politicians": "تصنيف:قوائم سياسيين قبارصة",
    "Category:Lists of Czech people": "تصنيف:قوائم تشيكيين",
    "Category:Lists of Czech people by occupation": "تصنيف:قوائم تشيكيين حسب المهنة",
    "Category:Lists of Czech politicians": "تصنيف:قوائم سياسيين تشيكيين",
    "Category:Lists of Czechoslovak people": "تصنيف:قوائم تشيكوسلوفاكيين",
    "Category:Lists of Czechoslovak people by occupation": "تصنيف:قوائم تشيكوسلوفاكيين حسب المهنة",
    "Category:Lists of Czechoslovak politicians": "تصنيف:قوائم سياسيين تشيكوسلوفاكيين",
    "Category:Lists of Danish people": "تصنيف:قوائم دنماركيين",
    "Category:Lists of Danish people by occupation": "تصنيف:قوائم دنماركيين حسب المهنة",
    "Category:Lists of Danish politicians": "تصنيف:قوائم سياسيين دنماركيين",
    "Category:Lists of Democratic republic of congo people": "تصنيف:قوائم كونغويين ديمقراطيين",
    "Category:Lists of Dutch people": "تصنيف:قوائم هولنديين",
    "Category:Lists of Dutch people by occupation": "تصنيف:قوائم هولنديين حسب المهنة",
    "Category:Lists of Dutch politicians": "تصنيف:قوائم سياسيين هولنديين",
    "Category:Lists of East Timorese people": "تصنيف:قوائم تيموريين شرقيين",
    "Category:Lists of East Timorese politicians": "تصنيف:قوائم سياسيين تيموريين شرقيين",
    "Category:Lists of Egyptian people": "تصنيف:قوائم مصريين",
    "Category:Lists of Egyptian people by occupation": "تصنيف:قوائم مصريين حسب المهنة",
    "Category:Lists of Egyptian politicians": "تصنيف:قوائم سياسيين مصريين",
    "Category:Lists of Emirati people": "تصنيف:قوائم إماراتيين",
    "Category:Lists of English sports-people": "تصنيف:قوائم رياضيين إنجليز",
    "Category:Lists of European people": "تصنيف:قوائم أوروبيين",
    "Category:Lists of European politicians": "تصنيف:قوائم سياسيين أوروبيين",
    "Category:Lists of Fijian people": "تصنيف:قوائم فيجيين",
    "Category:Lists of Finnish people": "تصنيف:قوائم فنلنديين",
    "Category:Lists of Finnish people by occupation": "تصنيف:قوائم فنلنديين حسب المهنة",
    "Category:Lists of Finnish politicians": "تصنيف:قوائم سياسيين فنلنديين",
    "Category:Lists of French military personnel": "تصنيف:قوائم عسكريين فرنسيين",
    "Category:Lists of French people": "تصنيف:قوائم فرنسيين",
    "Category:Lists of French people by occupation": "تصنيف:قوائم فرنسيين حسب المهنة",
    "Category:Lists of French politicians": "تصنيف:قوائم سياسيين فرنسيين",
    "Category:Lists of French sports-people": "تصنيف:قوائم رياضيين فرنسيين",
    "Category:Lists of German military personnel": "تصنيف:قوائم عسكريين ألمان",
    "Category:Lists of German politicians": "تصنيف:قوائم سياسيين ألمان",
    "Category:Lists of Greek people": "تصنيف:قوائم يونانيين",
    "Category:Lists of Greek people by occupation": "تصنيف:قوائم يونانيين حسب المهنة",
    "Category:Lists of Greek politicians": "تصنيف:قوائم سياسيين يونانيين",
    "Category:Lists of Greek sports-people": "تصنيف:قوائم رياضيين يونانيين",
    "Category:Lists of Greenlandic people": "تصنيف:قوائم غرينلانديين",
    "Category:Lists of Guatemalan people": "تصنيف:قوائم غواتيماليين",
    "Category:Lists of Guatemalan people by occupation": "تصنيف:قوائم غواتيماليين حسب المهنة",
    "Category:Lists of Guyanese people": "تصنيف:قوائم غيانيين",
    "Category:Lists of Guyanese people by occupation": "تصنيف:قوائم غيانيين حسب المهنة",
    "Category:Lists of Honduran people": "تصنيف:قوائم هندوراسيين",
    "Category:Lists of Honduran people by occupation": "تصنيف:قوائم هندوراسيين حسب المهنة",
    "Category:Lists of Honduran politicians": "تصنيف:قوائم سياسيين هندوراسيين",
    "Category:Lists of Hungarian people": "تصنيف:قوائم مجريين",
    "Category:Lists of Hungarian people by occupation": "تصنيف:قوائم مجريين حسب المهنة",
    "Category:Lists of Hungarian politicians": "تصنيف:قوائم سياسيين مجريين",
    "Category:Lists of Icelandic people": "تصنيف:قوائم آيسلنديين",
    "Category:Lists of Indian politicians": "تصنيف:قوائم سياسيين هنود",
    "Category:Lists of Indonesian people": "تصنيف:قوائم إندونيسيين",
    "Category:Lists of Indonesian people by occupation": "تصنيف:قوائم إندونيسيين حسب المهنة",
    "Category:Lists of Indonesian politicians": "تصنيف:قوائم سياسيين إندونيسيين",
    "Category:Lists of Iranian military personnel": "تصنيف:قوائم عسكريين إيرانيين",
    "Category:Lists of Iranian people": "تصنيف:قوائم إيرانيين",
    "Category:Lists of Iranian people by occupation": "تصنيف:قوائم إيرانيين حسب المهنة",
    "Category:Lists of Iranian politicians": "تصنيف:قوائم سياسيين إيرانيين",
    "Category:Lists of Iraqi people": "تصنيف:قوائم عراقيين",
    "Category:Lists of Iraqi people by occupation": "تصنيف:قوائم عراقيين حسب المهنة",
    "Category:Lists of Iraqi politicians": "تصنيف:قوائم سياسيين عراقيين",
    "Category:Lists of Irish people": "تصنيف:قوائم أيرلنديين",
    "Category:Lists of Irish people by occupation": "تصنيف:قوائم أيرلنديين حسب المهنة",
    "Category:Lists of Irish politicians": "تصنيف:قوائم سياسيين أيرلنديين",
    "Category:Lists of Islamic religious leaders": "تصنيف:قوائم قادة دينيين مسلمين",
    "Category:Lists of Israeli award winners": "تصنيف:قوائم إسرائيليين حائزي جوائز",
    "Category:Lists of Israeli people": "تصنيف:قوائم أعلام إسرائيليين",
    "Category:Lists of Israeli people by occupation": "تصنيف:قوائم إسرائيليين حسب المهنة",
    "Category:Lists of Israeli politicians": "تصنيف:قوائم سياسيين إسرائيليين",
    "Category:Lists of Italian nobility": "تصنيف:قوائم نبلاء إيطاليين",
    "Category:Lists of Italian people": "تصنيف:قوائم إيطاليين",
    "Category:Lists of Italian people by occupation": "تصنيف:قوائم إيطاليين حسب المهنة",
    "Category:Lists of Italian politicians": "تصنيف:قوائم سياسيين إيطاليين",
    "Category:Lists of Italian sports-people": "تصنيف:قوائم رياضيين إيطاليين",
    "Category:Lists of Ivorian people": "تصنيف:قوائم إيفواريين",
    "Category:Lists of Ivorian people by occupation": "تصنيف:قوائم إيفواريين حسب المهنة",
    "Category:Lists of Japanese people": "تصنيف:قوائم يابانيين",
    "Category:Lists of Japanese people by occupation": "تصنيف:قوائم يابانيين حسب المهنة",
    "Category:Lists of Japanese politicians": "تصنيف:قوائم سياسيين يابانيين",
    "Category:Lists of Jewish religious leaders": "تصنيف:قوائم قادة دينيين يهود",
    "Category:Lists of Jordanian people": "تصنيف:قوائم أردنيين",
    "Category:Lists of Jordanian people by occupation": "تصنيف:قوائم أردنيين حسب المهنة",
    "Category:Lists of Jordanian politicians": "تصنيف:قوائم سياسيين أردنيين",
    "Category:Lists of Kazakhstani people": "تصنيف:قوائم كازاخستانيين",
    "Category:Lists of Kenyan people": "تصنيف:قوائم كينيين",
    "Category:Lists of Kenyan people by occupation": "تصنيف:قوائم كينيين حسب المهنة",
    "Category:Lists of Kenyan politicians": "تصنيف:قوائم سياسيين كينيين",
    "Category:Lists of Korean people": "تصنيف:قوائم كوريين",
    "Category:Lists of Korean people by occupation": "تصنيف:قوائم كوريين حسب المهنة",
    "Category:Lists of Kuwaiti people": "تصنيف:قوائم كويتيين",
    "Category:Lists of Kuwaiti people by occupation": "تصنيف:قوائم كويتيين حسب المهنة",
    "Category:Lists of Kuwaiti politicians": "تصنيف:قوائم سياسيين كويتيين",
    "Category:Lists of Kyrgyzstani people": "تصنيف:قوائم قيرغيزستانيين",
    "Category:Lists of Kyrgyzstani politicians": "تصنيف:قوائم سياسيين قيرغيزستانيين",
    "Category:Lists of Lebanese people": "تصنيف:قوائم لبنانيين",
    "Category:Lists of Lebanese people by occupation": "تصنيف:قوائم لبنانيين حسب المهنة",
    "Category:Lists of Lebanese politicians": "تصنيف:قوائم سياسيين لبنانيين",
    "Category:Lists of Lebanese sports-people": "تصنيف:قوائم رياضيين لبنانيين",
    "Category:Lists of Libyan people": "تصنيف:قوائم ليبيين",
    "Category:Lists of Libyan people by occupation": "تصنيف:قوائم ليبيين حسب المهنة",
    "Category:Lists of Libyan politicians": "تصنيف:قوائم سياسيين ليبيين",
    "Category:Lists of Luxembourgian people": "تصنيف:قوائم لوكسمبورغيين",
    "Category:Lists of Luxembourgian people by occupation": "تصنيف:قوائم لوكسمبورغيين حسب المهنة",
    "Category:Lists of Luxembourgian politicians": "تصنيف:قوائم سياسيين لوكسمبورغيين",
    "Category:Lists of Malaysian people": "تصنيف:قوائم ماليزيين",
    "Category:Lists of Malaysian people by occupation": "تصنيف:قوائم ماليزيين حسب المهنة",
    "Category:Lists of Malaysian politicians": "تصنيف:قوائم سياسيين ماليزيين",
    "Category:Lists of Maltese people by occupation": "تصنيف:قوائم مالطيين حسب المهنة",
    "Category:Lists of Maltese politicians": "تصنيف:قوائم سياسيين مالطيين",
    "Category:Lists of Mauritian people": "تصنيف:قوائم موريشيوسيين",
    "Category:Lists of Mauritian people by occupation": "تصنيف:قوائم موريشيوسيين حسب المهنة",
    "Category:Lists of Mauritian politicians": "تصنيف:قوائم سياسيين موريشيوسيين",
    "Category:Lists of Mexican people": "تصنيف:قوائم مكسيكيين",
    "Category:Lists of Mexican people by occupation": "تصنيف:قوائم مكسيكيين حسب المهنة",
    "Category:Lists of Mexican politicians": "تصنيف:قوائم سياسيين مكسيكيين",
    "Category:Lists of Mongolian people": "تصنيف:قوائم منغوليين",
    "Category:Lists of Mongolian people by occupation": "تصنيف:قوائم منغوليين حسب المهنة",
    "Category:Lists of Montenegrin people": "تصنيف:قوائم مونتينيغريين",
    "Category:Lists of Montenegrin people by occupation": "تصنيف:قوائم مونتينيغريين حسب المهنة",
    "Category:Lists of Moroccan politicians": "تصنيف:قوائم سياسيين مغاربة",
    "Category:Lists of Mozambican people": "تصنيف:قوائم موزمبيقيين",
    "Category:Lists of Nepalese people": "تصنيف:قوائم نيباليين",
    "Category:Lists of Nepalese people by occupation": "تصنيف:قوائم نيباليين حسب المهنة",
    "Category:Lists of Nepalese politicians": "تصنيف:قوائم سياسيين نيباليين",
    "Category:Lists of New Zealand people": "تصنيف:قوائم نيوزيلنديين",
    "Category:Lists of New Zealand people by occupation": "تصنيف:قوائم نيوزيلنديين حسب المهنة",
    "Category:Lists of New Zealand politicians": "تصنيف:قوائم سياسيين نيوزيلنديين",
    "Category:Lists of Nigerian people": "تصنيف:قوائم نيجيريين",
    "Category:Lists of Nigerian people by occupation": "تصنيف:قوائم نيجيريين حسب المهنة",
    "Category:Lists of North American people": "تصنيف:قوائم أمريكيين شماليين",
    "Category:Lists of North American politicians": "تصنيف:قوائم سياسيين أمريكيين شماليين",
    "Category:Lists of North Korean people": "تصنيف:قوائم كوريين شماليين",
    "Category:Lists of Norwegian people": "تصنيف:قوائم نرويجيين",
    "Category:Lists of Norwegian people by occupation": "تصنيف:قوائم نرويجيين حسب المهنة",
    "Category:Lists of Norwegian politicians": "تصنيف:قوائم سياسيين نرويجيين",
    "Category:Lists of Oceanian people": "تصنيف:قوائم أوقيانوسيين",
    "Category:Lists of Oceanian politicians": "تصنيف:قوائم سياسيين أوقيانوسيين",
    "Category:Lists of Olympic competitors": "تصنيف:قوائم منافسين أولمبيين",
    "Category:Lists of Ottoman governors": "تصنيف:قوائم الولاة العثمانيين",
    "Category:Lists of Ottoman military personnel": "تصنيف:قوائم عسكريين عثمانيين",
    "Category:Lists of Pakistani people": "تصنيف:قوائم باكستانيين",
    "Category:Lists of Pakistani people by occupation": "تصنيف:قوائم باكستانيين حسب المهنة",
    "Category:Lists of Pakistani politicians": "تصنيف:قوائم سياسيين باكستانيين",
    "Category:Lists of Palestinian people": "تصنيف:قوائم فلسطينيين",
    "Category:Lists of Panamanian people": "تصنيف:قوائم بنميين",
    "Category:Lists of Panamanian people by occupation": "تصنيف:قوائم بنميين حسب المهنة",
    "Category:Lists of Panamanian politicians": "تصنيف:قوائم سياسيين بنميين",
    "Category:Lists of Polish people": "تصنيف:قوائم بولنديين",
    "Category:Lists of Polish people by occupation": "تصنيف:قوائم بولنديين حسب المهنة",
    "Category:Lists of Polish politicians": "تصنيف:قوائم سياسيين بولنديين",
    "Category:Lists of Portuguese people": "تصنيف:قوائم برتغاليين",
    "Category:Lists of Portuguese people by occupation": "تصنيف:قوائم برتغاليين حسب المهنة",
    "Category:Lists of Portuguese politicians": "تصنيف:قوائم سياسيين برتغاليين",
    "Category:Lists of Protestant bishops and archbishops": "تصنيف:قوائم أساقفة ورؤساء أساقفة بروتستانتيين",
    "Category:Lists of Puerto Rican people by occupation": "تصنيف:قوائم بورتوريكيين حسب المهنة",
    "Category:Lists of Puerto Rican politicians": "تصنيف:قوائم سياسيين بورتوريكيين",
    "Category:Lists of Romanian people": "تصنيف:قوائم رومانيين",
    "Category:Lists of Romanian people by occupation": "تصنيف:قوائم رومانيين حسب المهنة",
    "Category:Lists of Romanian politicians": "تصنيف:قوائم سياسيين رومانيين",
    "Category:Lists of Russian politicians": "تصنيف:قوائم سياسيين روس",
    "Category:Lists of Rwandan people": "تصنيف:قوائم أعلام روانديين",
    "Category:Lists of Saudi Arabian people": "تصنيف:قوائم سعوديين",
    "Category:Lists of Saudi Arabian people by occupation": "تصنيف:قوائم سعوديين حسب المهنة",
    "Category:Lists of Scottish people": "تصنيف:قوائم إسكتلنديين",
    "Category:Lists of Scottish people by occupation": "تصنيف:قوائم إسكتلنديين حسب المهنة",
    "Category:Lists of Senegalese people": "تصنيف:قوائم سنغاليين",
    "Category:Lists of Senegalese people by occupation": "تصنيف:قوائم سنغاليين حسب المهنة",
    "Category:Lists of Senegalese politicians": "تصنيف:قوائم سياسيين سنغاليين",
    "Category:Lists of Serbian politicians": "تصنيف:قوائم سياسيين صرب",
    "Category:Lists of Seychellois people": "تصنيف:قوائم سيشليين",
    "Category:Lists of Seychellois people by occupation": "تصنيف:قوائم سيشليين حسب المهنة",
    "Category:Lists of Seychellois politicians": "تصنيف:قوائم سياسيين سيشليين",
    "Category:Lists of Singaporean people": "تصنيف:قوائم سنغافوريين",
    "Category:Lists of Singaporean people by occupation": "تصنيف:قوائم سنغافوريين حسب المهنة",
    "Category:Lists of Singaporean politicians": "تصنيف:قوائم سياسيين سنغافوريين",
    "Category:Lists of Slovak people": "تصنيف:قوائم سلوفاكيين",
    "Category:Lists of Slovak people by occupation": "تصنيف:قوائم سلوفاكيين حسب المهنة",
    "Category:Lists of Slovak politicians": "تصنيف:قوائم سياسيين سلوفاكيين",
    "Category:Lists of South American people": "تصنيف:قوائم أمريكيين جنوبيين",
    "Category:Lists of South American politicians": "تصنيف:قوائم سياسيين أمريكيين جنوبيين",
    "Category:Lists of South Korean musicians": "تصنيف:قوائم موسيقيين كوريين جنوبيين",
    "Category:Lists of South Korean people": "تصنيف:قوائم كوريين جنوبيين",
    "Category:Lists of South Korean people by occupation": "تصنيف:قوائم كوريين جنوبيين حسب المهنة",
    "Category:Lists of South Korean politicians": "تصنيف:قوائم سياسيين كوريين جنوبيين",
    "Category:Lists of Southeast Asian people": "تصنيف:قوائم آسيويين جنوبيين شرقيين",
    "Category:Lists of Southeast Asian politicians": "تصنيف:قوائم سياسيين آسيويين جنوبيين شرقيين",
    "Category:Lists of Soviet politicians": "تصنيف:قوائم سياسيين سوفيت",
    "Category:Lists of Spanish politicians": "تصنيف:قوائم سياسيين إسبان",
    "Category:Lists of Spanish sports-people": "تصنيف:قوائم رياضيين إسبان",
    "Category:Lists of Sri Lankan people": "تصنيف:قوائم سريلانكيين",
    "Category:Lists of Sri Lankan people by occupation": "تصنيف:قوائم سريلانكيين حسب المهنة",
    "Category:Lists of Sri Lankan politicians": "تصنيف:قوائم سياسيين سريلانكيين",
    "Category:Lists of Sudanese people": "تصنيف:قوائم سودانيين",
    "Category:Lists of Sudanese people by occupation": "تصنيف:قوائم سودانيين حسب المهنة",
    "Category:Lists of Surinamese people": "تصنيف:قوائم سوريناميين",
    "Category:Lists of Surinamese people by occupation": "تصنيف:قوائم سوريناميين حسب المهنة",
    "Category:Lists of Surinamese politicians": "تصنيف:قوائم سياسيين سوريناميين",
    "Category:Lists of Swedish people": "تصنيف:قوائم سويديين",
    "Category:Lists of Swedish people by occupation": "تصنيف:قوائم سويديين حسب المهنة",
    "Category:Lists of Swiss people": "تصنيف:قوائم سويسريين",
    "Category:Lists of Syrian people": "تصنيف:قوائم سوريين",
    "Category:Lists of Syrian people by occupation": "تصنيف:قوائم سوريين حسب المهنة",
    "Category:Lists of Syrian politicians": "تصنيف:قوائم سياسيين سوريين",
    "Category:Lists of Tanzanian people": "تصنيف:قوائم تنزانيين",
    "Category:Lists of Tanzanian people by occupation": "تصنيف:قوائم تنزانيين حسب المهنة",
    "Category:Lists of Tanzanian politicians": "تصنيف:قوائم سياسيين تنزانيين",
    "Category:Lists of Thai people": "تصنيف:قوائم تايلنديين",
    "Category:Lists of Thai people by occupation": "تصنيف:قوائم تايلنديين حسب المهنة",
    "Category:Lists of Thai politicians": "تصنيف:قوائم سياسيين تايلنديين",
    "Category:Lists of Tunisian people": "تصنيف:قوائم تونسيين",
    "Category:Lists of Tunisian people by occupation": "تصنيف:قوائم تونسيين حسب المهنة",
    "Category:Lists of Tunisian politicians": "تصنيف:قوائم سياسيين تونسيين",
    "Category:Lists of Turkish military personnel": "تصنيف:قوائم عسكريين أتراك",
    "Category:Lists of Turkish politicians": "تصنيف:قوائم سياسيين أتراك",
    "Category:Lists of Turkmenistan people": "تصنيف:قوائم تركمانيين",
    "Category:Lists of Turkmenistan politicians": "تصنيف:قوائم سياسيين تركمانيين",
    "Category:Lists of Ugandan people": "تصنيف:قوائم أوغنديين",
    "Category:Lists of Ugandan people by occupation": "تصنيف:قوائم أوغنديين حسب المهنة",
    "Category:Lists of Ugandan politicians": "تصنيف:قوائم سياسيين أوغنديين",
    "Category:Lists of Ukrainian people": "تصنيف:قوائم أوكرانيين",
    "Category:Lists of Ukrainian people by occupation": "تصنيف:قوائم أوكرانيين حسب المهنة",
    "Category:Lists of Ukrainian politicians": "تصنيف:قوائم سياسيين أوكرانيين",
    "Category:Lists of Yemeni people": "تصنيف:قوائم يمنيين",
    "Category:Lists of Yemeni people by occupation": "تصنيف:قوائم اليمنيين حسب المهنة",
    "Category:Lists of Zambian people": "تصنيف:قوائم زامبيين",
    "Category:Lists of Zambian people by occupation": "تصنيف:قوائم زامبيين حسب المهنة",
    "Category:Lists of Zambian politicians": "تصنيف:قوائم سياسيين زامبيين",
    "Category:Lists of Zimbabwean people": "تصنيف:قوائم زيمبابويين",
    "Category:Lists of Zimbabwean people by occupation": "تصنيف:قوائم زيمبابويين حسب المهنة",
    "Category:Lists of Zimbabwean politicians": "تصنيف:قوائم سياسيين زيمبابويين",
    "Category:Lists of diplomats": "تصنيف:قوائم دبلوماسيين",
    "Category:Lists of entertainers": "تصنيف:قوائم فنانين ترفيهيين",
    "Category:Lists of fictional military personnel": "تصنيف:قوائم عسكريين خياليين",
    "Category:Lists of international association football players": "تصنيف:قوائم لاعبي كرة قدم دوليين",
    "Category:Lists of journalists": "تصنيف:قوائم صحفيين",
    "Category:Lists of legislative speakers": "تصنيف:قوائم المتحدثين التشريعيين",
    "Category:Lists of military personnel": "تصنيف:قوائم عسكريين",
    "Category:Lists of military personnel by country": "تصنيف:قوائم عسكريين حسب البلد",
    "Category:Lists of musicians": "تصنيف:قوائم موسيقيين",
    "Category:Lists of musicians by genre": "تصنيف:قوائم موسيقيين حسب النوع الفني",
    "Category:Lists of musicians by nationality": "تصنيف:قوائم موسيقيين حسب الجنسية",
    "Category:Lists of people from Georgia (country)": "تصنيف:قوائم جورجيين",
    "Category:Lists of politicians": "تصنيف:قوائم سياسيين",
    "Category:Lists of politicians by nationality": "تصنيف:قوائم سياسيين حسب الجنسية",
    "Category:Lists of politicians from Georgia (country)": "تصنيف:قوائم سياسيين جورجيين",
    "Category:Lists of politicians from the United Kingdom": "تصنيف:قوائم سياسيين من المملكة المتحدة",
    "Category:Lists of politicians lists": "تصنيف:قوائم بقوائم سياسيين",
    "Category:Lists of religious leaders": "تصنيف:قوائم زعماء روحيين",
    "Category:Lists of rulers in Asia": "تصنيف:قوائم حكام آسيويين",
    "Category:Lists of rulers in Europe": "تصنيف:قوائم حكام أوروبيين",
    "Category:Lists of scholars and academics": "تصنيف:قوائم دارسين وأكاديميين",
    "Category:Lists of social activists": "تصنيف:قوائم نشطاء اجتماعيين",
    "Category:Lists of sports medalists": "تصنيف:قوائم رياضيين فائزين بميداليات",
    "Category:Lists of sportsmen": "تصنيف:قوائم رياضيين رجال",
    "Category:Lists of sports-people": "تصنيف:قوائم رياضيين",
    "Category:Lists of sports-people by nationality": "تصنيف:قوائم رياضيين حسب الجنسية",
    "Category:Lists of sports-people by sport": "تصنيف:قوائم رياضيين حسب الرياضة",
    "Category:Lists of sports-people by sport and nationality": "تصنيف:قوائم رياضيين حسب الرياضة والجنسية",
    "Category:Lists of spouses of heads of state": "تصنيف:قوائم قرينات قادة وطنيين",
    "Category:Lists of things named after mathematicians": "تصنيف:أشياء مسماة نسبة لرياضياتيين",
    "Category:Local politicians in the Netherlands": "تصنيف:أصحاب مناصب سياسيين محليين في هولندا",
    "Category:Malaysian male squash players": "تصنيف:لاعبو سكواش ماليزيين",
    "Category:Mali men's A' international footballers": "تصنيف:لاعبو منتخب مالي لكرة القدم للرجال للمحليين",
    "Category:Malian football biography stubs": "تصنيف:بذرة أعلام كرة قدم ماليين",
    "Category:Massacres of Bengali Hindus": "تصنيف:مذابح الهندوس البنغاليين",
    "Category:Massacres of Bengali Hindus in British India": "تصنيف:مذابح الهندوس البنغاليين في الراج البريطاني",
    "Category:Massacres of Bengali Hindus in East Pakistan": "تصنيف:مذابح الهندوس البنغاليين في باكستان الشرقية",
    "Category:Massacres of Christians": "تصنيف:مجازر ضد المسيحيين",
    "Category:Massacres of Native Americans": "تصنيف:مذابح في السكان الأصليين في الولايات المتحدة",
    "Category:Massacres of Palestinians": "تصنيف:مذابح ضد الفلسطينيين",
    "Category:Massacres of Ukrainians": "تصنيف:مذابح ضد أوكرانيين",
    "Category:Massacres of Ukrainians during World War II": "تصنيف:مذابح ضد أوكرانيين خلال الحرب العالمية الثانية",
    "Category:Mauritania men's A' international footballers": "تصنيف:لاعبو منتخب موريتانيا لكرة القدم للرجال للمحليين",
    "Category:Mawlamyine": "تصنيف:ماولاميين",
    "Category:Mayors of Cayenne": "تصنيف:عمدات كايين",
    "Category:Melkite Christian communities in Lebanon": "تصنيف:تجمعات الروم الملكيين في لبنان",
    "Category:Melkite Greek Catholic Church": "تصنيف:كنيسة الروم الملكيين الكاثوليك",
    "Category:Melkite Greek Catholic Church by country": "تصنيف:كنيسة الروم الملكيين الكاثوليك حسب البلد",
    "Category:Melkite Greek Catholic Church in Brazil": "تصنيف:كنيسة الروم الملكيين الكاثوليك في البرازيل",
    "Category:Melkite Greek Catholic Church in Egypt": "تصنيف:كنيسة الروم الملكيين الكاثوليك في مصر",
    "Category:Melkite Greek Catholic Church in Israel": "تصنيف:كنيسة الروم الملكيين الكاثوليك في إسرائيل",
    "Category:Melkite Greek Catholic Church in Jordan": "تصنيف:كنيسة الروم الملكيين الكاثوليك في الأردن",
    "Category:Melkite Greek Catholic Church in Lebanon": "تصنيف:كنيسة الروم الملكيين الكاثوليك في لبنان",
    "Category:Melkite Greek Catholic Church in North America": "تصنيف:كنيسة الروم الملكيين الكاثوليك في أمريكا الشمالية",
    "Category:Melkite Greek Catholic Church in South America": "تصنيف:كنيسة الروم الملكيين الكاثوليك في أمريكا الجنوبية",
    "Category:Melkite Greek Catholic Church in Syria": "تصنيف:كنيسة الروم الملكيين الكاثوليك في سوريا",
    "Category:Melkite Greek Catholic Church in the United States": "تصنيف:كنيسة الروم الملكيين الكاثوليك في الولايات المتحدة",
    "Category:Melkite Greek Catholic Patriarchs of Antioch": "تصنيف:بطاركة كنيسة الروم الملكيين الكاثوليك",
    "Category:Melkite Greek Catholic churches in Israel": "تصنيف:كنائس الروم الملكيين الكاثوليك في إسرائيل",
    "Category:Members of Parliament for Haute-Vienne": "تصنيف:أعضاء البرلمان عن فيين العليا (إقليم فرنسي)",
    "Category:Members of Parliament for Vienne (department)": "تصنيف:أعضاء البرلمان عن فيين (إقليم فرنسي)",
    "Category:Members of the Academy of Persian Language and Literature": "تصنيف:أعضاء أكاديمية اللغة والأدب الفارسيين",
    "Category:Members of the Cabinet of the United States of Asian descent": "تصنيف:أمريكيون آسيويين أعضاء في مجلس وزراء الولايات المتحدة",
    "Category:Members of the Democratic Socialists of America": "تصنيف:أعضاء الاشتراكيين الديمقراطيين في أمريكا",
    "Category:Members of the Royal College of Veterinary Surgeons": "تصنيف:أعضاء الكلية الملكية للجراحين البيطريين",
    "Category:Members of the United States House of Representatives of Asian descent": "تصنيف:أمريكيون آسيويين أعضاء في مجلس النواب الأمريكي",
    "Category:Military officer training": "تصنيف:تدريب الضباط العسكريين",
    "Category:Ministers of health of Canada": "تصنيف:وزراء الصحة الكنديين",
    "Category:Minnesota Democratic–Farmer–Labor Party": "تصنيف:حزب العمال المزارعين الديمقراطيين في منيسوتا",
    "Category:Monarchs in Southeast Asia": "تصنيف:ملكيون آسيويين جنوبيون شرقيون",
    "Category:Montenegrin football biography stubs": "تصنيف:بذرة أعلام كرة قدم مونتينغريين",
    "Category:Monuments and memorials to musicians": "تصنيف:معالم أثرية ونصب تذكارية لموسيقيين",
    "Category:Monuments and memorials to politicians": "تصنيف:معالم أثرية ونصب تذكارية لسياسيين",
    "Category:Morocco men's A' international footballers": "تصنيف:لاعبو منتخب المغرب لكرة القدم للرجال للمحليين",
    "Category:Mosques destroyed by Christians": "تصنيف:مساجد دمرت على أيدي مسيحيين",
    "Category:Most-wanted Iraqi playing cards": "تصنيف:مجموعة أوراق اللعب لأهم المطلوبين العراقيين",
    "Category:Mothers of Abbasid caliphs": "تصنيف:أمهات الخلفاء العباسيين",
    "Category:Movement for Social Democracy": "تصنيف:حركة الديمقراطيين الاجتماعية",
    "Category:Movement of Socialist Democrats politicians": "تصنيف:سياسيو حركة الديمقراطيين الاشتراكيين",
    "Category:Mozambique men's A' international footballers": "تصنيف:لاعبو منتخب موزمبيق لكرة القدم للرجال للمحليين",
    "Category:Murdered Asian children": "تصنيف:أطفال آسيويين قتلوا",
    "Category:Musicians Institute alumni": "تصنيف:خريجو معهد الموسيقيين",
    "Category:Musicians work group articles": "تصنيف:مقالات فريق عمل الموسيقيين",
    "Category:Mythological kings of Sparta": "تصنيف:ملوك أسبرطة الأسطوريين",
    "Category:Māori culture": "تصنيف:ثقافة الماوريين",
    "Category:Māori weapons": "تصنيف:أسلحة الماوريين",
    "Category:Namibia men's A' international footballers": "تصنيف:لاعبو منتخب ناميبيا لكرة القدم للرجال للمحليين",
    "Category:Namibian football biography stubs": "تصنيف:بذرة أعلام كرة قدم ناميبيين",
    "Category:National A' association football teams": "تصنيف:منتخبات كرة قدم للمحليين",
    "Category:National Liberal Party (Lebanon) politicians": "تصنيف:سياسيو حزب الوطنيين الأحرار",
    "Category:Native American art": "تصنيف:فنون الأمريكيين الأصليين",
    "Category:Native American history": "تصنيف:تاريخ الأمريكيين الأصليين",
    "Category:Native American history by location": "تصنيف:تاريخ الأمريكيين الأصليين حسب الموقع",
    "Category:Native American history by state": "تصنيف:تاريخ الأمريكيين الأصليين حسب الولاية",
    "Category:Native American history of Alabama": "تصنيف:تاريخ الأمريكيين الأصليين في ألاباما",
    "Category:Native American history of Alaska": "تصنيف:تاريخ الأمريكيين الأصليين في ألاسكا",
    "Category:Native American history of Arizona": "تصنيف:تاريخ الأمريكيين الأصليين في أريزونا",
    "Category:Native American history of Arkansas": "تصنيف:تاريخ الأمريكيين الأصليين في أركنساس",
    "Category:Native American history of California": "تصنيف:تاريخ الأمريكيين الأصليين في كاليفورنيا",
    "Category:Native American history of Colorado": "تصنيف:تاريخ الأمريكيين الأصليين في كولورادو",
    "Category:Native American history of Connecticut": "تصنيف:تاريخ الأمريكيين الأصليين في كونيتيكت",
    "Category:Native American history of Florida": "تصنيف:تاريخ الأمريكيين الأصليين في فلوريدا",
    "Category:Native American history of Georgia (U.S. state)": "تصنيف:تاريخ الأمريكيين الأصليين في ولاية جورجيا",
    "Category:Native American history of Idaho": "تصنيف:تاريخ الأمريكيين الأصليين في أيداهو",
    "Category:Native American history of Illinois": "تصنيف:تاريخ الأمريكيين الأصليين في إلينوي",
    "Category:Native American history of Indiana": "تصنيف:تاريخ الأمريكيين الأصليين في إنديانا",
    "Category:Native American history of Iowa": "تصنيف:تاريخ الأمريكيين الأصليين في آيوا",
    "Category:Native American history of Kansas": "تصنيف:تاريخ الأمريكيين الأصليين في كانساس",
    "Category:Native American history of Louisiana": "تصنيف:تاريخ الأمريكيين الأصليين في لويزيانا",
    "Category:Native American history of Maine": "تصنيف:تاريخ الأمريكيين الأصليين في مين",
    "Category:Native American history of Maryland": "تصنيف:تاريخ الأمريكيين الأصليين في ماريلند",
    "Category:Native American history of Massachusetts": "تصنيف:تاريخ الأمريكيين الأصليين في ماساتشوستس",
    "Category:Native American history of Michigan": "تصنيف:تاريخ الأمريكيين الأصليين في ميشيغان",
    "Category:Native American history of Minnesota": "تصنيف:تاريخ الأمريكيين الأصليين في منيسوتا",
    "Category:Native American history of Missouri": "تصنيف:تاريخ الأمريكيين الأصليين في ميزوري",
    "Category:Native American history of Montana": "تصنيف:تاريخ الأمريكيين الأصليين في مونتانا",
    "Category:Native American history of Nebraska": "تصنيف:تاريخ الأمريكيين الأصليين في نبراسكا",
    "Category:Native American history of Nevada": "تصنيف:تاريخ الأمريكيين الأصليين في نيفادا",
    "Category:Native American history of New England": "تصنيف:تاريخ الأمريكيين الأصليين في نيو إنجلاند",
    "Category:Native American history of New Hampshire": "تصنيف:تاريخ الأمريكيين الأصليين في نيوهامشير",
    "Category:Native American history of New Mexico": "تصنيف:تاريخ الأمريكيين الأصليين في نيومكسيكو",
    "Category:Native American history of New York (state)": "تصنيف:تاريخ الأمريكيين الأصليين في ولاية نيويورك",
    "Category:Native American history of North Carolina": "تصنيف:تاريخ الأمريكيين الأصليين في كارولاينا الشمالية",
    "Category:Native American history of North Dakota": "تصنيف:تاريخ الأمريكيين الأصليين في داكوتا الشمالية",
    "Category:Native American history of Ohio": "تصنيف:تاريخ الأمريكيين الأصليين في أوهايو",
    "Category:Native American history of Oklahoma": "تصنيف:تاريخ الأمريكيين الأصليين في أوكلاهوما",
    "Category:Native American history of Oregon": "تصنيف:تاريخ الأمريكيين الأصليين في أوريغن",
    "Category:Native American history of Pennsylvania": "تصنيف:تاريخ الأمريكيين الأصليين في بنسلفانيا",
    "Category:Native American history of Rhode Island": "تصنيف:تاريخ الأمريكيين الأصليين في رود آيلاند",
    "Category:Native American history of South Carolina": "تصنيف:تاريخ الأمريكيين الأصليين في كارولاينا الجنوبية",
    "Category:Native American history of South Dakota": "تصنيف:تاريخ الأمريكيين الأصليين في داكوتا الجنوبية",
    "Category:Native American history of Tennessee": "تصنيف:تاريخ الأمريكيين الأصليين في تينيسي",
    "Category:Native American history of Texas": "تصنيف:تاريخ الأمريكيين الأصليين في تكساس",
    "Category:Native American history of Utah": "تصنيف:تاريخ الأمريكيين الأصليين في يوتا",
    "Category:Native American history of Vermont": "تصنيف:تاريخ الأمريكيين الأصليين في فيرمونت",
    "Category:Native American history of Virginia": "تصنيف:تاريخ الأمريكيين الأصليين في فرجينيا",
    "Category:Native American history of Washington (state)": "تصنيف:تاريخ الأمريكيين الأصليين في ولاية واشنطن",
    "Category:Native American history of West Virginia": "تصنيف:تاريخ الأمريكيين الأصليين في فرجينيا الغربية",
    "Category:Native American history of Wisconsin": "تصنيف:تاريخ الأمريكيين الأصليين في ويسكونسن",
    "Category:Native American history of Wyoming": "تصنيف:تاريخ الأمريكيين الأصليين في وايومنغ",
    "Category:Native American people in the American Revolution": "تصنيف:السكان الأصليين في الولايات المتحدة في الثورة الأمريكية",
    "Category:Native American religion": "تصنيف:ديانات الأمريكيين الأصليين",
    "Category:Native American studies": "تصنيف:دراسات الأمريكيين الأصليين",
    "Category:Native American tribes by state": "تصنيف:قبائل الأمريكيين الأصليين حسب الولاية",
    "Category:Native American tribes in Arizona": "تصنيف:قبائل الأمريكيين الأصليين في أريزونا",
    "Category:Native American tribes in Florida": "تصنيف:قبائل الأمريكيين الأصليين في فلوريدا",
    "Category:Native American tribes in New Mexico": "تصنيف:قبائل الأمريكيين الأصليين في نيو مكسيكو",
    "Category:Native American tribes in North Carolina": "تصنيف:قبائل الأمريكيين الأصليين في كارولينا الشمالية",
    "Category:Native American tribes in Oklahoma": "تصنيف:قبائل الأمريكيين الأصليين في أوكلاهوما",
    "Category:Native Americans in Alaska": "تصنيف:السكان الأصليين في الولايات المتحدة في ألاسكا",
    "Category:Native Americans in Arizona": "تصنيف:السكان الأصليين في الولايات المتحدة في أريزونا",
    "Category:Native Americans in South Dakota": "تصنيف:السكان الأصليين فى الولايات المتحدة في داكوتا الجنوبية",
    "Category:Native Americans in popular culture": "تصنيف:سكان الولايات المتحدة الأصليين في الثقافة الشعبية",
    "Category:Native Americans in the American Revolution": "تصنيف:السكان الأصليين في الولايات المتحدة في الثورة الأمريكية",
    "Category:Native Hawaiian activists": "تصنيف:ناشطون أمريكيون من الهاوائيين الأصليين",
    "Category:Naval battles involving the Ottoman Empire": "تصنيف:معارك العثمانيين البحرية",
    "Category:Naval battles involving the Umayyad Caliphate": "تصنيف:معارك الأمويين البحرية",
    "Category:Naval history of the Ottoman Empire": "تصنيف:تاريخ العثمانيين البحري",
    "Category:Naxalite–Maoist insurgency": "تصنيف:الحرب الشعبية في الهند- تمرد الناكسال الماويين",
    "Category:Neo-Nazi concepts": "تصنيف:معتقدات النازيين الجدد",
    "Category:Neo-Nazi organizations": "تصنيف:منظمات النازيين الجدد",
    "Category:Neo-Nazi political parties": "تصنيف:أحزاب النازيين الجدد السياسية",
    "Category:New Zealand film director navigational boxes": "تصنيف:صناديق تصفح مخرجي أفلام نيوزيلنديين",
    "Category:New Zealand military memorials and cemeteries": "تصنيف:نصب تذكارية ومقابر عسكريين نيوزيلنديين",
    "Category:New-age albums by Greek artists": "تصنيف:ألبومات العصر الحديث لفنانين يونانيين",
    "Category:Niger men's A' international footballers": "تصنيف:لاعبو منتخب النيجر لكرة القدم للرجال للمحليين",
    "Category:Nigeria men's A' international footballers": "تصنيف:لاعبو منتخب نيجيريا لكرة القدم للرجال للمحليين",
    "Category:Nigerian football biography stubs": "تصنيف:بذرة أعلام كرة قدم نيجيريين",
    "Category:Non-profit academic publishers": "تصنيف:ناشرون أكاديميون غير ربحيين",
    "Category:Norse colonization of North America": "تصنيف:استعمار الشماليين لأمريكا الشمالية",
    "Category:North Korean abductions of Japanese citizens": "تصنيف:اختطاف كوريا الشمالية مواطنين يابانيين",
    "Category:Novelist navigational boxes": "تصنيف:صناديق تصفح روائيين",
    "Category:Novels about Nazis": "تصنيف:روايات عن نازيين",
    "Category:Novels about architects": "تصنيف:روايات عن معماريين",
    "Category:Novels about journalists": "تصنيف:روايات عن صحفيين",
    "Category:Novels about mass media people": "تصنيف:روايات عن إعلاميين",
    "Category:Novels about politicians": "تصنيف:روايات عن سياسيين",
    "Category:Novels about revolutionaries": "تصنيف:روايات عن الثوريين",
    "Category:Oceanian film director navigational boxes": "تصنيف:صناديق تصفح مخرجي أفلام أوقيانوسيين",
    "Category:Official residences of subnational executives": "تصنيف:المساكن الرسمية للمدراء التنفيذيين دون الوطنيين",
    "Category:Offshoots of the Arab Nationalist Movement": "تصنيف:مجموعات حركة قوميين عرب انفصالية",
    "Category:Olympic champions navigational boxes": "تصنيف:قوالب تصفح الأبطال الأولمبيين",
    "Category:Opposition to same-sex marriage": "تصنيف:معارضة زواج المثليين",
    "Category:Organisations serving Indigenous Australians": "تصنيف:منظمات تخدم السكان الأصليين الأستراليين",
    "Category:Organization of American Historians": "تصنيف:منظمة المؤرخين الأمريكيين",
    "Category:Organization of Ukrainian Nationalists": "تصنيف:تنظيم القوميين الأوكرانيين",
    "Category:Oriental Orthodox monarchs": "تصنيف:ملوك مسيحيون غير خلقيدونيين",
    "Category:Ostrogothic Kingdom": "تصنيف:مملكة القوط الشرقيين",
    "Category:Ostrogothic kings": "تصنيف:ملوك القوط الشرقيين",
    "Category:Ottoman governors of Anatolia": "تصنيف:ولاة الأناضول العثمانيين",
    "Category:Palestine refugee camps": "تصنيف:مخيمات اللاجئين الفلسطينيين",
    "Category:Palestinian Fedayeen insurgency": "تصنيف:تمرد الفدائيين الفلسطينيين",
    "Category:Palestinian casualties in the Second Intifada": "تصنيف:ضحايا فلسطينيين في الانتفاضة الفلسطينية الثانية",
    "Category:Palestinian refugee camps in Jordan": "تصنيف:مخيمات اللاجئين الفلسطينيين في الأردن",
    "Category:Palestinian refugee camps in Lebanon": "تصنيف:مخيمات اللاجئين الفلسطينيين في لبنان",
    "Category:Palestinian refugee camps in Syria": "تصنيف:مخيمات اللاجئين الفلسطينيين في سوريا",
    "Category:Palestinian refugee camps in the Gaza Strip": "تصنيف:مخيمات اللاجئين الفلسطينيين في قطاع غزة",
    "Category:Palestinian refugee camps in the West Bank": "تصنيف:مخيمات اللاجئين الفلسطينيين في الضفة الغربية",
    "Category:Palestinian stone-throwing": "تصنيف:رمي الفلسطينيين للحجارة",
    "Category:Paraguayan football biography stubs": "تصنيف:بذرة أعلام كرة قدم باراغوايانيين",
    "Category:Party of Democratic Socialism (Germany) politicians": "تصنيف:حزب الاشتراكيين الديمقراطيين (ألمانيا)",
    "Category:Party of European Socialists": "تصنيف:حزب الاشتراكيين الأوروبيين",
    "Category:Patriots in the American Revolution": "تصنيف:الوطنيين في الثورة الأمريكية",
    "Category:Patriottentijd": "تصنيف:عصر الوطنيين",
    "Category:Payne County, Oklahoma": "تصنيف:مقاطعة بايين (أوكلاهوما)",
    "Category:People educated at Synge Street CBS": "تصنيف:أشخاص متعلمون في مدرسة شارع سينغ للأخوان المسيحيين",
    "Category:People from Camiguin": "تصنيف:أشخاص من كاميغويين",
    "Category:People from Camiguin by occupation": "تصنيف:أشخاص من كاميغويين حسب المهنة",
    "Category:People from Cayenne": "تصنيف:أشخاص من كايين",
    "Category:People from Compiègne": "تصنيف:أشخاص من كومبيين",
    "Category:People from East Francia": "تصنيف:أشخاص من مملكة الفرنجة الشرقيين",
    "Category:People from Haute-Vienne": "تصنيف:أشخاص من فيين العليا (إقليم فرنسي)",
    "Category:People from Kayin State": "تصنيف:أشخاص من ولاية كايين",
    "Category:People from Maringouin, Louisiana": "تصنيف:أشخاص من مارينغويين (لويزيانا)",
    "Category:People from Mawlamyine": "تصنيف:أشخاص من ماولاميين",
    "Category:People from Payne County, Oklahoma": "تصنيف:أشخاص من مقاطعة بايين (أوكلاهوما)",
    "Category:People from Saint-Jean-de-Maurienne": "تصنيف:أشخاص من سان-جان-دي-موريين",
    "Category:People from Vienne": "تصنيف:أشخاص من فيين (إقليم فرنسي)",
    "Category:People from Vienne (department)": "تصنيف:أشخاص من فيين (إقليم فرنسي)",
    "Category:People from Vienne, Isère": "تصنيف:أشخاص من فيين",
    "Category:People from West Francia": "تصنيف:أشخاص من مملكة الفرنجة الغربيين",
    "Category:People from the Ostrogothic Kingdom": "تصنيف:أشخاص من مملكة القوط الشرقيين",
    "Category:People listed in Russia as media foreign agents": "تصنيف:أشخاص مدرجون في روسيا كعملاء إعلاميين أجانب",
    "Category:People of the Hussite Wars": "تصنيف:أشخاص في حروب الهوسيين",
    "Category:People of the Ostrogothic Kingdom": "تصنيف:أشخاص من مملكة القوط الشرقيين",
    "Category:People of the Patriottentijd": "تصنيف:شخصيات من عصر الوطنيين",
    "Category:People under the Salghurids": "تصنيف:أشخاص في عهد السلغوريين",
    "Category:Persecution by Buddhists": "تصنيف:اضطهاد من قبل بوذيين",
    "Category:Persecution by Christians": "تصنيف:اضطهاد من قبل مسيحيين",
    "Category:Persecution of Ahmadis": "تصنيف:اضطهاد الأحمديين",
    "Category:Persecution of Alawites": "تصنيف:اضطهاد العلويين",
    "Category:Persecution of Assyrians": "تصنيف:اضطهاد الآشوريين",
    "Category:Persecution of Assyrians by ISIL": "تصنيف:اضطهاد تنظيم الدولة الإسلامية (داعش) للآشوريين",
    "Category:Persecution of Assyrians in Iraq": "تصنيف:اضطهاد الآشوريين في العراق",
    "Category:Persecution of Assyrians in Turkey": "تصنيف:اضطهاد الآشوريين في تركيا",
    "Category:Persecution of Assyrians in the Ottoman Empire": "تصنيف:اضطهاد الآشوريين في الدولة العثمانية",
    "Category:Persecution of Bahá'ís": "تصنيف:اضطهاد البهائيين",
    "Category:Persecution of Bengali Hindus": "تصنيف:اضطهاد الهندوس البنغاليين",
    "Category:Persecution of Buddhists": "تصنيف:اضطهاد البوذيين",
    "Category:Persecution of Christians": "تصنيف:اضطهاد المسيحيين",
    "Category:Persecution of Christians by ISIL": "تصنيف:اضطهاد تنظيم الدولة الإسلامية (داعش) للمسيحيين",
    "Category:Persecution of Christians by Muslims": "تصنيف:اضطهاد منسوب للمسلمين ضد المسيحيين",
    "Category:Persecution of Christians in Indonesia": "تصنيف:اضطهاد المسيحيين في إندونيسيا",
    "Category:Persecution of Christians in Iran": "تصنيف:اضطهاد المسيحيين في إيران",
    "Category:Persecution of Christians in Iraq": "تصنيف:اضطهاد المسيحيين في العراق",
    "Category:Persecution of Christians in Pakistan": "تصنيف:اضطهاد المسيحيين في باكستان",
    "Category:Persecution of Christians in Turkey": "تصنيف:اضطهاد المسيحيين في تركيا",
    "Category:Persecution of Christians in the Ottoman Empire": "تصنيف:اضطهاد المسيحيين في الدولة العثمانية",
    "Category:Persecution of Eastern Orthodox Christians": "تصنيف:اضطهاد المسيحيين الأرثوذكس الشرقيين",
    "Category:Persecution of Greeks": "تصنيف:اضطهاد اليونانيين",
    "Category:Persecution of Greeks in Turkey": "تصنيف:اضطهاد اليونانيين في تركيا",
    "Category:Persecution of Greeks in the Ottoman Empire": "تصنيف:اضطهاد اليونانيين في الدولة العثمانية",
    "Category:Persecution of Greeks in the Ottoman Empire before the 20th century": "تصنيف:اضطهاد اليونانيين في الدولة العثمانية قبل القرن 20",
    "Category:Persecution of Greeks in the Ottoman Empire in the 20th century": "تصنيف:اضطهاد اليونانيين في الدولة العثمانية بعد القرن 20",
    "Category:Persecution of Iraqi Turkmen": "تصنيف:اضطهاد التركمانيين العراقيين",
    "Category:Persecution of Muslims by Christians": "تصنيف:اضطهاد المسلمين من قبل المسيحيين",
    "Category:Persecution of Oriental Orthodox Christians": "تصنيف:اضطهاد المسيحيين الأرثوذكس المشرقيين",
    "Category:Persecution of Ottoman Muslims": "تصنيف:اضطهاد المسلمين العثمانيين",
    "Category:Persecution of Pagans": "تصنيف:اضطهاد الوثنيين",
    "Category:Persecution of Yazidis": "تصنيف:اضطهاد اليزيديين",
    "Category:Persecution of Yazidis by ISIL": "تصنيف:اضطهاد تنظيم الدولة الإسلامية (داعش) لليزيديين",
    "Category:Persecution of Yazidis in Iraq": "تصنيف:اضطهاد اليزيديين في العراق",
    "Category:Persecution of early Christians": "تصنيف:اضطهاد المسيحيين الأوائل",
    "Category:Persecution of homosexuals in Nazi Germany": "تصنيف:اضطهاد المثليين في ألمانيا النازية والهولوكوست",
    "Category:Persecution of pagans in the late Roman Empire": "تصنيف:اضطهاد الوثنيين في الإمبراطورية الرومانية المتأخرة",
    "Category:Philippine dynasty": "تصنيف:سلالة الفيليبيين",
    "Category:Pinyin": "تصنيف:بينيين",
    "Category:Poets under the Salghurids": "تصنيف:شعراء في عهد السلغوريين",
    "Category:Police raids on Islamists": "تصنيف:غارات الشرطة على الإسلاميين",
    "Category:Polish deportees to Soviet Union": "تصنيف:المهجريين البولنديين إلى الاتحاد السوفيتي",
    "Category:Polish deportees to the Soviet Union": "تصنيف:المهجريين البولنديين إلى الاتحاد السوفيتي",
    "Category:Polish exiles": "تصنيف:المنفيين البولنديين",
    "Category:Polish football biography stubs": "تصنيف:بذرة أعلام كرة قدم بولنديين",
    "Category:Polish people imprisoned in Russia": "تصنيف:سجناء بولنديين في روسيا",
    "Category:Polish sports-people stubs": "تصنيف:بذرة عن رياضيين بولنديين",
    "Category:Political people stubs": "تصنيف:بذرة عن أشخاص سياسيين",
    "Category:Political positions of American politicians": "تصنيف:مواقف سياسية للسياسيين الأمريكيين",
    "Category:Political positions of politicians": "تصنيف:مواقف سياسية للسياسيين",
    "Category:Politicians from Camiguin": "تصنيف:سياسيون من كاميغويين",
    "Category:Politics and government work group articles": "تصنيف:مقالات فريق عمل السياسيين وصناع القرار",
    "Category:Polyenes": "تصنيف:بوليين",
    "Category:Pop albums by American artists": "تصنيف:ألبومات بوب لفنانين أمريكيين",
    "Category:Pop albums by Australian artists": "تصنيف:ألبومات بوب لفنانين أستراليين",
    "Category:Pop albums by British artists": "تصنيف:ألبومات بوب لفنانين بريطانيين",
    "Category:Pop albums by Canadian artists": "تصنيف:ألبومات بوب لفنانين كنديين",
    "Category:Pop albums by Egyptian artists": "تصنيف:ألبومات بوب لفنانين مصريين",
    "Category:Pop albums by Emirati artists": "تصنيف:ألبومات بوب لفنانين إماراتيين",
    "Category:Pop albums by Iraqi artists": "تصنيف:ألبومات بوب لفنانين عراقيين",
    "Category:Pop albums by Japanese artists": "تصنيف:ألبومات بوب لفنانين يابانيين",
    "Category:Pop albums by Lebanese artists": "تصنيف:ألبومات بوب لفنانين لبنانيين",
    "Category:Pop albums by Libyan artists": "تصنيف:ألبومات بوب لفنانين ليبيين",
    "Category:Pop albums by Mexican artists": "تصنيف:ألبومات بوب لفنانين مكسيكيين",
    "Category:Pop albums by Romanian artists": "تصنيف:ألبومات بوب لفنانين رومانيين",
    "Category:Pop albums by South Korean artists": "تصنيف:ألبومات بوب لفنانين كوريين جنوبيين",
    "Category:Populated places in Payne County, Oklahoma": "تصنيف:أماكن مأهولة في مقاطعة بايين (أوكلاهوما)",
    "Category:Portuguese football biography stubs": "تصنيف:بذرة أعلام كرة قدم برتغاليين",
    "Category:Presidents of the American Association of Geographers": "تصنيف:رؤساء رابطة الجغرافيين الامريكيين",
    "Category:Presidents of the American Institute of Architects": "تصنيف:رؤساء الجمعية الأمريكية للمعماريين",
    "Category:Presidents of the Institution of Civil Engineers": "تصنيف:رؤساء معهد المهندسين المدنيين",
    "Category:Presidents of the Institution of Structural Engineers": "تصنيف:رؤساء معهد المهندسين الإنشائيين",
    "Category:Presidents of the Party of European Socialists": "تصنيف:رؤساء حزب الاشتراكيين الأوروبيين",
    "Category:Presidents of the Royal Institute of British Architects": "تصنيف:رؤساء المعهد الملكي للمعماريين البريطانيين",
    "Category:Progressive Alliance of Socialists and Democrats": "تصنيف:التحالف التقدمي للاشتراكيين والديمقراطيين",
    "Category:Progressive Conservative Party of Ontario MPPs": "تصنيف:أعضاء في برلمان مقاطعة أونتاريو عن حزب المحافظين التقدميين",
    "Category:Progressive Conservative Party of Ontario politicians": "تصنيف:سياسيون في حزب المحافظين التقدميين في أونتاريو",
    "Category:Progressive Democrats": "تصنيف:حزب الديمقراطيين التقدميين",
    "Category:Progressive music albums by Swedish artists": "تصنيف:ألبومات موسيقى تقدمية لفنانين سويديين",
    "Category:Public image of American politicians": "تصنيف:صورة عامة للسياسيين الأميركيين",
    "Category:Public image of politicians": "تصنيف:صورة عامة للسياسيين",
    "Category:Qatari football biography stubs": "تصنيف:بذرة أعلام كرة قدم قطريين",
    "Category:Racially motivated violence against African Americans": "تصنيف:العنف بدوافع عنصرية ضد الأمريكيين الأفارقة",
    "Category:Racially motivated violence against Asian Americans": "تصنيف:عنف بدوافع عنصرية ضد الأمريكيين الآسيويين",
    "Category:Rattachism": "تصنيف:راتشيين",
    "Category:Raëlian practices": "تصنيف:معتقدات الرائيليين",
    "Category:Refugee Olympic Team at the 2016 Summer Olympics": "تصنيف:فريق الرياضيين الأولمبيين اللاجئين في الألعاب الأولمبية الصيفية 2016",
    "Category:Reggae albums by American artists": "تصنيف:ألبومات ريغي لفنانين أمريكيين",
    "Category:Reggae albums by Barbadian artists": "تصنيف:ألبومات ريغيه لفنانين بربادوسيين",
    "Category:Reggae albums by Egyptian artists": "تصنيف:ألبومات ريغيه لفنانين مصريين",
    "Category:Religious music albums by American artists": "تصنيف:ألبومات موسيقى دينية لفنانين أمريكيين",
    "Category:Religious music albums by South Korean artists": "تصنيف:ألبومات موسيقى دينية لفنانين كوريين جنوبيين",
    "Category:Religious persecution by communists": "تصنيف:اضطهاد ديني من قبل الشيوعيين",
    "Category:Republic of Ireland LGBT rights case law": "تصنيف:قضايا محاكم أيرلندية حول حقوق المثليين",
    "Category:Republic of Ireland LGBTQ rights case law": "تصنيف:قضايا محاكم أيرلندية حول معاملة المثليين",
    "Category:Republic of Ireland association football biography stubs": "تصنيف:بذرة أعلام كرة قدم أيرلنديين",
    "Category:republic of congo men's A' international footballers": "تصنيف:لاعبو منتخب جمهورية الكونغو لكرة القدم للرجال للمحليين",
    "Category:Rescue of Jews by Poles in occupied Poland in 1939-1945": "تصنيف:انقاذ اليهود على يد البولنديين في بولندا المحتلة في 1939-1945",
    "Category:Rescue of Jews by Poles in occupied Poland in 1939–1945": "تصنيف:انقاذ اليهود على يد البولنديين في بولندا المحتلة في 1939-1945",
    "Category:Rhythm and blues albums by British artists": "تصنيف:ألبومات ريذم أند بلوز لفنانين بريطانيين",
    "Category:Rivers of Haute-Vienne": "تصنيف:أنهار فيين العليا (إقليم فرنسي)",
    "Category:Rivers of Payne County, Oklahoma": "تصنيف:أنهار مقاطعة بايين (أوكلاهوما)",
    "Category:Rivers of Vienne": "تصنيف:أنهار فيين (إقليم فرنسي)",
    "Category:Rivers of Vienne (department)": "تصنيف:أنهار فيين (إقليم فرنسي)",
    "Category:Robot comics": "تصنيف:قصص مصورة عن آليين",
    "Category:Rock albums by British artists": "تصنيف:ألبومات روك لفنانين بريطانيين",
    "Category:Rock albums by Swedish artists": "تصنيف:ألبومات روك لفنانين سويديين",
    "Category:Romanian football biography stubs": "تصنيف:بذرة أعلام كرة قدم رومانيين",
    "Category:Royal Governors of Venezuela": "تصنيف:الحكام الملكيين لفنزويلا",
    "Category:Royal Institute of British Architects": "تصنيف:المعهد الملكي للمهندسين المعماريين البريطانيين",
    "Category:Royal governors of Venezuela": "تصنيف:الحكام الملكيين لفنزويلا",
    "Category:Rwanda men's A' international footballers": "تصنيف:لاعبو منتخب رواندا لكرة القدم للرجال للمحليين",
    "Category:Sahrawi refugee camps": "تصنيف:مخيمات اللاجئين الصحراويين",
    "Category:Saint-Jean-de-Maurienne": "تصنيف:سان-جان-دي-موريين",
    "Category:Saints from East Francia": "تصنيف:قديسون من مملكة الفرنجة الشرقيين",
    "Category:Samaritan culture and history": "تصنيف:تاريخ وثقافة السامريين",
    "Category:Same-sex adoption": "تصنيف:تبني المثليين للأطفال",
    "Category:Same-sex adoption in Europe": "تصنيف:تبني المثليين للأطفال في أوروبا",
    "Category:Same-sex adoption in the United States": "تصنيف:تبني المثليين للأطفال في الولايات المتحدة",
    "Category:Same-sex marriage by country": "تصنيف:زواج المثليين حسب البلد",
    "Category:Same-sex marriage by country subdivision": "تصنيف:زواج المثليين حسب المستوى دون الوطني للبلد",
    "Category:Same-sex marriage in Australia": "تصنيف:زواج المثليين في أستراليا",
    "Category:Same-sex marriage in Brazil": "تصنيف:زواج المثليين في البرازيل",
    "Category:Same-sex marriage in British Overseas Territories": "تصنيف:زواج المثليين في أقاليم ما وراء البحار البريطانية",
    "Category:Same-sex marriage in Canada": "تصنيف:زواج المثليين في كندا",
    "Category:Same-sex marriage in Canada by province or territory": "تصنيف:زواج المثليين في كندا حسب المقاطعة أو الإقليم",
    "Category:Same-sex marriage in Denmark": "تصنيف:زواج المثليين في الدنمارك",
    "Category:Same-sex marriage in France": "تصنيف:زواج المثليين في فرنسا",
    "Category:Same-sex marriage in Mexico": "تصنيف:زواج المثليين في المكسيك",
    "Category:Same-sex marriage in Mexico by state": "تصنيف:زواج المثليين في المكسيك حسب الولاية",
    "Category:Same-sex marriage in dependent territories of the United Kingdom": "تصنيف:زواج المثليين في تبعيات التاج البريطاني",
    "Category:Same-sex marriage in fiction": "تصنيف:زواج المثليين في الأعمال الخيالية",
    "Category:Same-sex marriage in the Crown Dependencies": "تصنيف:زواج المثليين في تبعيات التاج البريطاني",
    "Category:Same-sex marriage in the Netherlands": "تصنيف:زواج المثليين في هولندا",
    "Category:Same-sex marriage in republic of Ireland": "تصنيف:زواج المثليين في جمهورية أيرلندا",
    "Category:Same-sex marriage in the United Kingdom": "تصنيف:زواج المثليين في المملكة المتحدة",
    "Category:Same-sex marriage in the United States": "تصنيف:زواج المثليين في الولايات المتحدة",
    "Category:Saudi Arabian football biography stubs": "تصنيف:بذرة أعلام كرة قدم سعوديين",
    "Category:Science and academia work group articles": "تصنيف:مقالات فريق عمل الأكاديميين والعلماء",
    "Category:Sculptures of politicians": "تصنيف:منحوتات لسياسيين",
    "Category:Semi-vegetarianism": "تصنيف:شبه نباتيين",
    "Category:Senegal men's A' international footballers": "تصنيف:لاعبو منتخب السنغال لكرة القدم للرجال للمحليين",
    "Category:Senegalese film director navigational boxes": "تصنيف:صناديق تصفح مخرجي أفلام سنغاليين",
    "Category:Senegalese football biography stubs": "تصنيف:بذرة أعلام كرة قدم سنغاليين",
    "Category:Sephardi Jewish cuisine": "تصنيف:مطبخ اليهود الشرقيين",
    "Category:Serbian football biography stubs": "تصنيف:بذرة أعلام كرة قدم صربيين",
    "Category:Serbian geophysicists": "تصنيف:جيوفيزيائيين صرب",
    "Category:Sikh terrorism": "تصنيف:إرهاب منسوب للسيخيين",
    "Category:Slavery of Native Americans": "تصنيف:العبودية في السكان الأصليين في الولايات المتحدة",
    "Category:Slovak football biography stubs": "تصنيف:بذرة أعلام كرة قدم سلوفاكيين",
    "Category:Socialist Workers Party (United States)": "تصنيف:حزب العمال الاشتراكيين",
    "Category:Soft rock albums by Irish artists": "تصنيف:ألبومات سوفت روك لفنانين أيرلنديين",
    "Category:Songs about American politicians": "تصنيف:أغان عن سياسيين أمريكيين",
    "Category:Songs about comedians": "تصنيف:أغان عن كوميديين",
    "Category:Songs about fictional male characters": "تصنيف:أغان عن ذكور خياليين",
    "Category:Songs about military officers": "تصنيف:أغان عن ضباط عسكريين",
    "Category:Songs about musicians": "تصنيف:أغان عن موسيقيين",
    "Category:Songs about politicians": "تصنيف:أغان عن سياسيين",
    "Category:Songs about religious leaders": "تصنيف:أغان عن قادة دينيين",
    "Category:Songs about sports-people": "تصنيف:أغان عن رياضيين",
    "Category:South Korean football biography stubs": "تصنيف:بذرة أعلام كرة قدم كوريين جنوبيين",
    "Category:Southeast Asian American": "تصنيف:أمريكيون آسيويين جنوبيون شرقيون",
    "Category:Southeast Asian English": "تصنيف:إنجليز آسيويين جنوبيون شرقيون",
    "Category:Southeast Asian Jews": "تصنيف:يهود آسيويين جنوبيون شرقيون",
    "Category:Southeast Asian communists": "تصنيف:شيوعيون آسيويين جنوبيون شرقيون",
    "Category:Southeast Asian diaspora in the United States": "تصنيف:أمريكيون آسيويين جنوبيون شرقيون",
    "Category:Southeast Asian football biography stubs": "تصنيف:بذرة أعلام كرة قدم آسيويين جنوبيون شرقيون",
    "Category:Southeast Asian people by occupation": "تصنيف:آسيويين جنوبيون شرقيون حسب المهنة",
    "Category:Southeast Asian people by political orientation": "تصنيف:آسيويين جنوبيون شرقيون حسب التوجه السياسي",
    "Category:Southeast Asian people in sports": "تصنيف:آسيويين جنوبيون شرقيون في ألعاب رياضية",
    "Category:Southeast Asian people of Brazilian descent": "تصنيف:آسيويين جنوبيون شرقيون من أصل برازيلي",
    "Category:Southeast Asian people of Chinese descent": "تصنيف:آسيويين جنوبيون شرقيون من أصل صيني",
    "Category:Southeast Asian political people": "تصنيف:ساسة آسيويين جنوبيون شرقيون",
    "Category:Southeast Asian sports coaches": "تصنيف:مدربو رياضة آسيويين جنوبيون شرقيون",
    "Category:Soviet and Russian space program locations": "تصنيف:مواقع البرنامجين الفضائيين السوفيتي والروسي",
    "Category:Speeches by Nazis": "تصنيف:خطب النازيين",
    "Category:Sport in Haute-Vienne": "تصنيف:الرياضة في فيين العليا (إقليم فرنسي)",
    "Category:Sport in Vienne": "تصنيف:الرياضة في فيين (إقليم فرنسي)",
    "Category:Sport in Vienne (department)": "تصنيف:الرياضة في فيين (إقليم فرنسي)",
    "Category:Sports and games work group articles": "تصنيف:مقالات فريق عمل الرياضيين",
    "Category:sports-people from Camiguin": "تصنيف:رياضيون من كاميغويين",
    "Category:sports-people from Cayenne": "تصنيف:رياضيون من كايين",
    "Category:sports-people from Haute-Vienne": "تصنيف:رياضيون من فيين العليا (إقليم فرنسي)",
    "Category:sports-people from Vienne": "تصنيف:رياضيون من فيين (إقليم فرنسي)",
    "Category:sports-people from Vienne (department)": "تصنيف:رياضيون من فيين (إقليم فرنسي)",
    "Category:sports-people stubs": "تصنيف:بذرة رياضيين",
    "Category:Spouses of Iranian politicians": "تصنيف:قرينات سياسيين إيرانيين",
    "Category:Spouses of heads of state by country": "تصنيف:قرينات قادة وطنيين حسب البلد",
    "Category:Spouses of politicians": "تصنيف:أزواج سياسيين",
    "Category:Statues of politicians": "تصنيف:تماثيل سياسيين",
    "Category:Structures by American engineers": "تصنيف:منشآت من تصميم مهندسين أمريكيين",
    "Category:Subgroups of the Han Chinese": "تصنيف:مجموعات فرعية للهان الصينيين",
    "Category:Subnational legislators in South America": "تصنيف:المشرعون دون الوطنيين في أمريكا الجنوبية",
    "Category:Sudan men's A' international footballers": "تصنيف:لاعبو منتخب السودان لكرة القدم للرجال للمحليين",
    "Category:Sudanese football biography stubs": "تصنيف:بذرة أعلام كرة قدم سودانيين",
    "Category:Superhero films about Asian Americans": "تصنيف:أفلام أبطال خارقين عن أمريكيون آسيويين",
    "Category:Swedish football biography stubs": "تصنيف:بذرة أعلام كرة قدم سويديين",
    "Category:Swiss football biography stubs": "تصنيف:بذرة أعلام كرة قدم سويسريين",
    "Category:Synth-pop albums by Australian artists": "تصنيف:ألبومات سينثبوب لفنانين أستراليين",
    "Category:Syrian refugee camps": "تصنيف:مخيمات اللاجئين السوريين",
    "Category:Syrian-American history": "تصنيف:تاريخ السوريين في الولايات المتحدة",
    "Category:Table tennis Olympic champions navigational boxes": "تصنيف:صناديق تصفح أبطال أولمبيين في كرة الطاولة",
    "Category:Taekwondo Olympic champions navigational boxes": "تصنيف:صناديق تصفح أبطال أولمبيين في التايكواندو",
    "Category:Tanzania men's A' international footballers": "تصنيف:لاعبو منتخب تنزانيا لكرة القدم للرجال للمحليين",
    "Category:Tarxien Rainbows F.C. players": "تصنيف:لاعبو تاركسيين راينباوز",
    "Category:Television evangelists": "تصنيف:المبشرين التلفزيونيين",
    "Category:Television series about Nazis": "تصنيف:مسلسلات تلفزيونية عن نازيين",
    "Category:Television series about comedians": "تصنيف:مسلسلات تلفازية عن كوميديين",
    "Category:Television series about fictional musicians": "تصنيف:مسلسلات تلفزيونية عن موسيقيين خياليين",
    "Category:Television series about fictional serial killers": "تصنيف:مسلسلات تلفزيونية عن قتلة متسلسلين خياليين",
    "Category:Television series about serial killers": "تصنيف:مسلسلات تلفزيونية عن قتلة متسلسلين خياليين",
    "Category:Television shows about cocaine": "تصنيف:برامج تلفزيونية عن كوكايين",
    "Category:Timurid civil wars": "تصنيف:حروب التيموريين الأهلية",
    "Category:Timurid wars of succession": "تصنيف:حروب التيموريين الأهلية",
    "Category:Tourist attractions in Payne County, Oklahoma": "تصنيف:مواقع جذب سياحي في مقاطعة بايين (أوكلاهوما)",
    "Category:Towns in Payne County, Oklahoma": "تصنيف:بلدات في مقاطعة بايين (أوكلاهوما)",
    "Category:Trinitarian Order": "تصنيف:الآباء الثالوثيين",
    "Category:Tunisia at the African Nations Championship": "تصنيف:تونس في بطولة أمم إفريقيا للمحليين",
    "Category:Tunisia men's A' international footballers": "تصنيف:لاعبو منتخب تونس لكرة القدم للرجال للمحليين",
    "Category:Tunisian football biography stubs": "تصنيف:بذرة أعلام كرة قدم تونسيين",
    "Category:U.S. Air Force Test Pilot School alumni": "تصنيف:خريجو كلية تدريب الطيارين الاختباريين الأمريكية",
    "Category:UNRWA": "تصنيف:وكالة الأمم المتحدة لإغاثة وتشغيل اللاجئين الفلسطينيين",
    "Category:UNRWA officials": "تصنيف:موظفو وكالة الأمم المتحدة لإغاثة وتشغيل اللاجئين الفلسطينيين",
    "Category:Uganda men's A' international footballers": "تصنيف:لاعبو منتخب أوغندا لكرة القدم للرجال للمحليين",
    "Category:Ukrainian communities in the United States": "تصنيف:مجتمعات أوكرانيين في الولايات المتحدة",
    "Category:Ukrainian football biography stubs": "تصنيف:بذرة أعلام كرة قدم أوكرانيين",
    "Category:Ukrainian-Jewish culture in the United States": "تصنيف:ثقافة اليهود الأوكرانيين في الولايات المتحدة",
    "Category:Union of Democrats for republic politicians": "تصنيف:سياسيو اتحاد الديمقراطيين من أجل الجمهورية",
    "Category:United Nations Security Council resolutions concerning appointment of the Secretary-General": "تصنيف:قرارات مجلس الأمن التابع للأمم المتحدة بشأن تعيين الأمين العام",
    "Category:United Nations Security Council resolutions concerning the protection of civilians in armed conflict": "تصنيف:قرارات مجلس الأمن التابع للأمم المتحدة بشأن حماية المدنيين في النزاعات المسلحة",
    "Category:United States Naval Test Pilot School alumni": "تصنيف:خريجو كلية الطيارين الاختباريين البحرية الأمريكية",
    "Category:United States comics creator navigational boxes": "تصنيف:قوالب مبتكري قصص مصورة أمريكيين",
    "Category:University of al-Qarawiyyin": "تصنيف:جامعة القرويين",
    "Category:University of al-Qarawiyyin alumni": "تصنيف:خريجو جامعة القرويين",
    "Category:Uruguayan football biography stubs": "تصنيف:بذرة أعلام كرة قدم أوروغواينيين",
    "Category:Uzbekistani football biography stubs": "تصنيف:بذرة أعلام كرة قدم أوزبكستانيين",
    "Category:Venezuelan football biography stubs": "تصنيف:بذرة أعلام كرة قدم فنزويليين",
    "Category:Veterans' affairs": "تصنيف:قضايا قدماء المحاربين العسكريين",
    "Category:Veterans' affairs in the United States": "تصنيف:قضايا قدماء المحاربين العسكريين في الولايات المتحدة",
    "Category:Victims of anti-Christian violence": "تصنيف:ضحايا العنف ضد المسيحيين",
    "Category:Video albums by Barbadian artists": "تصنيف:ألبومات فيديو لفنانين بربادوسيين",
    "Category:Video game characters based on real people": "تصنيف:شخصيات ألعاب فيديو مستندة على أشخاص حقيقيين",
    "Category:Video games about Nazis": "تصنيف:ألعاب فيديو عن نازيين",
    "Category:Videographies of Lebanese artists": "تصنيف:فيديوغرافيات الفنانين اللبنانيين",
    "Category:Vienne": "تصنيف:فيين (إقليم فرنسي)",
    "Category:Vienne (department)": "تصنيف:فيين (إقليم فرنسي)",
    "Category:Vigilantism against sex offenders": "تصنيف:مطبقو عدالة ذاتية على المعتدين الجنسيين",
    "Category:Violence against Christians": "تصنيف:العنف ضد المسيحيين",
    "Category:Violence against Christians in India": "تصنيف:العنف ضد المسيحيين في الهند",
    "Category:Violence against LGBT people": "تصنيف:عنف ضد الأشخاص المثليين",
    "Category:Violence against LGBT people in Asia": "تصنيف:العنف ضد الأشخاص المثليين في آسيا",
    "Category:Violence against LGBT people in Europe": "تصنيف:العنف ضد الأشخاص المثليين في أوروبا",
    "Category:Violence against LGBT people in the United Kingdom": "تصنيف:العنف ضد الأشخاص المثليين في المملكة المتحدة",
    "Category:Violence against LGBT people in the United States": "تصنيف:العنف ضد الأشخاص المثليين في الولايات المتحدة",
    "Category:Violence against LGBTQ people": "تصنيف:عنف ضد الأشخاص المثليين",
    "Category:Violence against LGBTQ people in Asia": "تصنيف:العنف ضد الأشخاص المثليين في آسيا",
    "Category:Violence against LGBTQ people in Europe": "تصنيف:العنف ضد الأشخاص المثليين في أوروبا",
    "Category:Violence against LGBTQ people in the United Kingdom": "تصنيف:العنف ضد الأشخاص المثليين في المملكة المتحدة",
    "Category:Violence against LGBTQ people in the United States": "تصنيف:العنف ضد الأشخاص المثليين في الولايات المتحدة",
    "Category:Violence against journalists": "تصنيف:عنف ضد صحفيين",
    "Category:Visigothic Kingdom": "تصنيف:مملكة القوط الغربيين",
    "Category:Volleyball Olympic champions navigational boxes": "تصنيف:صناديق تصفح أبطال أولمبيين في كرة الطائرة",
    "Category:Wars between the United States and Native Americans": "تصنيف:حروب بين الولايات المتحدة والأمريكيين الأصليين",
    "Category:Wars involving the Ayyubid Sultanate": "تصنيف:حروب الأيوبيين",
    "Category:Wars involving the Celts": "تصنيف:حروب تضمنت الكلتيين",
    "Category:West Asian Jews": "تصنيف:يهود آسيويين غربيون",
    "Category:West Francia": "تصنيف:مملكة الفرنجة الغربيين",
    "Category:White nationalist symbols": "تصنيف:رموز القوميين البيض",
    "Category:Wikipedia articles incorporating a citation from the DCBL": "تصنيف:مقالات ويكيبيديا تتضمن نصًا من قاموس السيرة والأدب المسيحيين حتى نهاية القرن السادس",
    "Category:Wikipedia categories named after American actors": "تصنيف:تصنيفات سميت بأسماء ممثلين أمريكيين",
    "Category:Wikipedia categories named after American astronauts": "تصنيف:تصنيفات سميت بأسماء رواد فضاء أمريكيين",
    "Category:Wikipedia categories named after American composers": "تصنيف:تصنيفات سميت بأسماء ملحنين أمريكيين",
    "Category:Wikipedia categories named after American filmmakers": "تصنيف:تصنيفات سميت بأسماء صانعي أفلام أمريكيين",
    "Category:Wikipedia categories named after American military leaders": "تصنيف:تصنيفات سميت بأسماء قادة عسكريين أمريكيين",
    "Category:Wikipedia categories named after American musicians": "تصنيف:تصنيفات بأسماء موسيقيين أمريكيين",
    "Category:Wikipedia categories named after American politicians": "تصنيف:تصنيفات بأسماء سياسيين أمريكيين",
    "Category:Wikipedia categories named after American scientists": "تصنيف:تصنيفات سميت بأسماء علماء أمريكيين",
    "Category:Wikipedia categories named after American sports-people": "تصنيف:تصنيفات سميت بأسماء رياضيين أمريكيين",
    "Category:Wikipedia categories named after Argentine people": "تصنيف:تصنيفات سميت بأسماء أرجنتينيين",
    "Category:Wikipedia categories named after Argentine politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين أرجنتينيين",
    "Category:Wikipedia categories named after Argentine sports-people": "تصنيف:تصنيفات سميت بأسماء رياضيين أرجنتينيين",
    "Category:Wikipedia categories named after Australian actors": "تصنيف:تصنيفات سميت بأسماء ممثلين أستراليين",
    "Category:Wikipedia categories named after Australian musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين أستراليين",
    "Category:Wikipedia categories named after Australian politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين أستراليين",
    "Category:Wikipedia categories named after Austrian composers": "تصنيف:تصنيفات سميت بأسماء ملحنين نمساويين",
    "Category:Wikipedia categories named after Austrian filmmakers": "تصنيف:تصنيفات سميت بأسماء صانعي أفلام نمساويين",
    "Category:Wikipedia categories named after Austrian musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين نمساويين",
    "Category:Wikipedia categories named after Azerbaijani people": "تصنيف:تصنيفات سميت بأسماء أذربيجانيين",
    "Category:Wikipedia categories named after Bangladeshi people": "تصنيف:تصنيفات سميت بأسماء بنجلاديشيين",
    "Category:Wikipedia categories named after Barbadian people": "تصنيف:تصنيفات سميت بأسماء بربادوسيين",
    "Category:Wikipedia categories named after Belarusian people": "تصنيف:تصنيفات سميت بأسماء بيلاروسيين",
    "Category:Wikipedia categories named after Belgian musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين بلجيكيين",
    "Category:Wikipedia categories named after Belgian people": "تصنيف:تصنيفات سميت بأسماء بلجيكيين",
    "Category:Wikipedia categories named after Bolivian people": "تصنيف:تصنيفات سميت بأسماء بوليفيين",
    "Category:Wikipedia categories named after Brazilian musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين برازيليين",
    "Category:Wikipedia categories named after Brazilian politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين برازيليين",
    "Category:Wikipedia categories named after British actors": "تصنيف:تصنيفات سميت بأسماء ممثلين بريطانيين",
    "Category:Wikipedia categories named after British artists": "تصنيف:تصنيفات سميت بأسماء فنانين بريطانيين",
    "Category:Wikipedia categories named after British military leaders": "تصنيف:تصنيفات سميت بأسماء قادة عسكريين بريطانيين",
    "Category:Wikipedia categories named after British musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين بريطانيين",
    "Category:Wikipedia categories named after British philosophers": "تصنيف:تصنيفات سميت بأسماء فلاسفة بريطانيين",
    "Category:Wikipedia categories named after British politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين بريطانيين",
    "Category:Wikipedia categories named after British scientists": "تصنيف:تصنيفات سميت بأسماء علماء بريطانيين",
    "Category:Wikipedia categories named after Canadian actors": "تصنيف:تصنيفات سميت بأسماء ممثلين كنديين",
    "Category:Wikipedia categories named after Canadian filmmakers": "تصنيف:تصنيفات سميت بأسماء صانعي أفلام كنديين",
    "Category:Wikipedia categories named after Canadian musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين كنديين",
    "Category:Wikipedia categories named after Canadian people": "تصنيف:تصنيفات سميت بأسماء كنديين",
    "Category:Wikipedia categories named after Canadian politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين كنديين",
    "Category:Wikipedia categories named after Canadian sports-people": "تصنيف:تصنيفات سميت بأسماء رياضيين كنديين",
    "Category:Wikipedia categories named after Chilean people": "تصنيف:تصنيفات سميت بأسماء تشيليين",
    "Category:Wikipedia categories named after Chinese actors": "تصنيف:تصنيفات سميت بأسماء ممثلين صينيين",
    "Category:Wikipedia categories named after Chinese military leaders": "تصنيف:تصنيفات سميت بأسماء قادة عسكريين صينيين",
    "Category:Wikipedia categories named after Chinese musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين صينيين",
    "Category:Wikipedia categories named after Chinese politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين صينيين",
    "Category:Wikipedia categories named after Christian figures": "تصنيف:تصنيفات سميت بأسماء أعلام مسيحيين",
    "Category:Wikipedia categories named after Colombian musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين كولومبيين",
    "Category:Wikipedia categories named after Cypriot people": "تصنيف:تصنيفات سميت بأسماء قبرصيين",
    "Category:Wikipedia categories named after Czech filmmakers": "تصنيف:تصنيفات سميت بأسماء صانعي أفلام تشيكيين",
    "Category:Wikipedia categories named after Czech military leaders": "تصنيف:تصنيفات سميت بأسماء أفراد عسكريين تشيكيين",
    "Category:Wikipedia categories named after Czech people": "تصنيف:تصنيفات سميت بأسماء تشيكيين",
    "Category:Wikipedia categories named after Czech politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين تشيكيين",
    "Category:Wikipedia categories named after Czech scientists": "تصنيف:تصنيفات سميت بأسماء علماء تشيكيين",
    "Category:Wikipedia categories named after Czechoslovak people": "تصنيف:تصنيفات سميت بأسماء تشيكوسلوفاكيين",
    "Category:Wikipedia categories named after Czechoslovak politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين تشيكوسلوفاكيين",
    "Category:Wikipedia categories named after Dutch artists": "تصنيف:تصنيفات سميت بأسماء فنانين هولنديين",
    "Category:Wikipedia categories named after Dutch musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين هولنديين",
    "Category:Wikipedia categories named after Dutch people": "تصنيف:تصنيفات سميت بأسماء هولنديين",
    "Category:Wikipedia categories named after Egyptian people": "تصنيف:تصنيفات سميت بأسماء مصريين",
    "Category:Wikipedia categories named after English military leaders": "تصنيف:تصنيفات سميت بأسماء قادة عسكريين إنجليز",
    "Category:Wikipedia categories named after English musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين إنجليز",
    "Category:Wikipedia categories named after Filipino people": "تصنيف:تصنيفات سميت بأسماء فلبينيين",
    "Category:Wikipedia categories named after Finnish people": "تصنيف:تصنيفات سميت بأسماء فنلنديين",
    "Category:Wikipedia categories named after French actors": "تصنيف:تصنيفات سميت بأسماء ممثلين فرنسيين",
    "Category:Wikipedia categories named after French artists": "تصنيف:تصنيفات سميت بأسماء فنانين فرنسيين",
    "Category:Wikipedia categories named after French composers": "تصنيف:تصنيفات سميت بأسماء ملحنين فرنسيين",
    "Category:Wikipedia categories named after French military leaders": "تصنيف:تصنيفات سميت بأسماء قادة عسكريين فرنسيين",
    "Category:Wikipedia categories named after French musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين فرنسيين",
    "Category:Wikipedia categories named after French politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين فرنسيين",
    "Category:Wikipedia categories named after German military leaders": "تصنيف:تصنيفات سميت بأسماء قادة عسكريين ألمان",
    "Category:Wikipedia categories named after German musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين ألمان",
    "Category:Wikipedia categories named after German politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين ألمان",
    "Category:Wikipedia categories named after Greek artists": "تصنيف:تصنيفات سميت بأسماء فنانين يونانيين",
    "Category:Wikipedia categories named after Greek musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين يونانيين",
    "Category:Wikipedia categories named after Guatemalan musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين غواتيماليين",
    "Category:Wikipedia categories named after Haitian people": "تصنيف:تصنيفات سميت بأسماء هايتيين",
    "Category:Wikipedia categories named after Hindu religious leaders": "تصنيف:تصنيفات سميت بأسماء قادة دينيين هندوس",
    "Category:Wikipedia categories named after Hungarian people": "تصنيف:تصنيفات سميت بأسماء مجريين",
    "Category:Wikipedia categories named after Hungarian politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين مجريين",
    "Category:Wikipedia categories named after Icelandic musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين آيسلنديين",
    "Category:Wikipedia categories named after Icelandic people": "تصنيف:تصنيفات سميت بأسماء آيسلنديين",
    "Category:Wikipedia categories named after Indian musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين هنود",
    "Category:Wikipedia categories named after Indian politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين هنود",
    "Category:Wikipedia categories named after Indian sports-people": "تصنيف:تصنيفات سميت بأسماء رياضيين هنود",
    "Category:Wikipedia categories named after Iranian people": "تصنيف:تصنيفات سميت بأسماء إيرانيين",
    "Category:Wikipedia categories named after Iranian politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين إيرانيين",
    "Category:Wikipedia categories named after Iraqi people": "تصنيف:تصنيفات سميت بأسماء عراقيين",
    "Category:Wikipedia categories named after Irish people": "تصنيف:تصنيفات سميت بأسماء أيرلنديين",
    "Category:Wikipedia categories named after Irish politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين أيرلنديين",
    "Category:Wikipedia categories named after Italian artists": "تصنيف:تصنيفات سميت بأسماء فنانين إيطاليين",
    "Category:Wikipedia categories named after Italian composers": "تصنيف:تصنيفات سميت بأسماء ملحنين إيطاليين",
    "Category:Wikipedia categories named after Italian filmmakers": "تصنيف:تصنيفات سميت بأسماء صانعي أفلام إيطاليين",
    "Category:Wikipedia categories named after Italian military leaders": "تصنيف:تصنيفات سميت بأسماء قادة عسكريين إيطاليين",
    "Category:Wikipedia categories named after Italian musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين إيطاليين",
    "Category:Wikipedia categories named after Italian people": "تصنيف:تصنيفات سميت بأسماء إيطاليين",
    "Category:Wikipedia categories named after Italian politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين إيطاليين",
    "Category:Wikipedia categories named after Japanese musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين يابانيين",
    "Category:Wikipedia categories named after Japanese people": "تصنيف:تصنيفات سميت بأسماء يابانيين",
    "Category:Wikipedia categories named after Kenyan people": "تصنيف:تصنيفات سميت بأسماء كينيين",
    "Category:Wikipedia categories named after Korean politicians": "تصنيف:تصنيفات بأسماء سياسيين كوريين",
    "Category:Wikipedia categories named after Libyan people": "تصنيف:تصنيفات سميت بأسماء ليبيين",
    "Category:Wikipedia categories named after Mexican musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين مكسيكيين",
    "Category:Wikipedia categories named after Mexican people": "تصنيف:تصنيفات سميت بأسماء مكسيكيين",
    "Category:Wikipedia categories named after Mongolian people": "تصنيف:تصنيفات سميت بأسماء منغوليين",
    "Category:Wikipedia categories named after Nazis": "تصنيف:تصنيفات سميت بأسماء نازيين",
    "Category:Wikipedia categories named after New Zealand politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين نيوزيلنديين",
    "Category:Wikipedia categories named after Nigerian politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين نيجيريين",
    "Category:Wikipedia categories named after North Korean politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين كوريين شماليين",
    "Category:Wikipedia categories named after Norwegian musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين نرويجيين",
    "Category:Wikipedia categories named after Norwegian people": "تصنيف:تصنيفات سميت بأسماء نرويجيين",
    "Category:Wikipedia categories named after Pakistani people": "تصنيف:تصنيفات سميت بأسماء باكستانيين",
    "Category:Wikipedia categories named after Pakistani politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين باكستانيين",
    "Category:Wikipedia categories named after Paraguayan people": "تصنيف:تصنيفات سميت بأسماء باراغوايانيين",
    "Category:Wikipedia categories named after Polish military leaders": "تصنيف:تصنيفات سميت بأسماء قادة عسكريين بولنديين",
    "Category:Wikipedia categories named after Portuguese people": "تصنيف:تصنيفات سميت بأسماء برتغاليين",
    "Category:Wikipedia categories named after Romanian musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين رومانيين",
    "Category:Wikipedia categories named after Romanian people": "تصنيف:تصنيفات سميت بأسماء رومانيين",
    "Category:Wikipedia categories named after Russian military leaders": "تصنيف:تصنيفات سميت بأسماء قادة عسكريين روس",
    "Category:Wikipedia categories named after Russian musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين روس",
    "Category:Wikipedia categories named after Russian politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين روس",
    "Category:Wikipedia categories named after Scottish actors": "تصنيف:تصنيفات سميت بأسماء ممثلين إسكتلنديين",
    "Category:Wikipedia categories named after Scottish musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين إسكتلنديين",
    "Category:Wikipedia categories named after Scottish scientists": "تصنيف:تصنيفات سميت بأسماء علماء إسكتلنديين",
    "Category:Wikipedia categories named after South Korean musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين كوريين جنوبيين",
    "Category:Wikipedia categories named after Spanish military leaders": "تصنيف:تصنيفات سميت بأسماء قادة عسكريين إسبان",
    "Category:Wikipedia categories named after Spanish musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين إسبان",
    "Category:Wikipedia categories named after Spanish sports-people": "تصنيف:تصنيفات سميت بأسماء رياضيين إسبان",
    "Category:Wikipedia categories named after Sri Lankan people": "تصنيف:تصنيفات سميت بأسماء سريلانكيين",
    "Category:Wikipedia categories named after Swedish military leaders": "تصنيف:تصنيفات سميت بأسماء قادة عسكريين سويديين",
    "Category:Wikipedia categories named after Swedish musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين سويديين",
    "Category:Wikipedia categories named after Swiss people": "تصنيف:تصنيفات سميت بأسماء سويسريين",
    "Category:Wikipedia categories named after Taiwanese musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين تايوانيين",
    "Category:Wikipedia categories named after Tanzanian people": "تصنيف:تصنيفات سميت بأسماء تنزانيين",
    "Category:Wikipedia categories named after Thai people": "تصنيف:تصنيفات سميت بأسماء تايلنديين",
    "Category:Wikipedia categories named after Trinidad and Tobago people": "تصنيف:تصنيفات سميت بأسماء ترنيداديين",
    "Category:Wikipedia categories named after Turkish politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين أتراك",
    "Category:Wikipedia categories named after Ugandan people": "تصنيف:تصنيفات سميت بأسماء أوغنديين",
    "Category:Wikipedia categories named after Ukrainian politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين أوكرانيين",
    "Category:Wikipedia categories named after Uruguayan politicians": "تصنيف:تصنيفات سميت بأسماء سياسيين أوروغويانيين",
    "Category:Wikipedia categories named after Venezuelan people": "تصنيف:تصنيفات سميت بأسماء فنزويليين",
    "Category:Wikipedia categories named after Welsh musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين ويلزيين",
    "Category:Wikipedia categories named after Welsh people": "تصنيف:تصنيفات سميت بأسماء ويلزيين",
    "Category:Wikipedia categories named after ancient Greek people": "تصنيف:تصنيفات سميت بأسماء يونانيين قدماء",
    "Category:Wikipedia categories named after architects": "تصنيف:تصنيفات سميت بأسماء معماريين",
    "Category:Wikipedia categories named after astronomers": "تصنيف:تصنيفات سميت بأسماء فلكيين",
    "Category:Wikipedia categories named after economists": "تصنيف:تصنيفات سميت بأسماء اقتصاديين",
    "Category:Wikipedia categories named after linguists": "تصنيف:تصنيفات سميت بأسماء لغويين",
    "Category:Wikipedia categories named after military leaders": "تصنيف:تصنيفات بأسماء قادة عسكريين",
    "Category:Wikipedia categories named after musicians": "تصنيف:تصنيفات سميت بأسماء موسيقيين",
    "Category:Wikipedia categories named after musicians by nationality": "تصنيف:تصنيفات سميت بأسماء موسيقيين حسب الجنسية",
    "Category:Wikipedia categories named after national legislatures": "تصنيف:تصانيف بأسماء مشرعين قوميين",
    "Category:Wikipedia categories named after occultists": "تصنيف:تصنيفات سميت بأسماء غموضيين",
    "Category:Wikipedia categories named after politicians": "تصنيف:تصنيفات بأسماء سياسيين",
    "Category:Wikipedia categories named after sports-people": "تصنيف:تصنيفات سميت بأسماء رياضيين",
    "Category:Wikipedians interested in LGBT issues": "تصنيف:مستخدمون يدعمون حقوق المثليين",
    "Category:Wives of Abbasid caliphs": "تصنيف:زوجات الخلفاء العباسيين",
    "Category:Works about African-Americans": "تصنيف:أعمال عن أمريكيين أفارقة",
    "Category:Works about American military personnel": "تصنيف:أعمال عن أفراد عسكريين أمريكيين",
    "Category:Works about American politicians": "تصنيف:أعمال عن سياسيين أمريكيين",
    "Category:Works about Asian-Americans": "تصنيف:أعمال عن أمريكيون آسيويين",
    "Category:Works about British politicians": "تصنيف:أعمال عن سياسيين بريطانيين",
    "Category:Works about Chinese military personnel": "تصنيف:أعمال عن أفراد عسكريين صينيين",
    "Category:Works about Irish Travellers": "تصنيف:أعمال عن رحل أيرلنديين",
    "Category:Works about Native Americans": "تصنيف:أعمال عن السكان الأصليين فى الولايات المتحدة",
    "Category:Works about Nazis": "تصنيف:أعمال عن نازيين",
    "Category:Works about North Korean defectors": "تصنيف:أعمال عن كوريين شماليين منشقين",
    "Category:Works about cocaine": "تصنيف:أعمال عن كوكايين",
    "Category:Works about comedians": "تصنيف:أعمال عن كوميديين",
    "Category:Works about diplomats": "تصنيف:أعمال عن دبلوماسيين",
    "Category:Works about entertainers": "تصنيف:أعمال عن فنانين ترفيهيين",
    "Category:Works about fictional serial killers": "تصنيف:أعمال عن قتلة متسلسلين خياليين",
    "Category:Works about journalists": "تصنيف:أعمال عن صحفيين",
    "Category:Works about mass media people": "تصنيف:أعمال عن إعلاميين",
    "Category:Works about military leaders": "تصنيف:أعمال عن قادة عسكريين",
    "Category:Works about military personnel": "تصنيف:أعمال عن أفراد عسكريين",
    "Category:Works about music and musicians": "تصنيف:أعمال عن الموسيقى والموسيقيين",
    "Category:Works about playwrights": "تصنيف:أعمال عن كتاب مسرحيين",
    "Category:Works about politicians": "تصنيف:أعمال عن سياسيين",
    "Category:Works about religious leaders": "تصنيف:أعمال عن قادة دينيين",
    "Category:Works about revolutionaries": "تصنيف:أعمال عن الثوريين",
    "Category:Works about sports-people": "تصنيف:أعمال عن رياضيين",
    "Category:Works about war correspondents": "تصنيف:أعمال عن مراسلين حربيين",
    "Category:Works by Algerian people": "تصنيف:أعمال جزائريين",
    "Category:Works by American comedians": "تصنيف:أعمال كوميديين أمريكيين",
    "Category:Works by American filmmakers": "تصنيف:أعمال صانعي أفلام أمريكيين",
    "Category:Works by American people": "تصنيف:أعمال أمريكيين",
    "Category:Works by Andorran people": "تصنيف:أعمال أندوريين",
    "Category:Works by Angolan people": "تصنيف:أعمال أنغوليين",
    "Category:Works by Argentine people": "تصنيف:أعمال أرجنتينيين",
    "Category:Works by Armenian people": "تصنيف:أعمال أرمينيين",
    "Category:Works by Australian filmmakers": "تصنيف:أعمال صانعي أفلام أستراليين",
    "Category:Works by Australian people": "تصنيف:أعمال أستراليين",
    "Category:Works by Austrian filmmakers": "تصنيف:أعمال صانعي أفلام نمساويين",
    "Category:Works by Austrian people": "تصنيف:أعمال نمساويين",
    "Category:Works by Azerbaijani people": "تصنيف:أعمال أذربيجانيين",
    "Category:Works by Bahamian people": "تصنيف:أعمال بهاميين",
    "Category:Works by Bahraini people": "تصنيف:أعمال بحرينيين",
    "Category:Works by Bangladeshi people": "تصنيف:أعمال بنغلاديشيين",
    "Category:Works by Barbadian people": "تصنيف:أعمال بربادوسيين",
    "Category:Works by Belarusian people": "تصنيف:أعمال بيلاروسيين",
    "Category:Works by Belgian people": "تصنيف:أعمال بلجيكيين",
    "Category:Works by Belizean people": "تصنيف:أعمال بليزيين",
    "Category:Works by Beninese people": "تصنيف:أعمال بنينيين",
    "Category:Works by Bhutanese people": "تصنيف:أعمال بوتانيين",
    "Category:Works by Bissau-Guinean people": "تصنيف:أعمال غينيين بيساويين",
    "Category:Works by Bolivian people": "تصنيف:أعمال بوليفيين",
    "Category:Works by Bosnia and Herzegovina people": "تصنيف:أعمال بوسنيين",
    "Category:Works by Botswana people": "تصنيف:أعمال بوتسوانيين",
    "Category:Works by Brazilian people": "تصنيف:أعمال برازيليين",
    "Category:Works by British filmmakers": "تصنيف:أعمال صانعي أفلام بريطانيين",
    "Category:Works by British people": "تصنيف:أعمال بريطانيين",
    "Category:Works by Bulgarian people": "تصنيف:أعمال بلغاريين",
    "Category:Works by Burkinabe people": "تصنيف:أعمال بوركينابيين",
    "Category:Works by Burmese people": "تصنيف:أعمال بورميين",
    "Category:Works by Burundian people": "تصنيف:أعمال بورونديين",
    "Category:Works by Cambodian people": "تصنيف:أعمال كمبوديين",
    "Category:Works by Cameroonian people": "تصنيف:أعمال كاميرونيين",
    "Category:Works by Canadian people": "تصنيف:أعمال كنديين",
    "Category:Works by Cape Verdean people": "تصنيف:أعمال أخضريين",
    "Category:Works by Chadian people": "تصنيف:أعمال تشاديين",
    "Category:Works by Chilean people": "تصنيف:أعمال تشيليين",
    "Category:Works by Chinese filmmakers": "تصنيف:أعمال صانعي أفلام صينيين",
    "Category:Works by Chinese people": "تصنيف:أعمال صينيين",
    "Category:Works by Colombian people": "تصنيف:أعمال كولومبيين",
    "Category:Works by Comorian people": "تصنيف:أعمال قمريين",
    "Category:Works by Costa Rican people": "تصنيف:أعمال كوستاريكيين",
    "Category:Works by Croatian people": "تصنيف:أعمال كرواتيين",
    "Category:Works by Cuban people": "تصنيف:أعمال كوبيين",
    "Category:Works by Cypriot people": "تصنيف:أعمال قبرصيين",
    "Category:Works by Czech people": "تصنيف:أعمال تشيكيين",
    "Category:Works by Czechoslovak people": "تصنيف:أعمال تشيكوسلوفاكيين",
    "Category:Works by Danish filmmakers": "تصنيف:أعمال صانعي أفلام دنماركيين",
    "Category:Works by Danish people": "تصنيف:أعمال دنماركيين",
    "Category:Works by Dominican Republic people": "تصنيف:أعمال دومينيكانيين",
    "Category:Works by Dutch people": "تصنيف:أعمال هولنديين",
    "Category:Works by East German people": "تصنيف:أعمال ألمانيين شرقيين",
    "Category:Works by Ecuadorian people": "تصنيف:أعمال إكوادوريين",
    "Category:Works by Egyptian people": "تصنيف:أعمال مصريين",
    "Category:Works by Emirati people": "تصنيف:أعمال إماراتيين",
    "Category:Works by Equatoguinean people": "تصنيف:أعمال غينيين استوائيين",
    "Category:Works by Estonian people": "تصنيف:أعمال إستونيين",
    "Category:Works by Ethiopian people": "تصنيف:أعمال إثيوبيين",
    "Category:Works by Filipino people": "تصنيف:أعمال فلبينيين",
    "Category:Works by Finnish people": "تصنيف:أعمال فنلنديين",
    "Category:Works by French filmmakers": "تصنيف:أعمال صانعي أفلام فرنسيين",
    "Category:Works by French people": "تصنيف:أعمال فرنسيين",
    "Category:Works by Gabonese people": "تصنيف:أعمال غابونيين",
    "Category:Works by Ghanaian people": "تصنيف:أعمال غانيين",
    "Category:Works by Gibraltarian people": "تصنيف:أعمال جبل طارقيين",
    "Category:Works by Greek people": "تصنيف:أعمال يونانيين",
    "Category:Works by Guatemalan people": "تصنيف:أعمال غواتيماليين",
    "Category:Works by Guinean people": "تصنيف:أعمال غينيين",
    "Category:Works by Guyanese people": "تصنيف:أعمال غيانيين",
    "Category:Works by Haitian people": "تصنيف:أعمال هايتيين",
    "Category:Works by Honduran people": "تصنيف:أعمال هندوراسيين",
    "Category:Works by Hong Kong people": "تصنيف:أعمال هونغ كونغيين",
    "Category:Works by Hungarian people": "تصنيف:أعمال مجريين",
    "Category:Works by Icelandic people": "تصنيف:أعمال آيسلنديين",
    "Category:Works by Indonesian people": "تصنيف:أعمال إندونيسيين",
    "Category:Works by Iranian people": "تصنيف:أعمال إيرانيين",
    "Category:Works by Iraqi people": "تصنيف:أعمال عراقيين",
    "Category:Works by Irish people": "تصنيف:أعمال أيرلنديين",
    "Category:Works by Israeli people": "تصنيف:أعمال إسرائيليين",
    "Category:Works by Italian filmmakers": "تصنيف:أعمال صانعي أفلام إيطاليين",
    "Category:Works by Ivorian people": "تصنيف:أعمال إيفواريين",
    "Category:Works by Jamaican people": "تصنيف:أعمال جامايكيين",
    "Category:Works by Japanese filmmakers": "تصنيف:أعمال صانعي أفلام يابانيين",
    "Category:Works by Japanese people": "تصنيف:أعمال يابانيين",
    "Category:Works by Jordanian people": "تصنيف:أعمال أردنيين",
    "Category:Works by Kazakhstani people": "تصنيف:أعمال كازاخستانيين",
    "Category:Works by Kenyan people": "تصنيف:أعمال كينيين",
    "Category:Works by Korean people": "تصنيف:أعمال كوريين",
    "Category:Works by Kosovan people": "تصنيف:أعمال كوسوفيين",
    "Category:Works by Kuwaiti people": "تصنيف:أعمال كويتيين",
    "Category:Works by Laotian people": "تصنيف:أعمال لاوسيين",
    "Category:Works by Latvian people": "تصنيف:أعمال لاتفيين",
    "Category:Works by Lebanese people": "تصنيف:أعمال لبنانيين",
    "Category:Works by Lesotho people": "تصنيف:أعمال ليسوثويين",
    "Category:Works by Liberian people": "تصنيف:أعمال ليبيريين",
    "Category:Works by Libyan people": "تصنيف:أعمال ليبيين",
    "Category:Works by Lithuanian people": "تصنيف:أعمال ليتوانيين",
    "Category:Works by Luxembourgian people": "تصنيف:أعمال لوكسمبورغيين",
    "Category:Works by Macedonian people": "تصنيف:أعمال مقدونيين",
    "Category:Works by Malagasy people": "تصنيف:أعمال مدغشقريين",
    "Category:Works by Malawian people": "تصنيف:أعمال ملاويون",
    "Category:Works by Malaysian people": "تصنيف:أعمال ماليزيين",
    "Category:Works by Maldivian people": "تصنيف:أعمال مالديفيين",
    "Category:Works by Malian people": "تصنيف:أعمال ماليين",
    "Category:Works by Maltese people": "تصنيف:أعمال مالطيين",
    "Category:Works by Mauritanian people": "تصنيف:أعمال موريتانيين",
    "Category:Works by Mauritian people": "تصنيف:أعمال موريشيوسيين",
    "Category:Works by Mexican filmmakers": "تصنيف:أعمال صانعي أفلام مكسيكيين",
    "Category:Works by Mexican people": "تصنيف:أعمال مكسيكيين",
    "Category:Works by Moldovan people": "تصنيف:أعمال مولدوفيين",
    "Category:Works by Monegasque people": "تصنيف:أعمال موناكيين",
    "Category:Works by Mongolian people": "تصنيف:أعمال منغوليين",
    "Category:Works by Moroccan people": "تصنيف:أعمال مغربيين",
    "Category:Works by Mozambican people": "تصنيف:أعمال موزمبيقيين",
    "Category:Works by Namibian people": "تصنيف:أعمال ناميبيين",
    "Category:Works by Nepalese people": "تصنيف:أعمال نيباليين",
    "Category:Works by New Zealand people": "تصنيف:أعمال نيوزيلنديين",
    "Category:Works by Nicaraguan people": "تصنيف:أعمال نيكاراغويين",
    "Category:Works by Nigerian people": "تصنيف:أعمال نيجيريين",
    "Category:Works by North Korean people": "تصنيف:أعمال كوريين شماليين",
    "Category:Works by Norwegian filmmakers": "تصنيف:أعمال صانعي أفلام نرويجيين",
    "Category:Works by Norwegian people": "تصنيف:أعمال نرويجيين",
    "Category:Works by Pakistani people": "تصنيف:أعمال باكستانيين",
    "Category:Works by Palestinian people": "تصنيف:أعمال فلسطينيين",
    "Category:Works by Panamanian people": "تصنيف:أعمال بنميين",
    "Category:Works by Paraguayan people": "تصنيف:أعمال باراغوايانيين",
    "Category:Works by Peruvian people": "تصنيف:أعمال بيرويين",
    "Category:Works by Polish filmmakers": "تصنيف:أعمال صانعي أفلام بولنديين",
    "Category:Works by Polish people": "تصنيف:أعمال بولنديين",
    "Category:Works by Portuguese filmmakers": "تصنيف:أعمال صانعي أفلام برتغاليين",
    "Category:Works by Portuguese people": "تصنيف:أعمال برتغاليين",
    "Category:Works by Puerto Rican people": "تصنيف:أعمال بورتوريكيين",
    "Category:Works by Qatari people": "تصنيف:أعمال قطريين",
    "Category:Works by republic of congo people": "تصنيف:أعمال كونغويين",
    "Category:Works by Romanian filmmakers": "تصنيف:أعمال صانعي أفلام رومانيين",
    "Category:Works by Romanian people": "تصنيف:أعمال رومانيين",
    "Category:Works by Russian people": "تصنيف:أعمال روسيين",
    "Category:Works by Rwandan people": "تصنيف:أعمال روانديين",
    "Category:Works by Salvadoran people": "تصنيف:أعمال سلفادوريين",
    "Category:Works by Saudi Arabian people": "تصنيف:أعمال سعوديين",
    "Category:Works by Scottish filmmakers": "تصنيف:أعمال صانعي أفلام إسكتلنديين",
    "Category:Works by Scottish people": "تصنيف:أعمال إسكتلنديين",
    "Category:Works by Senegalese people": "تصنيف:أعمال سنغاليين",
    "Category:Works by Seychellois people": "تصنيف:أعمال سيشليين",
    "Category:Works by Singaporean people": "تصنيف:أعمال سنغافوريين",
    "Category:Works by Slovak filmmakers": "تصنيف:أعمال صانعي أفلام سلوفاكيين",
    "Category:Works by Slovak people": "تصنيف:أعمال سلوفاكيين",
    "Category:Works by Slovenian people": "تصنيف:أعمال سلوفينيين",
    "Category:Works by Somalian people": "تصنيف:أعمال صوماليين",
    "Category:Works by South Korean filmmakers": "تصنيف:أعمال صانعي أفلام كوريين جنوبيين",
    "Category:Works by South Korean people": "تصنيف:أعمال كوريين جنوبيين",
    "Category:Works by South Sudanese people": "تصنيف:أعمال جنوبيين سودانيين",
    "Category:Works by Sri Lankan people": "تصنيف:أعمال سريلانكيين",
    "Category:Works by Sudanese people": "تصنيف:أعمال سودانيين",
    "Category:Works by Surinamese people": "تصنيف:أعمال سوريناميين",
    "Category:Works by Swazi people": "تصنيف:أعمال سوازيلنديين",
    "Category:Works by Swedish filmmakers": "تصنيف:أعمال صانعي أفلام سويديين",
    "Category:Works by Swedish people": "تصنيف:أعمال سويديين",
    "Category:Works by Swiss people": "تصنيف:أعمال سويسريين",
    "Category:Works by Syrian people": "تصنيف:أعمال سوريين",
    "Category:Works by Taiwanese people": "تصنيف:أعمال تايوانيين",
    "Category:Works by Tanzanian people": "تصنيف:أعمال تنزانيين",
    "Category:Works by Thai people": "تصنيف:أعمال تايلنديين",
    "Category:Works by Togolese people": "تصنيف:أعمال توغويين",
    "Category:Works by Trinidad and Tobago people": "تصنيف:أعمال ترنيداديين",
    "Category:Works by Tunisian people": "تصنيف:أعمال تونسيين",
    "Category:Works by Ugandan people": "تصنيف:أعمال أوغنديين",
    "Category:Works by Ukrainian people": "تصنيف:أعمال أوكرانيين",
    "Category:Works by Uruguayan people": "تصنيف:أعمال أوروغويانيين",
    "Category:Works by Uzbekistani people": "تصنيف:أعمال أوزبكستانيين",
    "Category:Works by Venezuelan people": "تصنيف:أعمال فنزويليين",
    "Category:Works by Vietnamese people": "تصنيف:أعمال فيتناميين",
    "Category:Works by Welsh people": "تصنيف:أعمال ويلزيين",
    "Category:Works by Yemeni people": "تصنيف:أعمال يمنيين",
    "Category:Works by Yugoslav people": "تصنيف:أعمال يوغسلافيين",
    "Category:Works by Zambian people": "تصنيف:أعمال زامبيين",
    "Category:Works by Zimbabwean people": "تصنيف:أعمال زيمبابويين",
    "Category:Works by ancient Roman people": "تصنيف:أعمال رومانيين قدماء",
    "Category:Works by musician": "تصنيف:أعمال حسب الموسيقيين",
    "Category:World Athletics Championships athletes for Sudan": "تصنيف:بطولة العالم لألعاب القوى للرياضيين من السودان",
    "Category:World music albums by Egyptian artists": "تصنيف:ألبومات موسيقى العالم لفنانين مصريين",
    "Category:World music albums by Indonesian artists": "تصنيف:ألبومات موسيقى العالم لفنانين إندونيسيين",
    "Category:World music albums by Lebanese artists": "تصنيف:ألبومات موسيقى العالم لفنانين لبنانيين",
    "Category:YMCA": "تصنيف:جمعية الشبان المسيحيين",
    "Category:Yazidi communities": "تصنيف:المناطق المأهولة باليزيديين",
    "Category:Yemeni refugees": "تصنيف:اللاجئين اليمنيين",
    "Category:Yemenite Association politicians": "تصنيف:حزب السياسيين اليمنيين",
    "Category:Zambia men's A' international footballers": "تصنيف:لاعبو منتخب زامبيا لكرة القدم للرجال للمحليين",
    "Category:Zimbabwe men's A' international footballers": "تصنيف:لاعبو منتخب زيمبابوي لكرة القدم للرجال للمحليين",
}

data2 = {
    "Category:Adaptations of works by American writers": "تصنيف:أعمال مقتبسة عن أعمال كتاب أمريكيين",
    "Category:Adaptations of works by Argentine writers": "تصنيف:تكييفات أعمال كتاب أرجنتينيين",
    "Category:Adaptations of works by Austrian writers": "تصنيف:تكييفات أعمال كتاب نمساويين",
    "Category:Adaptations of works by Canadian writers": "تصنيف:تكييفات أعمال كتاب كنديين",
    "Category:Adaptations of works by Chinese writers": "تصنيف:تكييفات أعمال كتاب صينيين",
    "Category:Adaptations of works by Czech writers": "تصنيف:تكييفات أعمال كتاب تشيكيين",
    "Category:Adaptations of works by Danish writers": "تصنيف:أعمال مقتبسة عن أعمال كتاب دنماركيين",
    "Category:Adaptations of works by French writers": "تصنيف:أعمال مقتبسة عن أعمال كتاب فرنسيين",
    "Category:Adaptations of works by Greek writers": "تصنيف:أعمال مقتبسة عن أعمال كتاب يونانيين",
    "Category:Adaptations of works by Irish writers": "تصنيف:أعمال مقتبسة عن أعمال كتاب أيرلنديين",
    "Category:Adaptations of works by Italian writers": "تصنيف:أعمال مقتبسة عن أعمال كتاب إيطاليين",
    "Category:Adaptations of works by Japanese writers": "تصنيف:أعمال مقتبسة عن أعمال كتاب يابانيين",
    "Category:Adaptations of works by Korean writers": "تصنيف:تكييفات أعمال كتاب كوريين",
    "Category:Adaptations of works by New Zealand writers": "تصنيف:تكييفات أعمال كتاب نيوزيلنديين",
    "Category:Adaptations of works by Norwegian writers": "تصنيف:أعمال مقتبسة عن أعمال كتاب نرويجيين",
    "Category:Adaptations of works by Polish writers": "تصنيف:تكييفات أعمال كتاب بولنديين",
    "Category:Adaptations of works by Scottish writers": "تصنيف:اقتباسات لأعمال كتاب إسكتلنديين",
    "Category:Adaptations of works by South Korean writers": "تصنيف:تكييفات أعمال كتاب كوريين جنوبيين",
    "Category:Adaptations of works by Swedish writers": "تصنيف:تكييفات أعمال كتاب سويديين",
    "Category:Adaptations of works by Venezuelan writers": "تصنيف:تكييفات أعمال كتاب فنزويليين",
    "Category:Adaptations of works by ancient Greek writers": "تصنيف:أعمال مقتبسة عن أعمال كتاب يونانيين قدماء",
    "Category:American anti-globalization writers": "تصنيف:كتاب أمريكيين مناهضين للعولمة",
    "Category:American writers' organizations": "تصنيف:منظمات الكتاب الأمريكيين",
    "Category:Asian writers by nationality": "تصنيف:كتاب آسيويين حسب الجنسية",
    "Category:Asian writers in French": "تصنيف:كتاب آسيويين في الفرنسية",
    "Category:Bibliographies of British writers": "تصنيف:قوائم مؤلفات كتاب بريطانيين",
    "Category:Bibliographies of Czech writers": "تصنيف:قوائم مؤلفات كتاب تشيكيين",
    "Category:Bibliographies of Irish writers": "تصنيف:قوائم مؤلفات كتاب أيرلنديين",
    "Category:Bibliographies of Swiss writers": "تصنيف:قوائم مؤلفات كتاب سويسريين",
    "Category:Federal Writers' Project": "تصنيف:مشروع الكتاب الفيدراليين",
    "Category:Films based on works by American writers": "تصنيف:أفلام مبنية على أعمال كتاب أمريكيين",
    "Category:Films based on works by British writers": "تصنيف:أفلام مقتبسة من أعمال كتاب بريطانيين",
    "Category:Films based on works by Canadian writers": "تصنيف:أفلام مبنية على أعمال كتاب كنديين",
    "Category:Films based on works by Czech writers": "تصنيف:أفلام مبنية على أعمال كتاب تشيكيين",
    "Category:Films based on works by Dutch writers": "تصنيف:أفلام مبنية على أعمال كتاب هولنديين",
    "Category:Films based on works by Japanese writers": "تصنيف:أفلام مبنية على أعمال كتاب يابانيين",
    "Category:Films based on works by Korean writers": "تصنيف:أفلام مبنية على أعمال كتاب كوريين",
    "Category:Films based on works by Polish writers": "تصنيف:أفلام مبنية على أعمال كتاب بولنديين",
    "Category:Films based on works by Scottish writers": "تصنيف:أعمال مستندة إلى أعمال كتاب إسكتلنديين",
    "Category:Films based on works by South Korean writers": "تصنيف:أفلام مبنية على أعمال كتاب كوريين جنوبيين",
    "Category:Films based on works by Venezuelan writers": "تصنيف:أفلام مبنية على أعمال كتاب فنزويليين",
    "Category:Lists of British writers": "تصنيف:قوائم كتاب بريطانيين",
    "Category:Video games based on works by Canadian writers": "تصنيف:ألعاب فيديو مبنية على أعمال كتاب كنديين",
    "Category:Video games based on works by New Zealand writers": "تصنيف:ألعاب فيديو مبنية على أعمال كتاب نيوزيلنديين",
    "Category:Wikipedia categories named after American writers": "تصنيف:تصنيفات بأسماء كتاب أمريكيين",
    "Category:Wikipedia categories named after Argentine writers": "تصنيف:تصنيفات سميت بأسماء كتاب أرجنتينيين",
    "Category:Wikipedia categories named after Australian writers": "تصنيف:تصنيفات سميت بأسماء كتاب أستراليين",
    "Category:Wikipedia categories named after Austrian writers": "تصنيف:تصنيفات سميت بأسماء كتاب نمساويين",
    "Category:Wikipedia categories named after Belgian writers": "تصنيف:تصنيفات سميت بأسماء كتاب بلجيكيين",
    "Category:Wikipedia categories named after British writers": "تصنيف:تصنيفات بأسماء كتاب بريطانيين",
    "Category:Wikipedia categories named after Canadian writers": "تصنيف:تصنيفات سميت بأسماء كتاب كنديين",
    "Category:Wikipedia categories named after Chinese writers": "تصنيف:تصنيفات سميت بأسماء كتاب صينيين",
    "Category:Wikipedia categories named after French writers": "تصنيف:تصنيفات بأسماء كتاب فرنسيين",
    "Category:Wikipedia categories named after Irish writers": "تصنيف:تصنيفات سميت بأسماء كتاب أيرلنديين",
    "Category:Wikipedia categories named after Italian writers": "تصنيف:تصنيفات سميت بأسماء كتاب إيطاليين",
    "Category:Wikipedia categories named after Japanese writers": "تصنيف:تصنيفات سميت بأسماء كتاب يابانيين",
    "Category:Wikipedia categories named after Swedish writers": "تصنيف:تصنيفات سميت بأسماء كتاب سويديين",
    "Category:Wikipedia categories named after Swiss writers": "تصنيف:تصنيفات سميت بأسماء كتاب سويسريين",
    "Category:Works by American writers": "تصنيف:أعمال كتاب أمريكيين",
    "Category:Works by Argentine writers": "تصنيف:أعمال كتاب أرجنتينيين",
    "Category:Works by Australian writers": "تصنيف:أعمال كتاب أستراليين",
    "Category:Works by Austrian writers": "تصنيف:أعمال كتاب نمساويين",
    "Category:Works by Belgian writers": "تصنيف:أعمال كتاب بلجيكيين",
    "Category:Works by British writers": "تصنيف:أعمال كتاب بريطانيين",
    "Category:Works by Canadian writers": "تصنيف:أعمال كتاب كنديين",
    "Category:Works by Chinese writers": "تصنيف:أعمال كتاب صينيين",
    "Category:Works by Colombian writers": "تصنيف:أعمال كتاب كولومبيين",
    "Category:Works by Czech writers": "تصنيف:أعمال كتاب تشيكيين",
    "Category:Works by Danish writers": "تصنيف:أعمال كتاب دنماركيين",
    "Category:Works by Dutch writers": "تصنيف:أعمال كتاب هولنديين",
    "Category:Works by Egyptian writers": "تصنيف:أعمال كتاب مصريين",
    "Category:Works by French writers": "تصنيف:أعمال كتاب فرنسيين",
    "Category:Works by Greek writers": "تصنيف:أعمال كتاب يونانيين",
    "Category:Works by Hungarian writers": "تصنيف:أعمال كتاب مجريين",
    "Category:Works by Iranian writers": "تصنيف:أعمال كتاب إيرانيين",
    "Category:Works by Irish writers": "تصنيف:أعمال كتاب أيرلنديين",
    "Category:Works by Italian writers": "تصنيف:أعمال كتاب إيطاليين",
    "Category:Works by Japanese writers": "تصنيف:أعمال كتاب يابانيين",
    "Category:Works by Libyan writers": "تصنيف:أعمال كتاب ليبيين",
    "Category:Works by Malaysian writers": "تصنيف:أعمال كتاب ماليزيين",
    "Category:Works by Mexican writers": "تصنيف:أعمال كتاب مكسيكيين",
    "Category:Works by North Korean writers": "تصنيف:أعمال كتاب كوريين شماليين",
    "Category:Works by Norwegian writers": "تصنيف:أعمال كتاب نرويجيين",
    "Category:Works by Polish writers": "تصنيف:أعمال كتاب بولنديين",
    "Category:Works by Saudi Arabian writers": "تصنيف:أعمال كتاب سعوديين",
    "Category:Works by Scottish writers": "تصنيف:أعمال كتاب إسكتلنديين",
    "Category:Works by South Korean writers": "تصنيف:أعمال كتاب كوريين جنوبيين",
    "Category:Works by Swedish writers": "تصنيف:أعمال كتاب سويديين",
    "Category:Works by Swiss writers": "تصنيف:أعمال كتاب سويسريين",
    "Category:Works by Ukrainian writers": "تصنيف:أعمال كتاب أوكرانيين",
    "Category:Works by Yemeni writers": "تصنيف:أعمال كتاب يمنيين",
    "Category:Works by ancient Greek writers": "تصنيف:أعمال كتاب يونانيين قدماء",
    "Category:Works by ancient Latin writers": "تصنيف:أعمال كتاب لاتينيين قدماء",
    "Category:Works by writers from the Ottoman Empire": "تصنيف:أعمال عثمانيين",
}
to_test = [
    ("text_to_fix_1", data1),
    ("text_to_fix_2", data2),
]


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.skip2
@pytest.mark.dump
def test_all_dump(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    diff_result2 = {x: v for x, v in diff_result.items() if v}
    # dump_diff(diff_result2, name)

    expected2 = {x: v for x, v in expected.items() if v and x in diff_result2}
    # dump_diff(expected2, f"{name}_expected")

    save3 = [f"* [[:{v}]]>[[:{diff_result2[x]}]]" for x, v in expected.items() if v and x in diff_result2]
    dump_diff(save3, f"{name}_d", _sort=False)

    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"
